/*
 *= CMU (UNIVERSAL RADIO COMMUNICATION TESTER VISA) =========================
 * LabWindows/CVI 5.0 Instrument Driver for BTS options K30/K31/K32/K33/K41
 * Original Release : 17.05.2000
 *
 * By : ROHDE & SCHWARZ FRANCE
 *      CONTACTS :
 *              Christophe Petit
 *              Telephone : 00 33 1 41 36 10 18
 *              Fax       : 00 33 1 41 36 11 10
 *              e-Mail    : Christophe.Petit@rsf.rohde-schwarz.com
 *
 *              Franois Ribiere
 *              Telephone : 00 33 1 41 36 10 83
 *              Fax       : 00 33 1 41 36 11 10
 *              e-Mail    : Francois.Ribiere@rsf.rohde-schwarz.com
 *
 *              Rohde & Schwarz France
 *              Parc Tertiaire de Meudon
 *              9-11, rue Jeanne Braconnier
 *              92366 Meudon-la-Foret Cedex
 *
 * Version : V4.40.1
 *
 * HISTORY   :
 *  see ChangeLog
 * ===========================================================================*/

#include <ctype.h>

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>
#include <locale.h>

#include <visa.h>
//Don't change the order of the next includes!!!
//#include "rscmu200.h"
#include "rscmu300.h"
#include "rscmuk3g.h"

/*===========================================================================*/
/*= DEFINES =================================================================*/
/*===========================================================================*/
/*---------------------------------------------------------------------------*/
/* Instrument driver revision:
/*---------------------------------------------------------------------------*/
#define RSCMUK3G_VERSION        "4.40.1"   // Instrument driver version string
#define RSCMUK3G_BETA           ""          // "BETA" or empty
#define RSCMUK3G_CREATIONDATE   "03/2009"   // Instrument driver creation month/year
#define RSCMUK3G_CVIVERSION     "8.5"       // Used Labwindows/CVI-version

#define RSCMUK3G_REVISION "Rev " RSCMUK3G_VERSION RSCMUK3G_BETA", "RSCMUK3G_CREATIONDATE", CVI "RSCMUK3G_CVIVERSION // Instrument driver revision

/*===========================================================================*/
/*= INSTRUMENT-DEPENDENT COMMAND ARRAYS =====================================*/
/*===========================================================================*/
static ViString mode_On_Off[] = {"OFF","ON",VI_NULL};
static ViString repetition_meas[] = {"CONT","SING",VI_NULL};
static ViString mode_ScopeMeas [] = {"SCAL","ARR",VI_NULL};
static ViString mode_StopCondition[] = {"NONE","SOER",VI_NULL};
static ViString mode_StopCondition_SON[] = {"NONE","SON",VI_NULL};
static ViString Channel_Type[] = {"TCH","CCH",VI_NULL};
static ViString mode_BERapplication[] = {"BAV","BER",VI_NULL};
static ViString StrStepMode[] = {"NONE","STEP",VI_NULL};
static ViString modulation_type[] = {"GMSK","EPSK",VI_NULL};
static ViString StrCommand[] = {"CONF","INIT","ABOR","STOP","CONT","READ","FETC","SAMP","CALC",VI_NULL};
static ViString StrFilter[] = {"G500","B600",VI_NULL};
static ViString StrSubArr[] = {"ALL","ARIT","MIN","MAX","IVAL"};
static ViString StrStatMode[] = {"CURR","AVER","MAX","MIN",VI_NULL};
static ViString StrErep[] = {"OFF","SRQ","SOPC","SRSQ",VI_NULL};
static ViString measurementStatusArr[] = {"OFF","RUN","STOP","ERR","STEP","RDY",VI_NULL};


/*===========================================================================*/
/* RSCMU300_GSM_SIG/NSIG_Globals is initialized for each Session in an 'init'
/* function and defines the Driver's datas
/*===========================================================================*/

// Structure "RSCMU300_GSM_Sig_Globals" is initialized for each Session in an 'init' function
struct  RSCMU300_GSM_Sig_Globals
{
  struct RSCMU300_SESSION_Globals RSCMU300_tGlobal;
  struct RSCMU300_HandOver  RSCMU300_tHandOver;

};

// Structure "RSCMU300_GSM_NSig_Globals" is initialized for each Session in an 'init' function
struct  RSCMU300_GSM_NSig_Globals
{
  struct RSCMU300_SESSION_Globals RSCMU300_tGlobal;
};

/*===========================================================================*/
/* LOCAL FUNCTIONS DECLARATION
/*===========================================================================*/
/*---------------------------------------------------------------------------*/
/* These functions are used to extract the results in the different functions
/* of power and modulation. Some results depend on the statistic mode (Current,
/* Average or MMax value).
/*---------------------------------------------------------------------------*/

ViStatus _VI_FUNC RSCMU300_ScanPow      (ViChar[100][100], ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPReal64);
ViStatus _VI_FUNC RSCMU300_ScanPerrGmsk (ViChar[100][100], ViInt32, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64);
ViStatus _VI_FUNC RSCMU300_ScanOverEpsk (ViChar[100][100], ViInt32, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64);
ViStatus _VI_FUNC RSCMU300_ScanOverEpskV306 (ViChar[100][100], ViInt32, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64);
ViStatus _VI_FUNC RSCMU300_ScanEvmEpsk  (ViChar[100][100], ViInt32, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64);
ViStatus _VI_FUNC RSCMU300_ScanEvmEpskV306  (ViChar[100][100], ViInt32, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64);
ViStatus _VI_FUNC RSCMU300_ScanPerrEpsk (ViChar[100][100], ViInt32, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64);
ViStatus _VI_FUNC RSCMU300_ScanPerrEpskV306 (ViChar[100][100], ViInt32, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64);
ViStatus _VI_FUNC RSCMU300_ScanMerrEpsk (ViChar[100][100], ViInt32, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64);
ViStatus _VI_FUNC RSCMU300_ScanMerrEpskV306 (ViChar[100][100], ViInt32, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64);

ViStatus _VI_FUNC RSCMU300_MeasNpow (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU300_MeasScalPowerMSlot (ViSession,ViInt32,ViInt32,ViInt32,ViReal64 *,ViReal64 *,ViReal64 *,ViReal64 *,ViReal64 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_MeasArrayPowerMslot (ViSession,ViInt32,ViInt32,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_MeasSubarrPowerMslot (ViSession,ViInt32,ViInt32,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_MeasScalRACH (ViSession,ViInt32,ViReal64 *,ViReal64 *,ViReal64 *,ViChar[]);

ViStatus RSCMU300_MeasSpecModSwitch (ViSession, ViChar *, ViReal64 *, ViInt32 *, ViReal64 *, ViInt32 *, ViChar[]);
ViStatus RSCMU300_MeasArray (ViSession,ViChar *,ViReal64[], ViChar[]);
ViStatus RSCMU300_FetcSpecMSwStatus (ViSession, ViChar *, ViInt32 *, ViInt32 *, ViInt32 *, ViInt32 *, ViChar[]);
ViStatus RSCMU300_MeasSpecVarMeaPoint (ViSession, ViChar *,ViInt32,ViInt32, ViReal64,ViChar[]);
ViStatus RSCMU300_ConfEventReporting (ViSession, ViChar *, ViInt32, ViChar[]);
ViStatus RSCMU300_ConfSubArr (ViSession, ViChar *, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus RSCMU300_MeasArrayInt (ViSession,ViChar *,ViInt32[],ViChar[]);
ViStatus RSCMU300_MeasSclarDemodBit (ViSession,ViChar *,ViInt32 *,ViChar[]);
ViStatus RSCMU300_MeasPeakDemodBit (ViSession ,ViChar *,ViInt32 *,ViInt32 *,ViChar[]);
ViStatus RSCMU300_MeasIqanScalarNSig (ViSession,ViChar *,ViReal64  *,ViReal64  *,ViReal64  *,ViReal64  *,ViChar[]);
ViStatus RSCMU300_MeasIqanScalarSig (ViSession,ViChar *,ViReal64  *,ViReal64  *,ViReal64  *,ViReal64  *,ViReal64  *,ViChar[]);

/*---------------------------------------------------------------------------*/
/* These functions are called by the test objects POWer, SPECtrum:MODulation
/* and SPECtrum:SWITching in Non Signalling mode, and are common to the GMSK
/* and 8PSK modulation.
/* There are no local functions for Signalling mode because of the parameter
/* "ViInt32 Channel" which is not common in the two modulations (only TCH for
/* EPSK).
/* The functions are based on the calling functions and their first parameter,
/* "ViInt32 modulation", is used to differenciate GMSK and 8PSK (by using the
/* local constants RSCMU300_GMSK and RSCMU300_EPSK in this parameter).
/*---------------------------------------------------------------------------*/
//               Test Object Power
//                  Configuration
//                     Control
ViStatus _VI_FUNC NSig_ConfPowContDef (ViInt32, ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC NSig_ConfPowScope (ViInt32, ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC NSig_ConfPowContRep (ViInt32, ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Limit Lines
ViStatus _VI_FUNC NSig_ConfPowLimDef (ViInt32, ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC NSig_ConfPowLimLowMode (ViInt32, ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC NSig_ConfPowLimUppMode (ViInt32, ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC NSig_ConfPowLimLow (ViInt32, ViSession, ViInt32, ViBoolean, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViChar[]);
ViStatus _VI_FUNC NSig_ConfPowLimUpp (ViInt32, ViSession, ViInt32, ViBoolean, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViChar[]);
//                     Time
ViStatus _VI_FUNC NSig_ConfPowTimeBit (ViInt32, ViSession, ViReal64, ViChar[]);
//                     Statistics
ViStatus _VI_FUNC NSig_ConfPowCont (ViInt32, ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC NSig_ConfPowStat (ViInt32, ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC NSig_ConfPowResMode (ViInt32, ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC NSig_ConfPowContRepSt (ViInt32, ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Measurement
ViStatus _VI_FUNC NSig_ConfSubPowRang (ViInt32, ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);
//                  Control
ViStatus _VI_FUNC NSig_InitPow (ViInt32, ViSession, ViChar[]);
ViStatus _VI_FUNC NSig_AborPow (ViInt32, ViSession, ViChar[]);
ViStatus _VI_FUNC NSig_StopPow (ViInt32, ViSession, ViChar[]);
ViStatus _VI_FUNC NSig_ContPow (ViInt32, ViSession, ViChar[]);
//                     Measurement Status
ViStatus _VI_FUNC NSig_FetcPowSt (ViInt32, ViSession, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Event Reporting System
ViStatus _VI_FUNC NSig_ConfPowErep (ViInt32, ViSession, ViInt32, ViChar[]);
//                  Results
//                     Scalar
ViStatus _VI_FUNC NSig_ReadPow (ViInt32, ViSession, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPReal64, ViChar[]);
ViStatus _VI_FUNC NSig_FetcPow (ViInt32, ViSession, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPReal64, ViChar[]);
ViStatus _VI_FUNC NSig_SampPow (ViInt32, ViSession, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPReal64, ViChar[]);
ViStatus _VI_FUNC NSig_CalcPowMatcLim (ViInt32, ViSession, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Array
ViStatus _VI_FUNC NSig_ReadArrPow (ViInt32, ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC NSig_FetcArrPow (ViInt32, ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC NSig_SampArrPow (ViInt32, ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC NSig_CalcArrPowMatcLim (ViInt32, ViSession, ViInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC NSig_CalcArrPowAreaMatc (ViInt32, ViSession, ViInt32, ViPUInt32, ViPUInt32, ViChar[]);
//                     SubArray
ViStatus _VI_FUNC NSig_ReadSubPow (ViInt32, ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC NSig_FetcSubPow (ViInt32, ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC NSig_SampSubPow (ViInt32, ViSession, ViInt32, ViReal64[], ViChar[]);

//               Test Object Spectrum Modulation
//                  Configuration
//                     Control
ViStatus _VI_FUNC NSig_ConfSpModContDef (ViInt32, ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC NSig_ConfSpModScope (ViInt32, ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC NSig_ConfSpModContRep (ViInt32, ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Limit Lines
ViStatus _VI_FUNC NSig_ConfSpModLimDef (ViInt32, ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC NSig_ConfSpModLimRefp (ViInt32, ViSession, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC NSig_ConfSpModLimMode (ViInt32, ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC NSig_ConfSpModLim (ViInt32, ViSession, ViInt32, ViBoolean, ViReal64, ViReal64, ViReal64, ViChar[]);
//                     Statistics
ViStatus _VI_FUNC NSig_ConfSpModCont (ViInt32, ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC NSig_ConfSpModStat (ViInt32, ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC NSig_ConfSpModResMode (ViInt32, ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC NSig_ConfSpModContRepSt (ViInt32, ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     MeasX
ViStatus _VI_FUNC NSig_ConfSpModContMpo (ViInt32, ViSession, ViInt32, ViBoolean, ViChar[]);
//                     Measurement
ViStatus _VI_FUNC NSig_ConfSubSpModRang (ViInt32, ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);
//                  Control
ViStatus _VI_FUNC NSig_InitSpMod (ViInt32, ViSession, ViChar[]);
ViStatus _VI_FUNC NSig_AborSpMod (ViInt32, ViSession, ViChar[]);
ViStatus _VI_FUNC NSig_StopSpMod (ViInt32, ViSession, ViChar[]);
ViStatus _VI_FUNC NSig_ContSpMod (ViInt32, ViSession, ViChar[]);
//                     Measurement Status
ViStatus _VI_FUNC NSig_FetcSpModSt (ViInt32, ViSession, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Event Reporting System
ViStatus _VI_FUNC NSig_ConfSpModErep (ViInt32, ViSession, ViInt32, ViChar[]);
//                  Results
//                     Scalar
ViStatus _VI_FUNC NSig_ReadSpMod (ViInt32, ViSession, ViPReal64, ViPInt32, ViChar[]);
ViStatus _VI_FUNC NSig_FetcSpMod (ViInt32, ViSession, ViPReal64, ViPInt32, ViChar[]);
ViStatus _VI_FUNC NSig_SampSpMod (ViInt32, ViSession, ViPReal64, ViPInt32, ViChar[]);
//                     Array
ViStatus _VI_FUNC NSig_ReadArrSpMod (ViInt32, ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC NSig_FetcArrSpMod (ViInt32, ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC NSig_SampArrSpMod (ViInt32, ViSession, ViReal64[], ViChar[]);
//                     SubArray
ViStatus _VI_FUNC NSig_ReadSubSpMod (ViInt32, ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC NSig_FetcSubSpMod (ViInt32, ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC NSig_SampSubSpMod (ViInt32, ViSession, ViReal64[], ViChar[]);

//               Test Object Spectrum Switching
//                  Configuration
//                     Control
ViStatus _VI_FUNC NSig_ConfSpSwContDef (ViInt32, ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC NSig_ConfSpSwScope (ViInt32, ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC NSig_ConfSpSwContRep (ViInt32, ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Limit Lines
ViStatus _VI_FUNC NSig_ConfSpSwLimDef (ViInt32, ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC NSig_ConfSpSwLimMode (ViInt32, ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC NSig_ConfSpSwLim (ViInt32, ViSession, ViInt32, ViBoolean, ViReal64, ViReal64, ViReal64, ViChar[]);
//                     Statistics
ViStatus _VI_FUNC NSig_ConfSpSwCont (ViInt32, ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC NSig_ConfSpSwStat (ViInt32, ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC NSig_ConfSpSwResMode (ViInt32, ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC NSig_ConfSpSwContRepSt (ViInt32, ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     MeasX
ViStatus _VI_FUNC NSig_ConfSpSwContMpo (ViInt32, ViSession, ViInt32, ViBoolean, ViChar[]);
//                     Measurement
ViStatus _VI_FUNC NSig_ConfSubSpSwRang (ViInt32, ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);
//                  Control
ViStatus _VI_FUNC NSig_InitSpSw (ViInt32, ViSession, ViChar[]);
ViStatus _VI_FUNC NSig_AborSpSw (ViInt32, ViSession, ViChar[]);
ViStatus _VI_FUNC NSig_StopSpSw (ViInt32, ViSession, ViChar[]);
ViStatus _VI_FUNC NSig_ContSpSw (ViInt32, ViSession, ViChar[]);
//                     Measurement Status
ViStatus _VI_FUNC NSig_FetcSpSwSt (ViInt32, ViSession, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Event Reporting System
ViStatus _VI_FUNC NSig_ConfSpSwErep (ViInt32, ViSession, ViInt32, ViChar[]);
//                  Results
//                     Scalar
ViStatus _VI_FUNC NSig_ReadSpSw (ViInt32, ViSession, ViPReal64, ViPInt32, ViChar[]);
ViStatus _VI_FUNC NSig_FetcSpSw (ViInt32, ViSession, ViPReal64, ViPInt32, ViChar[]);
ViStatus _VI_FUNC NSig_SampSpSw (ViInt32, ViSession, ViPReal64, ViPInt32, ViChar[]);
//                     Array
ViStatus _VI_FUNC NSig_ReadArrSpSw (ViInt32, ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC NSig_FetcArrSpSw (ViInt32, ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC NSig_SampArrSpSw (ViInt32, ViSession, ViReal64[], ViChar[]);
//                     SubArray
ViStatus _VI_FUNC NSig_ReadSubSpSw (ViInt32, ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC NSig_FetcSubSpSw (ViInt32, ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC NSig_SampSubSpSw (ViInt32, ViSession, ViReal64[], ViChar[]);

/*---------------------------------------------------------------------------*/
/* Other functions
/*---------------------------------------------------------------------------*/

ViStatus _VI_FUNC RSCMU300_GetAlarmResult (ViInt32 *, ViChar[100][100], ViInt32);





/*****************************************************************************/
/*****************************************************************************/
/*========== Class: Common Functions ========================================*/
/*****************************************************************************/
/*****************************************************************************/
/*
 * ----------------------------------------------------------------------------
 * GSM MEASUREMENTS WITHOUT SIGNALLING (NON SIGNALLING):
 * ----------------------------------------------------------------------------
 * In the Non Signalling mode, a GSM-specific RF signal can be
 * generated and an RF signal with GSM characteristics analyzed.
 * No signalling parameters are transferred and measured.
 * ----------------------------------------------------------------------------
 */
/* ----------------------------------------------------------------------------
 * Initialize
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Initialize
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Init_GSM_NSig (ViSession   BaseSession,
                                                                 ViPSession  GSMBSNSigSession,
                                                                 ViUInt32    GSMBSFunctionGpr,
                                                                 ViChar      _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViSession   globalSession = 0;
  ViSession   GSMSession = 0;
  ViInt32     secondAddr = 0, comp = 1;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      FctGrpBuffer[128]= "", resource[25]="";
  ViBoolean   Flag = RSCMU300_OFF;

  struct RSCMU300_Base_Globals     *p_globalvarBase;
  struct RSCMU300_GSM_NSig_Globals *p_globalvarGSM;

  /* --- Set standard "C" locale --- */
  {
    char *locale;

    locale = setlocale(LC_ALL, "C");
  }

  // Which Function Group does the User want?
  switch (GSMBSFunctionGpr)
  {
    case RSCMU300_GSM400BS_NSIG:
      strcpy (FctGrpBuffer, "\"GSM400BS_NSig\"");
      break;
    case RSCMU300_GSM850BS_NSIG:
      strcpy (FctGrpBuffer, "\"GSM850BS_NSig\"");
      break;
    case RSCMU300_GSM900BS_NSIG:
      strcpy (FctGrpBuffer, "\"GSM900BS_NSig\"");
      break;
    case RSCMU300_GSM1800BS_NSIG:
      strcpy (FctGrpBuffer, "\"GSM1800BS_NSig\"");
      break;
    case RSCMU300_GSM1900BS_NSIG:
      strcpy (FctGrpBuffer, "\"GSM1900BS_NSig\"");
      break;
  }

  // Init the Error Message
  strcpy (errorMessage, "No Error");

  // Get the current options (= Function Group Names) in the CMU.
  if ((RSCMU300_Status = viGetAttribute (BaseSession, VI_ATTR_USER_DATA,(ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_K3G_errorMessage (BaseSession, RSCMU300_Status, errorMessage);

  // Find the Secondary address for GSM_NSig
  while ((comp != 0) && (secondAddr < 30))
  {
    comp = strncmp (p_globalvarBase->RSCMU300_tSecAddr[secondAddr].FctGrp, FctGrpBuffer, strlen(FctGrpBuffer));
    secondAddr++;
    if (comp == 0)  Flag = RSCMU300_ON;
  }

  if (Flag == RSCMU300_OFF)
    return RSCMU300_K3G_errorMessage (*GSMBSNSigSession, RSCMU_ERROR_INVALID_FCT_GRP, errorMessage);

  // Hardware Connection
  comp = strncmp ("GPIB",p_globalvarBase->RSCMU300_tGlobal.RSCMU300_SCPIConnection, 4);

  if (comp == 0)
    sprintf(resource, "%s::%ld::%ld::INSTR",p_globalvarBase->RSCMU300_tGlobal.RSCMU300_SCPIConnection, p_globalvarBase->RSCMU300_tGlobal.RSCMU300_primary_address, secondAddr-1);
  else sprintf(resource, "%s::INSTR",p_globalvarBase->RSCMU300_tGlobal.RSCMU300_SCPIConnection);

  // Open default instrument session
  globalSession = p_globalvarBase->RSCMU300_tGlobal.RSCMU300_RmSessionDefault;

  if ((RSCMU300_Status = viOpen (globalSession, resource, VI_NULL, VI_NULL, GSMBSNSigSession)) != 0)
    return RSCMU300_K3G_errorMessage (globalSession, RSCMU300_Status, errorMessage);

  // Allocate space for "struct RSCMU300_SESSION_Globals"
  if ((p_globalvarGSM = (struct RSCMU300_GSM_NSig_Globals *)malloc(sizeof(struct RSCMU300_GSM_NSig_Globals))) == 0)
    return RSCMU300_initCleanUp (globalSession, *GSMBSNSigSession, RSCMU300_Status);

  if ((RSCMU300_Status = viSetAttribute(*GSMBSNSigSession, VI_ATTR_USER_DATA,(ViAttrState)p_globalvarGSM)) < 0)
    return RSCMU300_initCleanUp (globalSession, *GSMBSNSigSession, RSCMU300_Status);

  // Set initial values of variables for function Group 'GSM_NonSig' .
  strcpy (p_globalvarGSM->RSCMU300_tGlobal.FGrp_Name, FctGrpBuffer);
  p_globalvarGSM->RSCMU300_tGlobal.RSCMU300_primary_address = p_globalvarBase->RSCMU300_tGlobal.RSCMU300_primary_address;
  p_globalvarGSM->RSCMU300_tGlobal.RSCMU300_secondary_address = secondAddr - 1;
  p_globalvarGSM->RSCMU300_tGlobal.RSCMU300_TRACE = p_globalvarBase->RSCMU300_tGlobal.RSCMU300_TRACE;
  if (p_globalvarGSM->RSCMU300_tGlobal.RSCMU300_TRACE == RSCMU300_ON)
    p_globalvarGSM->RSCMU300_tGlobal.RSCMU300_AddrTargetFile = p_globalvarBase->RSCMU300_tGlobal.RSCMU300_AddrTargetFile;

  // Base CMU FW available
  strcpy (p_globalvarGSM->RSCMU300_tGlobal.CmuVersion, p_globalvarBase->RSCMU300_tGlobal.CmuVersion);
  p_globalvarGSM->RSCMU300_tGlobal.RSCMU300_FW_Version = p_globalvarBase->RSCMU300_tGlobal.RSCMU300_FW_Version;

  // Record the execution of this Init Function.
  p_globalvarBase->RSCMU300_tSecAddr[secondAddr - 1].SessionNb = *GSMBSNSigSession;

  // Timeout changed from 10s to 30 seconds
  if ((RSCMU300_Status = viSetAttribute (*GSMBSNSigSession, VI_ATTR_TMO_VALUE, 15000)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 * GROUP CONFIGURATION
 * -------------------
 * The functions in this section are used to configure the measurements in the
 * function group GSM900-BS Non Signalling globally, i.e. for all subsequent
 * measurements. They correspond to the settings in the popup menu of the
 * softkey Group Config. located to the left of the headline of each main menu.
 *-----------------------------------------------------------------------------
 *    Subsystem EPOWer (Expected Input Power)
 *    The subsystem EPOWer determines the expected input power for the currently
 *    used input. It corresponds to the tab Input Level in the popup menu Group
 *    Configuration.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Input level - Mode
/* Purpose : This function defines the mode for setting the maximum input
/*           level.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SensLevMode (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"MAN","AUT"};

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, Mode, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set the input level attenuation
  sprintf (wrtBuf, "EPOW:MODE %s", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Input level - Maximum
/* Purpose : This function sets the maximum input level. The permissible
/*           value range depends on the RF input used and the external
/*           attenuation set.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SensLevMax (ViSession instrSession,
                                                                       ViReal64  Level,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Do not check if the function is correctly used because it depends on the
  // RF input used and the external attenuation set.

  sprintf (wrtBuf, "EPOW:VAL %.12f", Level);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Input level - attenuation
/* Purpose : This function sets an attenuation or gain factor for the
/*           RF input signal.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SensLevAtt (ViSession instrSession,
                                                                       ViInt32   Mode,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"NORM","LNO","LDIS"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set the input level attenuation
  sprintf (wrtBuf, "EPOW:ATT %s", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    Subsystem TRIGger (Trigger Mode)
 *    The subsystem TRIGger contains the commands for determination
 *    of the trigger mode. It corresponds to the index card Trigger in
/*    the popup menu Group Configuration.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Trigger Source
/* Purpose : This function defines the trigger condition. The setting POWer
/*           assumes bursted signals.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_TrigSour (ViSession instrSession,
                                                                     ViInt32   Source,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrSource[] = {"FRUN","RFP","IFP","EXT"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Source, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "TRIG:SOUR %s", StrSource[Source]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Trigger RF Power
/* Purpose : This Function sets the trigger RF power. It is valid for
/*           trigger Source RFPower. Possible values are Low, Medium and High.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_TrigThrRFPow (ViSession instrSession,
                                                  ViInt32   RFPower,
                                                  ViChar    errorMessage[])
{

    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[] = {"LOW","MED", "HIGH", VI_NULL};
    struct RSCMU300_SESSION_Globals  *p_globalvarBase;

    // Queries the specified attribute:
    CHECKRET(viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase));

    if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_22)
      {
      RETMSG(RSCMU300_setEnum(instrSession, "TRIG:THR",
                         RFPower, list,
                         RSCMU_ERROR_PARAMETER2));
      }
    else
      {
      RETMSG(RSCMU300_setEnum(instrSession, "TRIG:THR:RFP",
                         RFPower, list,
                         RSCMU_ERROR_PARAMETER2));
      }
}

/*===========================================================================*/
/* Function: Set Trigger IF Power
/* Purpose : This Function sets the trigger IF power. It is valid for
/*           trigger Source IFPower. Possible values between -47.0 and 0.0 dB.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_TrigThrIFPow (ViSession instrSession,
                                                  ViReal64  IFPower,
                                                  ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_22,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_setViReal64(instrSession, "TRIG:THR:IFP",
                             IFPower, -47.0,0.0,
                             RSCMU_ERROR_PARAMETER2));

}

/*===========================================================================*/
/* Function: Set Trigger Slope
/* Purpose : This Function sets the trigger slope. It is enabled for
/*           trigger Source RFPower and IFPower only.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_TrigSlop (ViSession instrSession,
                                              ViInt32   slope,
                                              ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[] = {"NEG","POS", VI_NULL};

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_22,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_setEnum(instrSession, "TRIG:SLOP",
                         slope, list,
                         RSCMU_ERROR_PARAMETER2));
}


/*===========================================================================*/
/* Function: Set Trigger External Source
/* Purpose : This Function sets the trigger extrenal source.
/*           Possible values are Pin 6, Pin 7 and Pin 8
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_TrigSourExt (ViSession instrSession,
                                                 ViInt32   extSource,
                                                 ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[] = {"PIN6","PIN7", "PIN8", VI_NULL};

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_22,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_setEnum(instrSession, "TRIG:SOUR:EXT",
                         extSource, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/*
/*                  Only for compatibility
/*
/* Function: Trigger Threshold
/* Purpose : This function sets the trigger level, i.e. the signal level at
/*           which the measurement is triggered. The function is enabled for
/*           trigger source RFPower and IFPower only.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_TrigThr (ViSession instrSession,
                                                                    ViInt32   TriggerThreshold,
                                                                    ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrTriggerThreshold[] = {"LOW","MED","HIGH"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TriggerThreshold, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set the trigger threshold:
  sprintf (wrtBuf, "TRIG:THR %s", StrTriggerThreshold[TriggerThreshold]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 * CONNECTION CONTROL
 * ------------------
 * The functions presented in this section determine the signals
 * analyzed and generated by the CMU, the inputs and outputs used
 * to this end as well as the reference frequency.
 * It corresponds to the settings in the popup menu of the softkey
 * Connect. Control, located to the right of the headline of each
 * main menu.
 * ----------------------------------------------------------------------------
 *      Subsystem RFANanlyzer (Analyzed Input Signals)
 *      This subsystem contains the functions to determine the signals
 *      received and analyzed by the CMU. It corresponds to the panel
 *      Analyzer Settings in the index card Signal in the popup menu
 *      Connect. Control.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: RF Channel (Number)
/* Purpose : This function determines the channel number of the RF signal
/*           analyzed. The assignment of channel numbers meets the GSM
/*           specification for the uplink (signal direction from mobile to
/*           CMU).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_RfanChan (ViSession instrSession,
                                                                     ViInt32   ChannelNumber,
                                                                     ViChar     _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  struct RSCMU300_SESSION_Globals  *p_globalvarSession;

  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU300_Status;

  // Check if the function is correctly used (depends on the current Function Group):
  if (strncmp ("\"GSM900BS_NSig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    if ((RSCMU300_invalidViInt32Range (ChannelNumber, 0, 124)) && (RSCMU300_invalidViInt32Range (ChannelNumber, 955, 1023)))
      return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1800BS_NSig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, ChannelNumber, 512, 885, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1900BS_NSig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, ChannelNumber, 512, 810, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM400BS_NSig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, ChannelNumber, 259, 340, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM850BS_NSig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, ChannelNumber, 128, 251, RSCMU_ERROR_PARAMETER2, errorMessage);
  }

  // Set the unit on "CH"
  sprintf (wrtBuf, "RFAN:FREQ:UNIT CH");
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Set the channel number of the RF signal analysed:
  sprintf (wrtBuf, "RFAN:FREQ %ld", ChannelNumber);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: RF Channel (Frequency)
/* Purpose : This function determines the frequency of the RF signal
/*           analyzed. The assignment of frequencies meets the GSM
/*           specification for the uplink (signal direction from mobile to
/*           CMU).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_RfanFreq (ViSession instrSession,
                                                                     ViReal64  Frequency,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, Frequency, 0.2, 2700.0, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set the unit on "MHz"
  sprintf (wrtBuf, "RFAN:FREQ:UNIT MHz");
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Set the frequency of the RF signal generated:
  sprintf (wrtBuf, "RFAN:FREQ %.12f", Frequency);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Frequency Offset
/* Purpose : This command sets an offset shifting the channel frequency
/*           set with the previous function. The offset frequency must be
/*           in multiples of 1 Hz.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_RfanFreqOffset (ViSession instrSession,
                                                                           ViReal64  FreqOffset,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, FreqOffset, RSCMU300_GSMNONSIG_FREQNEG, RSCMU300_GSMNONSIG_FREQPOS, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf, "RFAN:FOFF %.12f KHZ", FreqOffset);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Training Sequence
/* Purpose : This function determines the training sequence of the signal
/*           analyzed by the CMU. If no training sequence is determined
/*           (OFF), the CMU will measure all signals.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_RfanTseq (ViSession instrSession,
                                                                     ViInt32   TrainingSequence,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrTrainingSequence[] = {"OFF","GSM0","GSM1","GSM2","GSM3","GSM4","GSM5","GSM6","GSM7","DUMM","ANY"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TrainingSequence, 0, 10, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "RFAN:TSEQ %s", StrTrainingSequence[TrainingSequence]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 *    Generator Level - Subsystem RFGenerator:LEVel
 *    This subsystem determines the level of the generated RF signals. It
 *    corresponds to the input field RF Level of the panel RF Generator in the
 *    index card Signal in the popup menu Connect. Control.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Level in the used timeslot
/* Purpose : This function sets the RF generator level in the used
/*           timeslot. The permissible value range depends on the used
/*           RF output of the CMU and the external attenuation set.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SourRfgLevUtim (ViSession instrSession,
                                                                           ViReal64  RFLevelUsed,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Do not check if the function is correctly used because it depends on the
  // RF input used and the external attenuation set.

  // Set absolute level in used timeslot:
  sprintf (wrtBuf, "SOUR:RFG:LEV:UTIM %.12f", RFLevelUsed);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Level in the unused timeslots
/* Purpose : This function sets the RF generator level in the unused
/*           timeslots relative to the level in the used timeslot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SourRfgLevUnt (ViSession instrSession,
                                                                          ViReal64  RFLevelUnused,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Do not check if the function is correctly used because it depends on the
  // RF input used and the external attenuation set.

  // Set relative level for unused timeslots:
  sprintf (wrtBuf, "SOUR:RFG:LEV:UNT %.12f", RFLevelUnused);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    RF Generator Frequency
 *    This subsystem contains the functions for determining the
 *    frequency of the generated RF signals.
 *    It corresponds to the softkeys RF Channel and Freq. Offset of
 *    the panel RF Generator in the index card Signal in the popup
 *    menu Connect. Control.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: RF Channel (Number)
/* Purpose : This function determines the channel number of the RF signal
/*           generated. The assignment of channel numbers meets the GSM
/*           specification for the downlink (signal direction from CMU to
/*           mobile).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SourRfgFreqChan (ViSession instrSession,
                                                                            ViInt32   ChannelNumber,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  struct RSCMU300_SESSION_Globals  *p_globalvarSession;

  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU300_Status;

  // Check if the function is correctly used (depends on the current Function Group):
  if (strncmp ("\"GSM900BS_NSig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    if ((RSCMU300_invalidViInt32Range (ChannelNumber, 0, 124)) && (RSCMU300_invalidViInt32Range (ChannelNumber, 955, 1023)))
      return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1800BS_NSig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, ChannelNumber, 512, 885, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1900BS_NSig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, ChannelNumber, 512, 810, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM400BS_NSig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, ChannelNumber, 259, 340, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM850BS_NSig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, ChannelNumber, 128, 251, RSCMU_ERROR_PARAMETER2, errorMessage);
  }

  // Set the unit on "CH"
  sprintf (wrtBuf, "SOUR:RFG:FREQ:UNIT CH");
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Set the channel number of the RF signal generated:
  sprintf (wrtBuf, "SOUR:RFG:FREQ %ld", ChannelNumber);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: RF Channel (Frequency)
/* Purpose : This function determines the frequency of the RF signal
/*           generated. The assignment of frequencies meets the GSM
/*           specification for the downlink (signal direction from CMU to
/*           mobile).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SourRfgFreq (ViSession instrSession,
                                                                        ViReal64  Frequency,
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, Frequency, 0.2, 2700.0, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set the unit on "MHz"
  sprintf (wrtBuf, "SOUR:RFG:FREQ:UNIT MHz");
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Set the frequency of the RF signal generated:
  sprintf (wrtBuf, "SOUR:RFG:FREQ %.12f", Frequency);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: RF Frequency Offset
/* Purpose : This function specifies the frequency offset for the CMU
/*           signals in the selected RF Channel.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SourRfgFreqOffset (ViSession instrSession,
                                                                              ViReal64  FrequencyOffSet,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, FrequencyOffSet, RSCMU300_GSMNONSIG_FREQNEG, RSCMU300_GSMNONSIG_FREQPOS, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf, "SOUR:RFG:FOFF %.12f", FrequencyOffSet);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    RF GENERATOR MODULATION
 *    -----------------------
 *    This subsystem contains the functions for determination of an
 *    information which is modulated on the RF signal generated by the
 *    CMU and the signal shape.
 *    It corresponds to the panel Generator Modulation in the index
 *    card Signal in the popup menu Connect. Control.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Selection of bit modulation
/* Purpose : This function selects a bit sequence used to modulate the
/*           signal generated by the CMU.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfRfgModBitSel (ViSession instrSession,
                                                                             ViInt32   Selection,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  ViString    StrSelection[] = {"OFF","PRBS","DUMM","ALL0","EALL0","EPRB"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Selection, 0, 5, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:RFG:MOD:BMOD %s", StrSelection[Selection]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Selection of training sequence
/* Purpose : This function selects the training sequence used to modulate
/*           the signal generated by the CMU.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfRfgModTseqSel (ViSession instrSession,
                                                                              ViInt32   Selection,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrSelection[] = {"ALL0","GSM0","GSM1","GSM2","GSM3","GSM4","GSM5","GSM6","GSM7","DUMM"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Selection, 0, 9, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:RFG:MOD:TSEQ %s", StrSelection[Selection]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Signal shape
/* Purpose : This function  determines whether the the CMU generates a
/*           bursted or a continuous RF carrier signal.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfRfgModTran (ViSession instrSession,
                                                                           ViInt32   SignalShape,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrSignalShape[] = {"BURS","CONT"};

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, SignalShape, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:RFG:MOD:TRAN %s", StrSignalShape[SignalShape]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    GENERAL CONTROL OF RF GENERATOR
 *    -------------------------------
 *    This subsystem contains the functions for controlling the
 *    internal RF generator.
 *    It corresponds to the softkey RF Generator in the index card
 *    Signal in the popup menu Connect. Control and the measurement
 *    menu Analyzer/Generator.
 * ----------------------------------------------------------------------------
 *      GENERATOR CONTROL
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start RF generator
/* Purpose : This function starts or stop the RF Generator.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitRfg (ViSession instrSession,
                                                                    ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "INIT:RFG", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}
/*===========================================================================*/
/* Function: Switch off RF generator
/* Purpose : This function stops the RF Generator.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborRfg (ViSession instrSession,
                                                                    ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "ABORT:RFG", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Generator Status
/* Purpose : This function returns the current generator status.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcRfgSt (ViSession instrSession,
                                                                      ViPInt32  RFGeneratorStatus,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";

  // Fetch the generator status:
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:RFG:STAT?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Get the RF generator status value:
  *RFGeneratorStatus = RSCMU300_GetGenStatVal (rdBuf);

  if (*RFGeneratorStatus < 0)
    return RSCMU_ERROR_GEN_STAT_UNKNOWN;

  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      INPUT AND OUTPUT CONNECTORS
 *      The subsystem IOConnector contains the commands for
 *      configuration of the input and output connectors.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Selection of input connector
/* Purpose : This command determines the connector to be used for incoming
/*           RF signals. The bidirectional connectors RF 1 and RF 2 can be
/*           used both as input and output connectors in the very same
/*           measurement (see OUTPut[:STATe]).
/*           Only one input and one output may be active at a time, which
/*           is why the cur-rently active one is automatically deactivated
/*           on switchover.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_Inp (ViSession instrSession,
                                                                ViInt32   State,
                                                                ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrState[] = {"RF1","RF2","RF4"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, State, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "INP %s", StrState[State]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Selection of output connector
/* Purpose : This function determines the connector to be used for
/*           outgoing RF signals. The bidirectional connectors RF 1 and
/*           RF 2 can be used both as input and output connectors in the
/*           very same measurement.
/*           Only one input and one output may be active at a time, which
/*           is why the cur-rently active one is automatically deactivated
/*           on switchover.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_Outp (ViSession instrSession,
                                                                 ViInt32   State,
                                                                 ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrState[] = {"RF1","RF2","RF3"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, State, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "OUTP %s", StrState[State]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: External attenuation at the input
/* Purpose : This command assigns an external attenuation value to the
/*           inputs of the instrument (RF 1, RF 2, RF 4 IN).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SensCorrLossInp (ViSession instrSession,
                                                                            ViInt32   InputNr,
                                                                            ViReal64  Absorption,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, InputNr, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, Absorption, RSCMU300_ATT_MIN, RSCMU300_ATT_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  switch (InputNr)
  {
    case RSCMU300_INPUT_RF1:
      sprintf (wrtBuf, "SENS:CORR:LOSS:INP1 %.12f", Absorption);
      break;
    case RSCMU300_INPUT_RF2:
      sprintf (wrtBuf, "SENS:CORR:LOSS:INP2 %.12f", Absorption);
      break;
    case RSCMU300_INPUT_RF4:
      sprintf (wrtBuf, "SENS:CORR:LOSS:INP4 %.12f", Absorption);
      break;
  }
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: External attenuation at the output
/* Purpose : This command assigns an external attenuation value to the
/*           outputs of the instrument (RF 1, RF 2, RF 3 OUT).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SourCorrLossOutp (ViSession instrSession,
                                                                             ViInt32   OutputNr,
                                                                             ViReal64  Absorption,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, OutputNr, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, Absorption, RSCMU300_ATT_MIN, RSCMU300_ATT_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  switch (OutputNr)
  {
    case RSCMU300_OUTPUT_RF1:
      sprintf (wrtBuf, "SOUR:CORR:LOSS:OUTP1 %.12f", Absorption);
      break;
    case RSCMU300_OUTPUT_RF2:
      sprintf (wrtBuf, "SOUR:CORR:LOSS:OUTP2 %.12f", Absorption);
      break;
    case RSCMU300_OUTPUT_RF3:
      sprintf (wrtBuf, "SOUR:CORR:LOSS:OUTP3 %.12f", Absorption);
      break;
  }
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *     SYNCHRONISATION
 *     ------------------
 *     Subsystem REFerence (Synchronization)
 *     The subsystem REFerence contains the commands for setting a system clock
 *     specific to the network. This frequency is set in the index card Synch.
 *     in the popup menu Connect. Control.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Switching on/off and setting the system clock
/* Purpose : This commands switches the system clock specific to the
/*           network at the REF OUT 2 connector on or off, and determines
/*           the system clock frequency applied to REF OUT 2.
/*           The frequency entered is internally rounded to one of a
/*           discrete values defined in the operating manual.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SourDmClock (ViSession instrSession,
                                                                        ViBoolean Mode,
                                                                        ViReal64  Frequency,
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, Mode, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, Frequency, RSCMU300_REF_FRQ_MIN, RSCMU300_REF_FRQ_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  // Setting the system clock
  sprintf (wrtBuf, "SOUR:DM:CLOC:FREQ %.12f", Frequency);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Switching the system clock ON or OFF
  sprintf (wrtBuf, "SOUR:DM:CLOC:STAT %s", mode_On_Off[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT WPOWER
 *
 *    The subsystem WPOWer contains the commands for measuring the
 *    wide-band power of the signal sent by the base tranceiver station.
 *    It corresponds to the softkey Power of the tab Signaling
 *    in the menu group Connect. Control.
 *-----------------------------------------------------------------------------
 *    CONFIGURATION CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfWpowContRep (ViSession instrSession,
                                                                            ViInt32   Repetition,
                                                                            ViInt32   StopCondition,
                                                                            ViInt32   StepMode,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, Repetition, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:WPOW:CONT:REP %s,%s,%s", repetition_meas[Repetition]
                                                , mode_StopCondition[StopCondition]
                                                , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfWpowContRepSt (ViSession instrSession,
                                                                              ViInt32   NbRepetition,
                                                                              ViInt32   StopCondition,
                                                                              ViInt32   StepMode,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:WPOW:CONT:REP %ld,%s,%s", NbRepetition
                                                , mode_StopCondition[StopCondition]
                                                , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Init Measurements
/* Purpose : This function start the measurement,
/*           setting it to the status beyond.
/*           RUN        Start measurement without waiting
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitWpow (ViSession instrSession,
                                                                    ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "INIT:WPOW", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort Measurements
/* Purpose : This function abort running signal-power measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborWpow (ViSession instrSession,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "ABOR:WPOW", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Stop Measurements
/* Purpose : This function stop measurement after current statistic cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopWpow (ViSession instrSession,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "STOP:WPOW", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Run Next Measurement Step
/* Purpose : This function runs next signal-power measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContWpow (ViSession instrSession,
                                                                     ViChar _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CONT:WPOW", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch measurement status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcWpowSt (ViSession instrSession,
                                                                       ViPInt32  MeasStatus,
                                                                       ViPInt32  CurrentStatCycleCount,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Fetch the measurement status:
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:WPOW:STAT?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMeasStatVal(MeasStatus, tab, 0 );

  // Get the counter for current statistics cycle
  if (strcmp (tab[1], "NONE") != 0)
    sscanf (tab[1], "%ld", CurrentStatCycleCount);
  else *CurrentStatCycleCount = RSCMU300_OFF;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfWpowErep (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:WPOW:EREP %s", StrErep[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    RESULTS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Meas. Peak Burst Power
/* Purpose : This function starts the measurement of the maximum burst
/*           power of the signals sent by the BTS (peak burst power)
/*           and outputs the result.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadWpow (ViSession instrSession,
                                                                     ViPReal64 MaxBurstPower,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:WPOW?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf, "%le", MaxBurstPower);
  else
    return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_NAN, errorMessage);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Meas. Peak Burst Power
/* Purpose : This function starts the measurement of the maximum burst
/*           power of the signals sent by the BTS (peak burst power)
/*           and outputs the result.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcWpow (ViSession instrSession,
                                                                     ViPReal64 MaxBurstPower,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:WPOW?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Extract the CMU_response
  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf, "%le", MaxBurstPower);
  else
    return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_NAN, errorMessage);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Meas. Peak Burst Power
/* Purpose : This function starts the measurement of the maximum burst
/*           power of the signals sent by the BTS (peak burst power)
/*           and outputs the result.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampWpow (ViSession instrSession,
                                                                     ViPReal64 MaxBurstPower,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:WPOW?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Extract the CMU_response
  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf, "%le", MaxBurstPower);
  else
    return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_NAN, errorMessage);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 * MEASUREMENT OBJECT NARROW-BAND POWER
 *
 * The subsystem NPOWer measures the power of the signal transmitted by the
 * mobile phone using the RF analyzer configuration of the POWer measurement.
 * Compared to WPOWer, the NPOWer measurement uses a narrow-band (500 kHz Gauss)
 * filter. The narrow-band NPOWer measurement yields the average, maximum and
 * minimum burst power of the current burst (display mode Current) and of the
 * averaged measurement curve (display mode Average).
 * The entire measurement curves (arrays) are not available, and no limit check
 * is performed. NPOWer is a quick and precise alternative to the WPOWer or
 * POWer measurements if only scalar results are needed.
 * Note: A Free Run trigger (TRIGger[:SEQuence]:SOURce FRUN) should be avoided
 * because it delays the NPOWer measurement.
 * ----------------------------------------------------------------------------
 *      MEASUREMENT CONTROL
 *      This subsystem contains the functions for general control of the
 *      narrow-band power measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start new measurement
/* Purpose : This function starts the narrow-band power measurement, setting it
/*           to the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_InitNpow (ViSession instrSession, ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  RETMSG(RSCMU300_sendCmd(instrSession, "INIT:NPOW"));
}

/*===========================================================================*/
/* Function: Abort Measurements
/* Purpose : This function abort running narrow-band power measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_AborNpow (ViSession instrSession, ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  RETMSG(RSCMU300_sendCmd(instrSession, "ABOR:NPOW"));
}

/*===========================================================================*/
/* Function: Stop Measurements
/* Purpose : This function stop measurement after current statistic cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_StopNpow (ViSession instrSession, ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  RETMSG(RSCMU300_sendCmd(instrSession, "STOP:NPOW"));
}

/*===========================================================================*/
/* Function: Run Next Measurement Step
/* Purpose : This function runs next narrow-band power measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_ContNpow (ViSession instrSession, ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  RETMSG(RSCMU300_sendCmd(instrSession, "CONT:NPOW"));
}

/*===========================================================================*/
/* Function: Fetch measurement status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_FetcNpowStat (ViSession  instrSession,
                                                     ViInt32   *MeasurementStatus,
                                                     ViInt32   *CountingNo,
                                                     ViInt32   *StatisticNo,
                                                     ViChar     errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_FetcStatus (instrSession, RSCMU300_NPOW, RSCMU300_NONE, MeasurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_ConfNpowErep (ViSession instrSession,
                                                     ViInt32 Report,
                                                     ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  RETMSG(RSCMU300_setEnum(instrSession, "CONF:NPOW:EREP",
                          Report, StrErep, RSCMU_ERROR_PARAMETER2));

}


/*
 * ----------------------------------------------------------------------------
 *      CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Scope of Measurement
/* Purpose : This function selects the type of measured values and determines
/*           the number of bursts forming one statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_ConfNpowCont (ViSession instrSession,
                                                     ViInt32   NbBurst,
                                                     ViInt32   repetition,
                                                     ViInt32   NbRepetition,
                                                     ViInt32   StopCondition,
                                                     ViInt32   StepMode,
                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_BUFS(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the calling function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, 1, 1000, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, repetition, 0, 2, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, 1, 10000, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER6, errorMessage);

  if (repetition != RSCMU300_MULTIPLE)
    sprintf(wrtBuf, "CONF:NPOW:CONT %ld,%s,%s,%s", NbBurst
                                                , repetition_meas[repetition]
                                                , mode_StopCondition_SON[StopCondition]
                                                , StrStepMode[StepMode]);
  else
    sprintf(wrtBuf, "CONF:NPOW:CONT %ld,%ld,%s,%s", NbBurst
                                                , NbRepetition
                                                , mode_StopCondition_SON[StopCondition]
                                                , StrStepMode[StepMode]);

  RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}


/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_ConfNpowContRep (ViSession instrSession,
                                                        ViInt32   repetition,
                                                        ViInt32   NbRepetition,
                                                        ViInt32   StopCondition,
                                                        ViInt32   StepMode,
                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_BUFS(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the calling function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, repetition, 0, 2, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, 1, 10000, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER6, errorMessage);

  if (repetition != RSCMU300_MULTIPLE)
    sprintf(wrtBuf, "CONF:NPOW:CONT:REP %s,%s,%s", repetition_meas[repetition]
                                                 , mode_StopCondition_SON[StopCondition]
                                                 , StrStepMode[StepMode]);
  else
    sprintf(wrtBuf, "CONF:NPOW:CONT:REP %ld,%ld,%s", NbRepetition
                                                 , mode_StopCondition_SON[StopCondition]
                                                 , StrStepMode[StepMode]);

  RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*
 * ----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Statistic Count
/* Purpose : This function selects the type of measured values and determines
/*           the number of bursts forming one statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_ConfNpowContStat (ViSession instrSession,
                                                         ViInt32   NbBurst,
                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  RETMSG(RSCMU300_setViInt32(instrSession, "CONF:NPOW:CONT:STAT",
                                            NbBurst, 1, 1000,
                                            RSCMU_ERROR_PARAMETER2));
}

/*
 * ----------------------------------------------------------------------------
 *      RESULTS
 *-----------------------------------------------------------------------------
*/
/*===========================================================================*/
/* Function: Read Scalar
/* Purpose : This function starts the NPOWer measurement and returns the
/*           results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_ReadNpow (ViSession  instrSession,
                                                 ViReal64  *AvgPowCurr,
                                                 ViReal64  *MinPowCurr,
                                                 ViReal64  *MaxPowCurr,
                                                 ViReal64  *AvgPowAvg,
                                                 ViReal64  *MinPowAvg,
                                                 ViReal64  *MaxPowAvg,
                                                 ViChar    errorMessage[])
{
  return RSCMU300_MeasNpow (instrSession, RSCMU300_COMMAND_READ, AvgPowCurr, MinPowCurr, MaxPowCurr,
    AvgPowAvg, MinPowAvg, MaxPowAvg, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Scalar
/* Purpose : This function reads out measurements (unsynchronized) and returns
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_FetcNpow (ViSession  instrSession,
                                                 ViReal64  *AvgPowCurr,
                                                 ViReal64  *MinPowCurr,
                                                 ViReal64  *MaxPowCurr,
                                                 ViReal64  *AvgPowAvg,
                                                 ViReal64  *MinPowAvg,
                                                 ViReal64  *MaxPowAvg,
                                                 ViChar    errorMessage[])
{
  return RSCMU300_MeasNpow (instrSession, RSCMU300_COMMAND_FETC, AvgPowCurr, MinPowCurr, MaxPowCurr,
    AvgPowAvg, MinPowAvg, MaxPowAvg, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Scalar
/* Purpose : This function reads out measurements (synchronized) and returns
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_SampNpow (ViSession  instrSession,
                                                 ViReal64  *AvgPowCurr,
                                                 ViReal64  *MinPowCurr,
                                                 ViReal64  *MaxPowCurr,
                                                 ViReal64  *AvgPowAvg,
                                                 ViReal64  *MinPowAvg,
                                                 ViReal64  *MaxPowAvg,
                                                 ViChar    errorMessage[])
{
  return RSCMU300_MeasNpow (instrSession, RSCMU300_COMMAND_SAMP, AvgPowCurr, MinPowCurr, MaxPowCurr,
    AvgPowAvg, MinPowAvg, MaxPowAvg, errorMessage);
}


/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT SPECtrum[:COMMon]
 *
 *    The subsystem SPECtrum[:COMMon] provides settings that are
 *    common to the two applications Spectrum due to Modulation (see
 *    p. 6.56 ff) and Spectrum due to Switching (see p. 6.64 ff).
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: noise correction
/* Purpose : this function switches the noise correction for the Spectrum
/*           measurement on or off. The noise correction improves the dynamic
/*           range but slightly reduces the speed of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpComNoiseCorr (ViSession instrSession,
                                                                               ViBoolean Correction,
                                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, Correction, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:NOIS:CORR %s", mode_On_Off[Correction]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Select Limit Line Template
/* Purpose : These function selects the limit line to be applied.
/*           The current template can be queried using
/*           [SENSe:]SPECtrum:<Application>:LIMit:LINE:USED?.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpecLimLineSel (ViSession instrSession,
                                                        ViInt32   select,
                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViString    list[] = {"GMSK","EPSK","AUTO", VI_NULL};

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  RETMSG(RSCMU300_setEnum(instrSession, "CONFigure:SPECtrum:LIMit:LINE:SELect", select, list,
                         RSCMU_ERROR_PARAMETER2));
}


/*
 *-----------------------------------------------------------------------------
 * Close
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Close
/* Purpose : This function close the Basic Unit session and release the
/*           resources
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Close_GSM_NSig (ViSession instrSession,
                                                                  ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  struct RSCMU300_GSM_NSig_Globals *p_globalvarGSM;

  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarGSM)) < 0)
    return RSCMU300_K3G_errorMessage (instrSession, RSCMU300_Status, errorMessage);

  // Deallocate all system resources allocated to the GSMBSNSig Session:
  if ((RSCMU300_Status = viClose (instrSession)) < 0)
    return RSCMU300_Status;

  // Deallocate the space pointed by p_globalvarGSM:
  if (p_globalvarGSM)
    free (p_globalvarGSM);

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 * GSM MEASUREMENTS WITH SIGNALLING (SIGNALLING):
 * ----------------------------------------------------------------------------
 */
/* ----------------------------------------------------------------------------
 * Initialize
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Initialize
/* Purpose : This function can be called only after the initialization
/*           of the "Basic Unit".It opens the instrument, queries the
/*           instrument for its ID, and initializes the instrument
/*           to a known state.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Init_GSM_Sig (ViSession  BaseSession,
                                                                ViPSession GSMSigSession,
                                                                ViUInt32   GSMFunctionGpr,
                                                                ViChar     _VI_FAR errorMessage[])
{

  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViSession   globalSession = 0;
  ViSession   GSMSession = 0;
  ViInt32     secondAddr = 0, comp = 1;
  ViInt16     i;
  ViReal64    Flag = RSCMU300_OFF;
  ViChar      wrtBuf[WR_BUFFER_SIZE]= "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      FctGrpBuffer[128]= "";
  ViChar      resource[25]="";

  struct RSCMU300_Base_Globals     *p_globalvarBase;
  struct RSCMU300_GSM_Sig_Globals  *p_globalvarGSM;

  /* --- Set standard "C" locale --- */
  {
    char *locale;

    locale = setlocale(LC_ALL, "C");
  }

  // Which Function Group does the User want?
  switch (GSMFunctionGpr)
  {
    case RSCMU300_GSM400BS_SIG:
      strcpy (FctGrpBuffer, "\"GSM400BS_Sig\"");
      break;
    case RSCMU300_GSM850BS_SIG:
      strcpy (FctGrpBuffer, "\"GSM850BS_Sig\"");
      break;
    case RSCMU300_GSM900BS_SIG:
      strcpy (FctGrpBuffer, "\"GSM900BS_Sig\"");
      break;
    case RSCMU300_GSM1800BS_SIG:
      strcpy (FctGrpBuffer, "\"GSM1800BS_Sig\"");
      break;
    case RSCMU300_GSM1900BS_SIG:
      strcpy (FctGrpBuffer, "\"GSM1900BS_Sig\"");
      break;
  }

  // Init the Error Message
  strcpy (errorMessage, "No Error");

  // Get the current options (= Function Group Names) in the CMU.
  if ((RSCMU300_Status = viGetAttribute (BaseSession, VI_ATTR_USER_DATA,(ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_K3G_errorMessage (BaseSession, RSCMU300_Status, errorMessage);

  // Find the Secondary address for GSM_Sig
  while ((comp != 0) && (secondAddr < 30))
  {
    comp = strncmp (p_globalvarBase->RSCMU300_tSecAddr[secondAddr].FctGrp, FctGrpBuffer, strlen(FctGrpBuffer));
    secondAddr++;
    if (comp == 0)  Flag = RSCMU300_ON;
  }

  if (Flag == RSCMU300_OFF)
    return RSCMU300_K3G_errorMessage (*GSMSigSession, RSCMU_ERROR_INVALID_FCT_GRP, errorMessage);

  // Hardware Connection
  comp = strncmp ("GPIB",p_globalvarBase->RSCMU300_tGlobal.RSCMU300_SCPIConnection, 4);

  if (comp == 0)
    sprintf(resource, "%s::%ld::%ld::INSTR",p_globalvarBase->RSCMU300_tGlobal.RSCMU300_SCPIConnection, p_globalvarBase->RSCMU300_tGlobal.RSCMU300_primary_address, secondAddr-1);
  else sprintf(resource, "%s::INSTR",p_globalvarBase->RSCMU300_tGlobal.RSCMU300_SCPIConnection);

  // Open default instrument session
  globalSession = p_globalvarBase->RSCMU300_tGlobal.RSCMU300_RmSessionDefault;

  if ((RSCMU300_Status = viOpen (globalSession, resource, VI_NULL, VI_NULL, GSMSigSession)) != 0)
    return RSCMU300_K3G_errorMessage (globalSession, RSCMU300_Status, errorMessage);

  // Allocate space for "struct RSCMU300_SESSION_Globals"
  if ((p_globalvarGSM = (struct RSCMU300_GSM_Sig_Globals *) malloc (sizeof (struct RSCMU300_GSM_Sig_Globals))) == 0)
    return RSCMU300_initCleanUp (globalSession, *GSMSigSession, RSCMU300_Status);

  if ((RSCMU300_Status = viSetAttribute(*GSMSigSession, VI_ATTR_USER_DATA,(ViAttrState)p_globalvarGSM)) < 0)
    return RSCMU300_initCleanUp (globalSession, *GSMSigSession, RSCMU300_Status);

  // Set initial values of variables for function Group 'GSM_Sig'.
  strcpy (p_globalvarGSM->RSCMU300_tGlobal.FGrp_Name, FctGrpBuffer);
  p_globalvarGSM->RSCMU300_tGlobal.RSCMU300_primary_address = p_globalvarBase->RSCMU300_tGlobal.RSCMU300_primary_address;
  p_globalvarGSM->RSCMU300_tGlobal.RSCMU300_secondary_address = secondAddr - 1;
  p_globalvarGSM->RSCMU300_tGlobal.RSCMU300_TRACE = p_globalvarBase->RSCMU300_tGlobal.RSCMU300_TRACE;
  if (p_globalvarGSM->RSCMU300_tGlobal.RSCMU300_TRACE == RSCMU300_ON)
    p_globalvarGSM->RSCMU300_tGlobal.RSCMU300_AddrTargetFile = p_globalvarBase->RSCMU300_tGlobal.RSCMU300_AddrTargetFile;

  // Base CMU FW available
  strcpy (p_globalvarGSM->RSCMU300_tGlobal.CmuVersion, p_globalvarBase->RSCMU300_tGlobal.CmuVersion);
  p_globalvarGSM->RSCMU300_tGlobal.RSCMU300_FW_Version = p_globalvarBase->RSCMU300_tGlobal.RSCMU300_FW_Version;

  // Record the execution of this Init Function.
  p_globalvarBase->RSCMU300_tSecAddr[secondAddr - 1].SessionNb = *GSMSigSession;

  // Record the "HandOverName" for the actual Session.
  switch (GSMFunctionGpr)
  {
    case RSCMU300_GSM400BS_SIG:
      strcpy (p_globalvarGSM->RSCMU300_tHandOver.HandOverSessionName, "\"GSM400BsDualBand\"");
      break;
    case RSCMU300_GSM850BS_SIG:
      strcpy (p_globalvarGSM->RSCMU300_tHandOver.HandOverSessionName, "\"GSM850BsDualBand\"");
      break;
    case RSCMU300_GSM900BS_SIG:
      strcpy (p_globalvarGSM->RSCMU300_tHandOver.HandOverSessionName, "\"GSM900BsDualBand\"");
      break;
    case RSCMU300_GSM1800BS_SIG:
      strcpy (p_globalvarGSM->RSCMU300_tHandOver.HandOverSessionName, "\"GSM1800BsDualBand\"");
      break;
    case RSCMU300_GSM1900BS_SIG:
      strcpy (p_globalvarGSM->RSCMU300_tHandOver.HandOverSessionName, "\"GSM1900BsDualBand\"");
      break;
  }

  // Timeout changed from 10s to 30 seconds
  if ((RSCMU300_Status = viSetAttribute (*GSMSigSession, VI_ATTR_TMO_VALUE, 15000)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 * GROUP CONFIGURATION
 * ------------------
 * The functions in this section are used to configure the
 * measurements in the menu group GSM900/1800/1900-BS Signalling
 * globally. They correspond to the settings in the popup menu of
 * the softkey Group Config. Located to the left of the headline of
 * each main menu.
 *
 *-----------------------------------------------------------------------------
 *    INPUT LEVEL
 *    This subsystem contains the functions for determination or
 *    modification of the input level for the currently used input.
 *    It corresponds to the index card Input Level in the popup menu
 *    Group Configuration.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Input Level - Mode
/* Purpose : This Function defines the mode for setting the maximum input
/*           level.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensLevMode (ViSession instrSession,
                                                                       ViInt32   mode,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  return RSCMU300_GSM_NSig_SensLevMode(instrSession, mode, errorMessage);
}

/*===========================================================================*/
/* Function: Input Level - Maximum
/* Purpose : This Function sets the maximum input level. The permissible
/*           value range depends on the RF input used and the external
/*           attenuation set.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensLevMax(ViSession instrSession,
                                                                     ViReal64  LevMax,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  return RSCMU300_GSM_NSig_SensLevMax (instrSession, LevMax, errorMessage);
}

/*===========================================================================*/
/* Function: Input level - Attenuation
/* Purpose : This function sets the attenuation or gain factor for the
/*           RF input signal.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensLevAtt (ViSession instrSession,
                                                                      ViInt32   Mode,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  return RSCMU300_GSM_NSig_SensLevAtt (instrSession, Mode, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    TRIGGER MODE
 *    The subsystem TRIGger contains the functions for determination
 *    of the trigger mode.
 *    It corresponds to the index card Trigger in the popup menu Group
 *    Configuration.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Trigger Mode
/* Purpose : This function defines the trigger mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_TrigSour(ViSession instrSession,
                                                                   ViInt32   TriggerMode,
                                                                   ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    mode_Trigger_mode[] = {"SIGN","RFP","IFP","FRUN"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TriggerMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Define the Trigger mode
  sprintf (wrtBuf, "TRIG:SOUR %s", mode_Trigger_mode[TriggerMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Trigger RF Power
/* Purpose : This Function sets the trigger RF power. It is valid for
/*           trigger Source RFPower. Possible values are Low, Medium and High.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_TrigThrRFPow (ViSession instrSession,
                                                  ViInt32   RFPower,
                                                  ViChar    errorMessage[])
{

    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[] = {"LOW","MED", "HIGH", VI_NULL};
    struct RSCMU300_SESSION_Globals  *p_globalvarBase;

    // Queries the specified attribute:
    CHECKRET(viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase));

    if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_22)
      {
      RETMSG(RSCMU300_setEnum(instrSession, "TRIG:THR",
                         RFPower, list,
                         RSCMU_ERROR_PARAMETER2));
      }
    else
      {
      RETMSG(RSCMU300_setEnum(instrSession, "TRIG:THR:RFP",
                         RFPower, list,
                         RSCMU_ERROR_PARAMETER2));
      }
}

/*===========================================================================*/
/* Function: Set Trigger IF Power
/* Purpose : This Function sets the trigger IF power. It is valid for
/*           trigger Source IFPower. Possible values between -47.0 and 0.0 dB.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_TrigThrIFPow (ViSession instrSession,
                                                  ViReal64  IFPower,
                                                  ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_22,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_setViReal64(instrSession, "TRIG:THR:IFP",
                             IFPower, -47.0,0.0,
                             RSCMU_ERROR_PARAMETER2));

}

/*===========================================================================*/
/* Function: Set Trigger Slope
/* Purpose : This Function sets the trigger slope. It is enabled for
/*           trigger Source RFPower and IFPower only.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_TrigSlop (ViSession instrSession,
                                              ViInt32   slope,
                                              ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[] = {"NEG","POS", VI_NULL};

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_22,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_setEnum(instrSession, "TRIG:SLOP",
                         slope, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/*
/*                  Only for compatibility
/*
/* Function: Set Threshold
/* Purpose : This function sets the threshold at which the trigger signal
/*           triggers the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_TrigThr (ViSession instrSession,
                                                                   ViInt32   TriggerThreshold,
                                                                   ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrTriggerThreshold[] = {"LOW","MED","HIGH"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TriggerThreshold, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set the trigger threshold:
  sprintf (wrtBuf, "TRIG:THR %s", StrTriggerThreshold[TriggerThreshold]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Trigger Signal
/* Purpose : This function assigns the trigger signal (or no signal)
/*           to pins 2 to 5 of the AUX 3/4 connector.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ExtTrigOutSignal (ViSession instrSession,
                                                     ViInt32 routing,
                                                     ViInt32 triggerSignal,
                                                     ViChar errorMessage[])
{
    ViString    lsRouting[] = {"PIN2","PIN3", "PIN4", "PIN5", VI_NULL};
    ViString    lsSignal[] = {"NONE","FCL", VI_NULL};
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    GET_WRT_BUF(instrSession);

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_22,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    CHECK_VI_INT32_RANGE(instrSession, routing, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, triggerSignal, 0, 1, RSCMU_ERROR_PARAMETER3, errorMessage);

    sprintf (wrtBuf, "TRIG:OUTP:%s:SIGN %s" , routing[lsRouting], triggerSignal[lsSignal]);

    RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));

}

/*===========================================================================*/
/* Function: Trigger Delay Enable
/* Purpose : This function qualifies whether the trigger signal at pins 2 to 5
/*           of the AUX 3 connector is delayed by the specified delay time
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ExtTrigOutDelayEnable (ViSession instrSession,
                                                          ViInt32 routing,
                                                          ViInt32 delayEnable,
                                                          ViChar  errorMessage[])
{
    ViString    lsRouting[] = {"PIN2","PIN3", "PIN4", "PIN5", VI_NULL};
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    GET_WRT_BUF(instrSession);

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_22,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    CHECK_VI_INT32_RANGE(instrSession, routing, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_BOOLEAN_RANGE(instrSession, delayEnable, RSCMU_ERROR_PARAMETER3, errorMessage);

    sprintf (wrtBuf, "TRIG:OUTP:%s:DEL:ENAB %s" , routing[lsRouting], mode_On_Off[delayEnable]);

    RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));


}

/*===========================================================================*/
/* Function: Trigger Delay Time
/* Purpose : This function sets a delay time
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ExtTrigOutDelayValue (ViSession instrSession,
                                                         ViInt32 delayValue,
                                                         ViChar errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_22,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_setViInt32(instrSession, "TRIG:OUTP:DEL:VAL",
                            delayValue, 0, 7,
                            RSCMU_ERROR_PARAMETER2));
}

/*
 *-----------------------------------------------------------------------------
 * CONNECTION CONTROL
 * ------------------
 *-----------------------------------------------------------------------------
 *    CALL SETUP AND CLEARDOWN
 *    The subsystem SIGNalling controls the call setup and cleardown
 *    from the CMU to the BTS and determines the signalling parameters.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Controlling the Signalling
/* Purpose : This function changes between the different signalling states
/*           of the CMU.
/*
/*           Available values:
/*           SRUN | Start synchronization
/*           SSTP | Stop synchronization
/*           CCH  | Switch to control channel
/*           TCH  | Switch to traffic channel
/*           LUP  | Location update
/*           SLUP | Stop location update
/*           RLUP | Retry location update
/*           MOC  | MOC
/*           SMOC | Stop MOC/MTC
/*           RMOC | Retry MOC
/*           SCR  | Stop call release
/*           CREL | Call release
/*
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ProcSignAct (ViSession instrSession,
                                                                       ViInt32   signallingState,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViUInt32    retCnt = 0;
  ViInt32     prevState;

  CHECK_VI_INT32_RANGE(instrSession, signallingState, 0, 13, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (signallingState)
  {
    case RSCMU300_SIGCONT_SRUN:
      if ((RSCMU300_Status = RSCMU300_GSM_Sig_SensSignStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU300_Status;
      // Be sured that CMU is UNS
      if (prevState != RSCMU300_SIGSTATE_UNS)
        return RSCMU300_K3G_errorMessage (instrSession, RSCMU300_ERROR_SIGN_STAT, errorMessage);
      // Start synchronization
      if ((RSCMU300_Status = RSCMU300_Query (instrSession, "PROC:SIGN:ACT SRUN", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
        return RSCMU300_Status;
    break;

    case RSCMU300_SIGCONT_SSTP:
      if ((RSCMU300_Status = RSCMU300_GSM_Sig_SensSignStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU300_Status;
      // Be sured that CMU is Synchronized on CCH or TCH or a call is established
      if ((prevState != RSCMU300_SIGSTATE_CCH) && (prevState != RSCMU300_SIGSTATE_TCH) && (prevState != RSCMU300_SIGSTATE_CEST))
        return RSCMU300_K3G_errorMessage (instrSession, RSCMU300_ERROR_SIGN_STAT, errorMessage);
      // Stop synchronization
      if ((RSCMU300_Status = RSCMU300_Query (instrSession, "PROC:SIGN:ACT SSTP", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
        return RSCMU300_Status;
    break;

    case RSCMU300_SIGCONT_CCH:
      if ((RSCMU300_Status = RSCMU300_GSM_Sig_SensSignStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU300_Status;
      // Be sured that CMU is on TCH test.
      if (prevState != RSCMU300_SIGSTATE_TCH)
        return RSCMU300_K3G_errorMessage (instrSession, RSCMU300_ERROR_SIGN_STAT, errorMessage);
      // Switch to Control Channel CCH
      if ((RSCMU300_Status = RSCMU300_Query (instrSession, "PROC:SIGN:ACT CCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
        return RSCMU300_Status;
    break;

    case RSCMU300_SIGCONT_TCH:
      if ((RSCMU300_Status = RSCMU300_GSM_Sig_SensSignStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU300_Status;
      // Be sured that CMU is on CCH test.
      if (prevState != RSCMU300_SIGSTATE_CCH)
        return RSCMU300_K3G_errorMessage (instrSession, RSCMU300_ERROR_SIGN_STAT, errorMessage);
      // Switch to Control Channel TCH
      if ((RSCMU300_Status = RSCMU300_Query (instrSession, "PROC:SIGN:ACT TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
        return RSCMU300_Status;
    break;

    case RSCMU300_SIGCONT_LUP:
      if ((RSCMU300_Status = RSCMU300_GSM_Sig_SensSignStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU300_Status;
      // Be sured that CMU is on CCH test.
      if (prevState != RSCMU300_SIGSTATE_CCH)
        return RSCMU300_K3G_errorMessage (instrSession, RSCMU300_ERROR_SIGN_STAT, errorMessage);
      // Go to Location update
      if ((RSCMU300_Status = RSCMU300_Query (instrSession, "PROC:SIGN:ACT LUP", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
        return RSCMU300_Status;
    break;

    case RSCMU300_SIGCONT_SLUP:
      if ((RSCMU300_Status = RSCMU300_GSM_Sig_SensSignStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU300_Status;
      // Be sured that CMU is in Location Update State or in Location Update Failed State.
      if ((prevState != RSCMU300_SIGSTATE_LUIP) && (prevState != RSCMU300_SIGSTATE_LUF))
        return RSCMU300_K3G_errorMessage (instrSession, RSCMU300_ERROR_SIGN_STAT, errorMessage);
      // Stop Location Update
      if ((RSCMU300_Status = RSCMU300_Query (instrSession, "PROC:SIGN:ACT SLUP", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
        return RSCMU300_Status;
    break;

    case RSCMU300_SIGCONT_RLUP:
      if ((RSCMU300_Status = RSCMU300_GSM_Sig_SensSignStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU300_Status;
      // Be sured that CMU is in Location Update Failed State.
      if (prevState != RSCMU300_SIGSTATE_LUF)
        return RSCMU300_K3G_errorMessage (instrSession, RSCMU300_ERROR_SIGN_STAT, errorMessage);
      // Stop Location Update
      if ((RSCMU300_Status = RSCMU300_Query (instrSession, "PROC:SIGN:ACT RLUP", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
        return RSCMU300_Status;
    break;

    case RSCMU300_SIGCONT_MOC:
      if ((RSCMU300_Status = RSCMU300_GSM_Sig_SensSignStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU300_Status;
      // Be sured that CMU is on CCH test.
      if (prevState != RSCMU300_SIGSTATE_CCH)
        return RSCMU300_K3G_errorMessage (instrSession, RSCMU300_ERROR_SIGN_STAT, errorMessage);
      // Go to MOC
      if ((RSCMU300_Status = RSCMU300_Query (instrSession, "PROC:SIGN:ACT MOC", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
        return RSCMU300_Status;
    break;

    case RSCMU300_SIGCONT_SMOC:
      if ((RSCMU300_Status = RSCMU300_GSM_Sig_SensSignStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU300_Status;
      // Be sured that CMU is in MOCP or MOCF or MTCP or MTCF state.
      if ((prevState != RSCMU300_SIGSTATE_MOCP) && (prevState != RSCMU300_SIGSTATE_MOCF) && (prevState != RSCMU300_SIGSTATE_MTCP) && (prevState != RSCMU300_SIGSTATE_MTCF))
        return RSCMU300_K3G_errorMessage (instrSession, RSCMU300_ERROR_SIGN_STAT, errorMessage);
      // Stop Location Update
      if ((RSCMU300_Status = RSCMU300_Query (instrSession, "PROC:SIGN:ACT SMOC", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
        return RSCMU300_Status;
    break;

    case RSCMU300_SIGCONT_RMOC:
      if ((RSCMU300_Status = RSCMU300_GSM_Sig_SensSignStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU300_Status;
      // Be sured that CMU is in MOCF or MTCF State.
      if ((prevState != RSCMU300_SIGSTATE_MOCF) && (prevState != RSCMU300_SIGSTATE_MOCF))
        return RSCMU300_K3G_errorMessage (instrSession, RSCMU300_ERROR_SIGN_STAT, errorMessage);
      // Stop Location Update
      if ((RSCMU300_Status = RSCMU300_Query (instrSession, "PROC:SIGN:ACT RMOC", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
        return RSCMU300_Status;
    break;

    case RSCMU300_SIGCONT_SCR:
      if ((RSCMU300_Status = RSCMU300_GSM_Sig_SensSignStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU300_Status;
      // Be sured that CMU is in CRIP or CRF State.
      if ((prevState != RSCMU300_SIGSTATE_CRIP) && (prevState != RSCMU300_SIGSTATE_CRF))
        return RSCMU300_K3G_errorMessage (instrSession, RSCMU300_ERROR_SIGN_STAT, errorMessage);
      // Stop Location Update
      if ((RSCMU300_Status = RSCMU300_Query (instrSession, "PROC:SIGN:ACT SCR", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
        return RSCMU300_Status;
    break;

    case RSCMU300_SIGCONT_CREL:
      if ((RSCMU300_Status = RSCMU300_GSM_Sig_SensSignStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU300_Status;
      // Be sured that CMU is in CEST or CRIP State.
      if ((prevState != RSCMU300_SIGSTATE_CRIP) && (prevState != RSCMU300_SIGSTATE_CEST))
        return RSCMU300_K3G_errorMessage (instrSession, RSCMU300_ERROR_SIGN_STAT, errorMessage);
      // Stop Location Update
      if ((RSCMU300_Status = RSCMU300_Query (instrSession, "PROC:SIGN:ACT CREL", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
        return RSCMU300_Status;
    break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sense Signalling State
/* Purpose : This function reads out the current signalling state of the
/*           CMU.
/*
/*           States:
/*           UNS  | Unsynchronized
/*           SIP  | synchronization in progress
/*           CCH  | synchronized, CCH Test
/*           TCH  | synchronized, TCH Test
/*           LUIP | Location update in progress
/*           LUF  | Location update failed
/*           CEST | Call established
/*           CREL | Call release
/*           CRIP | Call release in progress
/*           CRF  | Call release failed
/*           MOCP | MOC in progress
/*           MOCF | MOC failed
/*           MTCP | MTC in progress
/*           MTCF | MTC failed
/*
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensSignStat (ViSession instrSession,
                                                                        ViPInt32  SignallingState,
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SENS:SIGN:STAT?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Extract the CMU response:
  if (strncmp ("UNS", rdBuf, 3) == 0)
    *SignallingState = RSCMU300_SIGSTATE_UNS;
  else if (strncmp ("SIP", rdBuf, 3) == 0)
    *SignallingState = RSCMU300_SIGSTATE_SIP;
  else if (strncmp ("CCH", rdBuf, 3) == 0)
    *SignallingState = RSCMU300_SIGSTATE_CCH;
  else if (strncmp ("TCH", rdBuf, 3) == 0)
    *SignallingState = RSCMU300_SIGSTATE_TCH;
  else if (strncmp ("LUIP", rdBuf, 4) == 0)
    *SignallingState = RSCMU300_SIGSTATE_LUIP;
  else if (strncmp ("LUF", rdBuf, 3) == 0)
    *SignallingState = RSCMU300_SIGSTATE_LUF;
  else if (strncmp ("CEST", rdBuf, 4) == 0)
    *SignallingState = RSCMU300_SIGSTATE_CEST;
  else if (strncmp ("CREL", rdBuf, 4) == 0)
    *SignallingState = RSCMU300_SIGSTATE_CREL;
  else if (strncmp ("CRIP", rdBuf, 4) == 0)
    *SignallingState = RSCMU300_SIGSTATE_CRIP;
  else if (strncmp ("CRF", rdBuf, 3) == 0)
    *SignallingState = RSCMU300_SIGSTATE_CRF;
  else if (strncmp ("MOCP", rdBuf, 4) == 0)
    *SignallingState = RSCMU300_SIGSTATE_MOCP;
  else if (strncmp ("MOCF", rdBuf, 4) == 0)
    *SignallingState = RSCMU300_SIGSTATE_MOCF;
  else if (strncmp ("MTCP", rdBuf, 4) == 0)
    *SignallingState = RSCMU300_SIGSTATE_MTCP;
  else if (strncmp ("MTCF", rdBuf, 4) == 0)
    *SignallingState = RSCMU300_SIGSTATE_MTCF;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    BASE STATION SIGNAL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Synchronization mode
/* Purpose : This function determines the synchronization mode. Depending on
/*           the synchronization mode, either the control channel number or the
/*           training sequence code must be defined for the synchronization
/*           signal.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSignSynchMode (ViSession instrSession,
                                                                             ViInt32   mode,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    Strmode[] = {"NUBC","NUET"};

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, mode, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set the trigger threshold:
  sprintf (wrtBuf, "CONF:SIGN:SMOD %s", Strmode[mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Number of Control Channel CCH
/* Purpose : this function defines the Control Channel number (and thus the
/*           frequency) of the signal which the CMU trnasmits for synchronization.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSignCchChan (ViSession instrSession,
                                                                           ViInt32   ControlChannelNb,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct RSCMU300_SESSION_Globals  *p_globalvarSession;

  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU300_Status;

  // Check if the function is correctly used:
  // Which Current Function Group?
  if (strncmp ("\"GSM900BS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    if ((RSCMU300_invalidViInt32Range (ControlChannelNb, 0, 124)) && (RSCMU300_invalidViInt32Range (ControlChannelNb, 955, 1023)))
      return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1800BS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, ControlChannelNb, 512, 885, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1900BS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, ControlChannelNb, 512, 810, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM400BS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, ControlChannelNb, 259, 340, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM850BS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, ControlChannelNb, 128, 251, RSCMU_ERROR_PARAMETER2, errorMessage);
  }

  sprintf (wrtBuf, "CONF:BSS:CCH:CHAN %ld", ControlChannelNb);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Number of Traffic Channel
/* Purpose : After the call has been set up, this function determines the
/*           number (and thus the frequency) of the traffic channel for
/*           signals of the CMU.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSignTchChan (ViSession instrSession,
                                                                           ViInt32   TrafficChannelNb,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct RSCMU300_SESSION_Globals  *p_globalvarSession;

  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU300_Status;


  // Check if the function is correctly used:
  // Which Current Function Group?
  if (strncmp ("\"GSM900BS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    if ((RSCMU300_invalidViInt32Range (TrafficChannelNb, 0, 124)) && (RSCMU300_invalidViInt32Range (TrafficChannelNb, 955, 1023)))
      return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1800BS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, TrafficChannelNb, 512, 885, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1900BS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, TrafficChannelNb, 512, 810, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM400BS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, TrafficChannelNb, 259, 340, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM850BS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, TrafficChannelNb, 128, 251, RSCMU_ERROR_PARAMETER2, errorMessage);
  }

  sprintf (wrtBuf, "CONF:BSS:TCH:CHAN %ld", TrafficChannelNb);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sense Traffic Channel Number
/* Purpose : In the Call Established signalling state, this function queries
/*           the traffic channel number (and thus the frequency) for signals
/*           received by the CMU.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensSignTchChan (ViSession instrSession,
                                                                           ViPInt32  TrafficChannelNb,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_status = RSCMU300_Query (instrSession,"BSS:TCH:CHAN?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_status;

  // Extract the CMU_response
  sscanf (rdBuf, "%ld", TrafficChannelNb);
  return RSCMU300_status;
}

/*===========================================================================*/
/* Function: Set Timeslot
/* Purpose : After the call has been set up, this function selects the
/*           timeslot of the traffic channel for signals of the CMU.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSignTchTimeSlot (ViSession instrSession,
                                                                               ViInt32   TimeSlot,
                                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TimeSlot, RSCMU300_BTS_TIMESLOT_MIN, RSCMU300_BTS_TIMESLOT_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:BSS:TCH:TIM %ld", TimeSlot);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sense Timeslot
/* Purpose : In the Call Established signalling state, this function queries
/*           the traffic channel timeslot for signals received by the CMU.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensSignTchTimeSlot (ViSession instrSession,
                                                                               ViPInt32  Timeslot,
                                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_status = RSCMU300_Query (instrSession,"BSS:TCH:TIM?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_status;

  // Extract the CMU_response
  sscanf (rdBuf, "%ld", Timeslot);
  return RSCMU300_status;
}

/*===========================================================================*/
/* Function: Channel Type
/* Purpose : This function determines the speech coding and transmission rate
/*           in the traffic channel.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSignTchType (ViSession instrSession,
                                                                           ViInt32   channelType,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrSelection[] = {"FRAT","EFR","E432","HRAT","FD144","FD96","FD48","HD48","HD24","EGC1","CS1","CS2",
                  "CS3","CS4","MCS1","MCS2","MCS3","MCS4","MCS5","MCS6","MCS7","MCS8","MCS9","AMRH","AMRF"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channelType, 0, 24, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:BSS:TCH:CHTY %s", StrSelection[channelType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;

}

/*===========================================================================*/
/* Function: Selection of training sequence
/* Purpose : This function determines the training sequence in the BTS traffic
/*           channel signal. It is avaliable for wired synchronization only.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBssTseq (ViSession instrSession,
                                                ViInt32   sequence,
                                                ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViString    list[] = {"","GSM0","GSM1","GSM2","GSM3","GSM4","GSM5","GSM6","GSM7",VI_NULL};

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  RETMSG(RSCMU300_setEnum(instrSession, "CONF:BSS:TCH:TSEQ",
                         sequence, list,
                         RSCMU_ERROR_PARAMETER2));
}


/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT INFO
 *
 *    The subsystem INFO contains the commands for the frame timing and the
 *    network data. It corresponds to the Signaling Info table in the
 *    Signaling (Synchronized) tab.
 *
 *-----------------------------------------------------------------------------
 *    FRAME TIMING
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: get multiframe
/* Purpose : this function reads the multiframe currently transmitted by the
/*           base station
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InfoFrameMult (ViSession instrSession,
                                                                         ViPInt32  multiframe,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_status = RSCMU300_Query (instrSession,"INFO:FTIM:MULT?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_status;

  // Extract the CMU_response
  sscanf (rdBuf, "%ld", multiframe);
  return RSCMU300_status;
}

/*===========================================================================*/
/* Function: get superframe
/* Purpose:  This function reads the superframe currently transmitted by the
/*           base station.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InfoFrameSup (ViSession instrSession,
                                                                        ViPInt32  superframe,
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_status = RSCMU300_Query (instrSession,"INFO:FTIM:SUP?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_status;

  // Extract the CMU_response
  sscanf (rdBuf, "%ld", superframe);

  return RSCMU300_status;
}

/*
 *-----------------------------------------------------------------------------
 *    NETWORK DATA
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: get Mobile Country Code
/* Purpose:  this function reads the Mobile Country Code.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InfoNetwMcc (ViSession instrSession,
                                                                       ViPInt32  MobileCountryCode,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_status = RSCMU300_Query (instrSession,"INFO:NWD:MCC?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_status;

  // Extract the CMU_response
  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf, "%ld", MobileCountryCode);
  else
    return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_NAN, errorMessage);

  return RSCMU300_status;
}

/*===========================================================================*/
/* Function: get Mobile Network Code
/* Purpose:  this function reads the Mobile Network Code.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InfoNetwMnc (ViSession instrSession,
                                                                       ViPInt32  MobileNetworkCode,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_status = RSCMU300_Query (instrSession,"INFO:NWD:MNC?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_status;

  // Extract the CMU_response
  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf, "%ld", MobileNetworkCode);
  else
    return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_NAN, errorMessage);

  return RSCMU300_status;
}

/*===========================================================================*/
/* Function: get Location Area Code
/* Purpose:  this function reads the Location Area Code.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InfoNetwLocArea (ViSession instrSession,
                                                                           ViPUInt32 LocationAreaCode,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_status = RSCMU300_Query (instrSession,"INFO:NWD:LOC:AREA?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_status;

  // Extract the CMU_response
  sscanf (rdBuf, "%ld", LocationAreaCode);

  return RSCMU300_status;
}

/*===========================================================================*/
/* Function: get Base Station Identification Code
/* Purpose:  this function reads the Base Station Identification Code.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InfoNetwBsic (ViSession instrSession,
                                                                        ViPInt32  BTSIdentCode,
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_status = RSCMU300_Query (instrSession,"INFO:NWD:BSIC?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_status;

  //Get the status operation register event part
  sscanf (rdBuf, "%ld", BTSIdentCode);

  return RSCMU300_status;
}

/*===========================================================================*/
/* Function: get Location Update Flag
/* Purpose:  this function reads the Location Update Flag of the location
/*           area.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InfoNetwLocUpd (ViSession instrSession,
                                                                          ViPInt32  LocationUpdateFlag,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_status = RSCMU300_Query (instrSession,"INFO:NWD:LOC:UPD?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_status;

  // Extract the CMU response:
  if (strncmp ("NPER", rdBuf, 4) == 0)
    *LocationUpdateFlag = RSCMU300_NOTP;
  if (strncmp ("PERF", rdBuf, 4) == 0)
    *LocationUpdateFlag = RSCMU300_PERF;

  return RSCMU300_status;
}

/*
 *-----------------------------------------------------------------------------
 *    SACCH INFO
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: get requested transmission power level
/* Purpose:  this function reads the transmission power level as requested
/*           by the base station.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InfoSacchReqPow (ViSession instrSession,
                                                                           ViPInt32  PowerLevel,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_status = RSCMU300_Query (instrSession,"INFO:SACC:REQ:POW?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_status;

  // Extract the CMU response:
  sscanf (rdBuf, "%ld", PowerLevel);

  return RSCMU300_status;
}

/*===========================================================================*/
/* Function: get requested timing
/* Purpose:  this function reads the timing as requested by the base station.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InfoSacchReqTim (ViSession instrSession,
                                                                           ViPInt32  Timing,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_status = RSCMU300_Query (instrSession,"INFO:SACC:REQ:TIM?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_status;

  // Extract the CMU response:
  sscanf (rdBuf, "%ld", Timing);

  return RSCMU300_status;
}

/*
 *-----------------------------------------------------------------------------
 *    MSSIGNAL
 *
 *    The subsystem MSSignal controls the (re)transmission parameters and the
 *    signals of the CMU. It corresponds to the tabs MS Signal (for different
 *    signalling states, see command PROCedure:SIGNalling:ACTion) in the
 *    popup menu Connect. Control.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: defines the bit stream
/* Purpose:  this function defines the data transmitted in the Traffic
/*           Channel. In a Receiver Quality (BER) measurement one of the
/*           pseudo random sequences must be used.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssBitStr (ViSession instrSession,
                                                                         ViInt32   BitStream,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrBitStream[] = {"LOOP","ECHO","PR9","PR11","PR15","PR16","LBBB","HAND"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, BitStream, 0, 7, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MSS:BITS %s", StrBitStream[BitStream]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Configure Punctering Scheme EGPRS
/* Purpose : This function selects the punctering schemes for EGPRS Coding Schemes
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBssPScheme (ViSession instrSession,
                                                   ViInt32 MCS1, ViInt32 MCS2,
                                                   ViInt32 MCS3, ViInt32 MCS4,
                                                   ViInt32 MCS5, ViInt32 MCS6,
                                                   ViInt32 MCS71st,
                                                   ViInt32 MCS72nd,
                                                   ViInt32 MCS81st,
                                                   ViInt32 MCS82nd,
                                                   ViInt32 MCS91st,
                                                   ViInt32 MCS92nd,
                                                   ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViString    list[] = {"P1","P2","P3", VI_NULL};
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, MCS1, RSCMU_P1, RSCMU_P2, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, MCS2, RSCMU_P1, RSCMU_P2, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, MCS3, RSCMU_P1, RSCMU_P3, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, MCS4, RSCMU_P1, RSCMU_P3, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, MCS5, RSCMU_P1, RSCMU_P2, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, MCS6, RSCMU_P1, RSCMU_P2, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, MCS71st, RSCMU_P1, RSCMU_P3, RSCMU_ERROR_PARAMETER9, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, MCS72nd, RSCMU_P1, RSCMU_P3, RSCMU_ERROR_PARAMETER10, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, MCS81st, RSCMU_P1, RSCMU_P3, RSCMU_ERROR_PARAMETER11, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, MCS82nd, RSCMU_P1, RSCMU_P3, RSCMU_ERROR_PARAMETER12, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, MCS91st, RSCMU_P1, RSCMU_P3, RSCMU_ERROR_PARAMETER13, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, MCS92nd, RSCMU_P1, RSCMU_P3, RSCMU_ERROR_PARAMETER14, errorMessage);

  sprintf (wrtBuf, "CONFigure:BSSignal:TCH:PSCHeme %s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s"  , MCS1[list]
                                                                                         , MCS2[list]
                                                                                         , MCS3[list]
                                                                                         , MCS4[list]
                                                                                         , MCS5[list]
                                                                                         , MCS6[list]
                                                                                         , MCS71st[list]
                                                                                         , MCS72nd[list]
                                                                                         , MCS81st[list]
                                                                                         , MCS82nd[list]
                                                                                         , MCS91st[list]
                                                                                         , MCS92nd[list]);

  RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Sets the transmit timing delay in 1/4 Bit units
/* Purpose:  this function sets the delay time between the start of the
/*           timeslot and the actual transmission of the burst.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssTxTim (ViSession instrSession,
                                                                        ViInt32   Delay,
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Delay, RSCMU300_TX_DELAY_MIN, RSCMU300_TX_DELAY_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MSS:TXT %ld", Delay);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Speech Data Rearrangement
/* Purpose:  configures the speech codec in the TX and RX path
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssSDRearrange (ViSession instrSession,
                                                       ViInt32   enable,
                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_22,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  RETMSG(RSCMU300_setEnum(instrSession, "CONFigure:MSSignal:SDRearrange",
                         enable, mode_On_Off,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: MSS level in used timeslot
/* Purpose:  This function determines the RF level in the used timeslot of
/*           the CMU traffic and control channel signal.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssLevUtim (ViSession instrSession,
                                                                          ViReal64  LevelUsed,
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, LevelUsed, RSCMU300_UTS_LEVEL_MIN, RSCMU300_UTS_LEVEL_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MSS:LEV:UTIM %.12f", LevelUsed);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: MSS level in unused timeslot
/* Purpose:  This function determines the RF level in the unused timeslots
/*           relative to the used timeslot level of the CMU traffic and
/*           control channel signal.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssLevUnt (ViSession instrSession,
                                                                         ViReal64  LevelUnused,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, LevelUnused, RSCMU300_UTS_LEVEL_MIN, RSCMU300_UTS_LEVEL_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MSS:LEV:UNT %.12f", LevelUnused);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}



/*===========================================================================*/
/* Function: Set Number of downlink Channel
/* Purpose : This command switches the duplex spacing between uplink
/*           and downlink frequencies on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssDuplSpaceEnable (ViSession instrSession,
                                                           ViBoolean enable,
                                                           ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  RETMSG(RSCMU300_setEnum(instrSession, "CONF:MSS:DSP:NORM:ENAB",
                         enable, mode_On_Off,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Set Number of downlink Channel
/* Purpose : This command sets the downlink channel used by the CMU if the
/*           duplex spacing  is switched off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssDlChan (ViSession instrSession,
                                                  ViInt32   downlinkChannelNb,
                                                  ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  struct RSCMU300_SESSION_Globals  *p_globalvarSession;

  // Queries the specified attribute:
  CHECKRET(viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession));

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  // Which Current Function Group?
  if (strncmp ("\"GSM900BS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    if ((RSCMU300_invalidViInt32Range (downlinkChannelNb, 0, 124)) && (RSCMU300_invalidViInt32Range (downlinkChannelNb, 955, 1023)))
      return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1800BS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, downlinkChannelNb, 512, 885, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1900BS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, downlinkChannelNb, 512, 810, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM400BS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, downlinkChannelNb, 259, 340, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM850BS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, downlinkChannelNb, 128, 251, RSCMU_ERROR_PARAMETER2, errorMessage);
  }

  sprintf (wrtBuf, "CONF:MSS:DSP:CHAN %ld", downlinkChannelNb);
  RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/*              Forced Hopping
/*  The subsystem MSSignal:FHOPPing defines the forced hopping parameters of the CMU.
/*  It corresponds to the Forced Hopping section in the MS Signal tab of the Connection Control menu.
/*===========================================================================*/


/*===========================================================================*/
/* Function: Enable Forced Hopping
/* Purpose : This function switches forced hopping of the CMU in the TCH Test state on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssForcHoppEnable (ViSession instrSession,
                                                          ViBoolean enable,
                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  RETMSG(RSCMU300_setEnum(instrSession, "CONF:MSS:FHOP:ENAB",
                         enable, mode_On_Off,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: MAIO
/* Purpose : This function defines the MAIO that the CMU uses to calculate the
/*           radio frequency channel for each TDMA frame.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssForcHoppMaio (ViSession instrSession,
                                                        ViInt32   maio,
                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  RETMSG(RSCMU300_setViInt32(instrSession,
                            "CONF:MSS:FHOP:MAIO",
                            maio,
                            0, 63,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Set Hopping Sequence
/* Purpose : This function define the hopping sequence to be used for forced frequency hopping.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssForcHoppSeq (ViSession instrSession,
                                                        ViChar   channels[],
                                                        ViChar   errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      *StrChan;
  ViChar      *DataValue;
  ViInt32     iChannel;
  ViInt32     i;
  struct      RSCMU300_SESSION_Globals  *p_globalvarSession;
  GET_BUFS(instrSession);

  // Queries the specified attribute:
  CHECKRET(viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession));

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Translates characters to uppercase:
  for (i=0; i<strlen (channels); i++)
    channels[i] = toupper(channels[i]);

  StrChan = (char *) malloc(i+1);
 // StrChan = (char *) malloc(sizeof(channels));
  strcpy(StrChan, channels);
  DataValue = strtok (channels, ",");

  if (strncmp ("\"GSM400BS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    while (DataValue)
    {
      //Compares each channel with the GSM400 channel range
      if(!strstr((DataValue), "OFF"))
      {
        iChannel = atoi(DataValue);
        if((iChannel < 259) || (iChannel > 340))
        {
          free(StrChan);
          return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);
        }
      }
      DataValue = strtok (NULL, ",");
    }
  }
  else if (strncmp ("\"GSM850BS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    while (DataValue)
    {
      //Compares each channel with the GSM850 channel range
      if(!strstr((DataValue), "OFF"))
      {
        iChannel = atoi(DataValue);
        if((iChannel < 128) || (iChannel > 251))
        {
          free(StrChan);
          return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);
        }
      }
      DataValue = strtok (NULL, ",");
    }
  }
  // Which Current Fonction Group?
  else if (strncmp ("\"GSM900BS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    while (DataValue)
    {
      //Compares each channel with the GSM900 channel range
      if(!strstr((DataValue), "OFF"))
      {
        iChannel = atoi(DataValue);
        if(((iChannel > 124) && (iChannel < 955)) || (iChannel > 1024))
        {
          free (StrChan);
          return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);
        }
      }
      DataValue = strtok (NULL, ",");
    }
  }

  else if (strncmp ("\"GSM1800BS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    while (DataValue)
    {
      //Compares each channel with the GSM1800 channel range
      if(!strstr((DataValue), "OFF"))
      {
        iChannel = atoi(DataValue);
        if((iChannel < 512) || (iChannel > 885))
        {
          free(StrChan);
          return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);
        }
      }
      DataValue = strtok (NULL, ",");
    }
  }

  else if (strncmp ("\"GSM1900BS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    while (DataValue)
    {
      //Compares each channel with the GSM1900 channel range
      if(!strstr((DataValue), "OFF"))
      {
        iChannel = atoi(DataValue);
        if((iChannel < 512) || (iChannel > 810))
        {
          free(StrChan);
          return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);
        }
      }
      DataValue = strtok (NULL, ",");
    }
  }

  // Configue the Hopping Sequence
  sprintf(wrtBuf, "CONF:MSS:FHOP:A %s", StrChan);
  free(StrChan);
  RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}



/*===========================================================================*/
/* Function: Enable UL CCH Generator
/* Purpose : This function switches uplink Generator of the CMU on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssUlCchBerEnable (ViSession instrSession,
                                                          ViBoolean enable,
                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_08,RSCMU_ERROR_FW_VERSION_3_08));

  RETMSG(RSCMU300_setEnum(instrSession, "CONF:MSS:ULCB:ENAB",
                         enable, mode_On_Off,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Channel Type UL CCH Generator
/* Purpose : This function determines the Channel Type for uplink CCH Generator.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssUlCchBerChType (ViSession instrSession,
                                                          ViInt32   type,
                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViString    list[] = {"SDC4","SDC8","FACF","SAC",VI_NULL};

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_08,RSCMU_ERROR_FW_VERSION_3_08));

  RETMSG(RSCMU300_setEnum(instrSession, "CONF:MSS:ULCB:CCH:CHTY",
                         type, list,
                         RSCMU_ERROR_PARAMETER2));



}

/*===========================================================================*/
/* Function: Bit Steam UL CCH Generator
/* Purpose : This function determines the Bit Stream for uplink CCH Generator
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssUlCchBerBitStr (ViSession instrSession,
                                                          ViInt32   bitStream,
                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViString    list[] = {"","","PR9","PR11","PR15","PR16",VI_NULL};

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_08,RSCMU_ERROR_FW_VERSION_3_08));

  RETMSG(RSCMU300_setEnum(instrSession, "CONF:MSS:ULCB:CCH:BITS",
                         bitStream, list,
                         RSCMU_ERROR_PARAMETER2));
}


/*
 *-----------------------------------------------------------------------------
 *    NETWORK
 *
 *    The subsystem NETWork determines the parameters of the radio network and
 *    the existing radio link. The subsystem corresponds to the Network tab in
 *    the Connect. Control menu.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: sets the default settings
/* Purpose:  If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwDef (ViSession instrSession,
                                                                       ViBoolean DefaultValues,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, DefaultValues, 1, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DEF:NETW %s", mode_On_Off[DefaultValues]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    NETWORK[:MS] (Mobile settings)
 *
 *    The subsystem NETWork[:MS] defines the mobile parameters. The subsystem
 *    corresponds to the table field Mobile Settings in the popup menu Network.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: sets the alerting time at the CMU
/* Purpose:  This function sets the time until the CMU accepts a call from
/*           the mobile station (equivalent to the time after which a mobile
/*           is picked up).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwMsAutoHookOff (ViSession instrSession,
                                                                                 ViReal64  Time,
                                                                                 ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Time, RSCMU300_ALERT_TIME_MIN, RSCMU300_ALERT_TIME_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:AUT %.12f", Time);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function:
/* Purpose:
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwMsAutoTimingAdj (ViSession instrSession,
                                                            ViInt32   enable,
                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_25,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  RETMSG(RSCMU300_setEnum(instrSession, "CONFigure:NETWork:MS:ATADjust",
                         enable, mode_On_Off,
                         RSCMU_ERROR_PARAMETER2));
}

/*
 *-----------------------------------------------------------------------------
 *     NETWork:SUBScriberid
 *
 *     The subsystem NETWork:SUBScriberid gives information on the identity
 *     of the mobile. The subsystem corresponds to the table field Network
 *     Subscriber Identity in the Network tab.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: sets the PIN of the SIM card
/* Purpose:  This function determines the PIN of the SIM card.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwSubsScpin (ViSession instrSession,
                                                                             ViInt32   Scpin,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Scpin, RSCMU300_PIN_MIN, RSCMU300_PIN_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:SUBS:SCP \"%ld\"", Scpin);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: sets the International Mobile Station Equipment Identity
/* Purpose:  This function determines the international mobile station
/*           equipment identity (IMEI).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwSubsImei (ViSession instrSession,
                                                                            ViChar    TAC[],
                                                                            ViChar    FAC[],
                                                                            ViChar    SNR[],
                                                                            ViChar    SVN[],
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      IMEI[20] = "";

  // Check if the function is correctly used:
  if ((strlen (TAC) < strlen (RSCMU300_IMEI_TAC_MIN)) || (strlen (TAC) > strlen (RSCMU300_IMEI_TAC_MAX)))
    return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);

  if ((strlen (FAC) < strlen (RSCMU300_IMEI_FAC_MIN)) || (strlen (FAC) > strlen (RSCMU300_IMEI_FAC_MAX)))
    return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER3, errorMessage);

  if ((strlen (SNR) < strlen (RSCMU300_IMEI_SNR_MIN)) || (strlen (SNR) > strlen (RSCMU300_IMEI_SNR_MAX)))
    return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER4, errorMessage);

  if ((strlen (SVN) < strlen (RSCMU300_IMEI_SVN_MIN)) || (strlen (SVN) > strlen (RSCMU300_IMEI_SVN_MAX)))
    return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER5, errorMessage);

  //Makes the 15-digit IMEI (format xxxxxx.xx.xxxxxx.x)
  strcpy (IMEI, TAC);
  strcat (IMEI, ".");
  strcat (IMEI, FAC);
  strcat (IMEI, ".");
  strcat (IMEI, SNR);
  strcat (IMEI, ".");
  strcat (IMEI, SVN);

  sprintf (wrtBuf, "CONF:NETW:SUBS:IMEI \"%s\"", IMEI);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: sets the International Mobile Subscriber Identity
/* Purpose:  This function determines the international mobile subscriber
/*           identity (IMSI).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwSubsImsi (ViSession instrSession,
                                                                            ViChar    MNC[],
                                                                            ViChar    MCC[],
                                                                            ViChar    MSIN[],
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals  *p_globalvarSession;
  ViChar      IMSI[18] = "";

  // Get the Globals
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU300_Status;

  // Check if the function is correctly used:
  if ((strlen (MNC) < strlen (RSCMU300_IMSI_MNC_MIN)) || (strlen (MNC) > strlen (RSCMU300_IMSI_MNC_MAX)))
    return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (strncmp ("\"GSM900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    if ((strlen (MCC) < strlen (RSCMU300_IMSI_MCC_MIN)) || (strlen (MCC) > strlen (RSCMU300_IMSI_MCC_MAX)))
      return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER3, errorMessage);

    if ((strlen (MSIN) < strlen (RSCMU300_IMSI_MSIN_MIN)) || (strlen (MSIN) > strlen (RSCMU300_IMSI_MSIN_MAX)))
      return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER4, errorMessage);
  }
  else if (strncmp ("\"GSM1800MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    if ((strlen (MCC) < strlen (RSCMU300_IMSI_MCC_MIN)) || (strlen (MCC) > strlen (RSCMU300_IMSI_MCC_MAX)))
      return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER3, errorMessage);

    if ((strlen (MSIN) < strlen (RSCMU300_IMSI_MSIN_MIN)) || (strlen (MSIN) > strlen (RSCMU300_IMSI_MSIN_MAX)))
      return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER4, errorMessage);
  }
  else if (strncmp ("\"GSM1900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    if ((strlen (MCC) < strlen (RSCMU300_IMSI_MCC_GSM1900_MIN)) || (strlen (MCC) > strlen (RSCMU300_IMSI_MCC_GSM1900_MAX)))
      return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER3, errorMessage);

    if ((strlen (MSIN) < strlen (RSCMU300_IMSI_MSIN_GSM1900_MIN)) || (strlen (MSIN) > strlen (RSCMU300_IMSI_MSIN_GSM1900_MAX)))
      return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER4, errorMessage);
  }
  else if (strncmp ("\"GSM400MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    if ((strlen (MCC) < strlen (RSCMU300_IMSI_MCC_MIN)) || (strlen (MCC) > strlen (RSCMU300_IMSI_MCC_MAX)))
      return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER3, errorMessage);

    if ((strlen (MSIN) < strlen (RSCMU300_IMSI_MSIN_MIN)) || (strlen (MSIN) > strlen (RSCMU300_IMSI_MSIN_MAX)))
      return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER4, errorMessage);
  }
  else if (strncmp ("\"GSM850MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    if ((strlen (MCC) < strlen (RSCMU300_IMSI_MCC_MIN)) || (strlen (MCC) > strlen (RSCMU300_IMSI_MCC_MAX)))
      return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER3, errorMessage);

    if ((strlen (MSIN) < strlen (RSCMU300_IMSI_MSIN_MIN)) || (strlen (MSIN) > strlen (RSCMU300_IMSI_MSIN_MAX)))
      return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER4, errorMessage);
  }

  //Makes the IMSI (format depending on the GSM band)
  strcpy (IMSI, MNC);
  strcat (IMSI, ".");
  strcat (IMSI, MCC);
  strcat (IMSI, ".");
  strcat (IMSI, MSIN);

  sprintf (wrtBuf, "CONF:NETW:SUBS:IMSI \"%s\"", IMSI);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: sets the dialled number
/* Purpose:  This function determines the dialled number
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwSubsDnum (ViSession instrSession,
                                                                            ViChar    Number[],
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  if (strlen (Number) > RSCMU300_DNUM_MAX)
    return RSCMU300_K3G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:SUBS:DNUM \"%s\"", Number);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *     NETWork:MREPort (Measurement Report)
 *
 *     The subsystem NETWork:MREPort determines parameters for the received
 *     signal. The subsystem corresponds to the table field Measurement Report
 *     in the Network tab.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: measurement report mode
/* Purpose:  This command selects the mode of configuring the measurement
/*           report.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwMrepMode (ViSession instrSession,
                                                                            ViInt32   Mode,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    strMrepMode[] = {"MAN","RXQ","AUT"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:MREP:MODE %s", strMrepMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: RX level for manual measurement report
/* Purpose:  This function determines the RX Level which is transmitted to
/*           the base station in MANual mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwMrepManRxlev (ViSession instrSession,
                                                                                ViInt32   RXLevel,
                                                                                ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, RXLevel, 0, 63, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:MREP:MAN:RXL %ld", RXLevel);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: RX level for manual measurement report
/* Purpose:  This function determines the RX Level which is transmitted to
/*           the base station in MANual mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwMrepManRxQ (ViSession instrSession,
                                                                              ViInt32   RXQuality,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, RXQuality, 0, 7, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:MREP:MAN:RXQU %ld", RXQuality);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: RX Level for auto RX Quality measurement report
/* Purpose:  This function determines the RX Level which is transmitted to
/*           the base station in RXQualauto mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwMrepAutRxLev (ViSession instrSession,
                                                                                ViInt32   RXLevel,
                                                                                ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, RXLevel, 0, 63, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:MREP:AUTO:RXL %ld", RXLevel);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Offset added to the measured RX Level
/* Purpose:  This function determines the Offset which is added to the measured
/*           RX Level in AUTomatic mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwMrepAutOffset (ViSession instrSession,
                                                                                 ViInt32   Offset,
                                                                                 ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Offset, RSCMU300_RXLEV_OFFSET_MIN, RSCMU300_RXLEV_OFFSET_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:MREP:AUTO:RXOF %ld", Offset);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: RX Quality at RX Level
/* Purpose:  This function defines the RX Quality at RX Level table values
/*           which is used in RXQUalauto and AUTomatic mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwMrepAutRxLQ (ViSession instrSession,
                                                                               ViInt32   RXLevel1,
                                                                               ViInt32   RXLevel2,
                                                                               ViInt32   RXLevel3,
                                                                               ViInt32   RXLevel4,
                                                                               ViInt32   RXLevel5,
                                                                               ViInt32   RXLevel6,
                                                                               ViInt32   RXLevel7,
                                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, RXLevel1, 0, 63, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, RXLevel2, 0, 63, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, RXLevel3, 0, 63, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, RXLevel4, 0, 63, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, RXLevel5, 0, 63, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, RXLevel6, 0, 63, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, RXLevel7, 0, 63, RSCMU_ERROR_PARAMETER8, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:MREP:AUTO:RXLQ %ld,%ld,%ld,%ld,%ld,%ld,%ld", RXLevel1
                                                                  , RXLevel2
                                                                  , RXLevel3
                                                                  , RXLevel4
                                                                  , RXLevel5
                                                                  , RXLevel6
                                                                  , RXLevel7);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      INPUT AND OUTPUT CONNECTORS
 *      The subsystem IOConnector contains the commands for
 *      configuration of the input and output connectors.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set INPUT Connector
/* Purpose : This function determines the connector to be used for
/*           incoming RF signals.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Inp (ViSession instrSession,
                                                               ViInt32   Input,
                                                               ViChar    _VI_FAR errorMessage[])
{
  return RSCMU300_GSM_NSig_Inp (instrSession, Input, errorMessage);
}

/*===========================================================================*/
/* Function: Set OUTPUT Connector
/* Purpose : This function determines the connector to be used for outcoming
/*           RF signals.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Outp (ViSession instrSession,
                                                                ViInt32   Output,
                                                                ViChar    _VI_FAR errorMessage[])
{
  return RSCMU300_GSM_NSig_Outp (instrSession,  Output, errorMessage);
}

/*===========================================================================*/
/* Function: Set Ext. Attenuation at Output
/* Purpose : This function assigns an external attenuation value to one
/*           of the outputs defined.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SourCorrLossOutp (ViSession instrSession,
                                                                            ViInt32   OutputConnector,
                                                                            ViReal64  externalAttenuation,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  return RSCMU300_GSM_NSig_SourCorrLossOutp (instrSession, OutputConnector, externalAttenuation, errorMessage);
}

/*===========================================================================*/
/* Function: Sense Ext. Attenuation at Input
/* Purpose : This function queries the external attenuation value at one
/*           of the inputs defined.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensCorrLossInp (ViSession instrSession,
                                                                           ViInt32   InputConnector,
                                                                           ViReal64  externalAttenuation,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  return RSCMU300_GSM_NSig_SensCorrLossInp(instrSession, InputConnector, externalAttenuation, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      SYNCHRONISATION
 *      Subsystem REFerence (Synchronization)
 *      The subsystem REFerence contains the commands for setting a system clock
 *      specific to the network. This frequency is set in the index card Synch.
 *      in the popup menu Connect. Control.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Switching on/off and setting the system clock
/* Purpose : This commands switches the system clock specific to the
/*           network at the REF OUT 2 connector on or off, and determines
/*           the system clock frequency applied to REF OUT 2.
/*           The frequency entered is internally rounded to one of a
/*           discrete values defined in the operating manual.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SourDmClock (ViSession instrSession,
                                                                       ViBoolean Mode,
                                                                       ViReal64  Frequency,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  return RSCMU300_GSM_NSig_SourDmClock (instrSession, Mode, Frequency, errorMessage);
}


/*
 *-----------------------------------------------------------------------------
 *      EXTernal[:TRIGger] (External Trigger Input)
 *
 *      The subsystem EXTernal[:TRIGger] configures the External Trigger
 *      synchronization mode (see command CONFigure:SIGNalling:SMODe NUEtrg on
 *      page 6.76; the EXTernal[:TRIGger] commands are not effective in the
 *      other synchronization modes). The subsystem corresponds to the External
 *      Trigger Input panel of the Synch. tab in the popup menu Connect. Control.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: external trigger input polarity
/* Purpose : This function defines the polarity of the external trigger
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SourExtTrigPol (ViSession instrSession,
                                                                          ViInt32   Polarity,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrPolarity[] = {"RIS","FALL"};

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, Polarity, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set the trigger threshold:
  sprintf (wrtBuf, "CONF:EXT:POL %s", StrPolarity[Polarity]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: external trigger delay time for TCH signal (slots)
/* Purpose : This function defines a number of timeslots by which the TX TCH
/*           signal of the CMU is shifted relative to the external trigger
/*           signal.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SourExtTrigSlotOffset (ViSession instrSession,
                                                                                 ViInt32   SlotOffset,
                                                                                 ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, SlotOffset, RSCMU300_SLOTOFFSET_MIN, RSCMU300_SLOTOFFSET_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:EXT:SOFF %ld", SlotOffset);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: external trigger delay time for TCH signal (1/4 bit)
/* Purpose : This function defines a delay time in  bit units by which the
/*           TX TCH signal of the CMU is shifted relative to the external
/*           trigger signal.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SourExtTrigBitDelay (ViSession instrSession,
                                                                               ViInt32   DelayTime,
                                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, DelayTime, RSCMU300_BITDELAY_MIN, RSCMU300_BITDELAY_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:EXT:BITD %ld", DelayTime);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT WPOWER
 *
 *    The subsystem WPOWer contains the commands for measuring the
 *    wide-band power of the signal sent by the base tranceiver station.
 *    It corresponds to the softkey Power of the tab Signaling
 *    in the menu group Connect. Control.
 *-----------------------------------------------------------------------------
 *    CONFIGURATION CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfWpowContRep (ViSession instrSession,
                                                                           ViInt32   Repetition,
                                                                           ViInt32   StopCondition,
                                                                           ViInt32   StepMode,
                                                                           ViChar    _VI_FAR errorMessage[])
{
    return RSCMU300_GSM_NSig_ConfWpowContRep (instrSession, Repetition, StopCondition, StepMode, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfWpowContRepSt (ViSession instrSession,
                                                                             ViInt32   NbRepetition,
                                                                             ViInt32   StopCondition,
                                                                             ViInt32   StepMode,
                                                                             ViChar    _VI_FAR errorMessage[])
{
    return RSCMU300_GSM_NSig_ConfWpowContRepSt (instrSession, NbRepetition, StopCondition, StepMode, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Init Measurements
/* Purpose : This function start the measurement,
/*           setting it to the status beyond.
/*           RUN        Start measurement without waiting
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitWpow (ViSession instrSession,
                                                                    ViChar    _VI_FAR errorMessage[])
{
    return RSCMU300_GSM_NSig_InitWpow (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Abort Measurements
/* Purpose : This function abort running signal-power measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborWpow (ViSession instrSession,
                                                                    ViChar    _VI_FAR errorMessage[])
{
    return RSCMU300_GSM_NSig_AborWpow (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Stop Measurements
/* Purpose : This function stop measurement after current statistic cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopWpow (ViSession instrSession,
                                                                    ViChar    _VI_FAR errorMessage[])
{
    return RSCMU300_GSM_NSig_StopWpow (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Run Next Measurement Step
/* Purpose : This function runs next signal-power measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContWpow (ViSession instrSession,
                                                                    ViChar    _VI_FAR errorMessage[])
{
    return RSCMU300_GSM_NSig_ContWpow (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch measurement status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcWpowSt (ViSession instrSession,
                                                                      ViPInt32  MeasStatus,
                                                                      ViPInt32  CurrentStatCycleCount,
                                                                      ViChar    _VI_FAR errorMessage[])
{
    return RSCMU300_GSM_NSig_FetcWpowSt (instrSession, MeasStatus, CurrentStatCycleCount, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfWpowErep (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViChar    _VI_FAR errorMessage[])
{
    return RSCMU300_GSM_NSig_ConfWpowErep (instrSession, Mode, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    RESULTS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Meas. Peak Burst Power
/* Purpose : This function starts the measurement of the maximum burst
/*           power of the signals sent by the BTS (peak burst power)
/*           and outputs the result.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadWpow (ViSession instrSession,
                                                                    ViPReal64 MaxBurstPower,
                                                                    ViChar    _VI_FAR errorMessage[])
{
    return RSCMU300_GSM_NSig_ReadWpow (instrSession, MaxBurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Meas. Peak Burst Power
/* Purpose : This function starts the measurement of the maximum burst
/*           power of the signals sent by the BTS (peak burst power)
/*           and outputs the result.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcWpow (ViSession instrSession,
                                                                    ViPReal64 MaxBurstPower,
                                                                    ViChar    _VI_FAR errorMessage[])
{
    return RSCMU300_GSM_NSig_FetcWpow (instrSession, MaxBurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Meas. Peak Burst Power
/* Purpose : This function starts the measurement of the maximum burst
/*           power of the signals sent by the BTS (peak burst power)
/*           and outputs the result.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampWpow (ViSession instrSession,
                                                                    ViPReal64 MaxBurstPower,
                                                                    ViChar    _VI_FAR errorMessage[])
{
    return RSCMU300_GSM_NSig_SampWpow (instrSession, MaxBurstPower, errorMessage);
}





/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT POWER/T MULTISLOT
 *
 * The subsystem POWer:MSLot measures the MS output carrier power versus time
 * in up to 4 consecutive timeslots. The subsystem corresponds to the
 * measurement menu Power, application P/t Multislot, and the associated popup
 * menu Power Configuration.
 * Note: The POWer:MSLot measurement can not be carried out with a Free Run
 * trigger (TRIG-ger[:SEQuence]:SOURce FRUN).
 * ----------------------------------------------------------------------------
 *      CONTROL OF POWER MEASUREMENT
 *      This subsystem contains the functions for general control of the
 *      power measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start Measurements
/* Purpose : This function starts measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitPowMsl (ViSession instrSession,
                                               ViInt32   channel,
                                               ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "INIT:POW:MSL:%s", Channel_Type[channel]);
  RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));

}

/*===========================================================================*/
/* Function: Abort Measurements
/* Purpose : This function abort measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborPowMsl (ViSession instrSession,
                                               ViInt32   channel,
                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "ABOR:POW:MSL:%s", Channel_Type[channel]);
  RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Stop Measurements
/* Purpose : This function stops measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopPowMsl (ViSession instrSession,
                                               ViInt32   channel,
                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "STOP:POW:MSL:%s", Channel_Type[channel]);
  RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Continue Measurements
/* Purpose : This function continues measurement after stop,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContPowMsl (ViSession instrSession,
                                               ViInt32   channel,
                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONT:POW:MSL:%s", Channel_Type[channel]);
  RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Measurement Status
/* Purpose : This function returns the status of the current Power/t multislot
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPowMslStat (ViSession  instrSession,
                                                   ViInt32    channel,
                                                   ViInt32    *MeasurementStatus,
                                                   ViInt32    *CountingNo,
                                                   ViInt32    *StatisticNo,
                                                   ViChar     errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar*     str;
  GET_BUFS(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

 // Fetch the status of the measurement:
  sprintf (wrtBuf, "FETC:POW:MSL:%s:STAT?", Channel_Type[channel]);
  CHECKRETMSG(RSCMU300_getViString(instrSession, wrtBuf, rdBuf, RD_BUFFER_SIZE,0));
  if (!(str = strtok(rdBuf,",")))
      return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_INTERPRETING_RESPONSE, errorMessage);

  // Get the status of the measurement:
  CHECKRET(RSCMU300_getIndexFromString(instrSession, rdBuf, measurementStatusArr, MeasurementStatus));

  if (!(str = strtok(NULL,",")))
      return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_INTERPRETING_RESPONSE, errorMessage);

  if(!sscanf(str,"%ld",CountingNo))
      *CountingNo = RSCMU300_NONE;

  if (!(str = strtok(NULL,",")))
      return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_INTERPRETING_RESPONSE, errorMessage);
  if (strcmp(str,"NONE") != 0)
      sscanf(str,"%ld",StatisticNo);
  else
      *StatisticNo = RSCMU300_NONE;

  return RSCMU300_Status;
}


/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowMslErep (ViSession  instrSession,
                                                   ViInt32    channel,
                                                   ViInt32    Report,
                                                   ViChar     errorMessage[])
{
 ViStatus    RSCMU300_Status = VI_SUCCESS;
 GET_WRT_BUF(instrSession);

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 // Check if the function is correctly used:
 CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
 CHECK_VI_INT32_RANGE(instrSession, Report, 0, 3, RSCMU_ERROR_PARAMETER3, errorMessage);

 sprintf (wrtBuf, "CONF:POW:MSL:%s:EREP %s", Channel_Type[channel], StrErep[Report]);
 RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*
 *-----------------------------------------------------------------------------
 *      CONFIGURATION CONTROL
 *-----------------------------------------------------------------------------
 */

/*===========================================================================*/
/* Function: Set Scope of Measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowMslCont (ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32   MeasuredValuesType,
                                                   ViInt32   NbBurst,
                                                   ViChar    errorMessage[])
{
 ViStatus    RSCMU300_Status = VI_SUCCESS;
 GET_WRT_BUF(instrSession);

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 // Check if the function is correctly used:
 CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
 CHECK_VI_INT32_RANGE(instrSession, MeasuredValuesType,0,1, RSCMU_ERROR_PARAMETER3, errorMessage);
 CHECK_VI_INT32_RANGE(instrSession, NbBurst, 1, 1000, RSCMU_ERROR_PARAMETER4, errorMessage);

 sprintf(wrtBuf,"CONF:POW:MSL:%s:CONT %s,%ld", Channel_Type[channel], mode_ScopeMeas[MeasuredValuesType], NbBurst);
 RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}


/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowMslContRep (ViSession  instrSession,
                                                      ViInt32    channel,
                                                      ViInt32    Repetition,
                                                      ViInt32    StopCondition,
                                                      ViInt32    StepMode,
                                                      ViChar     errorMessage[])
{
 ViStatus    RSCMU300_Status = VI_SUCCESS;
 GET_WRT_BUF(instrSession);

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 // Check if the function is correctly used:
 CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
 CHECK_VI_INT32_RANGE(instrSession, Repetition,0,1, RSCMU_ERROR_PARAMETER3, errorMessage);
 CHECK_VI_INT32_RANGE(instrSession, StopCondition,0,1, RSCMU_ERROR_PARAMETER4, errorMessage);
 CHECK_VI_INT32_RANGE(instrSession, StepMode,0,1, RSCMU_ERROR_PARAMETER5, errorMessage);

 sprintf (wrtBuf, "CONF:POW:MSL:%s:CONT:REP %s,%s,%s",Channel_Type[channel], repetition_meas[Repetition], mode_StopCondition_SON[StopCondition], StrStepMode[StepMode]);
 RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Set Statistics Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowMslContRepStat (ViSession  instrSession,
                                                          ViInt32    channel,
                                                          ViInt32    NbRepetition,
                                                          ViInt32    StopCondition,
                                                          ViInt32    StepMode,
                                                          ViChar     errorMessage[])
{
 ViStatus    RSCMU300_Status = VI_SUCCESS;
 GET_WRT_BUF(instrSession);

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 // Check if the function is correctly used:
 CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
 CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULT_MEAS_MIN, RSCMU300_MULT_MEAS_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
 CHECK_VI_INT32_RANGE(instrSession, StopCondition,0,1, RSCMU_ERROR_PARAMETER4, errorMessage);
 CHECK_VI_INT32_RANGE(instrSession, StepMode,0,1, RSCMU_ERROR_PARAMETER5, errorMessage);

 sprintf (wrtBuf, "CONF:POW:MSL:%s:CONT:REP %ld,%s,%s", Channel_Type[channel], NbRepetition, mode_StopCondition_SON[StopCondition], StrStepMode[StepMode]);
 RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}


/*
 *-----------------------------------------------------------------------------
 *      TEST CONFIGURATION
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Modulation view
/* Purpose : This function defines the modulation schemes and power/time
/*           templates for the Meas. Timeslot -1, Meas. Timeslot and the two
/*           following timeslots. Values for timeslots that are currently
/*           switched off (see function RSCMU300_GSM_NSig_ConfPowMslSco) are not
/*           taken into consideration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowMslMvi (ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32   timeslot_m1,
                                                  ViInt32   timeslot,
                                                  ViInt32   timeslot_p1,
                                                  ViInt32   timeslot_p2,
                                                  ViChar    errorMessage[])
{
 ViStatus    RSCMU300_Status = VI_SUCCESS;
 ViString    list[] = {"GMSK","EPSK","ANY","OFF",VI_NULL};
 GET_WRT_BUF(instrSession);

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 // Check if the function is correctly used:
 CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
 CHECK_VI_INT32_RANGE(instrSession, timeslot_m1, RSCMU300_MODVIEW_GMSK, RSCMU300_MODVIEW_OFF, RSCMU_ERROR_PARAMETER3, errorMessage);
 CHECK_VI_INT32_RANGE(instrSession, timeslot, RSCMU300_MODVIEW_GMSK, RSCMU300_MODVIEW_OFF, RSCMU_ERROR_PARAMETER4, errorMessage);
 CHECK_VI_INT32_RANGE(instrSession, timeslot_p1, RSCMU300_MODVIEW_GMSK, RSCMU300_MODVIEW_OFF, RSCMU_ERROR_PARAMETER5, errorMessage);
 CHECK_VI_INT32_RANGE(instrSession, timeslot_p2, RSCMU300_MODVIEW_GMSK, RSCMU300_MODVIEW_OFF, RSCMU_ERROR_PARAMETER6, errorMessage);

 sprintf (wrtBuf, "CONF:POW:MSL:%s:MVI %s,%s,%s,%s", Channel_Type[channel],list[timeslot_m1],list[timeslot],list[timeslot_p1],list[timeslot_p2]);
 RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Slot count
/* Purpose : This function defines the number of timeslots measured and
/*           determines the length of the measurement arrays.
/*           (see READ:ARRay:POWer:MSLot[:RESult]... commands).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowMslSco (ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32   nbr_of_timeslots,
                                                  ViChar    errorMessage[])
{
 ViStatus    RSCMU300_Status = VI_SUCCESS;
 GET_WRT_BUF(instrSession);

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 // Check if the function is correctly used:
 CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
 CHECK_VI_INT32_RANGE(instrSession, nbr_of_timeslots, 1, 4, RSCMU_ERROR_PARAMETER3, errorMessage);

 sprintf (wrtBuf, "CONF:POW:MSL:%s:SCO %ld", Channel_Type[channel],nbr_of_timeslots);
 RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: timing offset
/* Purpose : This function defines an offset time by which the burst is
/*           shifted relative to the time axis and the tolerance template.
/*           The values entered are rounded to  symbol steps.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowMslToff (ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViReal64  offset,
                                                   ViChar    errorMessage[])
{
 ViStatus    RSCMU300_Status = VI_SUCCESS;
 GET_WRT_BUF(instrSession);

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 // Check if the function is correctly used:
 CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
 CHECK_VI_REAL64_RANGE(instrSession, offset, -4.0, 4.0, RSCMU_ERROR_PARAMETER3, errorMessage);

 sprintf (wrtBuf, "CONF:POW:MSL:%s:TOFF %.12f", Channel_Type[channel],offset);
 RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}


/*===========================================================================*/
/* Function: Measured timeslot number
/* Purpose :This function selects the measured timeslot in the multislot application.
/*          (see also CONFigure:POWer:MSLot:...:SCOunt commands.)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowMslMeasSlot (ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViInt32   slot_nr,
                                                       ViChar    errorMessage[])
{
 ViStatus    RSCMU300_Status = VI_SUCCESS;
 GET_WRT_BUF(instrSession);

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_22,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 // Check if the function is correctly used:
 CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
 CHECK_VI_INT32_RANGE(instrSession, slot_nr, 0, 7, RSCMU_ERROR_PARAMETER3, errorMessage);

 sprintf (wrtBuf, "CONF:POW:MSL:%s:MESL %ld", Channel_Type[channel],slot_nr);
 RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}


/*===========================================================================*/
/* Function: Filter
/* Purpose : This function selects the measurement filter.
/*===========================================================================*/

ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowMslFilt (ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32   filter,
                                                   ViChar    errorMessage[])
{
 ViStatus    RSCMU300_Status = VI_SUCCESS;
 GET_WRT_BUF(instrSession);

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 // Check if the function is correctly used:
 CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
 CHECK_VI_INT32_RANGE(instrSession, filter, 0, 1, RSCMU_ERROR_PARAMETER3, errorMessage);

 sprintf (wrtBuf, "CONFigure:POWer:MSLot:%s:FILTer %s", Channel_Type[channel],StrFilter[filter]);
 RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Only for compatibility:.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowMslFilter (ViSession instrSession,
                                                     ViInt32   filter,
                                                     ViChar    errorMessage[])
{
 ViStatus    RSCMU300_Status = VI_SUCCESS;
 GET_WRT_BUF(instrSession);

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 RETMSG(RSCMU300_setEnum(instrSession, "CONF:POW:MSL:TCH:FILT",
                         filter, StrFilter,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: multislot guard
/* Purpose : This function defines the raising of the upper limit line in the
/*           guard period between two consecutive bursts.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowMslLimGlev (ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViReal64  level,
                                                      ViChar    errorMessage[])

{
 ViStatus    RSCMU300_Status = VI_SUCCESS;
 GET_WRT_BUF(instrSession);

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 // Check if the function is correctly used:
 CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
 CHECK_VI_REAL64_RANGE(instrSession, level, 0.0, 10.0, RSCMU_ERROR_PARAMETER3, errorMessage);

 // Configure  tests cycles:
 sprintf (wrtBuf, "CONF:POW:MSL:%s:LIM:LINE:GLEV %.12f", Channel_Type[channel],level);
 RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: configure subarrays
/* Purpose : This function configures the read, fetch and sample subarray
/*           functions. It restricts the measurement to up to 32 subranges
/*           where either all measurement results (the number of which is
/*           given by the second numerical parameter) or a single statistical
/*           value is returned. The subranges are defined by the start time
/*           and the number of test points which are located on a fixed,
/*           equidistant grid with a step width of  symbols. If <Start> does
/*           not coincide with a test point then the range will start at the
/*           next test point that is larger than <Start>.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubPowMslRang (ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViInt32   Statistics,
                                                      ViInt32   startTime,
                                                      ViInt32   Nbofsamples,
                                                      ViChar    errorMessage[])
{
 ViStatus    RSCMU300_Status = VI_SUCCESS;
 GET_WRT_BUF(instrSession);

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 // Check if the function is correctly used:
 CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
 CHECK_VI_INT32_RANGE(instrSession, Statistics, 0, 4, RSCMU_ERROR_PARAMETER3, errorMessage);
 CHECK_VI_INT32_RANGE(instrSession, startTime, -180, 520, RSCMU_ERROR_PARAMETER4, errorMessage);
 CHECK_VI_INT32_RANGE(instrSession, Nbofsamples, 1, 2613, RSCMU_ERROR_PARAMETER5, errorMessage);

 sprintf (wrtBuf, "CONF:SUB:POW:MSL:%s %s,%ld,%ld", Channel_Type[channel],StrSubArr[Statistics], startTime,Nbofsamples);
 RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*
 *-----------------------------------------------------------------------------
 *      MEASURED VALUES
 *      The functions of the following subsystems determine and output
 *      the results of the signal power measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function starts a single shot measurement and returns the
/*           results. For more details refer to the description of measurement
/*           control in chapter 5 of the CMU200 operating manual.
/*
/*           These are:
/*           Burst out of tolerance
/*           Average burst power (current burst)
/*           Average burst power of average trace
/*           Peak burst power (current burst)
/*           Timing advance error
/*           Burst template matching
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadPowMsl (ViSession  instrSession,
                                               ViInt32    channel,
                                               ViInt32    Slot,
                                               ViReal64   *BurstOutOfTol,
                                               ViReal64   *AvgBurstPwCurr,
                                               ViReal64   *AvgBurstPwAvg,
                                               ViReal64   *PeakBurstPwCurr,
                                               ViReal64   *TimingAdvError,
                                               ViInt32    *BurstMatching,
                                               ViChar     errorMessage[])
{
  return RSCMU300_MeasScalPowerMSlot (instrSession, RSCMU300_COMMAND_READ, channel, Slot, BurstOutOfTol, AvgBurstPwCurr,
    AvgBurstPwAvg, PeakBurstPwCurr, TimingAdvError, BurstMatching, errorMessage);
}

/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function returns the results. For more details refer to the
/*           description of measurement control in chapter 5 of the CMU200
/*           operating manual.
/*
/*           These are:
/*           Burst out of tolerance
/*           Average burst power (current burst)
/*           Average burst power of average trace
/*           Peak burst power (current burst)
/*           Timing advance error
/*           Burst template matching
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPowMsl (ViSession  instrSession,
                                               ViInt32    channel,
                                               ViInt32    Slot,
                                               ViReal64   *BurstOutOfTol,
                                               ViReal64   *AvgBurstPwCurr,
                                               ViReal64   *AvgBurstPwAvg,
                                               ViReal64   *PeakBurstPwCurr,
                                               ViReal64   *TimingAdvError,
                                               ViInt32    *BurstMatching,
                                               ViChar     errorMessage[])
{
  return RSCMU300_MeasScalPowerMSlot (instrSession, RSCMU300_COMMAND_FETC, channel, Slot, BurstOutOfTol, AvgBurstPwCurr,
    AvgBurstPwAvg, PeakBurstPwCurr, TimingAdvError, BurstMatching, errorMessage);
}

/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function waits until the results are valid (depending on
/*           the statistic count) and then returns the results. For more
/*           details refer to the description of measurement control in
/*           chapter 5 of the CMU200 operating manual.
/*
/*           These are:
/*           Burst out of tolerance
/*           Average burst power (current burst)
/*           Average burst power of average trace
/*           Peak burst power (current burst)
/*           Timing advance error
/*           Burst template matching
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampPowMsl (ViSession  instrSession,
                                               ViInt32    channel,
                                               ViInt32    Slot,
                                               ViReal64   *BurstOutOfTol,
                                               ViReal64   *AvgBurstPwCurr,
                                               ViReal64   *AvgBurstPwAvg,
                                               ViReal64   *PeakBurstPwCurr,
                                               ViReal64   *TimingAdvError,
                                               ViInt32    *BurstMatching,
                                               ViChar     errorMessage[])
{
  return RSCMU300_MeasScalPowerMSlot (instrSession, RSCMU300_COMMAND_SAMP, channel, Slot, BurstOutOfTol, AvgBurstPwCurr,
    AvgBurstPwAvg, PeakBurstPwCurr, TimingAdvError, BurstMatching, errorMessage);
}

/*===========================================================================*/
/* Function: Request Tolerance On Values
/* Purpose : This function indicates whether and in which way the per-
/*           missible tolerances for the scalar measured values have
/*           been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcPowMslLimMatc (ViSession  instrSession,
                                                      ViInt32    channel,
                                                      ViInt32    Slot,
                                                      ViInt32    *AvgBurstPwCurr,
                                                      ViInt32    *AvgBurstPwAvg,
                                                      ViInt32    *TimingAdvErr,
                                                      ViInt32    *BurstMatching,
                                                      ViChar     errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      tab[100][100];
  GET_BUFS(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Slot, 0, 3, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CALC:POW:MSL:%s:MATC:LIM?", Channel_Type[channel]);
  CHECKRETMSG(RSCMU300_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE,0));

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);


  // average burst power (current burst):
  RSCMU300_Status = RSCMU300_GetMatchingValue(AvgBurstPwCurr,tab, (4*Slot));

  // average burst power of average trace:
  RSCMU300_Status = RSCMU300_GetMatchingValue(AvgBurstPwAvg,tab, (4*Slot)+1);

  // timing advance error:
  RSCMU300_Status = RSCMU300_GetMatchingValue(TimingAdvErr,tab, (4*Slot)+2);

  // Get the burst template matching:
  RSCMU300_Status = RSCMU300_GetMatchingValue(BurstMatching, tab, (4*Slot)+3);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Power/t multislot array
/* Purpose : This function starts a single shot measurement and returns the
/*           burst power relative to the average burst power in the measurement
/*           slot at n equidistant measurement points with a fixed  symbol
/*           spacing. The time range measured corresponds to 1 to 4 entire
/*           timeslots plus 18  symbol periods before the beginning (symbol 0)
/*           of the first slot and 10 symbol periods after the end of the last
/*           slot. The resulting array lengths n are listed below.
/*
/*           Number of timeslots (according to     1      2      3      4
/*           RSCMU300_GSM_NSig_ConfPowMslSco)
/*           n                                   738   1363   1988   2613
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrPowMsl (ViSession  instrSession,
                                                  ViInt32    channel,
                                                  ViInt32    StatisticMode,
                                                  ViReal64   BurstPower[],
                                                  ViChar     errorMessage[])
{
  return RSCMU300_MeasArrayPowerMslot (instrSession, channel, RSCMU300_COMMAND_READ, StatisticMode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Power/t multislot array
/* Purpose : This function returns the burst power relative to the average
/*           burst power in the measurement slot at n equidistant measurement
/*           points with a fixed  symbol spacing. The time range measured
/*           corresponds to 1 to 4 entire timeslots plus 18  symbol periods
/*           before the beginning (symbol 0) of the first slot and 10 symbol
/*           periods after the end of the last slot. The resulting array
/*           lengths n are listed below.
/*
/*           Number of timeslots (according to     1      2      3      4
/*           RSCMU300_GSM_NSig_ConfPowMslSco)
/*           n                                   738   1363   1988   2613
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrPowMsl (ViSession  instrSession,
                                                  ViInt32    channel,
                                                  ViInt32    StatisticMode,
                                                  ViReal64   BurstPower[],
                                                  ViChar     errorMessage[])
{
  return RSCMU300_MeasArrayPowerMslot (instrSession, channel, RSCMU300_COMMAND_FETC, StatisticMode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Power/t multislot array
/* Purpose : This function waits until the results are valid (depending on
/*           the statistic count) and then returns the burst power relative
/*           to the average burst power in the measurement slot at n
/*           equidistant measurement points with a fixed  symbol spacing.
/*           The time range measured corresponds to 1 to 4 entire timeslots
/*           plus 18  symbol periods before the beginning (symbol 0) of the
/*           first slot and 10 symbol periods after the end of the last slot.
/*           The resulting array lengths n are listed below.
/*
/*           Number of timeslots (according to     1      2      3      4
/*           RSCMU300_GSM_NSig_ConfPowMslSco)
/*           n                                   738   1363   1988   2613
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrPowMsl (ViSession  instrSession,
                                                  ViInt32    channel,
                                                  ViInt32    StatisticMode,
                                                  ViReal64   BurstPower[],
                                                  ViChar     errorMessage[])
{
  return RSCMU300_MeasArrayPowerMslot (instrSession, channel, RSCMU300_COMMAND_SAMP, StatisticMode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Global burst matching
/* Purpose : This function indicates whether and in which way the per-
/*           missible tolerances for the scalar measured values have
/*           been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcArrPowMslLimMatc (ViSession  instrSession,
                                                         ViInt32    channel,
                                                         ViInt32    StatisticMode,
                                                         ViInt32   *ToleranceError,
                                                         ViChar     errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      tab[100][100];
  GET_BUFS(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, StatisticMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CALC:ARR:POW:MSL:%s:%s:MATC:LIM?", Channel_Type[channel], StrStatMode[StatisticMode]);
  CHECKRETMSG(RSCMU300_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE,0));

  // Get the matching value:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);
  RSCMU300_GetMatchingValue (ToleranceError, tab, 0);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: area limit matching
/* Purpose : A bit in the two output values is set if the corresponding
/*           section of the limit lines is exceeded. n is the total number of
/*           areas in the limit lines, depending on the number of bursts
/*           measured (according to RSCMU300_GSM_NSig_ConfPowMslSco).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcPowMslAreaLimMatc (ViSession  instrSession,
                                                          ViInt32    channel,
                                                          ViInt32    StatisticMode,
                                                          ViInt32   *UpperLimit,
                                                          ViInt32   *LowerLimit,
                                                          ViChar     errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      tab[100][100];
  GET_BUFS(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, StatisticMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CALC:ARR:POW:MSL:%s:%s:MATC:AREA?", Channel_Type[channel], StrStatMode[StatisticMode]);
  CHECKRETMSG(RSCMU300_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE,0));

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the upper Limit Matching
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%ld", UpperLimit);
  else *UpperLimit = RSCMU300_NAN_VI_INT32;

  // Get the lower Limit Matching
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%ld", LowerLimit);
  else *LowerLimit = RSCMU300_NAN_VI_INT32;

  return RSCMU300_Status;
}


/*===========================================================================*/
/* Function: Start/Stop time for all Areas
/* Purpose : These function returns the time of all areas of the multislot
/*           tolerance template, relative to the start of the measured
/*           timeslot (Meas. Slot). OFF means that the limit line and limit
/*           check in an area is switched off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensPowMslAreaLimTime (ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViInt32   Upp_Low,
                                                          ViReal64  timeValues[],
                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar     *StrValue;
  ViInt16     Index = 0;
  ViString    list[] = {"LOWer","UPPer", VI_NULL};
  GET_BUFS(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_22,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Upp_Low, 0, 1, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "SENSe:ARRay:POWer:MSLot:%s:AREA:LIMit:%s:TIME?", Channel_Type[channel], list[Upp_Low]);
  CHECKRETMSG(RSCMU300_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE,0));

  // Find all values by breaking the read buffer:
  StrValue = strtok(rdBuf, ",");

  while (StrValue)
  {
    if (strcmp (StrValue, "OFF") != 0)
      sscanf (StrValue, "%le", &timeValues[Index]);
    else timeValues[Index] = RSCMU300_NAN;

    StrValue = strtok (NULL, ",");

    Index++;
  }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Start/Stop level for all Areas
/* Purpose : These function return the level of all areas of the multislot
/*           tolerance template, relative to the useful level of the
/*           measured timeslot (Meas. Slot). OFF means that the limit
/*           line and limit check in an area is switched off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensPowMslAreaLimLevel (ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViInt32   Upp_Low,
                                                           ViReal64  levelValues[],
                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar     *StrValue;
  ViInt16     Index = 0;
  ViString    list[] = {"LOWer","UPPer", VI_NULL};
  GET_BUFS(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_22,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Upp_Low, 0, 1, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "SENSe:ARRay:POWer:MSLot:%s:AREA:LIMit:%s:LEVel?", Channel_Type[channel], list[Upp_Low]);
  CHECKRETMSG(RSCMU300_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE,0));

  // Find all values by breaking the read buffer:
  StrValue = strtok(rdBuf, ",");

  while (StrValue)
  {
    if (strcmp (StrValue, "OFF") != 0)
      sscanf (StrValue, "%le", &levelValues[Index]);
    else levelValues[Index] = RSCMU300_NAN;

    StrValue = strtok (NULL, ",");

    Index++;
  }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: timeslot of all Areas
/* Purpose : These function return the timeslot of all areas of the multislot
/*           tolerance template, relative to the measured timeslot (Meas.Slot, slot no. 0).
/*           The number of areas and thus the number of output values varies
/*           with the number of measured slots and the definition of the
/*           single slot Upp_Low.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensPowMslAreaLimInfo (ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViInt32   Upp_Low,
                                                          ViReal64  timeslot[],
                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar     *StrValue;
  ViInt16     Index = 0;
  ViString    list[] = {"LOWer","UPPer", VI_NULL};
  GET_BUFS(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_22,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Upp_Low, 0, 1, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "SENSe:ARRay:POWer:MSLot:%s:AREA:LIMit:%s:INFo?", Channel_Type[channel], list[Upp_Low]);
  CHECKRETMSG(RSCMU300_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE,0));

  // Find all values by breaking the read buffer:
  StrValue = strtok(rdBuf, ",");

  while (StrValue)
  {
    if (strcmp (StrValue, "NAN") != 0)
      sscanf (StrValue, "%le", &timeslot[Index]);
    else timeslot[Index] = RSCMU300_NAN;

    StrValue = strtok (NULL, ",");

    Index++;
  }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Start time of measurement curve
/* Purpose : This function returns the start time of the measurement curve
/*           relative to the beginning of the measured timeslot (Meas. Slot,
/*           slot no. 0). The start time is the relative time of the first
/*           sample of the curve; all remaining samples follow with a  symbol spacing.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensPowMslAreaLimSTime (ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViReal64 *startingTime,
                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_22,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SENSe:ARRay:POWer:MSLot:%s:AREA:LIMit:INFO:STIMe?", Channel_Type[channel]);

  RETMSG(RSCMU300_getViReal64(instrSession, wrtBuf, startingTime,
                             RSCMU_ERROR_PARAMETER3));
}

/*===========================================================================*/
/* Function: Read subarrays
/* Purpose : This function outputs the burst power versus time multislot in a
/*           fixed -bit pattern and in subranges defined ny means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubArrPowMsl (ViSession  instrSession,
                                                     ViInt32    channel,
                                                     ViInt32    StatisticMode,
                                                     ViReal64   BurstPower[],
                                                     ViChar     errorMessage[])
{
  return RSCMU300_MeasSubarrPowerMslot (instrSession, channel, RSCMU300_COMMAND_READ, StatisticMode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch subarrays
/* Purpose : This function outputs the burst power versus time multislot in a
/*           fixed -bit pattern and in subranges defined ny means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubArrPowMsl (ViSession  instrSession,
                                                     ViInt32    channel,
                                                     ViInt32    StatisticMode,
                                                     ViReal64   BurstPower[],
                                                     ViChar     errorMessage[])
{
  return RSCMU300_MeasSubarrPowerMslot (instrSession, channel, RSCMU300_COMMAND_FETC, StatisticMode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample subarrays
/* Purpose : This function outputs the burst power versus time multislot in a
/*           fixed -bit pattern and in subranges defined ny means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubArrPowMsl (ViSession  instrSession,
                                                     ViInt32    channel,
                                                     ViInt32    StatisticMode,
                                                     ViReal64   BurstPower[],
                                                     ViChar     errorMessage[])
{
  return RSCMU300_MeasSubarrPowerMslot (instrSession, channel, RSCMU300_COMMAND_SAMP, StatisticMode, BurstPower, errorMessage);
}



/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT SPECtrum[:COMMon]
 *
 *    The subsystem SPECtrum[:COMMon] provides settings that are
 *    common to the two applications Spectrum due to Modulation (see
 *    p. 6.56 ff) and Spectrum due to Switching (see p. 6.64 ff).
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: noise correction
/* Purpose : this function switches the noise correction for the Spectrum
/*           measurement on or off. The noise correction improves the dynamic
/*           range but slightly reduces the speed of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpComNoiseCorr (ViSession instrSession,
                                                                              ViBoolean Correction,
                                                                              ViChar    _VI_FAR errorMessage[])
{
    return RSCMU300_GSM_NSig_ConfSpComNoiseCorr (instrSession, Correction, errorMessage);
}

/*===========================================================================*/
/* Function: Select Limit Line Template
/* Purpose : These function selects the limit line to be applied.
/*           The current template can be queried using
/*           [SENSe:]SPECtrum:<Application>:LIMit:LINE:USED?.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpecLimLineSel (ViSession instrSession,
                                                       ViInt32   select,
                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViString    list[] = {"GMSK","EPSK","AUTO", VI_NULL};

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  RETMSG(RSCMU300_setEnum(instrSession, "CONFigure:SPECtrum:TCH:LIMit:LINE:SELect", select, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Bit stream for RXQ Measurements
/* Purpose:  this function defines the data transmitted in the Traffic
/*           channel. In a Receiver Quality (BER) measurement one of the
/*           pseudo random sequences must be used.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfRxqContBitStr (ViSession instrSession,
                                                      ViInt32 bitStream,
                                                      ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViString    list[] = {"","","PR9","PR11","PR15","PR16",VI_NULL};

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  RETMSG(RSCMU300_setEnum(instrSession, "CONF:RXQ:CONT:BITS",
                         bitStream, list,
                         RSCMU_ERROR_PARAMETER2));

}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT RXQUALITY: RF (CMU)
 *
 *    The Class RXQuality contains the commands for measuring the BTS
 *    receiver quality. The settings are used to assess the quality of
 *    transmission between the CMU and the device under test. The subsystem
 *    corresponds to the main menu Receiver Quality and the associated popup
 *    menu Receiver Quality Configuration.
 *-----------------------------------------------------------------------------
 *       COMMON CONTROLS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set hold off times
/* Purpose : This command defines defines hold off times during which the
/*           mobile can adapt itself to the new RF level at the beginning of
/*           the receiver quality measurement and send back the bit stream
/*           received. By reducing the hold off times, the measurement can be
/*           speeded up. The default settings for both times do not depend on
/*           the application.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfRxqContHtim (ViSession instrSession,
                                                                           ViReal64  AGCTime,
                                                                           ViReal64  synchTime,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, AGCTime, RSCMU300_AGC_TIME_MIN, RSCMU300_AGC_TIME_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, synchTime, RSCMU300_SYNCH_TIME_MIN, RSCMU300_SYNCH_TIME_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:RXQ:CONT:HTIM %.12f,%.12f", AGCTime, synchTime);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Common Controls Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfRxqContDef (ViSession instrSession,
                                                                          ViBoolean DefaultValues,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (DefaultValues)
  {
    sprintf (wrtBuf, "DEF:RXQ:CONT %s", mode_On_Off[DefaultValues]);
    if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
      return RSCMU300_Status;
  }
  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      BER measurement
 *
 *      The subsystem RXQuality:BER measures the receiver quality in the single
 *      shot mode. The subsystem corresponds to the main menu Receiver Quality,
 *      Application BER and the corresponding parts of the associated popup
 *      menu Receiver Quality Configuration.
 *-----------------------------------------------------------------------------
 *         TEST SETUP
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Data set as Application
/* Purpose : This function selects one out of 10 data sets as application,
/*           enabling 10 different BER measurements that can be parameterized.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBerTset (ViSession instrSession,
                                                                       ViInt32   TestSetup,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrTestSetup[]= {"","T1","T2","T3","T4","T5","T6","T7","T8","T9","T10"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TestSetup, RSCMU300_T1, RSCMU300_T10, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:RXQ:BER:TSET %s", StrTestSetup[TestSetup]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *         CONFIGURATION CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Number of frames
/* Purpose : This function defines the measured value, the number of
/*           frames to be averaged in a continuous measurement, and the
/*           number of frames to be sent in a single shot measurement,
/*           constituting a  statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBerCont (ViSession instrSession,
                                                ViInt32   TestSetup,
                                                ViInt32   mode,
                                                ViInt32   numberOfFrames,
                                                ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViString    StrMode[] = {"BER","RFER","BBB","BDBL"};
  struct RSCMU300_SESSION_Globals  *p_globalvarBase;
  GET_BUFS(instrSession);

  // Queries the specified attribute:
  CHECKRET(viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase));


  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TestSetup, RSCMU300_T1, RSCMU300_T10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, numberOfFrames, RSCMU300_NBFRAMES_MIN, RSCMU300_NBFRAMESSENT_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);
  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
    CHECK_VI_INT32_RANGE(instrSession, mode, RSCMU300_BER, RSCMU300_BBB, RSCMU_ERROR_PARAMETER3, errorMessage);
    }
  else
    {
    CHECK_VI_INT32_RANGE(instrSession, mode, RSCMU300_BER, RSCMU300_DBLER, RSCMU_ERROR_PARAMETER2, errorMessage);
    }

  sprintf (wrtBuf, "CONF:RXQ:BER%ld:CONT %s,%ld", TestSetup,StrMode[mode],numberOfFrames);
  RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Set Sensitivity Tests Cycles
/* Purpose : This function determines the stop condition and the
/*           stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBerContRep (ViSession instrSession,
                                                                          ViInt32   TestSetup,
                                                                          ViInt32   StopCondition,
                                                                          ViInt32   StepMode,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    mode_StopConditionBER[] = {"NONE","ALIM","FLIM"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TestSetup, RSCMU300_T1, RSCMU300_T10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, StopCondition, 0, 2, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:RXQ:BER%ld:CONT:REP %s,%s", TestSetup
                                                  , mode_StopConditionBER[StopCondition]
                                                  , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Level in the used timeslot
/* Purpose : This function sets the TCH absolute level in the used
/*           timeslot. The permissible value range depends on the used
/*           RF output of the CMU and the external attenuation set.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBerContLevUtim (ViSession instrSession,
                                                                              ViInt32   TestSetup,
                                                                              ViReal64  Level,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used
  CHECK_VI_INT32_RANGE(instrSession, TestSetup, RSCMU300_T1, RSCMU300_T10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, Level, RSCMU300_ABSLEVEL_MIN, RSCMU300_ABSLEVEL_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  // Set absolute level in used timeslot
  sprintf (wrtBuf, "CONF:RXQ:BER%ld:CONT:LEV:UTIM %.12f", TestSetup
                                                     , Level);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Level in the unused timeslots
/* Purpose : This function sets the TCH relative level in the unused
/*           timeslots relative to the level in the used timeslot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBerContLevUnt (ViSession instrSession,
                                                                             ViInt32   TestSetup,
                                                                             ViReal64  Level,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TestSetup, RSCMU300_T1, RSCMU300_T10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, Level, RSCMU300_GSM_SIG_UNUSEDSLOTMIN, RSCMU300_GSM_SIG_UNUSEDSLOTMAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  // Set absolute level for Unused Slots
  sprintf (wrtBuf, "CONF:RXQ:BER%ld:CONT:LEV:UNT %.12f", TestSetup
                                                    , Level);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      LIMITS
 *      The subsystem RXQuality:...:LIMit contains the commands for
 *      definition of tolerance values for the receiver quality.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Setting
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBerLimDef (ViSession instrSession,
                                                                         ViInt32   TestSetup,
                                                                         ViBoolean enableDefaultParameters,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TestSetup, RSCMU300_T1, RSCMU300_T10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, enableDefaultParameters, RSCMU_ERROR_PARAMETER3, errorMessage);

  if (enableDefaultParameters)
  {
    sprintf (wrtBuf, "DEF:RXQ:BER%ld:LIM %s", TestSetup
                                           , mode_On_Off[enableDefaultParameters]);
    if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
      return RSCMU300_Status;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Bit Error Class 2
/* Purpose : This function defines an upper limit for the bit error rate
/*           of class II (unprotected bits, see chapter 4)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBerLimCLII (ViSession instrSession,
                                                                          ViInt32   TestSetup,
                                                                          ViReal64  Limit,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TestSetup, RSCMU300_T1, RSCMU300_T10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, Limit, 0, 100, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:RXQ:BER%ld:LIM:CLII %.12f", TestSetup
                                                , Limit);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Bit Error Class 1b
/* Purpose : This function defines an upper limit for the bit error rate
/*           of class IB.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBerLimCLIB (ViSession instrSession,
                                                                          ViInt32   TestSetup,
                                                                          ViReal64  Limit,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TestSetup, RSCMU300_T1, RSCMU300_T10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, Limit, 0, 100, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:RXQ:BER%ld:LIM:CLIB %.12f", TestSetup
                                                , Limit);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Frame error rate
/* Purpose : This function defines an upper limit for the relative
/*           portion of invalid and therefore erased frames in the
/*           measurementof the sensisitivity.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBerLimFERR (ViSession instrSession,
                                                                          ViInt32   TestSetup,
                                                                          ViReal64  Limit,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, Limit, 0, 100, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:RXQ:BER%ld:LIM:FERR %.12f", TestSetup
                                                , Limit);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Data Block error rate
/* Purpose : This function defines an upper limit for the ratio of blocks with
/* bit errors in their data field to the total number of transferred blocks
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBerLimDBLER (ViSession instrSession,
                                                    ViInt32 TestSetup,
                                                    ViReal64  Limit,
                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TestSetup, RSCMU300_T1, RSCMU300_T10, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf, "CONF:RXQ:BER%ld:LIM:DBL", TestSetup);

  RETMSG(RSCMU300_setViReal64(instrSession, wrtBuf,
                             Limit, 0.0,100.0,
                             RSCMU_ERROR_PARAMETER3));
}

/*-----------------------------------------------------------------------------
 *      CONTROL OF RXQUALITY MEAS
 *      It contains the functions for general control of the receiver
 *      quality measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Init
/* Purpose : Start measurement without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitBer (ViSession instrSession,
                                                                   ViChar    _VI_FAR errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE]= "";

    if ((RSCMU300_Status = RSCMU300_Query (instrSession, "INIT:RXQ:BER", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
        return RSCMU300_Status;

    return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : This function aborts running measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborBer (ViSession instrSession,
                                                                   ViChar    _VI_FAR errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE]= "";

    if ((RSCMU300_Status = RSCMU300_Query (instrSession, "ABOR:RXQ:BER", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
        return RSCMU300_Status;

    return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : This function stops running measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopBer (ViSession instrSession,
                                                                   ViChar    _VI_FAR errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE]= "";

    if ((RSCMU300_Status = RSCMU300_Query (instrSession, "STOP:RXQ:BER", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
        return RSCMU300_Status;

    return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : This function proceed with next measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContBer (ViSession instrSession,
                                                                   ViChar    _VI_FAR errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE]= "";

    if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CONT:RXQ:BER", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
        return RSCMU300_Status;

    return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Measurement Status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcBerSt (ViSession instrSession,
                                                                     ViPInt32  MeasStatus,
                                                                     ViPInt32  CurrentEvalPeriodCount,
                                                                     ViChar    _VI_FAR errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE] = "";
    ViChar      tab[100][100];

    // Fetch the measurement status:
    if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:RXQ:BER:STAT?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
        return RSCMU300_Status;

    // Separate the CMU response:
    RSCMU300_SeparateDataValues (rdBuf, ",", tab);

    // Get the measurement status
    RSCMU300_Status = RSCMU300_GetMeasStatVal(MeasStatus, tab, 0 );

    // Get the counter for current evaluation period within a cycle
    RSCMU300_Status = RSCMU300_GetViInt32Value(tab, 1, CurrentEvalPeriodCount);

    return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBerErep (ViSession instrSession,
                                                                       ViInt32   Mode,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:RXQ:BER:EREP %s", StrErep[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      RESULTS: BIT ERROR RATE
 *      This subsystem (RXQ:...[:RESULT]) contains the functions for measurement
 *      and output of the bit error rate and its comparison with the tolerance
 *      values. The subsystem corresponds to the measurement menus Bit Error
 *      Rate for the different types of measurement (single shot or continuous)
 *      and measured values (RFER, BER, BBB).
 *-----------------------------------------------------------------------------
 *        RFER MEASUREMENTS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: RFER: measured values...
/* Purpose : This function start a bit-error-rate test and output the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_ReadBer (ViSession instrSession,
                                                                        ViPReal64 progressTime,
                                                                        ViPReal64 RBERClass2Bits,
                                                                        ViPReal64 RBERClass1bBits,
                                                                        ViPReal64 frameErasureRate,
                                                                        ViPInt32  CRCerrors,
                                                                        ViPInt32  measurementStatus,
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:RXQ:BER?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", RBERClass2Bits);
  else *RBERClass2Bits = RSCMU300_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%le", RBERClass1bBits);
  else *RBERClass1bBits = RSCMU300_NAN;
  // Get the Frame Erasure Rate
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%le", frameErasureRate);
  else *frameErasureRate = RSCMU300_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[4], "NAN") != 0)
    sscanf (tab[4], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (measurementStatus, tab, 5);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: RFER: fetch measured values...
/* Purpose : This function output the last measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_FetcBer (ViSession instrSession,
                                                                        ViPReal64 progressTime,
                                                                        ViPReal64 RBERClass2Bits,
                                                                        ViPReal64 RBERClass1bBits,
                                                                        ViPReal64 frameErasureRate,
                                                                        ViPInt32  CRCerrors,
                                                                        ViPInt32  measurementStatus,
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:RXQ:BER?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", RBERClass2Bits);
  else *RBERClass2Bits = RSCMU300_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%le", RBERClass1bBits);
  else *RBERClass1bBits = RSCMU300_NAN;
  // Get the Frame Erasure Rate
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%le", frameErasureRate);
  else *frameErasureRate = RSCMU300_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[4], "NAN") != 0)
    sscanf (tab[4], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (measurementStatus, tab, 5);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: RFER: sample measured values...
/* Purpose : This function output the last measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_SampBer (ViSession instrSession,
                                                                        ViPReal64 progressTime,
                                                                        ViPReal64 RBERClass2Bits,
                                                                        ViPReal64 RBERClass1bBits,
                                                                        ViPReal64 frameErasureRate,
                                                                        ViPInt32  CRCerrors,
                                                                        ViPInt32  measurementStatus,
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:RXQ:BER?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", RBERClass2Bits);
  else *RBERClass2Bits = RSCMU300_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%le", RBERClass1bBits);
  else *RBERClass1bBits = RSCMU300_NAN;
  // Get the Frame Erasure Rate
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%le", frameErasureRate);
  else *frameErasureRate = RSCMU300_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[4], "NAN") != 0)
    sscanf (tab[4], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (measurementStatus, tab, 5);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: RFER: Matching Tolerances
/* Purpose : This Function indicates whether and in which way the
/*           permissibleerror limits for the measured values of the bit
/*           error rate test have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_CalcBerLimMatc (ViSession instrSession,
                                                                               ViPInt32  total,
                                                                               ViPInt32  RBERClass2Bits,
                                                                               ViPInt32  RBERClass1bBits,
                                                                               ViPInt32  frameErasureRate,
                                                                               ViPInt32  CRCErrors,
                                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CALC:RXQ:BER:MATC:LIM?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMatchingValue(total,tab,0);

  // RBER for Class2 Bits
  RSCMU300_Status = RSCMU300_GetMatchingValue(RBERClass2Bits,tab,1);

  // RBER for Class1b Bits
  RSCMU300_Status = RSCMU300_GetMatchingValue(RBERClass1bBits,tab,2);

  // Frame erasure rate
  RSCMU300_Status = RSCMU300_GetMatchingValue(frameErasureRate,tab,3);

  // Cyclic redundancy check
  RSCMU300_Status = RSCMU300_GetMatchingValue(CRCErrors,tab,4);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *        BER MEASUREMENTS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: BER: measured values...
/* Purpose : This function starts a bit-error-rate test and output the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_ReadBer (ViSession instrSession,
                                                                       ViPReal64 progressTime,
                                                                       ViPReal64 RBERClass2Bits,
                                                                       ViPReal64 RBERClass1bBits,
                                                                       ViPInt32  CRCerrors,
                                                                       ViPInt32  measurementStatus,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:RXQ:BER?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", RBERClass2Bits);
  else *RBERClass2Bits = RSCMU300_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%le", RBERClass1bBits);
  else *RBERClass1bBits = RSCMU300_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (measurementStatus, tab, 4);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BER: fetch measured values...
/* Purpose : This function output the last measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_FetcBer (ViSession instrSession,
                                                                       ViPReal64 progressTime,
                                                                       ViPReal64 RBERClass2Bits,
                                                                       ViPReal64 RBERClass1bBits,
                                                                       ViPInt32  CRCerrors,
                                                                       ViPInt32  measurementStatus,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:RXQ:BER?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", RBERClass2Bits);
  else *RBERClass2Bits = RSCMU300_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%le", RBERClass1bBits);
  else *RBERClass1bBits = RSCMU300_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (measurementStatus, tab, 4);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BER: sample measured values...
/* Purpose : This function output the last measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_SampBer (ViSession instrSession,
                                                                       ViPReal64 progressTime,
                                                                       ViPReal64 RBERClass2Bits,
                                                                       ViPReal64 RBERClass1bBits,
                                                                       ViPInt32  CRCerrors,
                                                                       ViPInt32  measurementStatus,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:RXQ:BER?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", RBERClass2Bits);
  else *RBERClass2Bits = RSCMU300_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%le", RBERClass1bBits);
  else *RBERClass1bBits = RSCMU300_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (measurementStatus, tab, 4);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BER: Matching Tolerances
/* Purpose : This Function indicates whether and in which way the
/*           permissible error limits for the measured values of the bit
/*           error rate test have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_CalcBerLimMatc (ViSession instrSession,
                                                                              ViPInt32  total,
                                                                              ViPInt32  RBERClass2Bits,
                                                                              ViPInt32  RBERClass1bBits,
                                                                              ViPInt32  CRCErrors,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CALC:RXQ:BER:MATC:LIM?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMatchingValue(total,tab,0);

  // RBER for Class2 Bits
  RSCMU300_Status = RSCMU300_GetMatchingValue(RBERClass2Bits,tab,1);

  // RBER for Class1b Bits
  RSCMU300_Status = RSCMU300_GetMatchingValue(RBERClass1bBits,tab,2);

  // Cyclic redundancy check
  RSCMU300_Status = RSCMU300_GetMatchingValue(CRCErrors,tab,3);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *        BURST BY BURST MEASUREMENTS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: BBB: measured values...
/* Purpose : This function starts a bit-error-rate test and outputs the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Bbb_ReadBer (ViSession instrSession,
                                                                       ViPReal64 progressTime,
                                                                       ViPReal64 rawBER,
                                                                       ViPInt32  CRCerrors,
                                                                       ViPInt32  status,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:RXQ:BER?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the raw bit error rate
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", rawBER);
  else *rawBER = RSCMU300_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 3);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BBB: fetch measured values...
/* Purpose : This function outputs the bit-error-rate measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Bbb_FetcBer (ViSession instrSession,
                                                                       ViPReal64 progressTime,
                                                                       ViPReal64 rawBER,
                                                                       ViPInt32  CRCerrors,
                                                                       ViPInt32  status,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:RXQ:BER?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the raw bit error rate
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", rawBER);
  else *rawBER = RSCMU300_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 3);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BBB: sample measured values...
/* Purpose : This function starts a bit-error-rate test and outputs the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Bbb_SampBer (ViSession instrSession,
                                                                       ViPReal64 progressTime,
                                                                       ViPReal64 rawBER,
                                                                       ViPInt32  CRCerrors,
                                                                       ViPInt32  status,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:RXQ:BER?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the raw bit error rate
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", rawBER);
  else *rawBER = RSCMU300_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 3);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BBB: Matching Tolerances
/* Purpose : This Function indicates whether and in which way the
/*           permissible error limits for the measured values of the
/*           bit-error-rate have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Bbb_CalcBerLimMatc (ViSession instrSession,
                                                                              ViPInt32  total,
                                                                              ViPInt32  rawBER,
                                                                              ViPInt32  CRCerrors,
                                                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CALC:RXQ:BER:MATC:LIM?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMatchingValue(total,tab,0);

  // Raw bit error rate
  RSCMU300_Status = RSCMU300_GetMatchingValue(rawBER,tab,1);

  // Cyclic redundancy check
  RSCMU300_Status = RSCMU300_GetMatchingValue(CRCerrors,tab,2);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *        BER CIRCUIT-SWITCHED DATA MEASUREMENTS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: BER CSD: measured values...
/* Purpose : This function starts a bit-error-rate test and outputs the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_BerCsd_ReadBer (ViSession instrSession,
                                                                          ViPReal64 progressTime,
                                                                          ViPReal64 BER_CS,
                                                                          ViPInt32  CRCerrors,
                                                                          ViPInt32  status,
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:RXQ:BER?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate circuit-switched
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", BER_CS);
  else *BER_CS = RSCMU300_NAN;
  // 3rd result is non significant
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 4);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BER CSD: fetch measured values...
/* Purpose : This function outputs the bit-error-rate measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_BerCsd_FetcBer (ViSession instrSession,
                                                                          ViPReal64 progressTime,
                                                                          ViPReal64 BER_CS,
                                                                          ViPInt32  CRCerrors,
                                                                          ViPInt32  status,
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:RXQ:BER?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate circuit-switched
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", BER_CS);
  else *BER_CS = RSCMU300_NAN;
  // 3rd result is non significant
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 4);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BER CSD: measured values...
/* Purpose : This function starts a bit-error-rate test and outputs the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_BerCsd_SampBer (ViSession instrSession,
                                                                          ViPReal64 progressTime,
                                                                          ViPReal64 BER_CS,
                                                                          ViPInt32  CRCerrors,
                                                                          ViPInt32  status,
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:RXQ:BER?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate circuit-switched
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", BER_CS);
  else *BER_CS = RSCMU300_NAN;
  // 3rd result is non significant
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 4);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *        RFER PACKET-SWITCHED DATA MEASUREMENTS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: RFER PSD: measured values...
/* Purpose : This function starts a bit-error-rate test and outputs the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_RferPsd_ReadBer (ViSession instrSession,
                                                                           ViPReal64 progressTime,
                                                                           ViPReal64 BER_PS,
                                                                           ViPReal64 Dbler,
                                                                           ViPInt32  CRCerrors,
                                                                           ViPInt32  status,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:RXQ:BER?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate packet-switched
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", BER_PS);
  else *BER_PS = RSCMU300_NAN;
  // 3rd result is non significant
  // Get the DBLER
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%le", Dbler);
  else *Dbler = RSCMU300_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[4], "NAN") != 0)
    sscanf (tab[4], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 5);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: RFER PSD: measured values...
/* Purpose : This function outputs the measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_RferPsd_FetcBer (ViSession instrSession,
                                                                           ViPReal64 progressTime,
                                                                           ViPReal64 BER_PS,
                                                                           ViPReal64 Dbler,
                                                                           ViPInt32  CRCerrors,
                                                                           ViPInt32  status,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:RXQ:BER?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate packet-switched
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", BER_PS);
  else *BER_PS = RSCMU300_NAN;
  // 3rd result is non significant
  // Get the DBLER
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%le", Dbler);
  else *Dbler = RSCMU300_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[4], "NAN") != 0)
    sscanf (tab[4], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 5);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: RFER PSD: measured values...
/* Purpose : This function starts a bit-error-rate test and outputs the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_RferPsd_SampBer (ViSession instrSession,
                                                                           ViPReal64 progressTime,
                                                                           ViPReal64 BER_PS,
                                                                           ViPReal64 Dbler,
                                                                           ViPInt32  CRCerrors,
                                                                           ViPInt32  status,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:RXQ:BER?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate packet-switched
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", BER_PS);
  else *BER_PS = RSCMU300_NAN;
  // 3rd result is non significant
  // Get the DBLER
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%le", Dbler);
  else *Dbler = RSCMU300_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[4], "NAN") != 0)
    sscanf (tab[4], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 5);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *        BER PACKET-SWITCHED DATA MEASUREMENTS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: BER PSD: measured values...
/* Purpose : This function starts a bit-error-rate test and outputs the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_BerPsd_ReadBer (ViSession instrSession,
                                                                          ViPReal64 progressTime,
                                                                          ViPReal64 BER_PS,
                                                                          ViPInt32  CRCerrors,
                                                                          ViPInt32  status,
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:RXQ:BER?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate circuit-switched
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", BER_PS);
  else *BER_PS = RSCMU300_NAN;
  // 3rd result is non significant
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 4);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BER PSD: measured values...
/* Purpose : This function outputs the measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_BerPsd_FetcBer (ViSession instrSession,
                                                                          ViPReal64 progressTime,
                                                                          ViPReal64 BER_PS,
                                                                          ViPInt32  CRCerrors,
                                                                          ViPInt32  status,
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:RXQ:BER?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate circuit-switched
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", BER_PS);
  else *BER_PS = RSCMU300_NAN;
  // 3rd result is non significant
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 4);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BER PSD: measured values...
/* Purpose : This function starts a bit-error-rate test and outputs the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_BerPsd_SampBer (ViSession instrSession,
                                                                          ViPReal64 progressTime,
                                                                          ViPReal64 BER_PS,
                                                                          ViPInt32  CRCerrors,
                                                                          ViPInt32  status,
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:RXQ:BER?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate circuit-switched
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", BER_PS);
  else *BER_PS = RSCMU300_NAN;
  // 3rd result is non significant
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 4);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      BER Average measurement
 *
 *      The subsystem RXQuality:BAVerage:CONTrol sets the parameters for the
 *      continuous receiver quality measurement. The subsystem corresponds to
 *      the tab Control in the popup menu Receiver Quality Configuration.
 *-----------------------------------------------------------------------------
 *         CONFIGURATION CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Frames to average
/* Purpose : This command defines the measured value and the number of frames
/*           to be averaged in the continuous measurement, constituting a
/*           statistics cycle. For definition of the measured value (BER, RBER
/*           etc.) see chapter 4.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBavCont (ViSession instrSession,
                                                ViInt32   mode,
                                                ViInt32   numberOfFrames,
                                                ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViString    StrMode[] = {"BER","RFER","BBB","BDBL"};
  struct RSCMU300_SESSION_Globals  *p_globalvarBase;
  GET_BUFS(instrSession);

  // Queries the specified attribute:
  CHECKRET(viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, numberOfFrames, RSCMU300_NBFRAMES_MIN, RSCMU300_NBFRAMESAVER_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
    CHECK_VI_INT32_RANGE(instrSession, mode, RSCMU300_BER, RSCMU300_BBB, RSCMU_ERROR_PARAMETER2, errorMessage);
    }
  else
    {
    CHECK_VI_INT32_RANGE(instrSession, mode, RSCMU300_BER, RSCMU300_DBLER, RSCMU_ERROR_PARAMETER2, errorMessage);
    }

  sprintf (wrtBuf, "CONF:RXQ:BAV:CONT %s,%ld", StrMode[mode],numberOfFrames);
  RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Set Sensitivity Tests Cycles
/* Purpose : This function determines the stop condition and the
/*           stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBavContRep (ViSession instrSession,
                                                                          ViInt32   StopCondition,
                                                                          ViInt32   StepMode,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    mode_StopConditionBER[] = {"NONE","ALIM","FLIM"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StopCondition, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:RXQ:BAV:CONT:REP %s,%s", mode_StopConditionBER[StopCondition]
                                                , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Level in the used timeslot
/* Purpose : This function sets the TCH absolute level in the used
/*           timeslot. The permissible value range depends on the used
/*           RF output of the CMU and the external attenuation set.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBavContLevUtim (ViSession instrSession,
                                                                              ViReal64  Level,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used
  CHECK_VI_REAL64_RANGE(instrSession, Level, RSCMU300_ABSLEVEL_MIN, RSCMU300_ABSLEVEL_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set absolute level in used timeslot
  sprintf (wrtBuf, "CONF:RXQ:BAV:CONT:LEV:UTIM %.12f", Level);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Level in the unused timeslots
/* Purpose : This function sets the TCH relative level in the unused
/*           timeslots relative to the level in the used timeslot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBavContLevUnt (ViSession instrSession,
                                                                             ViReal64  Level,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, Level, RSCMU300_GSM_SIG_UNUSEDSLOTMIN, RSCMU300_GSM_SIG_UNUSEDSLOTMAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  // Set absolute level for Unused Slots
  sprintf (wrtBuf, "CONF:RXQ:BAV:CONT:LEV:UNT %.12f", Level);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      LIMITS
 *      The subsystem RXQuality:...:LIMit contains the commands for
 *      definition of tolerance values for the receiver quality.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Setting
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBavLimDef (ViSession instrSession,
                                                                         ViBoolean enableDefaultParameters,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, enableDefaultParameters, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (enableDefaultParameters)
  {
    sprintf (wrtBuf, "DEF:RXQ:BAV:LIM %s", mode_On_Off[enableDefaultParameters]);
    if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
      return RSCMU300_Status;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Bit Error Class 2
/* Purpose : This function defines an upper limit for the bit error rate
/*           of class II (unprotected bits, see chapter 4)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBavLimCLII (ViSession instrSession,
                                                                          ViReal64  Limit,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, Limit, 0, 100, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:RXQ:BAV:LIM:CLII %.12f", Limit);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Bit Error Class 1b
/* Purpose : This function defines an upper limit for the bit error rate
/*           of class IB.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBavLimCLIB (ViSession instrSession,
                                                                          ViReal64  Limit,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, Limit, 0, 100, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:RXQ:BAV:LIM:CLIB %.12f", Limit);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Frame error rate
/* Purpose : This function defines an upper limit for the relative
/*           portion of invalid and therefore erased frames in the
/*           measurementof the sensisitivity.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBavLimFERR (ViSession instrSession,
                                                                          ViReal64  Limit,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, Limit, 0, 100, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:RXQ:BAV:LIM:FERR %.12f", Limit);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Data Block error rate
/* Purpose : This function defines an upper limit for the ratio of blocks with
/* bit errors in their data field to the total number of transferred blocks
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBavLimDBLER (ViSession instrSession,
                                                    ViReal64  Limit,
                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  RETMSG(RSCMU300_setViReal64(instrSession, "CONF:RXQ:BAV:LIM:DBL",
                             Limit, 0.0,100.0,
                             RSCMU_ERROR_PARAMETER2));
}

/*-----------------------------------------------------------------------------
 *      CONTROL OF RXQUALITY MEAS
 *      It contains the functions for general control of the receiver
 *      quality measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Init
/* Purpose : Start measurement without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitBav (ViSession instrSession,
                                                                   ViChar    _VI_FAR errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE]= "";

    if ((RSCMU300_Status = RSCMU300_Query (instrSession, "INIT:RXQ:BAV", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
        return RSCMU300_Status;

    return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : This function aborts running measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborBav (ViSession instrSession,
                                                                   ViChar    _VI_FAR errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE]= "";

    if ((RSCMU300_Status = RSCMU300_Query (instrSession, "ABOR:RXQ:BAV", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
        return RSCMU300_Status;

    return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : This function stops running measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopBav (ViSession instrSession,
                                                                   ViChar    _VI_FAR errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE]= "";

    if ((RSCMU300_Status = RSCMU300_Query (instrSession, "STOP:RXQ:BAV", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
        return RSCMU300_Status;

    return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : This function proceed with next measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContBav (ViSession instrSession,
                                                                   ViChar    _VI_FAR errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE]= "";

    if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CONT:RXQ:BAV", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
        return RSCMU300_Status;

    return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Measurement Status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcBavSt (ViSession instrSession,
                                                                     ViPInt32  MeasStatus,
                                                                     ViPInt32  CurrentEvalPeriodCount,
                                                                     ViChar    _VI_FAR errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE] = "";
    ViChar      tab[100][100];

    // Fetch the measurement status:
    if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:RXQ:BAV:STAT?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
        return RSCMU300_Status;

    // Separate the CMU response:
    RSCMU300_SeparateDataValues (rdBuf, ",", tab);

    // Get the measurement status
    RSCMU300_Status = RSCMU300_GetMeasStatVal(MeasStatus, tab, 0 );

    // Get the counter for current evaluation period within a cycle
    RSCMU300_Status = RSCMU300_GetViInt32Value(tab, 1, CurrentEvalPeriodCount);

    return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBavErep (ViSession instrSession,
                                                                       ViInt32   Mode,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:RXQ:BAV:EREP %s", StrErep[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      RESULTS: BIT ERROR RATE
 *      This subsystem (RXQ:...[:RESULT]) contains the functions for measurement
 *      and output of the bit error rate and its comparison with the tolerance
 *      values. The subsystem corresponds to the measurement menus Bit Error
 *      Rate for the different types of measurement (single shot or continuous)
 *      and measured values (RFER, BER, BBB).
 *-----------------------------------------------------------------------------
 *        RFER MEASUREMENTS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: RFER: measured values...
/* Purpose : This function start a bit-error-rate test and output the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_ReadBav (ViSession instrSession,
                                                                        ViPReal64 progressTime,
                                                                        ViPReal64 RBERClass2Bits,
                                                                        ViPReal64 RBERClass1bBits,
                                                                        ViPReal64 frameErasureRate,
                                                                        ViPInt32  CRCerrors,
                                                                        ViPInt32  measurementStatus,
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:RXQ:BAV?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", RBERClass2Bits);
  else *RBERClass2Bits = RSCMU300_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%le", RBERClass1bBits);
  else *RBERClass1bBits = RSCMU300_NAN;
  // Get the Frame Erasure Rate
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%le", frameErasureRate);
  else *frameErasureRate = RSCMU300_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[4], "NAN") != 0)
    sscanf (tab[4], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (measurementStatus, tab, 5);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: RFER: fetch measured values...
/* Purpose : This function output the last measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_FetcBav (ViSession instrSession,
                                                                        ViPReal64 progressTime,
                                                                        ViPReal64 RBERClass2Bits,
                                                                        ViPReal64 RBERClass1bBits,
                                                                        ViPReal64 frameErasureRate,
                                                                        ViPInt32  CRCerrors,
                                                                        ViPInt32  measurementStatus,
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:RXQ:BAV?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", RBERClass2Bits);
  else *RBERClass2Bits = RSCMU300_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%le", RBERClass1bBits);
  else *RBERClass1bBits = RSCMU300_NAN;
  // Get the Frame Erasure Rate
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%le", frameErasureRate);
  else *frameErasureRate = RSCMU300_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[4], "NAN") != 0)
    sscanf (tab[4], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (measurementStatus, tab, 5);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: RFER: sample measured values...
/* Purpose : This function output the last measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_SampBav (ViSession instrSession,
                                                                        ViPReal64 progressTime,
                                                                        ViPReal64 RBERClass2Bits,
                                                                        ViPReal64 RBERClass1bBits,
                                                                        ViPReal64 frameErasureRate,
                                                                        ViPInt32  CRCerrors,
                                                                        ViPInt32  measurementStatus,
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:RXQ:BAV?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", RBERClass2Bits);
  else *RBERClass2Bits = RSCMU300_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%le", RBERClass1bBits);
  else *RBERClass1bBits = RSCMU300_NAN;
  // Get the Frame Erasure Rate
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%le", frameErasureRate);
  else *frameErasureRate = RSCMU300_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[4], "NAN") != 0)
    sscanf (tab[4], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (measurementStatus, tab, 5);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: RFER: Matching Tolerances
/* Purpose : This Function indicates whether and in which way the
/*           permissibleerror limits for the measured values of the bit
/*           error rate test have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_CalcBavLimMatc (ViSession instrSession,
                                                                               ViPInt32  total,
                                                                               ViPInt32  RBERClass2Bits,
                                                                               ViPInt32  RBERClass1bBits,
                                                                               ViPInt32  frameErasureRate,
                                                                               ViPInt32  CRCErrors,
                                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CALC:RXQ:BAV:MATC:LIM?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMatchingValue(total,tab,0);

  // RBER for Class2 Bits
  RSCMU300_Status = RSCMU300_GetMatchingValue(RBERClass2Bits,tab,1);

  // RBER for Class1b Bits
  RSCMU300_Status = RSCMU300_GetMatchingValue(RBERClass1bBits,tab,2);

  // Frame erasure rate
  RSCMU300_Status = RSCMU300_GetMatchingValue(frameErasureRate,tab,3);

  // Cyclic redundancy check
  RSCMU300_Status = RSCMU300_GetMatchingValue(CRCErrors,tab,4);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *        BER MEASUREMENTS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: BER: measured values...
/* Purpose : This function start a bit-error-rate test and output the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_ReadBav (ViSession instrSession,
                                                                       ViPReal64 progressTime,
                                                                       ViPReal64 RBERClass2Bits,
                                                                       ViPReal64 RBERClass1bBits,
                                                                       ViPInt32  CRCerrors,
                                                                       ViPInt32  measurementStatus,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:RXQ:BAV?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", RBERClass2Bits);
  else *RBERClass2Bits = RSCMU300_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%le", RBERClass1bBits);
  else *RBERClass1bBits = RSCMU300_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (measurementStatus, tab, 4);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BER: fetch measured values...
/* Purpose : This function output the last measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_FetcBav (ViSession instrSession,
                                                                       ViPReal64 progressTime,
                                                                       ViPReal64 RBERClass2Bits,
                                                                       ViPReal64 RBERClass1bBits,
                                                                       ViPInt32  CRCerrors,
                                                                       ViPInt32  measurementStatus,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:RXQ:BAV?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", RBERClass2Bits);
  else *RBERClass2Bits = RSCMU300_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%le", RBERClass1bBits);
  else *RBERClass1bBits = RSCMU300_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (measurementStatus, tab, 4);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BER: sample measured values...
/* Purpose : This function output the last measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_SampBav (ViSession instrSession,
                                                                       ViPReal64 progressTime,
                                                                       ViPReal64 RBERClass2Bits,
                                                                       ViPReal64 RBERClass1bBits,
                                                                       ViPInt32  CRCerrors,
                                                                       ViPInt32  measurementStatus,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:RXQ:BAV?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", RBERClass2Bits);
  else *RBERClass2Bits = RSCMU300_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%le", RBERClass1bBits);
  else *RBERClass1bBits = RSCMU300_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (measurementStatus, tab, 4);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BER: Matching Tolerances
/* Purpose : This Function indicates whether and in which way the
/*           permissibleerror limits for the measured values of the bit
/*           error rate test have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_CalcBavLimMatc (ViSession instrSession,
                                                                              ViPInt32  total,
                                                                              ViPInt32  RBERClass2Bits,
                                                                              ViPInt32  RBERClass1bBits,
                                                                              ViPInt32  CRCErrors,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CALC:RXQ:BAV:MATC:LIM?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMatchingValue(total,tab,0);

  // RBER for Class2 Bits
  RSCMU300_Status = RSCMU300_GetMatchingValue(RBERClass2Bits,tab,1);

  // RBER for Class1b Bits
  RSCMU300_Status = RSCMU300_GetMatchingValue(RBERClass1bBits,tab,2);

  // Cyclic redundancy check
  RSCMU300_Status = RSCMU300_GetMatchingValue(CRCErrors,tab,3);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *        BURST BY BURST MEASUREMENTS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: BBB: measured values...
/* Purpose : This function starts a bit-error-rate test and outputs the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Bbb_ReadBav (ViSession instrSession,
                                                                       ViPReal64 progressTime,
                                                                       ViPReal64 rawBER,
                                                                       ViPInt32  CRCerrors,
                                                                       ViPInt32  status,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:RXQ:BAV?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the raw bit error rate
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", rawBER);
  else *rawBER = RSCMU300_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 3);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BBB: fetch measured values...
/* Purpose : This function outputs the bit-error-rate measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Bbb_FetcBav (ViSession instrSession,
                                                                       ViPReal64 progressTime,
                                                                       ViPReal64 rawBER,
                                                                       ViPInt32  CRCerrors,
                                                                       ViPInt32  status,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:RXQ:BAV?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the raw bit error rate
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", rawBER);
  else *rawBER = RSCMU300_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 3);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BBB: sample measured values...
/* Purpose : This function starts a bit-error-rate test and outputs the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Bbb_SampBav (ViSession instrSession,
                                                                       ViPReal64 progressTime,
                                                                       ViPReal64 rawBER,
                                                                       ViPInt32  CRCerrors,
                                                                       ViPInt32  status,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:RXQ:BAV?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the raw bit error rate
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", rawBER);
  else *rawBER = RSCMU300_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 3);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BBB: Matching Tolerances
/* Purpose : This Function indicates whether and in which way the
/*           permissible error limits for the measured values of the
/*           bit-error-rate have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Bbb_CalcBavLimMatc (ViSession instrSession,
                                                                              ViPInt32  total,
                                                                              ViPInt32  rawBER,
                                                                              ViPInt32  CRCerrors,
                                                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CALC:RXQ:BAV:MATC:LIM?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMatchingValue(total,tab,0);

  // Raw bit error rate
  RSCMU300_Status = RSCMU300_GetMatchingValue(rawBER,tab,1);

  // Cyclic redundancy check
  RSCMU300_Status = RSCMU300_GetMatchingValue(CRCerrors,tab,2);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *        BER CIRCUIT-SWITCHED DATA MEASUREMENTS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: BER CSD: measured values...
/* Purpose : This function starts a bit-error-rate test and outputs the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_BerCsd_ReadBav (ViSession instrSession,
                                                                          ViPReal64 progressTime,
                                                                          ViPReal64 BER_CS,
                                                                          ViPInt32  CRCerrors,
                                                                          ViPInt32  status,
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:RXQ:BAV?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate circuit-switched
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", BER_CS);
  else *BER_CS = RSCMU300_NAN;
  // 3rd result is non significant
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 4);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BER CSD: fetch measured values...
/* Purpose : This function outputs the bit-error-rate measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_BerCsd_FetcBav (ViSession instrSession,
                                                                          ViPReal64 progressTime,
                                                                          ViPReal64 BER_CS,
                                                                          ViPInt32  CRCerrors,
                                                                          ViPInt32  status,
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:RXQ:BAV?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate circuit-switched
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", BER_CS);
  else *BER_CS = RSCMU300_NAN;
  // 3rd result is non significant
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 4);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BER CSD: measured values...
/* Purpose : This function starts a bit-error-rate test and outputs the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_BerCsd_SampBav (ViSession instrSession,
                                                                          ViPReal64 progressTime,
                                                                          ViPReal64 BER_CS,
                                                                          ViPInt32  CRCerrors,
                                                                          ViPInt32  status,
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:RXQ:BAV?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate circuit-switched
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", BER_CS);
  else *BER_CS = RSCMU300_NAN;
  // 3rd result is non significant
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 4);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *        RFER PACKET-SWITCHED DATA MEASUREMENTS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: RFER PSD: measured values...
/* Purpose : This function starts a bit-error-rate test and outputs the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_RferPsd_ReadBav (ViSession instrSession,
                                                                           ViPReal64 progressTime,
                                                                           ViPReal64 BER_PS,
                                                                           ViPReal64 Dbler,
                                                                           ViPInt32  CRCerrors,
                                                                           ViPInt32  status,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:RXQ:BAV?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate packet-switched
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", BER_PS);
  else *BER_PS = RSCMU300_NAN;
  // 3rd result is non significant
  // Get the DBLER
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%le", Dbler);
  else *Dbler = RSCMU300_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[4], "NAN") != 0)
    sscanf (tab[4], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 5);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: RFER PSD: measured values...
/* Purpose : This function outputs the measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_RferPsd_FetcBav (ViSession instrSession,
                                                                           ViPReal64 progressTime,
                                                                           ViPReal64 BER_PS,
                                                                           ViPReal64 Dbler,
                                                                           ViPInt32  CRCerrors,
                                                                           ViPInt32  status,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:RXQ:BAV?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate packet-switched
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", BER_PS);
  else *BER_PS = RSCMU300_NAN;
  // 3rd result is non significant
  // Get the DBLER
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%le", Dbler);
  else *Dbler = RSCMU300_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[4], "NAN") != 0)
    sscanf (tab[4], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 5);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: RFER PSD: measured values...
/* Purpose : This function starts a bit-error-rate test and outputs the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_RferPsd_SampBav (ViSession instrSession,
                                                                           ViPReal64 progressTime,
                                                                           ViPReal64 BER_PS,
                                                                           ViPReal64 Dbler,
                                                                           ViPInt32  CRCerrors,
                                                                           ViPInt32  status,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:RXQ:BAV?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate packet-switched
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", BER_PS);
  else *BER_PS = RSCMU300_NAN;
  // 3rd result is non significant
  // Get the DBLER
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%le", Dbler);
  else *Dbler = RSCMU300_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[4], "NAN") != 0)
    sscanf (tab[4], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 5);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *        BER PACKET-SWITCHED DATA MEASUREMENTS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: BER PSD: measured values...
/* Purpose : This function starts a bit-error-rate test and outputs the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_BerPsd_ReadBav (ViSession instrSession,
                                                                          ViPReal64 progressTime,
                                                                          ViPReal64 BER_PS,
                                                                          ViPInt32  CRCerrors,
                                                                          ViPInt32  status,
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:RXQ:BAV?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate circuit-switched
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", BER_PS);
  else *BER_PS = RSCMU300_NAN;
  // 3rd result is non significant
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 4);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BER PSD: measured values...
/* Purpose : This function outputs the measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_BerPsd_FetcBav (ViSession instrSession,
                                                                          ViPReal64 progressTime,
                                                                          ViPReal64 BER_PS,
                                                                          ViPInt32  CRCerrors,
                                                                          ViPInt32  status,
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:RXQ:BAV?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate circuit-switched
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", BER_PS);
  else *BER_PS = RSCMU300_NAN;
  // 3rd result is non significant
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 4);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BER PSD: measured values...
/* Purpose : This function starts a bit-error-rate test and outputs the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_BerPsd_SampBav (ViSession instrSession,
                                                                          ViPReal64 progressTime,
                                                                          ViPReal64 BER_PS,
                                                                          ViPInt32  CRCerrors,
                                                                          ViPInt32  status,
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:RXQ:BAV?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate circuit-switched
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", BER_PS);
  else *BER_PS = RSCMU300_NAN;
  // 3rd result is non significant
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%ld", CRCerrors);
  else *CRCerrors = RSCMU300_NAN_VI_INT32;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 4);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT RXQUALITY: Abis
 *
 *    In the Abis mode, the BTS decodes the data received and generates a Pulse
 *    Code Modulation (PCM) signal that is directly applied to the CMU's Abis
 *    interface. This bypasses all voice processing stages in the return path
 *    from the BTS under test to the CMU so that bit errors in the return path
 *    are largely excluded.
 *-----------------------------------------------------------------------------
 *         CONFIGURATION CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Interface Mode
/* Purpose : This function selects one of the supported Abis link protocols.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisIMode (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"E1DF","E1CR","T1SF","T1ES","T1CR"};
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 4, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:ABIS:IMOD %s", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Traffic Type
/* Purpose : This function selects the coding scheme and the transmission rate
/*           in the BTS traffic channel transferred via Abis interface.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisTType (ViSession instrSession,
                                                                         ViInt32   Type,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrType[] = {"TTFR","TTEF","TTHR","TF14","TF96","TF48"};
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Type, 0, 5, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:ABIS:TTYP %s", StrType[Type]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: PCM Time Slot
/* Purpose : This function selects the timeslot for the PCM (Pulse Code
/*           Modulation) traffic channel signal. The range of time slot numbers
/*           is restricted to 1 to 24 if a T1 link protocol is selected; see
/*           RSCMU300_GSM_NSig_ConfAbisIMode function.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisPCMTimeSlot (ViSession instrSession,
                                                                               ViInt32   TimeSlot,
                                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TimeSlot, 1, 31, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:ABIS:PCMT %ld", TimeSlot);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Time Slot Bit No
/* Purpose : This function selects the bit numbers within the PCM timeslot
/*       that define a full rate or half rate channel;
/*       see RSCMU300_GSM_Sig_ConfAbisTType function.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisTSBitNo (ViSession instrSession,
                                                                           ViInt32   TSBitno,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrTSBitno[] = {"BN01","BN23","BN45","BN67","BNR1","BNR2","BNR3","BNR4","BNR5","BNR6","BNR7"};
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TSBitno, 0, 10, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:ABIS:TSB %s", StrTSBitno[TSBitno]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Start Values: PCM Time Slot
/* Purpose : This function sets a start value for the PCM Time Slot. The scan
/*       routine (see section Scan - Subsystem ABIS:SCAN on page 10)
/*       searches from the PCM Time Slot defined with the Start Values
/*       softkey upwards.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisStarPCMTimeSlot (ViSession instrSession,
                                                                                   ViInt32   TimeSlot,
                                                                                   ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TimeSlot, 1, 31, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:ABIS:STAR:PCMT %ld", TimeSlot);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Start Values: Sub sChannel
/* Purpose : This function defines whether the Scan (see section Scan
/*       Subsystem ABIS:SCAN on page 10) searches for a full rate or half
/*       rate sub channel.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisStarSubChan (ViSession instrSession,
                                                                               ViInt32   SubChannel,
                                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrSubChannel[] = {"S168","S16K","S8K"};
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, SubChannel, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:ABIS:STAR:SUBC %s", StrSubChannel[SubChannel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *         SUBSYSTEM ABIS:SCAN
 *
 *         The subsystem ABIS:SCAN controls the automatic search for the sub
 *         channel times slot and bit number on the Abis interface. It corres-
 *         ponds to the Scan softkey in the Abis tab of the popup menu Connect.
 *         Control. The results of the scan can be queried by means of the
 *         commands CONFigure:ABIS:PCMTimeslot and CONFigure:ABIS:TSBitno.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Init
/* Purpose : Start the scan without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitAbisScan (ViSession instrSession,
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "INIT:ABIS:SCAN", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : This function aborts the scan
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborAbisScan (ViSession instrSession,
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "ABOR:ABIS:SCAN", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Measurement Status
/* Purpose : This function returns the scan status.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcAbisScanSt (ViSession  instrSession,
                                                                          ViInt32   *Status,
                                                                          ViChar     _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Fetch the measurement status:
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:ABIS:SCAN:STAT?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Get the RF generator status value:
  *Status = RSCMU300_GetStatVal (rdBuf);

  if (*Status < 0)
    return RSCMU_ERROR_STAT_UNKNOWN;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *         SUBSYSTEM ABIS:ALARmmonitor
 *
 *         The subsystem ABIS:ALARMMONITOR controls the alarm monitor on the
 *         Abis interface. It corresponds to the Alarm Monitor softkey and the
 *         Alarms output table in the Abis tab of the popup menu Connect.
 *         Control.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Init
/* Purpose : Start alarm monitor without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitAbisAlarm (ViSession instrSession,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "INIT:ABIS:ALAR", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : This function aborts alarm monitor.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborAbisAlarm (ViSession instrSession,
                                                                         ViChar     _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "ABOR:ABIS:ALAR", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Alarm Monitor Status
/* Purpose : This function returns the status of the alarm monitor.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcAbisAlarmSt (ViSession  instrSession,
                                                                           ViInt32   *Status,
                                                                           ViChar     _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Fetch the measurement status:
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:ABIS:ALAR:STAT?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Get the RF generator status value:
  *Status = RSCMU300_GetStatVal (rdBuf);

  if (*Status < 0)
    return RSCMU_ERROR_STAT_UNKNOWN;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Alarms
/* Purpose : This function is always a query. It returns the current result
/*           of the alarm monitor analysis.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensAbisAlarm (ViSession instrSession,
                                                                         ViInt32  *NoSignal,
                                                                         ViInt32  *AIS,
                                                                         ViInt32  *NoSynch,
                                                                         ViInt32  *NoCRC,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SENS:ABIS:ALAR?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get result for alarm type No Signal
  RSCMU300_Status = RSCMU300_GetAlarmResult (NoSignal, tab, 0);
  // Get result for alarm type AIS
  RSCMU300_Status = RSCMU300_GetAlarmResult (AIS, tab, 1);
  // Get result for alarm type No Synchronization
  RSCMU300_Status = RSCMU300_GetAlarmResult (NoSynch, tab, 2);
  // Get result for alarm type No CRC
  RSCMU300_Status = RSCMU300_GetAlarmResult (NoCRC, tab, 3);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      Abis BER measurement
 *
 *      The subsystem RXQuality:ABIS:BER controls the single shot receiver
 *      quality measurements via Abis interface.
 *-----------------------------------------------------------------------------
 *         TEST SETUP
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Test Setup
/* Purpose : This function selects one out of 10 data sets as application,
/*           enabling 10 different single shot Receiver Quality measurements
/*           that can be parameterized. When an application is switched over,
/*           the running measurement is stopped and all measured values are
/*           set invalid.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBerTset (ViSession instrSession,
                                                                           ViInt32   TestSetup,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrTestSetup[]= {"","T1","T2","T3","T4","T5","T6","T7","T8","T9","T10"};
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TestSetup, RSCMU300_T1, RSCMU300_T10, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:RXQ:ABIS:BER:TSET %s", StrTestSetup[TestSetup]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *         CONFIGURATION CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : This function sets all the parmeters of the subsystem to their
/*           default values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBerContDef (ViSession instrSession,
                                                                              ViInt32   TestSetup,
                                                                              ViBoolean EnableDefaultParameters,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TestSetup, RSCMU300_T1, RSCMU300_T10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, EnableDefaultParameters, RSCMU_ERROR_PARAMETER3, errorMessage);

  if (EnableDefaultParameters)
  {
    sprintf (wrtBuf, "DEF:RXQ:ABIS:BER%ld:CONT %s", TestSetup
                                                 , mode_On_Off[EnableDefaultParameters]);
    if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
      return RSCMU300_Status;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Number of frames
/* Purpose : This function defines the measured value, the number of
/*           frames to be averaged in a continuous measurement, and the
/*           number of frames to be sent in a single shot measurement,
/*           constituting a  statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBerCont (ViSession instrSession,
                                                                           ViInt32   TestSetup,
                                                                           ViInt32   mode,
                                                                           ViInt32   numberOfFrames,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"BER","RFER"};   //! the order respects the constants declaration
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TestSetup, RSCMU300_T1, RSCMU300_T10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, mode, 0, 1, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, numberOfFrames, RSCMU300_NBFRAMES_MIN, RSCMU300_NBFRAMESSENT_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:RXQ:ABIS:BER%ld:CONT %s,%ld", TestSetup
                                                   , StrMode[mode]
                                                   , numberOfFrames);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Sensitivity Tests Cycles
/* Purpose : This function determines the stop condition and the
/*           stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBerContRep (ViSession instrSession,
                                                                              ViInt32   TestSetup,
                                                                              ViInt32   StopCondition,
                                                                              ViInt32   StepMode,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    mode_StopConditionBER[] = {"NONE","ALIM","FLIM"};
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TestSetup, RSCMU300_T1, RSCMU300_T10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, StopCondition, 0, 2, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:RXQ:ABIS:BER%ld:CONT:REP %s,%s", TestSetup
                                                       , mode_StopConditionBER[StopCondition]
                                                       , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Level in the used timeslot
/* Purpose : This function sets the TCH absolute level in the used
/*           timeslot. The permissible value range depends on the used
/*           RF output of the CMU and the external attenuation set.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBerContLevUtim (ViSession instrSession,
                                                                                  ViInt32   TestSetup,
                                                                                  ViReal64  Level,
                                                                                  ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used
  CHECK_VI_INT32_RANGE(instrSession, TestSetup, RSCMU300_T1, RSCMU300_T10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, Level, RSCMU300_ABSLEVEL_MIN, RSCMU300_ABSLEVEL_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  // Set absolute level in used timeslot
  sprintf (wrtBuf, "CONF:RXQ:ABIS:BER%ld:CONT:TCH:LEV:UTIM %.12f", TestSetup
                                                              , Level);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Level in the unused timeslots
/* Purpose : This function sets the TCH relative level in the unused
/*           timeslots relative to the level in the used timeslot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBerContLevUnt (ViSession instrSession,
                                                                                 ViInt32   TestSetup,
                                                                                 ViReal64  Level,
                                                                                 ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TestSetup, RSCMU300_T1, RSCMU300_T10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, Level, RSCMU300_GSM_SIG_UNUSEDSLOTMIN, RSCMU300_GSM_SIG_UNUSEDSLOTMAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  // Set absolute level for Unused Slots
  sprintf (wrtBuf, "CONF:RXQ:ABIS:BER%ld:CONT:TCH:LEV:UNT %.12f", TestSetup
                                                             , Level);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      LIMITS
 *      The subsystem RXQuality:ABIS:BER<nr>:LIMit defines tolerance values for
 *      the single shot receiver quality measurements. The subsystem corresponds
 *      to the tab Limits in the popup menu Receiver Quality Configuration.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Setting
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBerLimDef (ViSession instrSession,
                                                                             ViInt32   TestSetup,
                                                                             ViBoolean enableDefaultParameters,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TestSetup, RSCMU300_T1, RSCMU300_T10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, enableDefaultParameters, RSCMU_ERROR_PARAMETER3, errorMessage);

  if (enableDefaultParameters)
  {
    sprintf (wrtBuf, "DEF:RXQ:ABIS:BER%ld:LIM %s", TestSetup
                                                , mode_On_Off[enableDefaultParameters]);
    if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
      return RSCMU300_Status;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Bit Error Class 2
/* Purpose : This function defines an upper limit for the bit error rate
/*           of class II (unprotected bits, see chapter 4)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBerLimCLII (ViSession instrSession,
                                                                              ViInt32   TestSetup,
                                                                              ViReal64  Limit,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TestSetup, RSCMU300_T1, RSCMU300_T10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, Limit, 0, 100, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:RXQ:ABIS:BER%ld:LIM:CLII %.12f", TestSetup
                                                     , Limit);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Bit Error Class 1b
/* Purpose : This function defines an upper limit for the bit error rate
/*           of class IB.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBerLimCLIB (ViSession instrSession,
                                                                              ViInt32   TestSetup,
                                                                              ViReal64  Limit,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TestSetup, RSCMU300_T1, RSCMU300_T10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, Limit, 0, 100, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:RXQ:ABIS:BER%ld:LIM:CLIB %.12f", TestSetup
                                                     , Limit);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Frame error rate
/* Purpose : This function defines an upper limit for the relative
/*           portion of invalid and therefore erased frames in the
/*           measurementof the sensisitivity.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBerLimFERR (ViSession instrSession,
                                                                              ViInt32   TestSetup,
                                                                              ViReal64  Limit,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, Limit, 0, 100, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:RXQ:ABIS:BER%ld:LIM:FERR %.12f", TestSetup
                                                     , Limit);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      CONTROL OF RXQUALITY ABIS MEAS
 *      It contains the functions for general control of the receiver
 *      quality measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Init
/* Purpose : Start measurement without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitAbisBer (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "INIT:RXQ:ABIS:BER", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : This function aborts running measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborAbisBer (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "ABOR:RXQ:ABIS:BER", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : This function stops running measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopAbisBer (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "STOP:RXQ:ABIS:BER", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : This function proceed with next measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContAbisBer (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CONT:RXQ:ABIS:BER", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Measurement Status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcAbisBerSt (ViSession instrSession,
                                                                         ViPInt32  MeasStatus,
                                                                         ViPInt32  CurrentEvalPeriodCount,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Fetch the measurement status:
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:RXQ:ABIS:BER:STAT?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMeasStatVal(MeasStatus, tab, 0 );

  // Get the counter for current evaluation period within a cycle
  RSCMU300_Status = RSCMU300_GetViInt32Value(tab, 1, CurrentEvalPeriodCount);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBerErep (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:RXQ:ABIS:BER:EREP %s", StrErep[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      RESULTS: BIT ERROR RATE
 *
 *      The subsystem RXQuality:ABIS:BER measures the bit error rate and compares
 *      it with the tolerance values. The subsystem corresponds to the measurement
 *      menus Receiver Quality in the BER application.
 *-----------------------------------------------------------------------------
 *        RFER MEASUREMENTS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: RFER: measured values...
/* Purpose : This function start a bit-error-rate test and output the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_ReadAbisBer (ViSession  instrSession,
                                                                            ViReal64  *progressTime,
                                                                            ViReal64  *RFERClass2Bits,
                                                                            ViReal64  *RFERClass1bBits,
                                                                            ViReal64  *frameErasureRate,
                                                                            ViInt32   *measurementStatus,
                                                                            ViChar     _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:RXQ:ABIS:BER?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", RFERClass2Bits);
  else *RFERClass2Bits = RSCMU300_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%le", RFERClass1bBits);
  else *RFERClass1bBits = RSCMU300_NAN;
  // Get the Frame Erasure Rate
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%le", frameErasureRate);
  else *frameErasureRate = RSCMU300_NAN;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (measurementStatus, tab, 4);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: RFER: fetch measured values...
/* Purpose : This function output the last measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_FetcAbisBer (ViSession  instrSession,
                                                                            ViReal64  *progressTime,
                                                                            ViReal64  *RFERClass2Bits,
                                                                            ViReal64  *RFERClass1bBits,
                                                                            ViReal64  *frameErasureRate,
                                                                            ViInt32   *measurementStatus,
                                                                            ViChar     _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:RXQ:ABIS:BER?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", RFERClass2Bits);
  else *RFERClass2Bits = RSCMU300_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%le", RFERClass1bBits);
  else *RFERClass1bBits = RSCMU300_NAN;
  // Get the Frame Erasure Rate
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%le", frameErasureRate);
  else *frameErasureRate = RSCMU300_NAN;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (measurementStatus, tab, 4);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: RFER: sample measured values...
/* Purpose : This function output the last measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_SampAbisBer (ViSession  instrSession,
                                                                            ViReal64  *progressTime,
                                                                            ViReal64  *RFERClass2Bits,
                                                                            ViReal64  *RFERClass1bBits,
                                                                            ViReal64  *frameErasureRate,
                                                                            ViInt32   *measurementStatus,
                                                                            ViChar     _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:RXQ:ABIS:BER?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", RFERClass2Bits);
  else *RFERClass2Bits = RSCMU300_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%le", RFERClass1bBits);
  else *RFERClass1bBits = RSCMU300_NAN;
  // Get the Frame Erasure Rate
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%le", frameErasureRate);
  else *frameErasureRate = RSCMU300_NAN;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (measurementStatus, tab, 4);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: RFER: Matching Tolerances
/* Purpose : This Function indicates whether and in which way the
/*           permissibleerror limits for the measured values of the bit
/*           error rate test have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_CalcAbisBerLimMatc (ViSession  instrSession,
                                                                                   ViInt32   *total,
                                                                                   ViInt32   *RFERClass2Bits,
                                                                                   ViInt32   *RFERClass1bBits,
                                                                                   ViInt32   *frameErasureRate,
                                                                                   ViChar     _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CALC:RXQ:ABIS:BER:MATC:LIM?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMatchingValue(total,tab,0);

  // RFER for Class2 Bits
  RSCMU300_Status = RSCMU300_GetMatchingValue(RFERClass2Bits,tab,1);

  // RFER for Class1b Bits
  RSCMU300_Status = RSCMU300_GetMatchingValue(RFERClass1bBits,tab,2);

  // Frame erasure rate
  RSCMU300_Status = RSCMU300_GetMatchingValue(frameErasureRate,tab,3);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *        BER MEASUREMENTS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: BER: measured values...
/* Purpose : This function start a bit-error-rate test and output the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_ReadAbisBer (ViSession  instrSession,
                                                                           ViReal64  *progressTime,
                                                                           ViReal64  *BERClass2Bits,
                                                                           ViReal64  *BERClass1bBits,
                                                                           ViInt32   *measurementStatus,
                                                                           ViChar     _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:RXQ:ABIS:BER?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", BERClass2Bits);
  else *BERClass2Bits = RSCMU300_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%le", BERClass1bBits);
  else *BERClass1bBits = RSCMU300_NAN;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (measurementStatus, tab, 3);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BER: fetch measured values...
/* Purpose : This function output the last measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_FetcAbisBer (ViSession  instrSession,
                                                                           ViReal64  *progressTime,
                                                                           ViReal64  *BERClass2Bits,
                                                                           ViReal64  *BERClass1bBits,
                                                                           ViInt32   *measurementStatus,
                                                                           ViChar     _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:RXQ:ABIS:BER?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", BERClass2Bits);
  else *BERClass2Bits = RSCMU300_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%le", BERClass1bBits);
  else *BERClass1bBits = RSCMU300_NAN;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (measurementStatus, tab, 3);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BER: sample measured values...
/* Purpose : This function output the last measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_SampAbisBer (ViSession  instrSession,
                                                                           ViReal64  *progressTime,
                                                                           ViReal64  *BERClass2Bits,
                                                                           ViReal64  *BERClass1bBits,
                                                                           ViInt32   *measurementStatus,
                                                                           ViChar     _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:RXQ:ABIS:BER?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", BERClass2Bits);
  else *BERClass2Bits = RSCMU300_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%le", BERClass1bBits);
  else *BERClass1bBits = RSCMU300_NAN;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (measurementStatus, tab, 3);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BER: Matching Tolerances
/* Purpose : This Function indicates whether and in which way the
/*           permissibleerror limits for the measured values of the bit
/*           error rate test have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_CalcAbisBerLimMatc (ViSession  instrSession,
                                                                                  ViInt32   *total,
                                                                                  ViInt32   *BERClass2Bits,
                                                                                  ViInt32   *BERClass1bBits,
                                                                                  ViChar     _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CALC:RXQ:ABIS:BER:MATC:LIM?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMatchingValue(total,tab,0);

  // BER for Class2 Bits
  RSCMU300_Status = RSCMU300_GetMatchingValue(BERClass2Bits,tab,1);

  // BER for Class1b Bits
  RSCMU300_Status = RSCMU300_GetMatchingValue(BERClass1bBits,tab,2);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      BER Average measurement
 *
 *      The subsystem RXQuality:BAVerage:CONTrol sets the parameters for the
 *      continuous receiver quality measurement. The subsystem corresponds to
 *      the tab Control in the popup menu Receiver Quality Configuration.
 *-----------------------------------------------------------------------------
 *         CONFIGURATION CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : This function sets all the parmeters of the subsystem to their
/*           default values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBavContDef (ViSession instrSession,
                                                                              ViBoolean EnableDefaultParameters,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, EnableDefaultParameters, RSCMU_ERROR_PARAMETER3, errorMessage);

  if (EnableDefaultParameters)
  {
    sprintf (wrtBuf, "DEF:RXQ:ABIS:BAV:CONT %s", mode_On_Off[EnableDefaultParameters]);
    if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
      return RSCMU300_Status;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Frames to average
/* Purpose : This command defines the measured value and the number of frames
/*           to be averaged in the continuous measurement, constituting a
/*           statistics cycle. For definition of the measured value (BER, RFER
/*           etc.) see chapter 4.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBavCont (ViSession instrSession,
                                                                           ViInt32   mode,
                                                                           ViInt32   numberOfFrames,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"BER","RFER"};
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, mode, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, numberOfFrames, RSCMU300_NBFRAMES_MIN, RSCMU300_NBFRAMESAVER_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:RXQ:ABIS:BAV:CONT %s,%ld", StrMode[mode]
                                                 , numberOfFrames);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Sensitivity Tests Cycles
/* Purpose : This function determines the stop condition and the
/*           stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBavContRep (ViSession instrSession,
                                                                              ViInt32   StopCondition,
                                                                              ViInt32   StepMode,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    mode_StopConditionBER[] = {"NONE","ALIM","FLIM"};
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StopCondition, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:RXQ:ABIS:BAV:CONT:REP %s,%s", mode_StopConditionBER[StopCondition]
                                                     , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Level in the used timeslot
/* Purpose : This function sets the TCH absolute level in the used
/*           timeslot. The permissible value range depends on the used
/*           RF output of the CMU and the external attenuation set.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBavContLevUtim (ViSession instrSession,
                                                                                  ViReal64  Level,
                                                                                  ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used
  CHECK_VI_REAL64_RANGE(instrSession, Level, RSCMU300_ABSLEVEL_MIN, RSCMU300_ABSLEVEL_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set absolute level in used timeslot
  sprintf (wrtBuf, "CONF:RXQ:ABIS:BAV:CONT:LEV:UTIM %.12f", Level);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Level in the unused timeslots
/* Purpose : This function sets the TCH relative level in the unused
/*           timeslots relative to the level in the used timeslot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBavContLevUnt (ViSession instrSession,
                                                                                 ViReal64  Level,
                                                                                 ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, Level, RSCMU300_GSM_SIG_UNUSEDSLOTMIN, RSCMU300_GSM_SIG_UNUSEDSLOTMAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  // Set absolute level for Unused Slots
  sprintf (wrtBuf, "CONF:RXQ:ABIS:BAV:CONT:LEV:UNT %.12f", Level);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      LIMITS
 *      The subsystem RXQuality:...:LIMit contains the commands for
 *      definition of tolerance values for the receiver quality.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Setting
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBavLimDef (ViSession instrSession,
                                                                             ViBoolean enableDefaultParameters,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, enableDefaultParameters, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (enableDefaultParameters)
  {
    sprintf (wrtBuf, "DEF:RXQ:ABIS:BAV:LIM %s", mode_On_Off[enableDefaultParameters]);
    if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
      return RSCMU300_Status;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Bit Error Class 2
/* Purpose : This function defines an upper limit for the bit error rate
/*           of class II (unprotected bits, see chapter 4)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBavLimCLII (ViSession instrSession,
                                                                              ViReal64  Limit,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, Limit, 0, 100, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:RXQ:ABIS:BAV:LIM:CLII %.12f", Limit);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Bit Error Class 1b
/* Purpose : This function defines an upper limit for the bit error rate
/*           of class IB.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBavLimCLIB (ViSession instrSession,
                                                                              ViReal64  Limit,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, Limit, 0, 100, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:RXQ:ABIS:BAV:LIM:CLIB %.12f", Limit);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Frame error rate
/* Purpose : This function defines an upper limit for the relative
/*           portion of invalid and therefore erased frames in the
/*           measurementof the sensisitivity.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBavLimFERR (ViSession instrSession,
                                                                              ViReal64  Limit,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, Limit, 0, 100, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:RXQ:ABIS:BAV:LIM:FERR %.12f", Limit);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      CONTROL OF RXQUALITY MEAS
 *      It contains the functions for general control of the receiver
 *      quality measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Init
/* Purpose : Start measurement without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitAbisBav (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "INIT:RXQ:ABIS:BAV", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : This function aborts running measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborAbisBav (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "ABOR:RXQ:ABIS:BAV", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

 return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : This function stops running measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopAbisBav (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "STOP:RXQ:ABIS:BAV", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : This function proceed with next measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContAbisBav (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CONT:RXQ:ABIS:BAV", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Measurement Status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcAbisBavSt (ViSession instrSession,
                                                                         ViPInt32  MeasStatus,
                                                                         ViPInt32  CurrentEvalPeriodCount,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Fetch the measurement status:
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:RXQ:ABIS:BAV:STAT?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMeasStatVal(MeasStatus, tab, 0 );

  // Get the counter for current evaluation period within a cycle
  RSCMU300_Status = RSCMU300_GetViInt32Value(tab, 1, CurrentEvalPeriodCount);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBavErep (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:RXQ:ABIS:BAV:EREP %s", StrErep[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      RESULTS: BIT ERROR RATE
 *
 *      The subsystem RXQuality:ABIS:BAVerage measures the bit error rate and
 *      compares it with the tolerance values. The subsystem corresponds to the
 *      measurement menus Receiver Quality for the single shot type of measurement
 *      and measured values (RFER, BER, BurstByBurst).
 *-----------------------------------------------------------------------------
 *        RFER MEASUREMENTS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: RFER: measured values...
/* Purpose : This function start a bit-error-rate test and output the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_ReadAbisBav (ViSession  instrSession,
                                                                            ViReal64  *progressTime,
                                                                            ViReal64  *RFERClass2Bits,
                                                                            ViReal64  *RFERClass1bBits,
                                                                            ViReal64  *frameErasureRate,
                                                                            ViInt32   *measurementStatus,
                                                                            ViChar     _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:RXQ:ABIS:BAV?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", RFERClass2Bits);
  else *RFERClass2Bits = RSCMU300_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%le", RFERClass1bBits);
  else *RFERClass1bBits = RSCMU300_NAN;
  // Get the Frame Erasure Rate
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%le", frameErasureRate);
  else *frameErasureRate = RSCMU300_NAN;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (measurementStatus, tab, 4);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: RFER: fetch measured values...
/* Purpose : This function output the last measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_FetcAbisBav (ViSession  instrSession,
                                                                            ViReal64  *progressTime,
                                                                            ViReal64  *RFERClass2Bits,
                                                                            ViReal64  *RFERClass1bBits,
                                                                            ViReal64  *frameErasureRate,
                                                                            ViInt32   *measurementStatus,
                                                                            ViChar     _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:RXQ:ABIS:BAV?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", RFERClass2Bits);
  else *RFERClass2Bits = RSCMU300_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%le", RFERClass1bBits);
  else *RFERClass1bBits = RSCMU300_NAN;
  // Get the Frame Erasure Rate
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%le", frameErasureRate);
  else *frameErasureRate = RSCMU300_NAN;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (measurementStatus, tab, 4);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: RFER: sample measured values...
/* Purpose : This function output the last measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_SampAbisBav (ViSession  instrSession,
                                                                            ViReal64  *progressTime,
                                                                            ViReal64  *RFERClass2Bits,
                                                                            ViReal64  *RFERClass1bBits,
                                                                            ViReal64  *frameErasureRate,
                                                                            ViInt32   *measurementStatus,
                                                                            ViChar     _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:RXQ:ABIS:BAV?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", RFERClass2Bits);
  else *RFERClass2Bits = RSCMU300_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%le", RFERClass1bBits);
  else *RFERClass1bBits = RSCMU300_NAN;
  // Get the Frame Erasure Rate
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%le", frameErasureRate);
  else *frameErasureRate = RSCMU300_NAN;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (measurementStatus, tab, 4);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: RFER: Matching Tolerances
/* Purpose : This Function indicates whether and in which way the
/*           permissibleerror limits for the measured values of the bit
/*           error rate test have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_CalcAbisBavLimMatc (ViSession  instrSession,
                                                                                   ViInt32   *total,
                                                                                   ViInt32   *RBERClass2Bits,
                                                                                   ViInt32   *RBERClass1bBits,
                                                                                   ViInt32   *frameErasureRate,
                                                                                   ViChar     _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CALC:RXQ:ABIS:BAV:MATC:LIM?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMatchingValue(total,tab,0);

  // RBER for Class2 Bits
  RSCMU300_Status = RSCMU300_GetMatchingValue(RBERClass2Bits,tab,1);

  // RBER for Class1b Bits
  RSCMU300_Status = RSCMU300_GetMatchingValue(RBERClass1bBits,tab,2);

  // Frame erasure rate
  RSCMU300_Status = RSCMU300_GetMatchingValue(frameErasureRate,tab,3);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *        BER MEASUREMENTS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: BER: measured values...
/* Purpose : This function start a bit-error-rate test and output the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_ReadAbisBav (ViSession  instrSession,
                                                                           ViReal64  *progressTime,
                                                                           ViReal64  *BERClass2Bits,
                                                                           ViReal64  *BERClass1bBits,
                                                                           ViInt32   *status,
                                                                           ViChar     _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:RXQ:ABIS:BAV?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", BERClass2Bits);
  else *BERClass2Bits = RSCMU300_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%le", BERClass1bBits);
  else *BERClass1bBits = RSCMU300_NAN;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 3);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BER: fetch measured values...
/* Purpose : This function output the last measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_FetcAbisBav (ViSession  instrSession,
                                                                           ViReal64  *progressTime,
                                                                           ViReal64  *BERClass2Bits,
                                                                           ViReal64  *BERClass1bBits,
                                                                           ViInt32   *status,
                                                                           ViChar     _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:RXQ:ABIS:BAV?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", BERClass2Bits);
  else *BERClass2Bits = RSCMU300_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%le", BERClass1bBits);
  else *BERClass1bBits = RSCMU300_NAN;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 3);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BER: sample measured values...
/* Purpose : This function output the last measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_SampAbisBav (ViSession  instrSession,
                                                                           ViReal64  *progressTime,
                                                                           ViReal64  *BERClass2Bits,
                                                                           ViReal64  *BERClass1bBits,
                                                                           ViInt32   *status,
                                                                           ViChar     _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:RXQ:ABIS:BAV?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", progressTime);
  else *progressTime = RSCMU300_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", BERClass2Bits);
  else *BERClass2Bits = RSCMU300_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%le", BERClass1bBits);
  else *BERClass1bBits = RSCMU300_NAN;

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetSensMeasStatVal (status, tab, 3);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: BER: Matching Tolerances
/* Purpose : This Function indicates whether and in which way the
/*           permissibleerror limits for the measured values of the bit
/*           error rate test have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_CalcAbisBavLimMatc (ViSession  instrSession,
                                                                                  ViInt32   *total,
                                                                                  ViInt32   *BERClass2Bits,
                                                                                  ViInt32   *BERClass1bBits,
                                                                                  ViChar     _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V2_82)
    return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CALC:RXQ:ABIS:BAV:MATC:LIM?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMatchingValue(total,tab,0);

  // RBER for Class2 Bits
  RSCMU300_Status = RSCMU300_GetMatchingValue(BERClass2Bits,tab,1);

  // RBER for Class1b Bits
  RSCMU300_Status = RSCMU300_GetMatchingValue(BERClass1bBits,tab,2);

  return RSCMU300_Status;
}





/*
 *-----------------------------------------------------------------------------
 *        RACH Test
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Configure Nr. of Bursts to be sent
/* Purpose : This function the number of access bursts to be sent in a RACH test.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfRachBurstsSent (ViSession instrSession,
                                                       ViInt32   bursts,
                                                       ViChar    errorMessage[])
{
 ViStatus    RSCMU300_Status = VI_SUCCESS;

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 RETMSG(RSCMU300_setViInt32(instrSession,
                            "CONF:RXQ:RACH:CONT:BTS",
                            bursts,
                            1, 1000000,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Configure Time between Bursts
/* Purpose : This function defines the time elapsed between two consecutive
/*           access bursts sent in a RACH test.
 /*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfRachRepTime (ViSession instrSession,
                                                    ViInt32  time,
                                                    ViChar   errorMessage[])
{
 ViStatus    RSCMU300_Status = VI_SUCCESS;
 GET_WRT_BUF(instrSession);

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 CHECK_VI_INT32_RANGE(instrSession, time, 1, 100000, RSCMU_ERROR_PARAMETER2, errorMessage);

 sprintf(wrtBuf, "CONF:RXQ:RACH:CONT:RTIM %ld %s", time,"ms");
 RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));

}

/*===========================================================================*/
/* Function: Level in the used timeslots
/* Purpose : This function defines the absolute control channel (CCH)
/*           level in the timeslot used for the RACH test.
 /*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfRachCCHLevUtim (ViSession instrSession,
                                                       ViReal64  levelUsed,
                                                       ViChar    errorMessage[])
{
 ViStatus    RSCMU300_Status = VI_SUCCESS;

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 RETMSG(RSCMU300_setViReal64(instrSession,
                             "CONF:RXQ:RACH:CONT:CCH:LEV:UTIM",
                             levelUsed,
                             -137.0, 13.0,
                             RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Level in the unused timeslots
/* Purpose : This function defines the relative control channel level (CCH)
/*           in the unused timeslots for the RACH test
 /*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfRachCCHLevUnt (ViSession instrSession,
                                                      ViReal64  levelUnused,
                                                      ViChar    errorMessage[])
{
 ViStatus    RSCMU300_Status = VI_SUCCESS;

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 RETMSG(RSCMU300_setViReal64(instrSession,
                             "CONF:RXQ:RACH:CONT:CCH:LEV:UNT",
                             levelUnused,
                             -127.0, 127.0,
                             RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Upper limit of error rate
/* Purpose : This function defines an upper limit for the relative
/*           portion of invalid and therefore erased frames
 /*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfRachLimFERR (ViSession instrSession,
                                                    ViReal64  limit,
                                                    ViChar    errorMessage[])
{
 ViStatus    RSCMU300_Status = VI_SUCCESS;

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 RETMSG(RSCMU300_setViReal64(instrSession,
                             "CONF:RXQ:RACH:LIM:FERR",
                             limit,
                             0.0, 100.0,
                             RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Init
/* Purpose : Start measurement without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitRach (ViSession instrSession,
                                             ViChar    errorMessage[])
{
 ViStatus    RSCMU300_Status = VI_SUCCESS;

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 RETMSG(RSCMU300_sendCmd(instrSession, "INIT:RXQ:RACH"));
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : This function aborts running measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborRach (ViSession instrSession,
                                             ViChar    errorMessage[])
{
 ViStatus    RSCMU300_Status = VI_SUCCESS;

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 RETMSG(RSCMU300_sendCmd(instrSession, "ABOR:RXQ:RACH"));
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : This function stops running measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopRach (ViSession instrSession,
                                             ViChar    errorMessage[])
{
 ViStatus    RSCMU300_Status = VI_SUCCESS;

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 RETMSG(RSCMU300_sendCmd(instrSession, "STOP:RXQ:RACH"));
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : This function proceed with next measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContRach (ViSession instrSession,
                                             ViChar    errorMessage[])
{
 ViStatus    RSCMU300_Status = VI_SUCCESS;

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 RETMSG(RSCMU300_sendCmd(instrSession, "CONT:RXQ:RACH"));
}

/*===========================================================================*/
/* Function: Fetch Measurement Status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcRachStat (ViSession instrSession,
                                                 ViInt32   *MeasurementStatus,
                                                 ViInt32   *CountingNo,
                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar*     str;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 // Fetch the status of the measurement:
  CHECKRETMSG(RSCMU300_getViString(instrSession,"FETC:RXQ:RACH:STAT?",rdBuf,RD_BUFFER_SIZE,0));
  if (!(str = strtok(rdBuf,",")))
      return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_INTERPRETING_RESPONSE, errorMessage);

  // Get the status of the measurement:
  CHECKRET(RSCMU300_getIndexFromString(instrSession, rdBuf, measurementStatusArr, MeasurementStatus));

  if (!(str = strtok(NULL,",")))
      return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_INTERPRETING_RESPONSE, errorMessage);

  if(!sscanf(str,"%ld",CountingNo))
      *CountingNo = RSCMU300_NONE;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when
/*           the measurement is terminated or stopped
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfRachErep (ViSession instrSession,
                                                 ViInt32   mode,
                                                 ViChar    errorMessage[])
{
 ViStatus    RSCMU300_Status = VI_SUCCESS;

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 RETMSG(RSCMU300_setEnum(instrSession, "CONF:RXQ:RACH:EREP",
                         mode, StrErep, RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Read measured values...
/* Purpose : This function start a bit-error-rate test and output the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_ReadRach (ViSession  instrSession,
                                                  ViReal64   *frameRate,
                                                  ViReal64   *burstsSent,
                                                  ViReal64   *progTime,
                                                  ViChar     errorMessage[])
{
  return RSCMU300_MeasScalRACH (instrSession, RSCMU300_COMMAND_READ, frameRate, burstsSent, progTime, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch measured values...
/* Purpose : This function output the last measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_FetcRach (ViSession  instrSession,
                                                  ViReal64   *frameRate,
                                                  ViReal64   *burstsSent,
                                                  ViReal64   *progTime,
                                                  ViChar     errorMessage[])
{
  return RSCMU300_MeasScalRACH (instrSession, RSCMU300_COMMAND_FETC, frameRate, burstsSent, progTime, errorMessage);
}

/*===========================================================================*/
/* Function: Sample measured values...
/* Purpose : This function output the last measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_SampRach (ViSession  instrSession,
                                                  ViReal64   *frameRate,
                                                  ViReal64   *burstsSent,
                                                  ViReal64   *progTime,
                                                  ViChar     errorMessage[])
{
  return RSCMU300_MeasScalRACH (instrSession, RSCMU300_COMMAND_SAMP, frameRate, burstsSent, progTime, errorMessage);
}

/*===========================================================================*/
/* Function: Matching Tolerances
/* Purpose : This Function indicates whether and in which way the
/*           permissibleerror limits for the measured values of the bit
/*           error rate test have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_CalcRachLimMatc (ViSession  instrSession,
                                                         ViInt32    *frameRate,
                                                         ViChar     errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      tab[100][100];
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  CHECKRETMSG(RSCMU300_getViString(instrSession, "CALC:RXQ:RACH:MATC:LIM?", rdBuf, RD_BUFFER_SIZE,0));

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Frame erasure rate
  RSCMU300_Status = RSCMU300_GetMatchingValue(frameRate,tab,0);

  return RSCMU300_Status;

}


/*
 *-----------------------------------------------------------------------------
 *      APPLICATION FUNCTIONS
 *-----------------------------------------------------------------------------
 */
/*=========================================================================*/
/* Function: RSCMU300_GSM_Sig_SyncToBts
/* Purpose : This function synchronizes to the base station. As soon as
/*           the base station is picked up the CMU changes to the signalling
/*           state Synchronized.
/*=========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SyncToBts (ViSession instrSession,
                                                                     ViInt32   Timeout,
                                                                     ViChar    errorMessage[])
{
  ViStatus  RSCMU300_Status = VI_SUCCESS;
  ViInt32   SignState;
  clock_t   StartTime = clock () / CLOCKS_PER_SEC;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Timeout, 0, 59, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Be sured that RSCMU is in UNS (UNSynchronized)
  if ((RSCMU300_Status = RSCMU300_GSM_Sig_SensSignStat (instrSession, &SignState, errorMessage)) < 0)
    return RSCMU300_Status;
  if (SignState != RSCMU300_SIGSTATE_UNS)
    return RSCMU300_K3G_errorMessage (instrSession, RSCMU300_ERROR_SIGN_STAT, errorMessage);

  RSCMU300_GSM_Sig_ProcSignAct(instrSession, RSCMU300_SIGCONT_SRUN, errorMessage);

  // Ask if CMU is in SYN
  do
  {
    if ((clock () / CLOCKS_PER_SEC) > (StartTime + Timeout))
      return RSCMU300_K3G_errorMessage (instrSession, RSCMU300_ERROR_CALL_TO_BTS_FAILED, errorMessage);

    if ((RSCMU300_Status = RSCMU300_GSM_Sig_SensSignStat (instrSession, &SignState, errorMessage)) < 0)
      return RSCMU300_Status;
  } while (SignState == RSCMU300_SIGSTATE_SIP);

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 * Close
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Close
/* Purpose : This function close the Basic Unit session and release the
/*           resources
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Close_GSM_Sig (ViSession GSMSigSession,
                                                                 ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  struct RSCMU300_GSMSig_Globals *p_globalvarGSM;

  if ((RSCMU300_Status = viGetAttribute (GSMSigSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarGSM)) < 0)
    return RSCMU300_K3G_errorMessage (GSMSigSession, RSCMU300_Status, errorMessage);

  // Deallocate all system resources allocated to the GSMSig Session:
  if ((RSCMU300_Status = viClose (GSMSigSession)) < 0)
    return RSCMU300_Status;

  // Deallocate the space pointed by p_globalvarGSM:
  if (p_globalvarGSM)
    free (p_globalvarGSM);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    I/Q-IF Interface
 *    The subsystem IQIF configures the signal paths for I/Q and IF signals
 *    provided by option CMU-B17, I/Q and IF Interfaces.
 *    It corresponds to the I/Q-IF tab of the Connection Control menu.
 * ----------------------------------------------------------------------------
 */

/*===========================================================================*/
/* Function: I/Q-IF
/* Purpose : This I/Q-IF parameter sets the both RX and TX path
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_ConfIQIFRXTX (ViSession instrSession,
                                                     ViInt32   iqif,
                                                     ViChar    errorMessage[])
{
    ViString    list[] = {"BYP","BYIQ","XOIO","IOIO","IOXO","FPAT", VI_NULL};
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_22,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_setEnum(instrSession, "CONF:IQIF:RXTX",
                         iqif, list,
                         RSCMU_ERROR_PARAMETER2));
}


/*===========================================================================*/
/* Function: I/Q-IF RX Path
/* Purpose : This I/Q-IF parameter sets the RX path
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_ConfIQIFRXPath (ViSession instrSession,
                                                       ViInt32   RXPath,
                                                       ViChar    errorMessage[])
{
    ViString    list[] = {"BYP","BYIQ","XOIO","IOIO","IOXO", VI_NULL};
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_22,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_setEnum(instrSession, "CONF:IQIF:RXP",
                         RXPath, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: I/Q-IF TX Path
/* Purpose : This I/Q-IF parameter sets the TX path
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_ConfIQIFTXPath (ViSession instrSession,
                                                       ViInt32   TXPath,
                                                       ViChar    errorMessage[])
{
    ViString    list[] = {"BYP","BYIQ","XOIO","IOIO","IOXO", VI_NULL};
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_22,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_setEnum(instrSession, "CONF:IQIF:TXP",
                         TXPath, list,
                         RSCMU_ERROR_PARAMETER2));
}



/*===========================================================================*/
/* AMR
/* CMU-K37
/*===========================================================================*/


/*===========================================================================*/
/* Function: AMR Half Rate Codec Mode Downlink
/* Purpose : This function sets the codec mode that the R&S CMU requests from
/*           the BTS. The setting is valid for Half Rate AMR speech coder tests
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_NetwAmrHrCModeDL (ViSession instrSession,
                                                     ViInt32 codecModeDL,
                                                     ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViString    list[] = {"","CM1","CM2","CM3","CM4", VI_NULL};
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  CHECK_VI_INT32_RANGE(instrSession, codecModeDL,1,4, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONFigure:NETWork:AMR:HRATe:DLCMode %s" , codecModeDL[list]);
  RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: AMR Half Rate Codec Mode Uplink
/* Purpose : This function sets the codec mode that the R&S CMU uses in uplink
/*           direction. The setting is valid for Half Rate AMR speech coder tests
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_NetwAmrHrCModeUL (ViSession instrSession,
                                                     ViInt32 codecModeUL,
                                                     ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViString    list[] = {"","CM1","CM2","CM3","CM4", VI_NULL};
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  CHECK_VI_INT32_RANGE(instrSession, codecModeUL,1,4, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONFigure:NETWork:AMR:HRATe:ULCMode %s" , codecModeUL[list]);
  RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: AMR Half Rate Rate set setting
/* Purpose : These function select four codec modes. The settings are valid
/* for Half Rate AMR speech coder tests. The instrument rejects the settings
/* (SCPI error -221, Settings conflict) unless the values meet all of the
/* following conditions:
/* - The rates must be in descending order so that <CM4> is the
/*   largest bit rate.
/* - Up to 3 codec modes can be switched off. OFF must be the
/*   first values of the parameter list, preceding the used
/*   codec modes.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_NetwAmrHrRSet (ViSession instrSession,
                                                  ViInt32 codecMode4,
                                                  ViInt32 codecMode3,
                                                  ViInt32 codecMode2,
                                                  ViInt32 codecMode1,
                                                  ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViString    list[] = {"OFF","C0475","C0515","C0590","C0670","C0740","C0795","C1020","C1220",  VI_NULL};
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, codecMode4,RSCMU300_OFF,RSCMU_AMR_CODMODE_12_2, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codecMode3,RSCMU300_OFF,RSCMU_AMR_CODMODE_12_2, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codecMode2,RSCMU300_OFF,RSCMU_AMR_CODMODE_12_2, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codecMode1,RSCMU300_OFF,RSCMU_AMR_CODMODE_12_2, RSCMU_ERROR_PARAMETER6, errorMessage);

  sprintf (wrtBuf, "CONFigure:NETWork:AMR:HRATe:RSETting %s, %s, %s, %s " ,
                        codecMode4[list],codecMode3[list],codecMode2[list],codecMode1[list]);
  RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: AMR Full Rate Codec Mode Downlink
/* Purpose : This function sets the codec mode that the R&S CMU requests from
/*           the BTS. The setting is valid for Full Rate AMR speech coder tests
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_NetwAmrFrCModeDL (ViSession instrSession,
                                                     ViInt32 codecModeDL,
                                                     ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViString    list[] = {"","CM1","CM2","CM3","CM4", VI_NULL};
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  CHECK_VI_INT32_RANGE(instrSession, codecModeDL,1,4, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONFigure:NETWork:AMR:FRATe:DLCMode %s" , codecModeDL[list]);
  RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: AMR Full Rate Codec Mode Uplink
/* Purpose : This function sets the codec mode that the R&S CMU uses in uplink
/*           direction. The setting is valid for Full Rate AMR speech coder tests
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_NetwAmrFrCModeUL (ViSession instrSession,
                                                     ViInt32 codecModeUL,
                                                     ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViString    list[] = {"","CM1","CM2","CM3","CM4", VI_NULL};
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  CHECK_VI_INT32_RANGE(instrSession, codecModeUL,1,4, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONFigure:NETWork:AMR:FRATe:ULCMode %s" , codecModeUL[list]);
  RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: AMR Full Rate Rate set setting
/* Purpose : These function select four codec modes. The settings are valid
/* for Full Rate AMR speech coder tests. The instrument rejects the settings
/* (SCPI error -221, Settings conflict) unless the values meet all of the
/* following conditions:
/* - The rates must be in descending order so that <CM4> is the
/*   largest bit rate.
/* - Up to 3 codec modes can be switched off. OFF must be the
/*   first values of the parameter list, preceding the used
/*   codec modes.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_NetwAmrFrRSet (ViSession instrSession,
                                                  ViInt32 codecMode4,
                                                  ViInt32 codecMode3,
                                                  ViInt32 codecMode2,
                                                  ViInt32 codecMode1,
                                                  ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViString    list[] = {"OFF","C0475","C0515","C0590","C0670","C0740","C0795","C1020","C1220",  VI_NULL};
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, codecMode4,RSCMU300_OFF,RSCMU_AMR_CODMODE_12_2, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codecMode3,RSCMU300_OFF,RSCMU_AMR_CODMODE_12_2, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codecMode2,RSCMU300_OFF,RSCMU_AMR_CODMODE_12_2, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codecMode1,RSCMU300_OFF,RSCMU_AMR_CODMODE_12_2, RSCMU_ERROR_PARAMETER6, errorMessage);

  sprintf (wrtBuf, "CONFigure:NETWork:AMR:FRATe:RSETting %s, %s, %s, %s " ,
                        codecMode4[list],codecMode3[list],codecMode2[list],codecMode1[list]);
  RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Sense AMR Half Rate Codec Mode Downlink
/* Purpose : This function is always a query and returns the codec mode used
/* by the BTS. The setting is valid for Half Rate AMR speech coder tests.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensMssAmrHrDl (ViSession instrSession,
                                                   ViInt32 *codecMode,
                                                   ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Get the Codec Mode
  CHECKRETMSG(RSCMU300_getViString(instrSession,"SENSe:INFO:AMR:HRATe:DLCMode?",rdBuf,RD_BUFFER_SIZE,0));

  if      (strncmp (rdBuf,"CM1", 3) == 0)
    *codecMode = 1;
  else if (strncmp (rdBuf,"CM2", 3) == 0)
    *codecMode = 2;
  else if (strncmp (rdBuf,"CM3", 3) == 0)
    *codecMode = 3;
  else if (strncmp (rdBuf,"CM4", 3) == 0)
    *codecMode = 4;
  else if (strcmp (rdBuf, "NAN") == 0)
    *codecMode = RSCMU300_NAN_VI_INT32;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sense AMR Half Rate Codec Mode Uplink
/* Purpose : This function is always a query and returns the UL codec mode
/* commanded by the BTS, irrespective of the used UL codec mode.
/* The setting is valid for Half Rate AMR speech coder tests
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensMssAmrHrUl (ViSession instrSession,
                                                   ViInt32 *codecMode,
                                                   ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Get the Codec Mode
  CHECKRETMSG(RSCMU300_getViString(instrSession,"SENSe:INFO:AMR:HRATe:ULCMode?",rdBuf,RD_BUFFER_SIZE,0));

  if      (strncmp (rdBuf,"CM1", 3) == 0)
    *codecMode = 1;
  else if (strncmp (rdBuf,"CM2", 3) == 0)
    *codecMode = 2;
  else if (strncmp (rdBuf,"CM3", 3) == 0)
    *codecMode = 3;
  else if (strncmp (rdBuf,"CM4", 3) == 0)
    *codecMode = 4;
  else if (strcmp (rdBuf, "NAN") == 0)
    *codecMode = RSCMU300_NAN_VI_INT32;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sense AMR Full Rate Codec Mode Downlink
/* Purpose : This function is always a query and returns the codec mode used
/* by the BTS. The setting is valid for Full Rate AMR speech coder tests.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensMssAmrFrDl (ViSession instrSession,
                                                   ViInt32 *codecMode,
                                                   ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Get the Codec Mode
  CHECKRETMSG(RSCMU300_getViString(instrSession,"SENSe:INFO:AMR:FRATe:DLCMode?",rdBuf,RD_BUFFER_SIZE,0));

  if      (strncmp (rdBuf,"CM1", 3) == 0)
    *codecMode = 1;
  else if (strncmp (rdBuf,"CM2", 3) == 0)
    *codecMode = 2;
  else if (strncmp (rdBuf,"CM3", 3) == 0)
    *codecMode = 3;
  else if (strncmp (rdBuf,"CM4", 3) == 0)
    *codecMode = 4;
  else if (strcmp (rdBuf, "NAN") == 0)
    *codecMode = RSCMU300_NAN_VI_INT32;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sense AMR Full Rate Codec Mode Uplink
/* Purpose : This function is always a query and returns the UL codec mode
/* commanded by the BTS, irrespective of the used UL codec mode.
/* The setting is valid for Full Rate AMR speech coder tests
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensMssAmrFrUl (ViSession instrSession,
                                                   ViInt32 *codecMode,
                                                   ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Get the Codec Mode
  CHECKRETMSG(RSCMU300_getViString(instrSession,"SENSe:INFO:AMR:FRATe:ULCMode?",rdBuf,RD_BUFFER_SIZE,0));

  if      (strncmp (rdBuf,"CM1", 3) == 0)
    *codecMode = 1;
  else if (strncmp (rdBuf,"CM2", 3) == 0)
    *codecMode = 2;
  else if (strncmp (rdBuf,"CM3", 3) == 0)
    *codecMode = 3;
  else if (strncmp (rdBuf,"CM4", 3) == 0)
    *codecMode = 4;
  else if (strcmp (rdBuf, "NAN") == 0)
    *codecMode = RSCMU300_NAN_VI_INT32;

  return RSCMU300_Status;
}


/*
 *-----------------------------------------------------------------------------
 *      UTILITY FUNCTIONS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: RSCMU300_K3G_RevisionQuery
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_K3G_RevisionQuery (ViSession instrSession,
                                                                     ViChar    instrDriverRev[],
                                                                     ViChar    instrRev[],
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  size_t      invertCommaPos;
  ViChar      rdBuf[RD_BUFFER_SIZE]="";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "*IDN?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the current Firmware Version
  invertCommaPos = strcspn (tab[3], "\"");
  strncpy (instrRev,tab[3], invertCommaPos);
  instrRev[invertCommaPos] = 0;

  /*-----------------------------------------------------------------------*/
  /* Instrument driver revision:
  /* The format for instrDriverRev is a string with four fields separated by
  /* commas, the first field is the revision of the instrument driver, the
  /* second field is the month and year of the version's release, the third
  /* field is the time of the version's release, and the four field is the
  /* version of CVI used to write the current version.
  /*-----------------------------------------------------------------------*/
  strcpy (instrDriverRev, RSCMUK3G_REVISION);
  strcat (instrDriverRev, ", ");
  /* From the complilation date of the current file */
  strcat (instrDriverRev, __DATE__);
  strcat (instrDriverRev, ", ");
  /* From the complilation time of the current file */
  strcat (instrDriverRev, __TIME__);
  //strcat (instrDriverRev, ", LW/CVI 5.01");

  return RSCMU300_Status;
}





 ViStatus _VI_FUNC RSCMU300_K3G_GetMMIFwVers (ViSession  instrSession,
                                              ViChar     MmiFgVers[],
                                              ViChar     errorMessage[])
 {
     int i=0;
     int len =0;

     ViStatus   RSCMU300_Status = VI_SUCCESS;
     ViChar     rdBuf[RD_BUFFER_SIZE] = "";
     ViChar     tab[100][100];

     CHECKRETMSG(RSCMU300_getViString(instrSession,
                                "SYSTem:VERSion:SW:MMI?",
                                rdBuf,
                                RD_BUFFER_SIZE,
                                RSCMU_ERROR_PARAMETER2));

     for ( i=0; i<len; i++)
             rdBuf[i] = toupper(rdBuf[i]);

     RSCMU300_SeparateDataValues (rdBuf, "[", tab);

     strcpy(MmiFgVers, tab[0]);

     strcat(MmiFgVers, "\"");

     return RSCMU300_Status;
 }


/*===========================================================================*/
/* Function: Error Message
/* Purpose : This function translates the error return value from the
/*           instrument driver into a user-readable string.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_K3G_errorMessage (ViSession instrSession,
                                                                    ViStatus  statusCode,
                                                                    ViChar    _VI_FAR message[])
{
    ViStatus RSCMU300_Status = VI_SUCCESS;
    ViInt16 i;

    /*=======================================================================*/
    /* RSCMU300_stringValPair is used in the RSCMU300_K3G_errorMessage function
    /*=======================================================================*/
    typedef struct  RSCMU300_stringValPair
    {
        ViStatus stringVal;
        ViString stringName;
    }  RSCMU300_tStringValPair;

    RSCMU300_Status = RSCMU300_Base_errorMessage (instrSession, statusCode, message);

    if (RSCMU300_Status == VI_WARN_UNKNOWN_STATUS)
    {
        #define K3G_EXPAND(id, value, text) {id, text},
        RSCMU300_tStringValPair statusDescArray[] = {
            RSCMU300_LIST_OF_SPECIFIC_K3G_ERROR_MESSAGES
        };
        #undef K3G_EXPAND

        for (i=0; statusDescArray[i].stringName; i++)
        {
            if (statusDescArray[i].stringVal == statusCode)
            {
                strcpy (message, statusDescArray[i].stringName);
                return (statusCode);
            }
        }
    }
    return RSCMU300_Status;
}


/*****************************************************************************/
/*****************************************************************************/
/*======== GMSK Functions ===================================================*/
/*****************************************************************************/
/*****************************************************************************/
/*
 * ----------------------------------------------------------------------------
 * GSM MEASUREMENTS WITHOUT SIGNALLING (NON SIGNALLING):
 * ----------------------------------------------------------------------------
 * In the Non Signalling mode, a GSM-specific RF signal can be
 * generated and an RF signal with GSM characteristics analyzed.
 * No signalling parameters are transferred and measured.
 * ----------------------------------------------------------------------------
 */
/*-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT POWER
 *    The subsystem POWer contains the commands for measuring the
 *    signal power.
 *    This subsystem corresponds to the measurement menu Power vs.
 *    Time and the associated popup menu Power vs Time Configuration.
 *-----------------------------------------------------------------------------
 *      TEST CONFIGURATION
 *      The functions of this subsystem determine the parameters of the
 *      signal power measurement. GSM signals are transferred in the
 *      form of bursts, which divided up into various tolerance ranges
 *      defined in the GSM standard.
 * ----------------------------------------------------------------------------
 *        CONFIGURATION CONTROL
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmContDef (ViSession instrSession,
                                                                             ViBoolean DefaultValues,
                                                                             ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowContDef(RSCMU300_GMSK, instrSession, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Scope of measurement
/* Purpose : This function defines the scope of the power measurement,
/*           combining the ...CONTrol:RMODe, ...CONTrol:STATistics, and the
/*           ...CONTrol:REPetition commands.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmScope (ViSession instrSession,
                                                                           ViInt32   MeasuredValuesType,
                                                                           ViInt32   NbBurst,
                                                                           ViInt32   repetition,
                                                                           ViInt32   NbRepetition,
                                                                           ViInt32   StopCondition,
                                                                           ViInt32   StepMode,
                                                                           ViChar    errorMessage[])
{
    return NSig_ConfPowScope(RSCMU300_GMSK, instrSession, MeasuredValuesType, NbBurst, repetition, NbRepetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles, the
/*           stop condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmContRep (ViSession instrSession,
                                                                             ViInt32   repetition,
                                                                             ViInt32   StopCondition,
                                                                             ViInt32   StepMode,
                                                                             ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowContRep (RSCMU300_GMSK, instrSession, repetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Filter
/* Purpose : This function selects the measurement filter.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowgGmFilter (ViSession instrSession,
                                                      ViInt32   filter,
                                                      ViChar    errorMessage[])
{
 ViStatus    RSCMU300_Status = VI_SUCCESS;

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 RETMSG(RSCMU300_setEnum(instrSession, "CONF:POW:NBUR:GMSK:FILT",
                         filter, StrFilter,
                         RSCMU_ERROR_PARAMETER2));
}

/*
 * -----------------------------------------------------------------------------
 *        LIMITS LINES
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Default limit Lines (ON/OFF)
/* Purpose : This function switches the default limit lines on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmLimDef (ViSession instrSession,
                                                                            ViBoolean defaultLimitLines,
                                                                            ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowLimDef(RSCMU300_GMSK, instrSession, defaultLimitLines, errorMessage);
}

/*===========================================================================*/
/* Function: Switches the lower limit lines ON/OFF
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmLimLowMode (ViSession instrSession,
                                                                                ViBoolean mode,
                                                                                ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowLimLowMode(RSCMU300_GMSK, instrSession, mode, errorMessage);
}

/*===========================================================================*/
/* Function: Switches the upper limit lines ON/OFF
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmLimUppMode (ViSession instrSession,
                                                                                ViBoolean mode,
                                                                                ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowLimUppMode(RSCMU300_GMSK, instrSession, mode, errorMessage);
}

/*===========================================================================*/
/* Function: Set Lower limit Lines
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmLimLow (ViSession instrSession,
                                                                            ViInt32   area,
                                                                            ViBoolean enable,
                                                                            ViBoolean StartPointBitON_OFF,
                                                                            ViReal64  StartPointBit,
                                                                            ViBoolean EndPointBitON_OFF,
                                                                            ViReal64  EndPointBit,
                                                                            ViBoolean StartPointRelLevON_OFF,
                                                                            ViReal64  StartPointRelLev,
                                                                            ViBoolean EndPointRelLevON_OFF,
                                                                            ViReal64  EndPointRelLev,
                                                                            ViBoolean StartPointAbsLevON_OFF,
                                                                            ViReal64  StartPointAbsLev,
                                                                            ViBoolean EndPointAbsLevON_OFF,
                                                                            ViReal64  EndPointAbsLev,
                                                                            ViBoolean visibility,
                                                                            ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowLimLow(RSCMU300_GMSK, instrSession, area, enable, StartPointBitON_OFF, StartPointBit,
                            EndPointBitON_OFF, EndPointBit, StartPointRelLevON_OFF, StartPointRelLev, EndPointRelLevON_OFF,
                            EndPointRelLev, StartPointAbsLevON_OFF, StartPointAbsLev, EndPointAbsLevON_OFF, EndPointAbsLev,
                            visibility, errorMessage);
}

/*===========================================================================*/
/* Function: Set Upper limit Lines
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmLimUpp (ViSession instrSession,
                                                                            ViInt32   area,
                                                                            ViBoolean enable,
                                                                            ViBoolean StartPointBitON_OFF,
                                                                            ViReal64  StartPointBit,
                                                                            ViBoolean EndPointBitON_OFF,
                                                                            ViReal64  EndPointBit,
                                                                            ViBoolean StartPointRelLevON_OFF,
                                                                            ViReal64  StartPointRelLev,
                                                                            ViBoolean EndPointRelLevON_OFF,
                                                                            ViReal64  EndPointRelLev,
                                                                            ViBoolean StartPointAbsLevON_OFF,
                                                                            ViReal64  StartPointAbsLev,
                                                                            ViBoolean EndPointAbsLevON_OFF,
                                                                            ViReal64  EndPointAbsLev,
                                                                            ViBoolean visibility,
                                                                            ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowLimUpp(RSCMU300_GMSK, instrSession, area, enable, StartPointBitON_OFF, StartPointBit,
                            EndPointBitON_OFF, EndPointBit, StartPointRelLevON_OFF, StartPointRelLev, EndPointRelLevON_OFF,
                            EndPointRelLev, StartPointAbsLevON_OFF, StartPointAbsLev, EndPointAbsLevON_OFF, EndPointAbsLev,
                            visibility, errorMessage);
}

/*
 * -----------------------------------------------------------------------------
 *        TIME
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Offset on the burst
/* Purpose : This function defines an offset time in  Bit units by which the
/*           burst is shifted relative to the time axis and the tolerance
/*           template.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmTimeBit (ViSession instrSession,
                                                                             ViReal64  timeBit,
                                                                             ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowTimeBit(RSCMU300_GMSK, instrSession, timeBit, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Result Mode and Statistics Count
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmCont (ViSession instrSession,
                                                                          ViInt32   MeasuredValuesType,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowCont(RSCMU300_GMSK, instrSession, MeasuredValuesType, NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set the number of bursts
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmStat (ViSession instrSession,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowStat(RSCMU300_GMSK, instrSession, NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set result mode
/* Purpose : This function specifies the type of measured values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmResMode (ViSession instrSession,
                                                                             ViInt32   MeasuredValuesType,
                                                                             ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowResMode (RSCMU300_GMSK, instrSession, MeasuredValuesType, errorMessage);
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles, the
/*           stop condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmContRepSt (ViSession instrSession,
                                                                               ViInt32   NbRepetition,
                                                                               ViInt32   StopCondition,
                                                                               ViInt32   StepMode,
                                                                               ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowContRepSt(RSCMU300_GMSK, instrSession, NbRepetition, StopCondition, StepMode, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      MEASUREMENT
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Definition of Subarrays
/* Purpose : This function configures the READ:SUBarrays:POWer...,
/*           FETCh:SUBarrays:POWer..., and SAMPle:SUBarrays:POWer commands. It
/*           restricts the measurement to up to 32 subranges where either all
/*           measurement results (the number of which is given by the second
/*           numerical parameter) or a single statistical value is returned.
/*           The subranges are defined by the start time and the number of
/*           test points which are located on a fixed, equidistant grid with
/*           a step width of  Bit.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSubPowGmRang (ViSession instrSession,
                                                                             ViInt32   statisticsMode,
                                                                             ViReal64  startTime_bit,
                                                                             ViInt32   number_of_samples,
                                                                             ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSubPowRang(RSCMU300_GMSK, instrSession, statisticsMode, startTime_bit, number_of_samples, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      MEASUREMENT CONTROL
 *      This subsystem contains the functions for general control of the
 *      power measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start new measurement
/* Purpose : This function starts the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitPowGm (ViSession instrSession,
                                                                      ViChar    _VI_FAR errorMessage[])
{
    return NSig_InitPow(RSCMU300_GMSK, instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Abort running measurement and switch off
/* Purpose : This function stops the power measurement, setting it to
/*           the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborPowGm (ViSession instrSession,
                                                                      ViChar    _VI_FAR errorMessage[])
{
    return NSig_AborPow(RSCMU300_GMSK, instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: stop measurement after current statistic cycle
/* Purpose : This function stops the power measurement, setting it to
/*           the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopPowGm (ViSession instrSession,
                                                                      ViChar    _VI_FAR errorMessage[])
{
    return NSig_StopPow(RSCMU300_GMSK, instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Next Measurement Step
/* Purpose : This function continue the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContPowGm (ViSession instrSession,
                                                                      ViChar    _VI_FAR errorMessage[])
{
    return NSig_ContPow(RSCMU300_GMSK, instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch measurement status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcPowGmSt (ViSession instrSession,
                                                                        ViPInt32  MeasStatus,
                                                                        ViPInt32  CurrentStatCycleCount,
                                                                        ViPInt32  CurrentEvalPeriodCount,
                                                                        ViChar    _VI_FAR errorMessage[])
{
    return NSig_FetcPowSt(RSCMU300_GMSK, instrSession, MeasStatus, CurrentStatCycleCount, CurrentEvalPeriodCount, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmErep (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowErep(RSCMU300_GMSK, instrSession, Mode, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      MEASURED VALUES
 *      The functions of this subsystem determine and output the results
 *      of the signal power measurement.
 * ----------------------------------------------------------------------------
 *        MEASUREMENT AND BURST POWER
 *        (Subsystem POWer[:RESult])
 *        It contains the functions for measurement and output of the
 *        burst power and its comparison with tolerance values.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : These commands are always queries. They start a measurement and
/*           output all scalar measurement results (see chapter 5). These are:
/*              Bursts out of tolerance (percentage)
/*              Average power of current burst
/*              Peak power of current burst
/*              Average power of averaged trace
/*           The calculation of results in an average or peak measurement is
/*           described in chapter 3 (cf. display modes).The following messages
/*           may be output for the value BurstMatching:
/*              MATC matching
/*              NMAT not matching
/*              INV invalid
/*              NTSC no training sequence code
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadPowGm (ViSession instrSession,
                                                                      ViPReal64 BurstOutOfTol,
                                                                      ViPReal64 AvgBurstPowerCurrent,
                                                                      ViPReal64 PeakBurstPower,
                                                                      ViPInt32  BurstMatching,
                                                                      ViPReal64 AvgBurstPowerAvg,
                                                                      ViChar    _VI_FAR errorMessage[])
{
    return NSig_ReadPow(RSCMU300_GMSK, instrSession, BurstOutOfTol, AvgBurstPowerCurrent, PeakBurstPower, BurstMatching, AvgBurstPowerAvg, errorMessage);
}

/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : These commands are always queries. They start a measurement and
/*           output all scalar measurement results (see chapter 5). These are:
/*              Bursts out of tolerance (percentage)
/*              Average power of current burst
/*              Peak power of current burst
/*              Average power of averaged trace
/*           The calculation of results in an average or peak measurement is
/*           described in chapter 3 (cf. display modes).The following messages
/*           may be output for the value BurstMatching:
/*              MATC matching
/*              NMAT not matching
/*              INV invalid
/*              NTSC no training sequence code
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcPowGm (ViSession instrSession,
                                                                      ViPReal64 BurstOutOfTol,
                                                                      ViPReal64 AvgBurstPowerCurrent,
                                                                      ViPReal64 PeakBurstPower,
                                                                      ViPInt32  BurstMatching,
                                                                      ViPReal64 AvgBurstPowerAvg,
                                                                      ViChar    _VI_FAR errorMessage[])
{
    return NSig_FetcPow(RSCMU300_GMSK, instrSession, BurstOutOfTol, AvgBurstPowerCurrent, PeakBurstPower, BurstMatching, AvgBurstPowerAvg, errorMessage);
}

/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : These commands are always queries. They start a measurement and
/*           output all scalar measurement results (see chapter 5). These are:
/*              Bursts out of tolerance (percentage)
/*              Average power of current burst
/*              Peak power of current burst
/*              Average power of averaged trace
/*           The calculation of results in an average or peak measurement is
/*           described in chapter 3 (cf. display modes).The following messages
/*           may be output for the value BurstMatching:
/*              MATC matching
/*              NMAT not matching
/*              INV invalid
/*              NTSC no training sequence code
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampPowGm (ViSession instrSession,
                                                                      ViPReal64 BurstOutOfTol,
                                                                      ViPReal64 AvgBurstPowerCurrent,
                                                                      ViPReal64 PeakBurstPower,
                                                                      ViPInt32  BurstMatching,
                                                                      ViPReal64 AvgBurstPowerAvg,
                                                                      ViChar    _VI_FAR errorMessage[])
{
    return NSig_SampPow(RSCMU300_GMSK, instrSession, BurstOutOfTol, AvgBurstPowerCurrent, PeakBurstPower, BurstMatching, AvgBurstPowerAvg, errorMessage);
}

/*===========================================================================*/
/* Function: Request Tolerance On Values
/* Purpose : This function indicates whether and in which way the per-
/*           missible tolerances for the scalar measured values  have
/*           been exceeded.
/*
/*           The following messages may be output for the values
/*           AvgBurstPower, AvgBurstPowerAvg and PeakBurst-Power:
/*
/*              NMAU Tolerance value underflow not matching, underflow
/*              NMAL Tolerance value exceeded not matching, overflow
/*              INV  Measurement invalid invalid
/*              OK   Tolerance value matched
/*
/*           The following messages may be output for the value
/*           BurstMatching:
/*
/*              MATC matching
/*              NMAT not matching
/*              INV  invalid
/*              NTSC no training sequence code
/*              OUT  out of range
/*
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcPowGmMatcLim (ViSession instrSession,
                                                                             ViPInt32  AvgBurstPowerCurrent,
                                                                             ViPInt32  PeakBurstPower,
                                                                             ViPInt32  BurstTemplateMatching,
                                                                             ViPInt32  AvgBurstPowerAvg,
                                                                             ViChar    _VI_FAR errorMessage[])
{
    return NSig_CalcPowMatcLim(RSCMU300_GMSK, instrSession, AvgBurstPowerCurrent, PeakBurstPower, BurstTemplateMatching, AvgBurstPowerAvg, errorMessage);
}

/*===========================================================================*/
/* Function: Burst power measured values
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrPowGm (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  BurstPower[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
    return NSig_ReadArrPow(RSCMU300_GMSK, instrSession, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetc Burst Power...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrPowGm (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  BurstPower[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
    return NSig_FetcArrPow(RSCMU300_GMSK, instrSession, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Burst Power...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrPowGm (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  BurstPower[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
    return NSig_SampArrPow(RSCMU300_GMSK, instrSession, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Tolerance error of power measurement
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcArrPowGmMatcLim (ViSession instrSession,
                                                                                ViInt32   statisticsMode,
                                                                                ViPInt32  burstMatching,
                                                                                ViChar    _VI_FAR errorMessage[])
{
    return NSig_CalcArrPowMatcLim(RSCMU300_GMSK, instrSession, statisticsMode, burstMatching, errorMessage);
}

/*===========================================================================*/
/* Function: indicates that the corresponding area of the limit lines is
/*           violated.
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcArrPowGmAreaMatc (ViSession instrSession,
                                                                                 ViInt32   statisticsMode,
                                                                                 ViPUInt32 upperLimit,
                                                                                 ViPUInt32 lowerLimit,
                                                                                 ViChar    _VI_FAR errorMessage[])
{
    return NSig_CalcArrPowAreaMatc(RSCMU300_GMSK, instrSession, statisticsMode, upperLimit, lowerLimit, errorMessage);
}

/*===========================================================================*/
/* Function: This function outputs the burst power versus time in a fixed
/*           -Bit pattern and in the subranges defined by means of the
/*           CONFigure:SUBarrays:POWer command.
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSubPowGm (ViSession instrSession,
                                                                         ViInt32   statisticsMode,
                                                                         ViReal64  burstPowerValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
    return NSig_ReadSubPow(RSCMU300_GMSK, instrSession, statisticsMode, burstPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: This function outputs the burst power versus time in a fixed
/*           -Bit pattern and in the subranges defined by means of the
/*           CONFigure:SUBarrays:POWer command.
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSubPowGm (ViSession instrSession,
                                                                         ViInt32   statisticsMode,
                                                                         ViReal64  burstPowerValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
    return NSig_FetcSubPow(RSCMU300_GMSK, instrSession, statisticsMode, burstPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: This function outputs the burst power versus time in a fixed
/*           -Bit pattern and in the subranges defined by means of the
/*           CONFigure:SUBarrays:POWer command.
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSubPowGm (ViSession instrSession,
                                                                         ViInt32   statisticsMode,
                                                                         ViReal64  burstPowerValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
    return NSig_SampSubPow(RSCMU300_GMSK, instrSession, statisticsMode, burstPowerValues, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT MODULATION PERRor
 *
 *    The subsystem MODulation:PERRor[:GMSK] measures the modulation parameters
 *    (frequency and phase errors) in GMSK modulation. The subsystem corresponds
 *    to the measurement menu Modulation, application Phase Error GMSK, and the
 *    associated popup menu Modulation Configuration.
 * ----------------------------------------------------------------------------
 *      CONFIGURATION CONTROL
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrGmContDef (ViSession instrSession,
                                                                              ViBoolean DefaultValues,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DEF:MOD:PERR:GMSK:CONT %s", mode_On_Off[DefaultValues]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Scope of measurement
/* Purpose : This function defines the scope of the power measurement,
/*           combining the ...CONTrol:RMODe, ...CONTrol:STATistics, and the
/*           ...CONTrol:REPetition commands.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrGmScope (ViSession instrSession,
                                                                            ViInt32   MeasuredValuesType,
                                                                            ViInt32   NbBurst,
                                                                            ViInt32   repetition,
                                                                            ViInt32   NbRepetition,
                                                                            ViInt32   StopCondition,
                                                                            ViInt32   StepMode,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, repetition, 0, 2, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER7, errorMessage);

  if (repetition != RSCMU300_MULTIPLE)
    sprintf(wrtBuf, "CONF:MOD:PERR:GMSK:CONT %s,%ld,%s,%s,%s", mode_ScopeMeas[MeasuredValuesType]
                                                            , NbBurst
                                                            , repetition_meas[repetition]
                                                            , mode_StopCondition[StopCondition]
                                                            , StrStepMode[StepMode]);
  else
    sprintf(wrtBuf, "CONF:MOD:PERR:GMSK:CONT %s,%ld,%ld,%s,%s", mode_ScopeMeas[MeasuredValuesType]
                                                            , NbBurst
                                                            , NbRepetition
                                                            , mode_StopCondition[StopCondition]
                                                            , StrStepMode[StepMode]);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrGmContRep (ViSession instrSession,
                                                                              ViInt32   Repetition,
                                                                              ViInt32   StopCondition,
                                                                              ViInt32   StepMode,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, Repetition, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:MOD:PERR:GMSK:CONT:REP %s,%s,%s", repetition_meas[Repetition]
                                                         , mode_StopCondition[StopCondition]
                                                         , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      LIMITS
 *      The subsystem MODulation:LIMit contains the commands for
 *      definition of tolerance values for the modulation measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Error Limits
/* Purpose : This function defines the limits for the peak and RMS phase error
/*           as well as for the frequency error in the current burst.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrGmLim (ViSession instrSession,
                                                                          ViInt32   KindOfBurst,
                                                                          ViReal64  MaxPhaseErrorLimit,
                                                                          ViReal64  RMSPhaseErrorLimit,
                                                                          ViReal64  FrequencyErrorLimit,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, KindOfBurst, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, MaxPhaseErrorLimit, 0, RSCMU300_PHASE_ERROR_LIMMAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, RMSPhaseErrorLimit, 0, RSCMU300_PHASE_ERROR_LIMMAX, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, FrequencyErrorLimit, 0, RSCMU300_FREQU_ERROR_LIMMAX, RSCMU_ERROR_PARAMETER5, errorMessage);

  switch (KindOfBurst)
  {
    case RSCMU300_CURRENT:
      sprintf (wrtBuf, "CONF:MOD:PERR:GMSK:CMM:LIM:SYMM:VAL %.12f,%.12f,%.12f", MaxPhaseErrorLimit
                                                                        , RMSPhaseErrorLimit
                                                                        , FrequencyErrorLimit);
      break;
    case RSCMU300_AVERAGE:
      sprintf (wrtBuf, "CONF:MOD:PERR:GMSK:AVER:LIM:SYMM:VAL %.12f,%.12f,%.12f", MaxPhaseErrorLimit
                                                                         , RMSPhaseErrorLimit
                                                                         , FrequencyErrorLimit);
      break;
  }
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/* ----------------------------------------------------------------------------
 *      TIME
 *      The subsystem MODulation...:TIME defines the decoding for the Modulation
 *      measurement. The subsystem corresponds to the popup window Decode in
 *      the graphical measurement menu Modulation.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Time Decode
/* Purpose : This function selects the type of decoding applied for the
/*           determination of phase and frequency errors.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrGmTimeDec (ViSession instrSession,
                                                                              ViInt32   TypeOfDecoding,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  ViString    StrType[] = {"STAN", "GTB"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TypeOfDecoding, 0, 1, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:PERR:GMSK:TIME:DEC %s", StrType[TypeOfDecoding]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      STATISTICS
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Number of bursts and result mode
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrGmCont (ViSession instrSession,
                                                                           ViInt32   MeasuredValuesType,
                                                                           ViInt32   NbBurst,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:PERR:GMSK:CONT:STAT %ld", NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  sprintf (wrtBuf, "CONF:MOD:PERR:GMSK:CONT:RMOD %s", mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set the number of bursts
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrGmStat (ViSession instrSession,
                                                                           ViInt32   NbBurst,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:PERR:GMSK:CONT:STAT %ld", NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set result mode
/* Purpose : This function specifies the type of measured values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrGmResMode (ViSession instrSession,
                                                                              ViInt32   MeasuredValuesType,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:PERR:GMSK:CONT:RMOD %s", mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrGmContRepSt (ViSession instrSession,
                                                                                ViInt32   NbRepetition,
                                                                                ViInt32   StopCondition,
                                                                                ViInt32   StepMode,
                                                                                ViChar   _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:MOD:PERR:GMSK:CONT:REP %ld,%s,%s", NbRepetition
                                                         , mode_StopCondition[StopCondition]
                                                         , StrStepMode[StepMode]);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      MEASUREMENT
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Definition of Subarrays
/* Purpose : This command configures the READ:SUBarrays..., FETCh:SUBarrays...,
/*           and SAMPle:SUBarrays:MODulation commands. It restricts the
/*           measurement to up to 32 subranges where either all measurement
/*           results (the number of which is given by the second numerical
/*           parameter) or a single statistical value is returned. The subranges
/*           are defined by the start time and the number of test points which
/*           are located on a fixed, equidistant grid with a step width of  Bit.
/*           The subranges may overlap but must be within the total range of the
/*           MODulation measurement. Test points outside this range are not
/*           measured (result NAN) and do not enter into the ARIThmetical,
/*           MINimum and MAXimum values.
/*           By default, only one range corresponding to the total measurement
/*           range is used and all measurement values are returned.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSubPerrGmRang (ViSession instrSession,
                                                                              ViInt32   StatisticsMode,
                                                                              ViReal64  StartTime,
                                                                              ViInt32   Samples,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"ALL","ARIT","MIN","MAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, StartTime, RSCMU300_SUBMOD_BIT_MIN, RSCMU300_SUBMOD_BIT_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Samples, RSCMU300_SUBMOD_SAMPLES_MIN, RSCMU300_SUBMOD_SAMPLES_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:MOD:PERR:GMSK %s,%.12f,%ld", StrMode[StatisticsMode]
                                                     , StartTime
                                                     , Samples);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      CONTROL OF MODULATION MEAS
 *      It contains the functions for general control of the modulation
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start Modulation Measurements
/* Purpose : This function start the modulation measurement,
/*           setting it to the status beyond.
/*           RUN        Start measurement without waiting
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitPerrGm (ViSession instrSession,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "INIT:MOD:PERR:GMSK", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort Modulation Measurements
/* Purpose : This function abort the running modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborPerrGm (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "ABOR:MOD:PERR:GMSK", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Stop Modulation Measurements
/* Purpose : This function stop measurement after current statistic cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopPerrGm (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "STOP:MOD:PERR:GMSK", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Run next measurement step
/* Purpose : This function runs next modulation measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContPerrGm (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CONT:MOD:PERR:GMSK", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Measurement Status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcPerrGmSt (ViSession instrSession,
                                                                         ViPInt32  MeasStatus,
                                                                         ViPInt32  CurrentStatCycleCount,
                                                                         ViPInt32  CurrentEvalPeriodCount,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Fetch the measurement status:
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:MOD:PERR:GMSK:STAT?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMeasStatVal(MeasStatus, tab, 0);

  // Get the counter for current statistics cycle
  if (strcmp (tab[1], "NONE") != 0)
    sscanf (tab[1], "%ld", CurrentStatCycleCount);
  else
    *CurrentStatCycleCount = RSCMU300_OFF;

  // Get the counter for current evaluation period within a cycle
  if (strcmp (tab[2], "NONE") != 0)
    sscanf (tab[2], "%ld", CurrentEvalPeriodCount);
  else *CurrentEvalPeriodCount = RSCMU300_OFF;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrGmErep (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:PERR:GMSK:EREP %s", StrErep[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      RESULTS: FREQUENCY AND PHASE ERROR
 *      The subsystem MODulation[:RESULT] contains the commands for
 *      measurement and output of the frequency and phase error and
 *      their comparison with the tolerance values.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This function start a measurement and output all scalar,
/*           numeric measurement results. These are:
/*
/*           Peak phase error of Current burst
/*           Peak phase error of Average trace
/*           Peak phase error of Max./Min. trace
/*
/*           RMS phase error of Current burst
/*           RMS phase error of Average trace
/*           RMS phase error of Max./Min. trace
/*
/*           Frequency error of Current burst
/*           Frequency error of Average trace
/*           Frequency error of Max./Min. trace
/*
/*           Average burst power of current burst
/*           Average burst power of average burst
/*           Relative portion of faulty bursts
/*
/*           Average measurement means that the results of the single-value
/*           measurement are averaged over several bursts. Extreme-value
/*           measurement means that the extreme value is determined from the
/*           results of the single-value measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadPerrGm (ViSession instrSession,
                                                                       ViInt32   StatisticsMode,
                                                                       ViPReal64 phErrPeak,
                                                                       ViPReal64 phErrRMS,
                                                                       ViPReal64 freqErr,
                                                                       ViPReal64 avgBurstPowerCurr,
                                                                       ViPReal64 avgBurstPowerAvg,
                                                                       ViPReal64 burstOutOfTol,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:MOD:PERR:GMSK?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  RSCMU300_Status = RSCMU300_ScanPerrGmsk (tab , 0, StatisticsMode, phErrPeak, phErrRMS, freqErr, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This function start a measurement and output all scalar,
/*           numeric measurement results. These are:
/*
/*           Peak phase error of Current burst
/*           Peak phase error of Average trace
/*           Peak phase error of Max./Min. trace
/*
/*           RMS phase error of Current burst
/*           RMS phase error of Average trace
/*           RMS phase error of Max./Min. trace
/*
/*           Frequency error of Current burst
/*           Frequency error of Average trace
/*           Frequency error of Max./Min. trace
/*
/*           Average burst power of current burst
/*           Average burst power of average burst
/*           Relative portion of faulty bursts
/*
/*           Average measurement means that the results of the single-value
/*           measurement are averaged over several bursts. Extreme-value
/*           measurement means that the extreme value is determined from the
/*           results of the single-value measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcPerrGm (ViSession instrSession,
                                                                       ViInt32   StatisticsMode,
                                                                       ViPReal64 phErrPeak,
                                                                       ViPReal64 phErrRMS,
                                                                       ViPReal64 freqErr,
                                                                       ViPReal64 avgBurstPowerCurr,
                                                                       ViPReal64 avgBurstPowerAvg,
                                                                       ViPReal64 burstOutOfTol,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:MOD:PERR:GMSK?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Scan the results of Modulation
  RSCMU300_ScanPerrGmsk ( tab, 0, StatisticsMode, phErrPeak, phErrRMS, freqErr, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This function start a measurement and output all scalar,
/*           numeric measurement results. These are:
/*
/*           Peak phase error of Current burst
/*           Peak phase error of Average trace
/*           Peak phase error of Max./Min. trace
/*
/*           RMS phase error of Current burst
/*           RMS phase error of Average trace
/*           RMS phase error of Max./Min. trace
/*
/*           Frequency error of Current burst
/*           Frequency error of Average trace
/*           Frequency error of Max./Min. trace
/*
/*           Average burst power of current burst
/*           Average burst power of average burst
/*           Relative portion of faulty bursts
/*
/*           Average measurement means that the results of the single-value
/*           measurement are averaged over several bursts. Extreme-value
/*           measurement means that the extreme value is determined from the
/*           results of the single-value measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampPerrGm (ViSession instrSession,
                                                                       ViInt32   StatisticsMode,
                                                                       ViPReal64 phErrPeak,
                                                                       ViPReal64 phErrRMS,
                                                                       ViPReal64 freqErr,
                                                                       ViPReal64 avgBurstPowerCurr,
                                                                       ViPReal64 avgBurstPowerAvg,
                                                                       ViPReal64 burstOutOfTol,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:MOD:PERR:GMSK?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Scan the results of Modulation
  RSCMU300_ScanPerrGmsk ( tab, 0, StatisticsMode, phErrPeak, phErrRMS, freqErr, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcPerrGmMatcLim (ViSession instrSession,
                                                                              ViInt32   StatisticsMode,
                                                                              ViPInt32  phErrPeak,
                                                                              ViPInt32  phErrRMS,
                                                                              ViPInt32  freqErr,
                                                                              ViPInt32  avgBurstPowerCurr,
                                                                              ViPInt32  avgBurstPowerAvg,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CALC:MOD:PERR:GMSK:MATC:LIM?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  switch (StatisticsMode)
  {
    case RSCMU300_CURRENT:
      // Max phase error with single-value measurement
      RSCMU300_Status = RSCMU300_GetMatchingValue(phErrPeak,tab,0);
      // RMS phase error with single-value measurement
      RSCMU300_Status = RSCMU300_GetMatchingValue(phErrRMS,tab,3);
      // Frequency error with single-value measurement
      RSCMU300_Status = RSCMU300_GetMatchingValue(freqErr,tab,6);
    break;
    case RSCMU300_AVERAGE:
      // Max phase error with average measurement
      RSCMU300_Status = RSCMU300_GetMatchingValue(phErrPeak, tab, 1);
      // RMS phase error with average measurement
      RSCMU300_Status = RSCMU300_GetMatchingValue(phErrRMS, tab, 4);
      // Frequency error with average measurement
      RSCMU300_Status = RSCMU300_GetMatchingValue(freqErr, tab, 7);
    break;
    case RSCMU300_MAXMIN:
      // Max phase error with extreme-value measurement
      RSCMU300_Status = RSCMU300_GetMatchingValue(phErrPeak,tab, 2);
      // RMS phase error with extreme-value measurement
      RSCMU300_Status = RSCMU300_GetMatchingValue(phErrRMS,tab, 5);
      // Frequency error with extreme-value measurement
      RSCMU300_Status = RSCMU300_GetMatchingValue(freqErr,tab, 8);
    break;
  }
  // Average burst power with single-value measurement
  RSCMU300_Status = RSCMU300_GetMatchingValue(avgBurstPowerCurr, tab, 9);
  // Average burst power of the average burst
  RSCMU300_Status = RSCMU300_GetMatchingValue(avgBurstPowerAvg, tab, 10);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Phase Error in Burst...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 588 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrPerrGm (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViReal64  PhaseErrorValues[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      PhaseErrorTmp[588][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:ARR:MOD:PERR:GMSK:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, PhaseErrorTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,PhaseErrorTmp,PhaseErrorValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Phase Error in Burst...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 588 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrPerrGm (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViReal64  PhaseErrorValues[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      PhaseErrorTmp[588][20];

  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:ARR:MOD:PERR:GMSK:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, PhaseErrorTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,PhaseErrorTmp,PhaseErrorValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample Phase Error in Burst...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 588 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrPerrGm (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViReal64  PhaseErrorValues[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      PhaseErrorTmp[588][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:ARR:MOD:PERR:GMSK:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, PhaseErrorTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,PhaseErrorTmp,PhaseErrorValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: This function outputs the phase error versus time in a fixed  Bit
/*           pattern and in the subranges defined by means of the CONFigure:
/*           SUBarrays:MODulation...
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSubPerrGm (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViReal64  PhaseErrorValues[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      PhaseErrorTmp[588][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:SUB:MOD:PERR:GMSK:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, PhaseErrorTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,PhaseErrorTmp,PhaseErrorValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: This function outputs the phase error versus time in a fixed  Bit
/*           pattern and in the subranges defined by means of the CONFigure:
/*           SUBarrays:MODulation...
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSubPerrGm (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViReal64  PhaseErrorValues[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      PhaseErrorTmp[588][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:SUB:MOD:PERR:GMSK:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, PhaseErrorTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,PhaseErrorTmp,PhaseErrorValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: This function outputs the phase error versus time in a fixed  Bit
/*           pattern and in the subranges defined by means of the CONFigure:
/*           SUBarrays:MODulation...
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSubPerrGm (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViReal64  PhaseErrorValues[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      PhaseErrorTmp[588][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:SUB:MOD:PERR:GMSK:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, PhaseErrorTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,PhaseErrorTmp,PhaseErrorValues);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT SPECTRUM/MODULATION
 *    The subsystem SPECtrum:MODulation contains the commands for measuring
 *    the off-carrier power due to the modulation of the GSM signal.
 *-----------------------------------------------------------------------------
 *      CONFIGURATION CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmContDef (ViSession instrSession,
                                                                               ViBoolean DefaultValues,
                                                                               ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpModContDef (RSCMU300_GMSK, instrSession, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Averaging Areas
/* Purpose : These function selects one or two 40-bit sections of the burst which
/*           are measured and averaged in order to calculate the Modulation results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SpecModAvgAreas (ViSession instrSession,
                                                     ViInt32   averaging_area,
                                                     ViChar    errorMessage[])
{
    ViString    list[] = {"A","B","AB", VI_NULL};
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    CHECKRETMSG(RSCMU300_checkVersion(instrSession, RSCMU300_V3_65, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_setEnum(instrSession, "CONFigure:SPECtrum:MODulation:AVGareas",
                            averaging_area, list,
                            RSCMU_ERROR_PARAMETER2));
}


/*===========================================================================*/
/* Function: Frequency Select f. Time Domain
/* Purpose : These function selects the measurement frequency for the time
/*           domain (power vs. time) measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpecModFSelFTimeD (ViSession instrSession,
                                                           ViInt32   select,
                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViString    list[] = {"OFF","N180","N160","N140","N120","N100","N080","N060","N040","N025","N020","N010",
                        "REF","P010","P020","P025","P040","P060","P080","P100","P120","P140","P160","P180",
                        "NV4","NV3","NV2","NV1","PV1","PV2","PV3","PV4", VI_NULL};

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession, RSCMU300_V3_65, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  RETMSG(RSCMU300_setEnum(instrSession, "CONFigure:SPECtrum:MODulation:TDFSelect", select, list,
                          RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Scope of measurement
/* Purpose : This function defines the scope of the power measurement,
/*           combining the ...CONTrol:RMODe, ...CONTrol:STATistics, and the
/*           ...CONTrol:REPetition commands.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmScope (ViSession instrSession,
                                                                             ViInt32   MeasuredValuesType,
                                                                             ViInt32   NbBurst,
                                                                             ViInt32   repetition,
                                                                             ViInt32   NbRepetition,
                                                                             ViInt32   StopCondition,
                                                                             ViInt32   StepMode,
                                                                             ViChar    errorMessage[])
{
    return NSig_ConfSpModScope (RSCMU300_GMSK, instrSession, MeasuredValuesType, NbBurst, repetition, NbRepetition,
                                StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmContRep (ViSession instrSession,
                                                                               ViInt32   Repetition,
                                                                               ViInt32   StopCondition,
                                                                               ViInt32   StepMode,
                                                                               ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpModContRep (RSCMU300_GMSK, instrSession, Repetition, StopCondition, StepMode, errorMessage);
}

/*-----------------------------------------------------------------------------
 *      LIMITS
 *      The subsystem SPECtrum:MODulation:LIMit contains the commands for
 *      definition of tolerance values for the spectrum measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default limit Lines
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmLimDef (ViSession instrSession,
                                                                              ViBoolean DefaultValues,
                                                                              ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpModLimDef (RSCMU300_GMSK, instrSession, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Reference Power
/* Purpose : This function defines the MS carrier output power domain where
/*           the limit lines are to be determined by linear interpolation
/*           (see Table 1). Below Min. Power, the lower limit line applies,
/*           above Max. Power, the upper limit line applies.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmLimRefp (ViSession instrSession,
                                                                               ViReal64  minPower,
                                                                               ViReal64  maxPower,
                                                                               ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpModLimRefp (RSCMU300_GMSK, instrSession, minPower, maxPower, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lines On/Off
/* Purpose : This function switches the limit checking for all measurepoints.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmLimMode (ViSession instrSession,
                                                                               ViBoolean limitLines,
                                                                               ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpModLimMode (RSCMU300_GMSK, instrSession, limitLines, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lines
/* Purpose : These commands activate and define limit lines for the spectrum
/*           due to modulation measurement.
/*           The limit lines for the spectrum due to modulation as specified
/*           in standard GSM 05.05 depend on the GSM band, the frequency, and
/*           (for frequencies that differ from the carrier frequency by more
/*           than 400 kHz) on the output power of the base station.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmLim (ViSession instrSession,
                                                                           ViInt32   measurePoint,
                                                                           ViBoolean enable,
                                                                           ViReal64  minPower,
                                                                           ViReal64  maxPower,
                                                                           ViReal64  AbsLevel,
                                                                           ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpModLim (RSCMU300_GMSK, instrSession, measurePoint, enable, minPower, maxPower, AbsLevel, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Statistic Count
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmCont (ViSession instrSession,
                                                                            ViInt32   MeasuredValuesType,
                                                                            ViInt32   NbBurst,
                                                                            ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpModCont (RSCMU300_GMSK, instrSession, MeasuredValuesType, NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set the number of bursts
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmStat (ViSession instrSession,
                                                                            ViInt32   NbBurst,
                                                                            ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpModStat (RSCMU300_GMSK, instrSession, NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set result mode
/* Purpose : This function specifies the type of measured values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmResMode (ViSession instrSession,
                                                                               ViInt32   MeasuredValuesType,
                                                                               ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpModResMode (RSCMU300_GMSK, instrSession, MeasuredValuesType, errorMessage);
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmContRepSt (ViSession instrSession,
                                                                                 ViInt32   NbRepetition,
                                                                                 ViInt32   StopCondition,
                                                                                 ViInt32   StepMode,
                                                                                 ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpModContRepSt (RSCMU300_GMSK, instrSession, NbRepetition, StopCondition, StepMode, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      MEASUREMENT CONFIGURATION
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Measure Points
/* Purpose : This function permits to select which frequencies a spectrum
/*           modulation measurement is performed. A reduction of the
/*           measurement points enhances the measurement speed.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmContMpo (ViSession instrSession,
                                                                               ViInt32   MeasurePoint,
                                                                               ViBoolean enable,
                                                                               ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpModContMpo (RSCMU300_GMSK, instrSession, MeasurePoint, enable, errorMessage);
}

/*===========================================================================*/
/* Function: Variable Measure Points
/* Purpose : This function sets and enables additional pairs of
/*           measurement points at up to 4 variable offset frequencies
/*           (numbered by the numeric suffix <nr> = 1 to 4).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpecModVarMpo (ViSession instrSession,
                                                       ViInt32 nr,
                                                       ViInt32 enable,
                                                       ViReal64 frequencyMHz,
                                                       ViChar errorMessage[])
{
    return RSCMU300_MeasSpecVarMeaPoint(instrSession, "CONFigure:SPECtrum:MODulation:CONTrol:VMPoint", nr, enable, frequencyMHz, errorMessage);
}

/*===========================================================================*/
/* Function: Definition of Subarrays
/* Purpose : This function configures the READ:SUBarrays.., FETCh:SUBarrays..,
/*           and SAMPle:SUBarrays:SPECtrum:MODulation[:GMSK] commands. It
/*           restricts the measurement to up to 32 subranges where either all
/*           measurement results (the number of which is given by the second
/*           numerical parameter) or a single statistical value is returned.
/*           The subranges are defined by the start time and the number of
/*           test points which are located at fixed frequencies (see command
/*           CONFigure:SPECtrum:MODulation[:GMSK]:LIMit:LINE<nr>).
/*           The subranges may overlap but must be within the total range of
/*           the spectrum due to modulation measurement. Test points outside
/*           this range are not measured (result NAN) and do not enter into
/*           the ARIThmetical, MINimum and MAXimum values.
/*           By default, only one range corresponding to the total measurement
/*           range is used and all measurement values are returned.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSubSpModGmRang (ViSession instrSession,
                                                                               ViInt32   StatisticsMode,
                                                                               ViReal64  StartFrequency,
                                                                               ViInt32   Samples,
                                                                               ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSubSpModRang (RSCMU300_GMSK, instrSession, StatisticsMode, StartFrequency, Samples, errorMessage);
}

/*===========================================================================*/
/* Function: Configure TimeDomain SubRanges
/* Purpose : This function configurates the READ..., FETCh... and
/*           SAMPle:SSUBarrays:SPECtrum:<Application>:TDOMain commands.
/*           If the requested number of results exceeds the measurement
/*           range, the count parameter will be corrected by the system.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSubSpecModTime (ViSession instrSession,
                                                        ViInt32   mode,
                                                        ViReal64  startTime,
                                                        ViInt32   numberOfSamples,
                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, mode, 0, 4, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, startTime, -30, 175, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, numberOfSamples, 1, 618, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU300_ConfSubArr (instrSession, "CONFigure:SUBarrays:SPECtrum:MODulation:TDOMain", mode, startTime, numberOfSamples, errorMessage);
}





/*-----------------------------------------------------------------------------
 *      CONTROL OF SPECTRUM MODULATION MEAS
 *      It contains the functions for general control of the spectrum
 *      modulation measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Init
/* Purpose : Start measurement without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitSpModGm (ViSession instrSession,
                                                                        ViChar    _VI_FAR errorMessage[])
{
    return NSig_InitSpMod (RSCMU300_GMSK, instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : Abort measurement and switch off => OFF
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborSpModGm (ViSession instrSession,
                                                                        ViChar    _VI_FAR errorMessage[])
{
    return NSig_AborSpMod (RSCMU300_GMSK, instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : Stop measurement => STOP
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopSpModGm (ViSession instrSession,
                                                                        ViChar    _VI_FAR errorMessage[])
{
    return NSig_StopSpMod (RSCMU300_GMSK, instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : Next measurement step (only counting mode) => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContSpModGm (ViSession instrSession,
                                                                        ViChar    _VI_FAR errorMessage[])
{
    return NSig_ContSpMod (RSCMU300_GMSK, instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Status
/* Purpose : This function is always a query. It immediately reads the
/*           measurement status (for polling, see chapters 3 and 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSpModGmSt (ViSession instrSession,
                                                                          ViPInt32  MeasStatus,
                                                                          ViPInt32  CurrentStatCycleCount,
                                                                          ViPInt32  CurrentEvalPeriodCount,
                                                                          ViChar    _VI_FAR errorMessage[])
{
    return NSig_FetcSpModSt (RSCMU300_GMSK, instrSession, MeasStatus, CurrentStatCycleCount, CurrentEvalPeriodCount, errorMessage);
}

/*===========================================================================*/
/* Function: Event Reporting Mode
/* Purpose : This function defines the events to be reported during the
/*           measurement (event reporting, see chapter 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmErep (ViSession instrSession,
                                                                            ViInt32   Mode,
                                                                            ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpModErep (RSCMU300_GMSK, instrSession, Mode, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      RESULTS: FREQUENCY SPECTRUM
 *      The subsystem SPECtrum:MODulation[:RESULT] contains the commands for
 *      measurement and output of signal spectrum.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start single shot measurement and return results
/* Purpose : This function starts a single shot measurement and returns the
/*           results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSpModGm (ViSession instrSession,
                                                                        ViPReal64 referencePower,
                                                                        ViPInt32  matching,
                                                                        ViChar    _VI_FAR errorMessage[])
{
    return NSig_ReadSpMod (RSCMU300_GMSK, instrSession, referencePower, matching, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This function only outputs the results without any care of the
/*           measurement state.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSpModGm (ViSession instrSession,
                                                                        ViPReal64 referencePower,
                                                                        ViPInt32  matching,
                                                                        ViChar    _VI_FAR errorMessage[])
{
    return NSig_FetcSpMod (RSCMU300_GMSK, instrSession, referencePower, matching, errorMessage);
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This function waits until the results are valid for the first
/*           time (depending on the chosen statistic count) and then outputs
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSpModGm (ViSession instrSession,
                                                                        ViPReal64 referencePower,
                                                                        ViPInt32  matching,
                                                                        ViChar    _VI_FAR errorMessage[])
{
    return NSig_SampSpMod (RSCMU300_GMSK, instrSession, referencePower, matching, errorMessage);
}

/*===========================================================================*/
/* Function: Read Array
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrSpModGm (ViSession instrSession,
                                                                           ViReal64  BurstPower[],
                                                                           ViChar    _VI_FAR errorMessage[])
{
    return NSig_ReadArrSpMod (RSCMU300_GMSK, instrSession, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Array
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrSpModGm (ViSession instrSession,
                                                                           ViReal64  BurstPower[],
                                                                           ViChar    _VI_FAR errorMessage[])
{
    return NSig_FetcArrSpMod (RSCMU300_GMSK, instrSession, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Array
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrSpModGm (ViSession instrSession,
                                                                           ViReal64  BurstPower[],
                                                                           ViChar    _VI_FAR errorMessage[])
{
    return NSig_SampArrSpMod (RSCMU300_GMSK, instrSession, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Read Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrVarSpecMod (ViSession instrSession,
                                                       ViReal64 burstPower[],
                                                       ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasArray(instrSession, "READ:ARRay:SPECtrum:MODulation:VMPoint", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrVarSpecMod (ViSession instrSession,
                                                       ViReal64 burstPower[],
                                                       ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:MODulation:VMPoint", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrVarSpecMod (ViSession instrSession,
                                                       ViReal64 burstPower[],
                                                       ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasArray(instrSession, "SAMPle:ARRay:SPECtrum:MODulation:VMPoint", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Read Array Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrSpecModTime (ViSession instrSession,
                                                        ViReal64  burstPower[],
                                                        ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasArray(instrSession, "READ:ARRay:SPECtrum:MODulation:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Array Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrSpecModTime (ViSession instrSession,
                                                        ViReal64  burstPower[],
                                                        ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:MODulation:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Array Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrSpecModTime (ViSession instrSession,
                                                        ViReal64  burstPower[],
                                                        ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasArray(instrSession, "SAMPle:ARRay:SPECtrum:MODulation:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: area limit matching
/* Purpose : A bit in the output values is set if the corresponding fixed
/*           measurement point exceeds the limit.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcSpecModAreaLimMatc (ViSession  instrSession,
                                                            ViInt32   *limitMatching,
                                                            ViChar     errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  CHECKRETMSG(RSCMU300_getViString(instrSession,"CALCulate:ARRay:SPECtrum:MODulation:AREA:LIMit:MATChing?",rdBuf,RD_BUFFER_SIZE,0));

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf,"%d", limitMatching);
  else *limitMatching = RSCMU300_NAN_VI_INT32;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read SubArray
/* Purpose : This outputs the off-carrier power due to modulation in the
/*           subranges
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSubSpModGm (ViSession instrSession,
                                                                           ViReal64  PowerValues[],
                                                                           ViChar    _VI_FAR errorMessage[])
{
    return NSig_ReadSubSpMod (RSCMU300_GMSK, instrSession, PowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch SubArray
/* Purpose : This outputs the off-carrier power due to modulation in the
/*           subranges
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSubSpModGm (ViSession instrSession,
                                                                           ViReal64  PowerValues[],
                                                                           ViChar    _VI_FAR errorMessage[])
{
    return NSig_FetcSubSpMod (RSCMU300_GMSK, instrSession, PowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch SubArray
/* Purpose : This outputs the off-carrier power due to modulation in the
/*           subranges
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSubSpModGm (ViSession instrSession,
                                                                           ViReal64  PowerValues[],
                                                                           ViChar    _VI_FAR errorMessage[])
{
    return NSig_SampSubSpMod (RSCMU300_GMSK, instrSession, PowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Read SubArray Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSubArrSpecModTime (ViSession instrSession,
                                                           ViReal64 burstPower[],
                                                           ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasArray(instrSession, "READ:SUBarrays:SPECtrum:MODulation:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch SubArray Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSubArrSpecModTime (ViSession instrSession,
                                                           ViReal64 burstPower[],
                                                           ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasArray(instrSession, "FETCh:SUBarrays:SPECtrum:MODulation:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample SubArray Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSubArrSpecModTime (ViSession instrSession,
                                                           ViReal64 burstPower[],
                                                           ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasArray(instrSession, "SAMPle:SUBarrays:SPECtrum:MODulation:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Current Limit Line Template
/* Purpose : These function is always a query and returns the
/*           current limit line template.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SensSpecModLimLineUsed (ViSession instrSession,
                                                            ViInt32  *currLimLine,
                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  CHECKRETMSG(RSCMU300_getViString(instrSession,"SENSe:SPECtrum:MODulation:LIMit:LINE:USED?",rdBuf,RD_BUFFER_SIZE,0));

  // Extract the CMU response:
  if (strncmp ("GMSK", rdBuf, 4) == 0)
    *currLimLine = RSCMU300_GMSK;
  else if (strncmp ("EPSK", rdBuf, 4) == 0)
    *currLimLine = RSCMU300_EPSK;

  return RSCMU300_Status;
}


/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT SPECTRUM/SWITCHING
 *    The subsystem SPECtrum:SWITching contains the commands for measuring
 *    the frequency spectrum.
 *-----------------------------------------------------------------------------
 *      CONFIGURATION CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmContDef (ViSession instrSession,
                                                                              ViBoolean DefaultValues,
                                                                              ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpSwContDef (RSCMU300_GMSK, instrSession, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Frequency Select f. Time Domain
/* Purpose : These function selects the measurement frequency for the time
/*           domain (power vs. time) measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpecSwitFSelFTimeD (ViSession instrSession,
                                                         ViInt32   select,
                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViString    list[] = {"OFF","N180","N160","N140","N120","N100","N080","N060","N040","N025","N020","N010",
                        "REF","P010","P020","P025","P040","P060","P080","P100","P120","P140","P160","P180",
                        "NV4","NV3","NV2","NV1","PV1","PV2","PV3","PV4", VI_NULL};

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession, RSCMU300_V3_65, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));


  RETMSG(RSCMU300_setEnum(instrSession, "CONFigure:SPECtrum:SWITching:TDFSelect", select, list,
                              RSCMU_ERROR_PARAMETER3));
}


/*===========================================================================*/
/* Function: Spectrum Switching continuous statistical mode
/* Purpose : This function defines the continuous statistical mode for the
/*           Spectrum due to Switching measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SpecSwitContStatMod (ViSession instrSession,
                                                         ViInt32 continuousStatisticalMode,
                                                         ViChar errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[] = {"PHOL","SCO", VI_NULL};

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_setEnum(instrSession, "CONFigure:SPECtrum:SWITching:CSMode",
                         continuousStatisticalMode, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Nr. of Slots
/* Purpose : This function sets the Number of slots per TDMA frame measured
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SpecSwitNoOfSlot (ViSession instrSession,
                                                      ViInt32 nr_ofSlots,
                                                      ViChar errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_setViInt32(instrSession,"CONFigure:SPECtrum:SWITching:NOSLots",
                          nr_ofSlots, 1, 8,
                          RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Scope of measurement
/* Purpose : This function defines the scope of the power measurement,
/*           combining the ...CONTrol:RMODe, ...CONTrol:STATistics, and the
/*           ...CONTrol:REPetition commands.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmScope (ViSession instrSession,
                                                                            ViInt32   MeasuredValuesType,
                                                                            ViInt32   NbBurst,
                                                                            ViInt32   repetition,
                                                                            ViInt32   NbRepetition,
                                                                            ViInt32   StopCondition,
                                                                            ViInt32   StepMode,
                                                                            ViChar    errorMessage[])
{
    return NSig_ConfSpSwScope (RSCMU300_GMSK, instrSession, MeasuredValuesType, NbBurst, repetition, NbRepetition,
                               StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmContRep (ViSession instrSession,
                                                                              ViInt32   repetition,
                                                                              ViInt32   StopCondition,
                                                                              ViInt32   StepMode,
                                                                              ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpSwContRep (RSCMU300_GMSK, instrSession, repetition, StopCondition, StepMode, errorMessage);
}


/*===========================================================================*/
/* Function: Spectrum Switching Slot Count
/* Purpose : This function defines whether a single timeslot or all timeslots
/*           are considered for the Spectrum due to Switching measurement..
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmSlotCount (ViSession instrSession,
                                                         ViInt32   slotCount,
                                                         ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[] = {"SSL","MSL", VI_NULL};

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_22,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_setEnum(instrSession, "CONF:SPEC:SWIT:GMSK:SCO",
                         slotCount, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*-----------------------------------------------------------------------------
 *      LIMITS
 *      The subsystem SPECtrum:SWITching:LIMit contains the commands for
 *      definition of tolerance values for the spectrum measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Limit Lines
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmLimDef (ViSession instrSession,
                                                                             ViBoolean DefaultValues,
                                                                             ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpSwLimDef (RSCMU300_GMSK, instrSession, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lines On/Off
/* Purpose : This function switches the limit checking for all measurepoints.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmLimMode (ViSession instrSession,
                                                                              ViBoolean limitLines,
                                                                              ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpSwLimMode (RSCMU300_GMSK, instrSession, limitLines, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lines
/* Purpose : These commands activate and define limit lines for the spectrum
/*           due to switching measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmLim (ViSession instrSession,
                                                   ViInt32 measurePoint,
                                                   ViBoolean enable,
                                                   ViReal64 minRelativeLimit,
                                                   ViReal64 maxRelativeLimit,
                                                   ViReal64 absoluteLimit,
                                                   ViChar errorMessage[])
{
    return NSig_ConfSpSwLim (RSCMU300_GMSK, instrSession, measurePoint, enable, minRelativeLimit, maxRelativeLimit, absoluteLimit, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Statistic Count
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmCont (ViSession instrSession,
                                                                           ViInt32   measuredValuesType,
                                                                           ViInt32   NbBurst,
                                                                           ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpSwCont (RSCMU300_GMSK, instrSession, measuredValuesType, NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set the number of bursts
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmStat (ViSession instrSession,
                                                                           ViInt32   NbBurst,
                                                                           ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpSwStat (RSCMU300_GMSK, instrSession, NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set result mode
/* Purpose : This function specifies the type of measured values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmResMode (ViSession instrSession,
                                                                              ViInt32   MeasuredValuesType,
                                                                              ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpSwResMode (RSCMU300_GMSK, instrSession, MeasuredValuesType, errorMessage);
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmContRepSt (ViSession instrSession,
                                                                                ViInt32   NbRepetition,
                                                                                ViInt32   StopCondition,
                                                                                ViInt32   StepMode,
                                                                                ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpSwContRepSt (RSCMU300_GMSK, instrSession, NbRepetition, StopCondition, StepMode, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      MEASUREMENT CONFIGURATION
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Measure Points
/* Purpose : This function permits to select which frequencies a spectrum
/*           switching measurement is performed. A reduction of the
/*           measurement points enhances the measurement speed.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmContMpo (ViSession instrSession,
                                                                              ViInt32   measurePoint,
                                                                              ViBoolean enable,
                                                                              ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpSwContMpo (RSCMU300_GMSK, instrSession, measurePoint, enable, errorMessage);
}

/*===========================================================================*/
/* Function: Variable Measure Points
/* Purpose : This function sets and enables additional pairs of
/*           measurement points at up to 4 variable offset frequencies
/*           (numbered by the numeric suffix <nr> = 1 to 4).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpecSwVarMpo (ViSession instrSession,
                                                      ViInt32 nr, ViInt32 enable,
                                                      ViReal64 frequencyMHz,
                                                      ViChar errorMessage[])
{
    return RSCMU300_MeasSpecVarMeaPoint(instrSession, "CONFigure:SPECtrum:SWITching:CONTrol:VMPoint", nr, enable, frequencyMHz, errorMessage);
}

/*===========================================================================*/
/* Function: Definition of Subarrays
/* Purpose : This function configures the READ:SUBarrays.., FETCh:SUBarrays..,
/*           and SAMPle:SUBarrays:SPECtrum:SWITching[:GMSK] commands. It
/*           restricts the measurement to up to 32 subranges where either all
/*           measurement results (the number of which is given by the second
/*           numerical parameter) or a single statistical value is returned.
/*           The subranges are defined by the start time and the number of
/*           test points which are located at fixed frequencies (see command
/*           CONFigure:SPECtrum:SWITching[:GMSK]:LIMit:LINE<nr>).
/*           The subranges may overlap but must be within the total range of
/*           the spectrum due to switching measurement. Test points outside
/*           this range are not measured (result NAN) and do not enter into
/*           the ARIThmetical, MINimum and MAXimum values.
/*           By default, only one range corresponding to the total measurement
/*           range is used and all measurement values are returned.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSubSpSwGmRang (ViSession instrSession,
                                                                              ViInt32   StatisticsMode,
                                                                              ViReal64  StartFrequency,
                                                                              ViInt32   Samples,
                                                                              ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSubSpSwRang (RSCMU300_GMSK, instrSession, StatisticsMode, StartFrequency, Samples, errorMessage);
}

/*===========================================================================*/
/* Function: Configure TimeDomain SubRanges
/* Purpose : This function configurates the READ..., FETCh... and
/*           SAMPle:SSUBarrays:SPECtrum:<Application>:TDOMain commands.
/*           If the requested number of results exceeds the measurement
/*           range, the count parameter will be corrected by the system.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSubSpecSwitTime (ViSession instrSession,
                                                        ViInt32   mode,
                                                        ViReal64  startTime,
                                                        ViInt32   numberOfSamples,
                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, mode, 0, 4, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, startTime, -30, 175, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, numberOfSamples, 1, 618, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU300_ConfSubArr (instrSession, "CONFigure:SUBarrays:SPECtrum:SWITching:TDOMain", mode, startTime, numberOfSamples, errorMessage);
}

/*-----------------------------------------------------------------------------
 *      CONTROL OF SPECTRUM SWITCHING MEAS
 *      It contains the functions for general control of the spectrum switching
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Init
/* Purpose : Start measurement without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitSpSwGm (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
    return NSig_InitSpSw (RSCMU300_GMSK, instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : Abort measurement and switch off => OFF
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborSpSwGm (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
    return NSig_AborSpSw (RSCMU300_GMSK, instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : Stop measurement => STOP
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopSpSwGm (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
    return NSig_StopSpSw (RSCMU300_GMSK, instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : Next measurement step (only counting mode) => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContSpSwGm (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
    return NSig_ContSpSw (RSCMU300_GMSK, instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Status
/* Purpose : This function is always a query. It immediately reads the
/*           measurement status (for polling, see chapters 3 and 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSpSwGmSt (ViSession instrSession,
                                                                         ViPInt32  MeasStatus,
                                                                         ViPInt32  CurrentStatCycleCount,
                                                                         ViPInt32  CurrentEvalPeriodCount,
                                                                         ViChar    _VI_FAR errorMessage[])
{
    return NSig_FetcSpSwSt (RSCMU300_GMSK, instrSession, MeasStatus, CurrentStatCycleCount, CurrentEvalPeriodCount, errorMessage);
}

/*===========================================================================*/
/* Function: Event Reporting Mode
/* Purpose : This function defines the events to be reported during the
/*           measurement (event reporting, see chapter 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmErep (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpSwErep (RSCMU300_GMSK, instrSession, Mode, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      RESULTS: FREQUENCY SPECTRUM
 *      The subsystem SPECtrum:SWITching[:RESULT] contains the commands for
 *      measurement and output of signal spectrum.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Read
/* Purpose : This function starts the measurement and outputs some results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSpSwGm (ViSession instrSession,
                                                                       ViPReal64 referencePower,
                                                                       ViPInt32  matching,
                                                                       ViChar    _VI_FAR errorMessage[])
{
    return NSig_ReadSpSw (RSCMU300_GMSK, instrSession, referencePower, matching, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This function only outputs the results without any care of the
/*           measurement state.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSpSwGm (ViSession instrSession,
                                                                       ViPReal64 referencePower,
                                                                       ViPInt32  matching,
                                                                       ViChar    _VI_FAR errorMessage[])
{
    return NSig_ReadSpSw (RSCMU300_GMSK, instrSession, referencePower, matching, errorMessage);
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This function waits until the results are valid for the first
/*           time (depending on the chosen statistic count) and then outputs
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSpSwGm (ViSession instrSession,
                                                                       ViPReal64 referencePower,
                                                                       ViPInt32  matching,
                                                                       ViChar    _VI_FAR errorMessage[])
{
    return NSig_SampSpSw (RSCMU300_GMSK, instrSession, referencePower, matching, errorMessage);
}

/*===========================================================================*/
/* Function: Read Array
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrSpSwGm (ViSession instrSession,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
    return NSig_ReadArrSpSw (RSCMU300_GMSK, instrSession, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Array
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrSpSwGm (ViSession instrSession,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
    return NSig_FetcArrSpSw (RSCMU300_GMSK, instrSession, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Array
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrSpSwGm (ViSession instrSession,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
    return NSig_SampArrSpSw (RSCMU300_GMSK, instrSession, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Read Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrVarSpecSwit (ViSession instrSession,
                                                       ViReal64 burstPower[],
                                                       ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasArray(instrSession, "READ:ARRay:SPECtrum:SWITching:VMPoint", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrVarSpecSwit (ViSession instrSession,
                                                       ViReal64 burstPower[],
                                                       ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:SWITching:VMPoint", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrVarSpecSwit (ViSession instrSession,
                                                       ViReal64 burstPower[],
                                                       ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasArray(instrSession, "SAMPle:ARRay:SPECtrum:SWITching:VMPoint", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Read Array Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrSpecSwitTime (ViSession instrSession,
                                                         ViReal64  burstPower[],
                                                         ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasArray(instrSession, "READ:ARRay:SPECtrum:SWITching:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Array Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrSpecSwitTime (ViSession instrSession,
                                                         ViReal64  burstPower[],
                                                         ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:SWITching:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Array Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrSpecSwitTime (ViSession instrSession,
                                                         ViReal64  burstPower[],
                                                         ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasArray(instrSession, "SAMPle:ARRay:SPECtrum:SWITching:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: area limit matching
/* Purpose : A bit in the output values is set if the corresponding fixed
/*           measurement point exceeds the limit.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcSpecSwiAreaLimMatc (ViSession  instrSession,
                                                            ViInt32   *limitMatching,
                                                            ViChar     errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  CHECKRETMSG(RSCMU300_getViString(instrSession,"CALCulate:ARRay:SPECtrum:SWITching:AREA:LIMit:MATChing?",rdBuf,RD_BUFFER_SIZE,0));

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf,"%d", limitMatching);
  else *limitMatching = RSCMU300_NAN_VI_INT32;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read SubArray
/* Purpose : This outputs the off-carrier power due to switching in the
/*           subranges
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSubSpSwGm (ViSession instrSession,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
    return NSig_ReadSubSpSw (RSCMU300_GMSK, instrSession, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch SubArray
/* Purpose : This outputs the off-carrier power due to switching in the
/*           subranges
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSubSpSwGm (ViSession instrSession,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
    return NSig_FetcSubSpSw (RSCMU300_GMSK, instrSession, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample SubArray
/* Purpose : This outputs the off-carrier power due to switching in the
/*           subranges
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSubSpSwGm (ViSession instrSession,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
    return NSig_SampSubSpSw (RSCMU300_GMSK, instrSession, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Read SubArray Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSubArrSpecSwitTime (ViSession instrSession,
                                                            ViReal64 burstPower[],
                                                            ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasArray(instrSession, "READ:SUBarrays:SPECtrum:SWITching:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch SubArray Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSubArrSpecSwitTime (ViSession instrSession,
                                                            ViReal64 burstPower[],
                                                            ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasArray(instrSession, "FETCh:SUBarrays:SPECtrum:SWITching:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample SubArray Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSubArrSpecSwitTime (ViSession instrSession,
                                                            ViReal64 burstPower[],
                                                            ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasArray(instrSession, "SAMPle:SUBarrays:SPECtrum:SWITching:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Current Limit Line Template
/* Purpose : These function is always a query and returns the
/*           current limit line template.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SensSpecSwiLimLineUsed (ViSession instrSession,
                                                            ViInt32  *currLimLine,
                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  CHECKRETMSG(RSCMU300_getViString(instrSession,"SENSe:SPECtrum:SWITching:LIMit:LINE:USED?",rdBuf,RD_BUFFER_SIZE,0));

  // Extract the CMU response:
  if (strncmp ("GMSK", rdBuf, 4) == 0)
    *currLimLine = RSCMU300_GMSK;
  else if (strncmp ("EPSK", rdBuf, 4) == 0)
    *currLimLine = RSCMU300_EPSK;

  return RSCMU300_Status;
}


/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT SPECTRUM/Modulation&Switching
 * ----------------------------------------------------------------------------
 */


/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpecMSwContRep (ViSession instrSession,
                                                     ViInt32   repetition,
                                                     ViInt32   stopCondition,
                                                     ViInt32   stepMode,
                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 // Check if the function is correctly used:
 CHECK_VI_INT32_RANGE(instrSession, repetition,RSCMU300_CONTINUOUS,RSCMU300_SINGLE_SHOT, RSCMU_ERROR_PARAMETER2, errorMessage);
 CHECK_VI_INT32_RANGE(instrSession, stopCondition,RSCMU300_NONE,RSCMU300_STOP_ON, RSCMU_ERROR_PARAMETER3, errorMessage);
 CHECK_VI_INT32_RANGE(instrSession, stepMode,RSCMU300_NONE,RSCMU300_STEP_ON, RSCMU_ERROR_PARAMETER4, errorMessage);

 sprintf (wrtBuf, "CONFigure:SPECtrum:MSWitching:CONTrol:REPetition %s,%s,%s",repetition_meas[repetition], mode_StopCondition_SON[stopCondition], StrStepMode[stepMode]);
 RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Init
/* Purpose : Start measurement without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitSpecMSw (ViSession instrSession,
                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  RETMSG(RSCMU300_sendCmd(instrSession, "INITiate:SPECtrum:MSWitching"));
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : Abort measurement and switch off => OFF
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborSpecMSw (ViSession instrSession,
                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  RETMSG(RSCMU300_sendCmd(instrSession, "ABORt:SPECtrum:MSWitching"));
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : Stop measurement => STOP
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopSpecMSw (ViSession instrSession,
                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  RETMSG(RSCMU300_sendCmd(instrSession, "STOP:SPECtrum:MSWitching"));
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : Next measurement step (only counting mode) => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContSpecMSw (ViSession instrSession,
                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  RETMSG(RSCMU300_sendCmd(instrSession, "CONTinue:SPECtrum:MSWitching"));
}

/*===========================================================================*/
/* Function: Spectrum Modulation Measurement Status
/* Purpose : This function returns the status of the current Spectrum
/*           Modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSpecMSwStat (ViSession instrSession,
                                                  ViInt32  *MeasurementStatus,
                                                  ViInt32  *CountingNo,
                                                  ViInt32  *ModStatisticNo,
                                                  ViInt32  *SwitchStatisticNo,
                                                  ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_FetcSpecMSwStatus (instrSession, "FETCh:SPECtrum:MSWitching:STATus", MeasurementStatus, CountingNo, ModStatisticNo, SwitchStatisticNo, errorMessage);
}

/*===========================================================================*/
/* Function: Event Reporting Mode
/* Purpose : This function defines the events to be reported during the
/*           measurement (event reporting, see chapter 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpecMSwErep (ViSession instrSession,
                                                  ViInt32   Mode,
                                                  ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_ConfEventReporting (instrSession, "CONFigure:SPECtrum:MSWitching:EREPorting", Mode, errorMessage);
}


/*===========================================================================*/
/* Function: Start single shot measurement and return results
/* Purpose : This function starts a single shot measurement and returns the
/*           results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSpecMSw (ViSession instrSession,
                                              ViReal64 *refPowMod,
                                              ViInt32  *matchingMod,
                                              ViReal64 *refPowSwitch,
                                              ViInt32  *matchingSwitch,
                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasSpecModSwitch (instrSession, "READ:SCALar:SPECtrum:MSWitching", refPowMod, matchingMod, refPowSwitch, matchingSwitch, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This function only outputs the results without any care of the
/*           measurement state.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSpecMSw (ViSession instrSession,
                                              ViReal64 *refPowMod,
                                              ViInt32  *matchingMod,
                                              ViReal64 *refPowSwitch,
                                              ViInt32  *matchingSwitch,
                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasSpecModSwitch (instrSession, "FETCh:SCALar:SPECtrum:MSWitching", refPowMod, matchingMod, refPowSwitch, matchingSwitch, errorMessage);
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This function waits until the results are valid for the first
/*           time (depending on the chosen statistic count) and then outputs
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSpecMSw (ViSession instrSession,
                                              ViReal64 *refPowMod,
                                              ViInt32  *matchingMod,
                                              ViReal64 *refPowSwitch,
                                              ViInt32  *matchingSwitch,
                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasSpecModSwitch (instrSession, "SAMPle:SCALar:SPECtrum:MSWitching", refPowMod, matchingMod, refPowSwitch, matchingSwitch, errorMessage);
}


/*===========================================================================*/
/* Function: Read
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrSpecMSw (ViSession instrSession,
                                                 ViReal64  burstPower[],
                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasArray(instrSession, "READ:ARRay:SPECtrum:MSWitching", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrSpecMSw (ViSession instrSession,
                                                 ViReal64  burstPower[],
                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:MSWitching", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrSpecMSw (ViSession instrSession,
                                                 ViReal64  burstPower[],
                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasArray(instrSession, "SAMPLe:ARRay:SPECtrum:MSWitching", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: area limit matching
/* Purpose : A bit in the output values is set if the corresponding fixed
/*           measurement point exceeds the limit.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcSpecMSwAreaLimMatc (ViSession  instrSession,
                                                         ViInt32   *modLimit,
                                                         ViInt32   *switLimit,
                                                         ViChar     errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      tab[100][100];
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  CHECKRETMSG(RSCMU300_getViString(instrSession,"CALCulate:ARRay:SPECtrum:MSWitching:AREA:LIMit:MATChing?",rdBuf,RD_BUFFER_SIZE,0));

  //sscanf(rdBuf,"%ld,%ld", modLimit, switLimit);

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%d", modLimit);
  else *modLimit = RSCMU300_NAN;

  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%d", switLimit);
  else *switLimit = RSCMU300_NAN;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrVarSpecMSw (ViSession instrSession,
                                                    ViReal64  burstPower[],
                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasArray(instrSession, "READ:ARRay:SPECtrum:MSWitching:VMPoint", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrVarSpecMSw (ViSession instrSession,
                                                    ViReal64 burstPower[],
                                                    ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:MSWitching:VMPoint", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrVarSpecMSw (ViSession instrSession,
                                                    ViReal64 burstPower[],
                                                    ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  return RSCMU300_MeasArray(instrSession, "SAMPLe:ARRay:SPECtrum:MSWitching:VMPoint", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Current Limit Line Template
/* Purpose : These function is always a query and returns the
/*           current limit line template.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SensSpecMswLimLineUsed (ViSession instrSession,
                                                         ViInt32  *currLimLine,
                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  CHECKRETMSG(RSCMU300_getViString(instrSession,"SENSe:SPECtrum:MSWitching:LIMit:LINE:USED?",rdBuf,RD_BUFFER_SIZE,0));

  // Extract the CMU response:
  if (strncmp ("GMSK", rdBuf, 4) == 0)
    *currLimLine = RSCMU300_GMSK;
  else if (strncmp ("EPSK", rdBuf, 4) == 0)
    *currLimLine = RSCMU300_EPSK;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 * GSM MEASUREMENTS WITH SIGNALLING (SIGNALLING):
 * ----------------------------------------------------------------------------
 */
/*-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT POWER
 *    The subsystem POWer contains the commands for measuring the
 *    signal power.
 *    This subsystem corresponds to the measurement menu Power vs.
 *    Time and the associated popup menu Power vs Time Configuration.
 *-----------------------------------------------------------------------------
 *      TEST CONFIGURATION
 *      The functions of this subsystem determine the parameters of the
 *      signal power measurement. GSM signals are transferred in the
 *      form of bursts, which divided up into various tolerance ranges
 *      defined in the GSM standard.
 * ----------------------------------------------------------------------------
 *        CONFIGURATION CONTROL
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmContDef (ViSession instrSession,
                                                                            ViInt32   channel,
                                                                            ViBoolean DefaultValues,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER3, errorMessage);

  if (DefaultValues == 1)
  {
    sprintf (wrtBuf, "DEF:POW:NBUR:GMSK:%s:CONT %s", Channel_Type[channel]
                                                   , mode_On_Off[DefaultValues]);
    if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
      return RSCMU300_Status;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Scope of measurement
/* Purpose : This function defines the scope of the power measurement,
/*           combining the ...CONTrol:RMODe, ...CONTrol:STATistics, and the
/*           ...CONTrol:REPetition commands.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmScope (ViSession instrSession,
                                                                          ViInt32   channel,
                                                                          ViInt32   MeasuredValuesType,
                                                                          ViInt32   NbBurst,
                                                                          ViInt32   repetition,
                                                                          ViInt32   NbRepetition,
                                                                          ViInt32   StopCondition,
                                                                          ViInt32   StepMode,
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, repetition, 0, 2, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER8, errorMessage);

  if (repetition != RSCMU300_MULTIPLE)
    sprintf(wrtBuf, "CONF:POW:NBUR:GMSK:%s:CONT %s,%ld,%s,%s,%s", Channel_Type[channel]
                                                               , mode_ScopeMeas[MeasuredValuesType]
                                                               , NbBurst
                                                               , repetition_meas[repetition]
                                                               , mode_StopCondition[StopCondition]
                                                               , StrStepMode[StepMode]);
  else
    sprintf(wrtBuf, "CONF:POW:NBUR:GMSK:%s:CONT %s %ld %ld %s %s", Channel_Type[channel]
                                                               , mode_ScopeMeas[MeasuredValuesType]
                                                               , NbBurst
                                                               , NbRepetition
                                                               , mode_StopCondition[StopCondition]
                                                               , StrStepMode[StepMode]);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles, the
/*           stop condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmContRep (ViSession instrSession,
                                                                            ViInt32   channel,
                                                                            ViInt32   RepetitionMode,
                                                                            ViInt32   StopCondition,
                                                                            ViInt32   StepMode,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, RepetitionMode, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER5, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:GMSK:%s:CONT:REP %s,%s,%s", Channel_Type[channel]
                                                            , repetition_meas[RepetitionMode]
                                                            , mode_StopCondition[StopCondition]
                                                            , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Filter
/* Purpose : This function selects the measurement filter.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowgGmFilter (ViSession instrSession,
                                                      ViInt32   filter,
                                                      ViChar    errorMessage[])
{
 ViStatus    RSCMU300_Status = VI_SUCCESS;

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 RETMSG(RSCMU300_setEnum(instrSession, "CONF:POW:NBUR:GMSK:TCH:FILT",
                         filter, StrFilter,
                         RSCMU_ERROR_PARAMETER2));
}

/*
 * -----------------------------------------------------------------------------
 *        LIMITS LINES
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Default limit Lines (ON/OFF)
/* Purpose : This function switches the default limit lines on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmLimDef (ViSession instrSession,
                                                                           ViInt32   channel,
                                                                           ViBoolean DefaultLimitLines,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultLimitLines, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "DEF:POW:NBUR:GMSK:%s:LIM:LINE %s", Channel_Type[channel]
                                                     , mode_On_Off[DefaultLimitLines]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
   return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Switches the lower limit lines ON/OFF
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmLimLowMode (ViSession instrSession,
                                                                               ViInt32   channel,
                                                                               ViBoolean enable,
                                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, enable, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:GMSK:%s:LIM:LINE:ASYM:LOW:ENAB %s", Channel_Type[channel]
                                                                    , mode_On_Off[enable]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Switches the upper limit lines ON/OFF
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmLimUppMode (ViSession instrSession,
                                                                               ViInt32   channel,
                                                                               ViBoolean enable,
                                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, enable, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:GMSK:%s:LIM:LINE:ASYM:UPP:ENAB %s", Channel_Type[channel]
                                                                    , mode_On_Off[enable]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Lower limit Lines
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmLimLow (ViSession instrSession,
                                                                           ViInt32   channel,
                                                                           ViInt32   area,
                                                                           ViBoolean enable,
                                                                           ViBoolean StartPointBitON_OFF,
                                                                           ViReal64  StartPointBit,
                                                                           ViBoolean EndPointBitON_OFF,
                                                                           ViReal64  EndPointBit,
                                                                           ViBoolean StartPointRelLevON_OFF,
                                                                           ViReal64  StartPointRelLev,
                                                                           ViBoolean EndPointRelLevON_OFF,
                                                                           ViReal64  EndPointRelLev,
                                                                           ViBoolean StartPointAbsLevON_OFF,
                                                                           ViReal64  StartPointAbsLev,
                                                                           ViBoolean EndPointAbsLevON_OFF,
                                                                           ViReal64  EndPointAbsLev,
                                                                           ViBoolean visibility,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      StartPointBitBuf[64]= "",
              EndPointBitBuf[64]= "",
              StartPointRelLevBuf[64]= "",
              EndPointRelLevBuf[64]= "",
              StartPointAbsLevBuf[64]= "",
              EndPointAbsLevBuf[64]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (StartPointBitON_OFF == RSCMU300_ON)
    sprintf(StartPointBitBuf, "%.12f", StartPointBit);
  else sprintf(StartPointBitBuf, "%s", "OFF");

  if (EndPointBitON_OFF == RSCMU300_ON)
    sprintf(EndPointBitBuf, "%.12f", EndPointBit);
  else sprintf(EndPointBitBuf, "%s", "OFF");

  if (StartPointRelLevON_OFF == RSCMU300_ON)
    sprintf(StartPointRelLevBuf, "%.12f", StartPointRelLev);
  else sprintf(StartPointRelLevBuf, "%s", "OFF");

  if (EndPointRelLevON_OFF == RSCMU300_ON)
    sprintf(EndPointRelLevBuf, "%.12f", EndPointRelLev);
  else sprintf(EndPointRelLevBuf, "%s", "OFF");

  if (StartPointAbsLevON_OFF == RSCMU300_ON)
    sprintf(StartPointAbsLevBuf, "%.12f", StartPointAbsLev);
  else sprintf(StartPointAbsLevBuf, "%s", "OFF");

  if (EndPointAbsLevON_OFF == RSCMU300_ON)
    sprintf(EndPointAbsLevBuf, "%.12f", EndPointAbsLev);
  else sprintf(EndPointAbsLevBuf, "%s", "OFF");

  sprintf (wrtBuf, "CONF:POW:NBUR:GMSK:%s:LIM:LINE:ASYM:LOW:AREA%ld:ENAB %s", Channel_Type[channel]
                                                                           , area
                                                                           , mode_On_Off[enable]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  sprintf (wrtBuf, "CONF:POW:NBUR:GMSK:%s:LIM:LINE:ASYM:LOW:AREA%ld %s,%s,%s,%s,%s,%s,%s", Channel_Type[channel]
                                                                                        , area
                                                                                        , StartPointBitBuf
                                                                                        , EndPointBitBuf
                                                                                        , StartPointRelLevBuf
                                                                                        , EndPointRelLevBuf
                                                                                        , StartPointAbsLevBuf
                                                                                        , EndPointAbsLevBuf
                                                                                        , mode_On_Off[visibility]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Upper limit Lines
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmLimUpp (ViSession instrSession,
                                                                           ViInt32   channel,
                                                                           ViInt32   area,
                                                                           ViBoolean enable,
                                                                           ViBoolean StartPointBitON_OFF,
                                                                           ViReal64  StartPointBit,
                                                                           ViBoolean EndPointBitON_OFF,
                                                                           ViReal64  EndPointBit,
                                                                           ViBoolean StartPointRelLevON_OFF,
                                                                           ViReal64  StartPointRelLev,
                                                                           ViBoolean EndPointRelLevON_OFF,
                                                                           ViReal64  EndPointRelLev,
                                                                           ViBoolean StartPointAbsLevON_OFF,
                                                                           ViReal64  StartPointAbsLev,
                                                                           ViBoolean EndPointAbsLevON_OFF,
                                                                           ViReal64  EndPointAbsLev,
                                                                           ViBoolean visibility,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      StartPointBitBuf[64]= "",
              EndPointBitBuf[64]= "",
              StartPointRelLevBuf[64]= "",
              EndPointRelLevBuf[64]= "",
              StartPointAbsLevBuf[64]= "",
              EndPointAbsLevBuf[64]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (StartPointBitON_OFF == RSCMU300_ON)
    sprintf(StartPointBitBuf, "%.12f", StartPointBit);
  else sprintf(StartPointBitBuf, "%s", "OFF");

  if (EndPointBitON_OFF == RSCMU300_ON)
    sprintf(EndPointBitBuf, "%.12f", EndPointBit);
  else sprintf(EndPointBitBuf, "%s", "OFF");

  if (StartPointRelLevON_OFF == RSCMU300_ON)
    sprintf(StartPointRelLevBuf, "%.12f", StartPointRelLev);
  else sprintf(StartPointRelLevBuf, "%s", "OFF");

  if (EndPointRelLevON_OFF == RSCMU300_ON)
    sprintf(EndPointRelLevBuf, "%.12f", EndPointRelLev);
  else sprintf(EndPointRelLevBuf, "%s", "OFF");

  if (StartPointAbsLevON_OFF == RSCMU300_ON)
    sprintf(StartPointAbsLevBuf, "%.12f", StartPointAbsLev);
  else sprintf(StartPointAbsLevBuf, "%s", "OFF");

  if (EndPointAbsLevON_OFF == RSCMU300_ON)
    sprintf(EndPointAbsLevBuf, "%.12f", EndPointAbsLev);
  else sprintf(EndPointAbsLevBuf, "%s", "OFF");

  sprintf (wrtBuf, "CONF:POW:NBUR:GMSK:%s:LIM:LINE:ASYM:UPP:AREA%ld:ENAB %s", Channel_Type[channel]
                                                                           , area
                                                                           , mode_On_Off[enable]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  sprintf (wrtBuf, "CONF:POW:NBUR:GMSK:%s:LIM:LINE:ASYM:UPP:AREA%ld %s,%s,%s,%s,%s,%s,%s", Channel_Type[channel]
                                                                                        , area
                                                                                        , StartPointBitBuf
                                                                                        , EndPointBitBuf
                                                                                        , StartPointRelLevBuf
                                                                                        , EndPointRelLevBuf
                                                                                        , StartPointAbsLevBuf
                                                                                        , EndPointAbsLevBuf
                                                                                        , mode_On_Off[visibility]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * -----------------------------------------------------------------------------
 *        TIME
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Offset on the burst
/* Purpose : This function defines an offset time in  Bit units by which the
/*           burst is shifted relative to the time axis and the tolerance
/*           template.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmTimeBit (ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViReal64  TimeBit,
                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, TimeBit, RSCMU300_TIMEBIT_MIN, RSCMU300_TIMEBIT_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
     sprintf (wrtBuf, "CONF:POW:NBUR:GMSK:%s:TIME:BOFF %.12f", Channel_Type[channel]
                                                        , TimeBit);
     }
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
     sprintf (wrtBuf, "CONF:POW:NBUR:GMSK:%s:TOFF %.12f", Channel_Type[channel]
                                                        , TimeBit);
    }

  RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*
 *-----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Scope of Measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmCont (ViSession instrSession,
                                                                         ViInt32   channel,
                                                                         ViInt32   MeasuredValuesType,
                                                                         ViInt32   NbBurst,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:GMSK:%s:CONT:STAT %ld", Channel_Type[channel]
                                                       , NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  sprintf (wrtBuf, "CONF:POW:NBUR:GMSK:%s:CONT:RMOD %s", Channel_Type[channel]
                                                       , mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set the number of bursts
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmStat (ViSession instrSession,
                                                                         ViInt32   channel,
                                                                         ViInt32   NbBurst,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:GMSK:%s:CONT:STAT %ld", Channel_Type[channel]
                                                       , NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set result mode
/* Purpose : This function specifies the type of measured values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmResMode (ViSession instrSession,
                                                                            ViInt32   channel,
                                                                            ViInt32   MeasuredValuesType,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:GMSK:%s:CONT:RMOD %s", Channel_Type[channel]
                                                       , mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles, the
/*           stop condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmContRepSt (ViSession instrSession,
                                                                              ViInt32   channel,
                                                                              ViInt32   NbRepetition,
                                                                              ViInt32   StopCondition,
                                                                              ViInt32   StepMode,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER5, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:GMSK:%s:CONT:REP %ld,%s,%s", Channel_Type[channel]
                                                            , NbRepetition
                                                            , mode_StopCondition[StopCondition]
                                                            , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      MEASUREMENT
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Definition of Subarrays
/* Purpose : This function configures the READ:SUBarrays:POWer...,
/*           FETCh:SUBarrays:POWer..., and SAMPle:SUBarrays:POWer commands. It
/*           restricts the measurement to up to 32 subranges where either all
/*           measurement results (the number of which is given by the second
/*           numerical parameter) or a single statistical value is returned.
/*           The subranges are defined by the start time and the number of
/*           test points which are located on a fixed, equidistant grid with
/*           a step width of  Bit.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubPowGmRang (ViSession instrSession,
                                                                            ViInt32   channel,
                                                                            ViInt32   StatisticsMode,
                                                                            ViReal64  StartTime,
                                                                            ViInt32   Samples,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"ALL","ARIT","MIN","MAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, StartTime, RSCMU300_SUBPOW_BIT_MIN, RSCMU300_SUBPOW_BIT_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Samples, RSCMU300_SUBPOW_SAMPLES_MIN, RSCMU300_SUBPOW_SAMPLES_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:POW:NBUR:GMSK:%s %s,%.12f,%ld", Channel_Type[channel]
                                                        , StrMode[StatisticsMode]
                                                        , StartTime
                                                        , Samples);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      MEASUREMENT CONTROL
 *      This subsystem contains the functions for general control of the
 *      power measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start new measurement
/* Purpose : This function starts the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitPowGm (ViSession instrSession,
                                                                     ViInt32   channel,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViUInt32    retCnt = 0;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "INIT:POW:NBUR:GMSK:%s", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort running measurement and switch off
/* Purpose : This function stops the power measurement, setting it to
/*           the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborPowGm (ViSession instrSession,
                                                                     ViInt32   channel,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViUInt32    retCnt = 0;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "ABOR:POW:NBUR:GMSK:%s", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: stop measurement after current statistic cycle
/* Purpose : This function stops the power measurement, setting it to
/*           the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopPowGm (ViSession instrSession,
                                                                     ViInt32   channel,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViUInt32    retCnt = 0;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "STOP:POW:NBUR:GMSK:%s", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Next Measurement Step
/* Purpose : This function continue the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContPowGm (ViSession instrSession,
                                                                     ViInt32   channel,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViUInt32    retCnt = 0;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONT:POW:NBUR:GMSK:%s", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch measurement status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPowGmSt (ViSession instrSession,
                                                                       ViInt32   channel,
                                                                       ViPInt32  MeasStatus,
                                                                       ViPInt32  CurrentStatCycleCount,
                                                                       ViPInt32  CurrentEvalPeriodCount,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Fetch the measurement status:
  sprintf (wrtBuf, "FETC:POW:NBUR:GMSK:%s:STAT?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMeasStatVal(MeasStatus, tab, 0 );

  // Get the counter for current statistics cycle
  if (strcmp (tab[1], "NONE") != 0)
    sscanf (tab[1], "%ld", CurrentStatCycleCount);
  else *CurrentStatCycleCount = RSCMU300_OFF;

  // Get the counter for current evaluation period within a cycle
  if (strcmp (tab[2], "NONE") != 0)
    sscanf (tab[2], "%ld", CurrentEvalPeriodCount);
  else *CurrentEvalPeriodCount = RSCMU300_OFF;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmErep (ViSession instrSession,
                                                                         ViInt32   channel,
                                                                         ViInt32   Mode,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:GMSK:%s:EREP %s", Channel_Type[channel]
                                                  , StrErep[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      MEASURED VALUES
 *      The functions of this subsystem determine and output the results
 *      of the signal power measurement.
 * ----------------------------------------------------------------------------
 *        MEASUREMENT AND BURST POWER
 *        (Subsystem POWer[:RESult])
 *        It contains the functions for measurement and output of the
 *        burst power and its comparison with tolerance values.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : These commands are always queries. They start a measurement and
/*           output all scalar measurement results (see chapter 5). These are:
/*              Bursts out of tolerance (percentage)
/*              Average power of current burst
/*              Peak power of current burst
/*              Average power of averaged trace
/*           The calculation of results in an average or peak measurement is
/*           described in chapter 3 (cf. display modes).The following messages
/*           may be output for the value BurstMatching:
/*              MATC matching
/*              NMAT not matching
/*              INV invalid
/*              NTSC no training sequence code
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadPowGm (ViSession instrSession,
                                                                     ViInt32   channel,
                                                                     ViPReal64 BurstOutOfTol,
                                                                     ViPReal64 AvgBurstPowerCurrent,
                                                                     ViPReal64 PeakBurstPower,
                                                                     ViPInt32  BurstMatching,
                                                                     ViPReal64 AvgBurstPowerAvg,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  sprintf (wrtBuf, "READ:POW:NBUR:GMSK:%s?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  RSCMU300_ScanPow (tab, 0, BurstOutOfTol, AvgBurstPowerCurrent, PeakBurstPower, BurstMatching, AvgBurstPowerAvg);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : These commands are always queries. They start a measurement and
/*           output all scalar measurement results (see chapter 5). These are:
/*              Bursts out of tolerance (percentage)
/*              Average power of current burst
/*              Peak power of current burst
/*              Average power of averaged trace
/*           The calculation of results in an average or peak measurement is
/*           described in chapter 3 (cf. display modes).The following messages
/*           may be output for the value BurstMatching:
/*              MATC matching
/*              NMAT not matching
/*              INV invalid
/*              NTSC no training sequence code
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPowGm (ViSession instrSession,
                                                                     ViInt32   channel,
                                                                     ViPReal64 BurstOutOfTol,
                                                                     ViPReal64 AvgBurstPowerCurrent,
                                                                     ViPReal64 PeakBurstPower,
                                                                     ViPInt32  BurstMatching,
                                                                     ViPReal64 AvgBurstPowerAvg,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  sprintf (wrtBuf, "FETC:POW:NBUR:GMSK:%s?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  RSCMU300_ScanPow (tab, 0, BurstOutOfTol, AvgBurstPowerCurrent, PeakBurstPower, BurstMatching, AvgBurstPowerAvg);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : These commands are always queries. They start a measurement and
/*           output all scalar measurement results (see chapter 5). These are:
/*              Bursts out of tolerance (percentage)
/*              Average power of current burst
/*              Peak power of current burst
/*              Average power of averaged trace
/*           The calculation of results in an average or peak measurement is
/*           described in chapter 3 (cf. display modes).The following messages
/*           may be output for the value BurstMatching:
/*              MATC matching
/*              NMAT not matching
/*              INV invalid
/*              NTSC no training sequence code
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampPowGm (ViSession instrSession,
                                                                     ViInt32   channel,
                                                                     ViPReal64 BurstOutOfTol,
                                                                     ViPReal64 AvgBurstPowerCurrent,
                                                                     ViPReal64 PeakBurstPower,
                                                                     ViPInt32  BurstMatching,
                                                                     ViPReal64 AvgBurstPowerAvg,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  sprintf (wrtBuf, "SAMP:POW:NBUR:GMSK:%s?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  RSCMU300_ScanPow (tab, 0, BurstOutOfTol, AvgBurstPowerCurrent, PeakBurstPower, BurstMatching, AvgBurstPowerAvg);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Request Tolerance On Values
/* Purpose : This function indicates whether and in which way the per-
/*           missible tolerances for the scalar measured values  have
/*           been exceeded.
/*
/*           The following messages may be output for the values
/*           AvgBurstPower, AvgBurstPowerAvg and PeakBurstPower:
/*
/*              NMAU Tolerance value underflow not matching, underflow
/*              NMAL Tolerance value exceeded not matching, overflow
/*              INV  Measurement invalid invalid
/*              OK   Tolerance value matched
/*
/*           The following messages may be output for the value
/*           BurstMatching:
/*
/*              MATC matching
/*              NMAT not matching
/*              INV  invalid
/*              NTSC no training sequence code
/*              OUT  out of range
/*
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcPowGmMatcLim (ViSession instrSession,
                                                                            ViInt32   channel,
                                                                            ViPInt32  AvgBurstPowerCurrent,
                                                                            ViPInt32  PeakBurstPower,
                                                                            ViPInt32  BurstTemplateMatching,
                                                                            ViPInt32  AvgBurstPowerAvg,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  sprintf (wrtBuf, "CALC:POW:NBUR:GMSK:%s:MATC:LIM?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Average Burst Power
  RSCMU300_Status = RSCMU300_GetMatchingValue(AvgBurstPowerCurrent,tab, 0);

  // Peak Burst Power
  RSCMU300_Status = RSCMU300_GetMatchingValue(PeakBurstPower,tab, 1);

  // Burst Matching
  RSCMU300_Status = RSCMU300_GetMatchingValue(BurstTemplateMatching,tab, 2);

    // Average Burst Power Average
  RSCMU300_Status = RSCMU300_GetMatchingValue(AvgBurstPowerAvg,tab, 3);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Burst power measured values
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrPowGm (ViSession instrSession,
                                                                        ViInt32   channel,
                                                                        ViInt32   Mode,
                                                                        ViReal64  BurstPower[],
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "READ:ARR:POW:NBUR:GMSK:%s:%s?", Channel_Type[channel]
                                                  , StrStatMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Burst power measured values
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrPowGm (ViSession instrSession,
                                                                        ViInt32   channel,
                                                                        ViInt32   Mode,
                                                                        ViReal64  BurstPower[],
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "FETC:ARR:POW:NBUR:GMSK:%s:%s?", Channel_Type[channel]
                                                  , StrStatMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Burst power measured values
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrPowGm (ViSession instrSession,
                                                                        ViInt32   channel,
                                                                        ViInt32   Mode,
                                                                        ViReal64  BurstPower[],
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "SAMP:ARR:POW:NBUR:GMSK:%s:%s?", Channel_Type[channel]
                                                  , StrStatMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Tolerance error of power measurement
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcArrPowGmMatcLim (ViSession instrSession,
                                                                               ViInt32   channel,
                                                                               ViInt32   StatisticsMode,
                                                                               ViPInt32  ToleranceError,
                                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER3, errorMessage);

  switch (StatisticsMode)
  {
    case RSCMU300_AVERAGE:
      sprintf (wrtBuf, "CALC:ARR:POW:NBUR:GMSK:%s:AVER:MATC:LIM?", Channel_Type[channel]);
      break;
    case RSCMU300_CURRENT:
      sprintf (wrtBuf, "CALC:ARR:POW:NBUR:GMSK:%s:CURR:MATC:LIM?", Channel_Type[channel]);
      break;
    case RSCMU300_MAXIMUM:
      sprintf (wrtBuf, "CALC:ARR:POW:NBUR:GMSK:%s:MAX:MATC:LIM?", Channel_Type[channel]);
      break;
    case RSCMU300_MINIMUM:
      sprintf (wrtBuf, "CALC:ARR:POW:NBUR:GMSK:%s:MIN:MATC:LIM?", Channel_Type[channel]);
      break;
  }

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Get the matching value:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);
  RSCMU300_GetMatchingValue (ToleranceError, tab, 0);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: indicates that the corresponding area of the limit lines is
/*           violated.
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcArrPowGmAreaMatc (ViSession instrSession,
                                                                                ViInt32   channel,
                                                                                ViInt32   StatisticsMode,
                                                                                ViPInt32  UpperLimit,
                                                                                ViPInt32  LowerLimit,
                                                                                ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER3, errorMessage);

  switch (StatisticsMode)
  {
    case RSCMU300_AVERAGE:
      sprintf (wrtBuf, "CALC:ARR:POW:NBUR:GMSK:%s:AVER:MATC:AREA?", Channel_Type[channel]);
      break;
    case RSCMU300_CURRENT:
      sprintf (wrtBuf, "CALC:ARR:POW:NBUR:GMSK:%s:CURR:MATC:AREA?", Channel_Type[channel]);
      break;
    case RSCMU300_MAXIMUM:
      sprintf (wrtBuf, "CALC:ARR:POW:NBUR:GMSK:%s:MAX:MATC:AREA?", Channel_Type[channel]);
      break;
    case RSCMU300_MINIMUM:
      sprintf (wrtBuf, "CALC:ARR:POW:NBUR:GMSK:%s:MIN:MATC:AREA?", Channel_Type[channel]);
      break;
  }
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the upper Limit Matching
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%ld", UpperLimit);
  else *UpperLimit = RSCMU300_NAN_VI_INT32;

  // Get the lower Limit Matching
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%ld", LowerLimit);
  else *LowerLimit = RSCMU300_NAN_VI_INT32;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: This function outputs the burst power versus time in a fixed
/*           -Bit pattern and in the subranges defined by means of the
/*           CONFigure:SUBarrays:POWer command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubPowGm (ViSession instrSession,
                                                                        ViInt32   channel,
                                                                        ViInt32   Mode,
                                                                        ViReal64  BurstPower[],
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[RSCMU300_SUBPOW_SAMPLES_MAX+1][20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "READ:SUB:POW:NBUR:GMSK:%s:%s?", Channel_Type[channel]
                                                  , StrStatMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: This function outputs the burst power versus time in a fixed
/*           -Bit pattern and in the subranges defined by means of the
/*           CONFigure:SUBarrays:POWer command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubPowGm (ViSession instrSession,
                                                                        ViInt32   channel,
                                                                        ViInt32   Mode,
                                                                        ViReal64  BurstPower[],
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[RSCMU300_SUBPOW_SAMPLES_MAX+1][20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "FETC:SUB:POW:NBUR:GMSK:%s:%s?", Channel_Type[channel]
                                                  , StrStatMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: This function outputs the burst power versus time in a fixed
/*           -Bit pattern and in the subranges defined by means of the
/*           CONFigure:SUBarrays:POWer command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubPowGm (ViSession instrSession,
                                                                        ViInt32   channel,
                                                                        ViInt32   Mode,
                                                                        ViReal64  BurstPower[],
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[RSCMU300_SUBPOW_SAMPLES_MAX+1][20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "SAMP:SUB:POW:NBUR:GMSK:%s:%s?", Channel_Type[channel]
                                                  , StrStatMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *    SUBSYSTEM POWer:SLOT
 *    The subsystem POWer:SLOT controls the Power vs. Slot measurement. It
 *    corresponds to the measurement menu Power with the application P/Slot:
 *    Power vs. Slot measurements are available in the TCH test mode and for
 *    GMSK modulation only.
 *-----------------------------------------------------------------------------
 *      TEST CONFIGURATION
 * ----------------------------------------------------------------------------
 *        CONFIGURATION CONTROL
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPSlotGmContDef (ViSession instrSession,
                                                                              ViBoolean DefaultValues,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DEF:POW:SLOT:GMSK:TCH:CONT %s", mode_On_Off[DefaultValues]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles, the
/*           stop condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPSlotGmContRep (ViSession instrSession,
                                                                              ViInt32   NbRepetition,
                                                                              ViInt32   StopCondition,
                                                                              ViInt32   StepMode,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, NbRepetition, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:POW:SLOT:GMSK:TCH:CONT:REP %s,%s,%s", repetition_meas[NbRepetition]
                                                             , mode_StopCondition[StopCondition]
                                                             , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Scope of Measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPSlotGmContRepSt (ViSession instrSession,
                                                                                ViInt32   NbRepetition,
                                                                                ViInt32   StopCondition,
                                                                                ViInt32   StepMode,
                                                                                ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:POW:SLOT:GMSK:TCH:CONT:REP %ld,%s,%s", NbRepetition
                                                             , mode_StopCondition[StopCondition]
                                                             , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      MEASUREMENT CONTROL
 *      This subsystem contains the functions for general control of the
 *      power vs slot measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start new measurement
/* Purpose : This function starts the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitPSlotGm (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "INIT:POW:SLOT:GMSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort running measurement and switch off
/* Purpose : This function stops the power measurement, setting it to
/*           the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborPSlotGm (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "ABOR:POW:SLOT:GMSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: stop measurement after current statistic cycle
/* Purpose : This function stops the power measurement, setting it to
/*           the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopPSlotGm (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "STOP:POW:SLOT:GMSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Next Measurement Step
/* Purpose : This function continue the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContPSlotGm (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CONT:POW:SLOT:GMSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch measurement status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPSlotGmSt (ViSession instrSession,
                                                                         ViPInt32  MeasStatus,
                                                                         ViPInt32  CurrentStatCycleCount,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Fetch the measurement status:
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:POW:SLOT:GMSK:TCH:STAT?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMeasStatVal (MeasStatus, tab, 0);

  // Get the counter for current statistics cycle
  if (strcmp (tab[1], "NONE") != 0)
    sscanf (tab[1], "%ld", CurrentStatCycleCount);
  else *CurrentStatCycleCount = RSCMU300_OFF;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch measurement status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPSlotGmErep (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:POW:SLOT:GMSK:TCH:EREP %s", StrErep[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      MEASURED VALUES
 *      The subsystem POWer:SLOT[:GMSK]...[:RESULT] contains the commands for
 *      measurement and output of the power versus SLOT application for three
 *      selected channels.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Read Power vs Slot
/* Purpose : This function starts a measurement and return all measurement
/*           results. The returned list contains the average burst power of
/*           the mobile phone in all eight timeslots of a TDMA frame.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadPSlotGm (ViSession instrSession,
                                                                       ViReal64  averageBurstPower[],
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[8][20];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:POW:SLOT:GMSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues, BurstPowerTmp, averageBurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Power vs Slot
/* Purpose : This function returns all last measurement results. The returned
/*           list contains the average burst power of the mobile phone in all
/*           eight timeslots of a TDMA frame.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPSlotGm (ViSession instrSession,
                                                                       ViReal64  averageBurstPower[],
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[8][20];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:POW:SLOT:GMSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues, BurstPowerTmp, averageBurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample Power vs Slot
/* Purpose : This function returns all last measurement results. The returned
/*           list contains the average burst power of the mobile phone in all
/*           eight timeslots of a TDMA frame.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampPSlotGm (ViSession instrSession,
                                                                       ViReal64  averageBurstPower[],
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[8][20];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:POW:SLOT:GMSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues, BurstPowerTmp, averageBurstPower);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT MODULATION PERRor
 *
 *    The subsystem MODulation measures the modulation parameters, i.e. the
 *    frequency and phase error of the measured bursts. The subsystem
 *    corresponds to the measurement menu Modulation and the associated popup
 *    menu Modulation Config.
 * ----------------------------------------------------------------------------
 *      CONFIGURATION CONTROL
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrGmContDef (ViSession instrSession,
                                                                             ViInt32   channel,
                                                                             ViBoolean DefaultValues,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "DEF:MOD:PERR:GMSK:%s:CONT %s", Channel_Type[channel]
                                                 , mode_On_Off[DefaultValues]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Scope of measurement
/* Purpose : This function defines the scope of the power measurement,
/*           combining the ...CONTrol:RMODe, ...CONTrol:STATistics, and the
/*           ...CONTrol:REPetition commands.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrGmScope (ViSession instrSession,
                                                                           ViInt32   channel,
                                                                           ViInt32   MeasuredValuesType,
                                                                           ViInt32   NbBurst,
                                                                           ViInt32   repetition,
                                                                           ViInt32   NbRepetition,
                                                                           ViInt32   StopCondition,
                                                                           ViInt32   StepMode,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, repetition, 0, 2, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER8, errorMessage);

  if (repetition != RSCMU300_MULTIPLE)
    sprintf(wrtBuf, "CONF:MOD:PERR:GMSK:%s:CONT %s,%ld,%s,%s,%s", Channel_Type[channel]
                                                               , mode_ScopeMeas[MeasuredValuesType]
                                                               , NbBurst
                                                               , repetition_meas[repetition]
                                                               , mode_StopCondition[StopCondition]
                                                               , StrStepMode[StepMode]);
  else
    sprintf(wrtBuf, "CONF:MOD:PERR:GMSK:%s:CONT %s %ld %ld %s %s", Channel_Type[channel]
                                                               , mode_ScopeMeas[MeasuredValuesType]
                                                               , NbBurst
                                                               , NbRepetition
                                                               , mode_StopCondition[StopCondition]
                                                               , StrStepMode[StepMode]);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrGmContRep (ViSession instrSession,
                                                                             ViInt32   channel,
                                                                             ViInt32   Repetition,
                                                                             ViInt32   StopCondition,
                                                                             ViInt32   StepMode,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, Repetition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER5, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:MOD:PERR:GMSK:%s:CONT:REP %s,%s,%s", Channel_Type[channel]
                                                            , repetition_meas[Repetition]
                                                            , mode_StopCondition[StopCondition]
                                                            , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      LIMITS
 *      The subsystem MODulation:LIMit contains the commands for
 *      definition of tolerance values for the modulation measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Error Limits
/* Purpose : This function defines the limits for the peak and RMS phase error
/*           as well as for the frequency error in the current burst.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrGmLim (ViSession instrSession,
                                                                         ViInt32   channel,
                                                                         ViInt32   KindOfBurst,
                                                                         ViReal64  MaxPhaseErrorLimit,
                                                                         ViReal64  RMSPhaseErrorLimit,
                                                                         ViReal64  FrequencyErrorLimit,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, KindOfBurst, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, MaxPhaseErrorLimit, 0, RSCMU300_PHASE_ERROR_LIMMAX, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, RMSPhaseErrorLimit, 0, RSCMU300_PHASE_ERROR_LIMMAX, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, FrequencyErrorLimit, 0, RSCMU300_FREQU_ERROR_LIMMAX, RSCMU_ERROR_PARAMETER6, errorMessage);

  switch (KindOfBurst)
  {
    case RSCMU300_CURRENT:
      sprintf (wrtBuf, "CONF:MOD:PERR:GMSK:%s:CMM:LIM:SYMM:VAL %.12f,%.12f,%.12f", Channel_Type[channel]
                                                                           , MaxPhaseErrorLimit
                                                                           , RMSPhaseErrorLimit
                                                                           , FrequencyErrorLimit);
      break;
    case RSCMU300_AVERAGE:
      sprintf (wrtBuf, "CONF:MOD:PERR:GMSK:%s:AVER:LIM:SYMM:VAL %.12f,%.12f,%.12f", Channel_Type[channel]
                                                                            , MaxPhaseErrorLimit
                                                                            , RMSPhaseErrorLimit
                                                                            , FrequencyErrorLimit);
      break;
  }
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/* ----------------------------------------------------------------------------
 *      TIME
 *      The subsystem MODulation...:TIME defines the decoding for the Modulation
 *      measurement. The subsystem corresponds to the popup window Decode in
 *      the graphical measurement menu Modulation.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Time Decode
/* Purpose : This function selects the type of decoding applied for the
/*           determination of phase and frequency errors.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrGmTimDec (ViSession instrSession,
                                                                            ViInt32   channel,
                                                                            ViInt32   TypeOfDecoding,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  ViString    StrType[] = {"STAN", "GTB"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, TypeOfDecoding, 0, 1, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:PERR:GMSK:%s:TIME:DEC %s", Channel_Type[channel]
                                                      , StrType[TypeOfDecoding]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Scope of measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrGmCont (ViSession instrSession,
                                                                          ViInt32   channel,
                                                                          ViInt32   MeasuredValuesType,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:PERR:GMSK:%s:CONT:STAT %ld", Channel_Type[channel]
                                                       , NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  sprintf (wrtBuf, "CONF:MOD:PERR:GMSK:%s:CONT:RMOD %s", Channel_Type[channel]
                                                       , mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set the number of bursts
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrGmStat (ViSession instrSession,
                                                                          ViInt32   channel,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:PERR:GMSK:%s:CONT:STAT %ld", Channel_Type[channel]
                                                       , NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set result mode
/* Purpose : This function specifies the type of measured values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrGmResMode (ViSession instrSession,
                                                                             ViInt32   channel,
                                                                             ViInt32   MeasuredValuesType,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:PERR:GMSK:%s:CONT:RMOD %s", Channel_Type[channel]
                                                       , mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrGmContRepSt (ViSession instrSession,
                                                                               ViInt32   channel,
                                                                               ViInt32   NbRepetition,
                                                                               ViInt32   StopCondition,
                                                                               ViInt32   StepMode,
                                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER5, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:MOD:PERR:GMSK:%s:CONT:REP %ld,%s,%s", Channel_Type[channel]
                                                            , NbRepetition
                                                            , mode_StopCondition[StopCondition]
                                                            , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      MEASUREMENT
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Definition of Subarrays
/* Purpose : This command configures the READ:SUBarrays..., FETCh:SUBarrays...,
/*           and SAMPle:SUBarrays:MODulation commands. It restricts the
/*           measurement to up to 32 subranges where either all measurement
/*           results (the number of which is given by the second numerical
/*           parameter) or a single statistical value is returned. The subranges
/*           are defined by the start time and the number of test points which
/*           are located on a fixed, equidistant grid with a step width of  Bit.
/*           The subranges may overlap but must be within the total range of the
/*           MODulation measurement. Test points outside this range are not
/*           measured (result NAN) and do not enter into the ARIThmetical,
/*           MINimum and MAXimum values.
/*           By default, only one range corresponding to the total measurement
/*           range is used and all measurement values are returned.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubPerrGmRang (ViSession instrSession,
                                                                             ViInt32   channel,
                                                                             ViInt32   StatisticsMode,
                                                                             ViReal64  StartTime,
                                                                             ViInt32   Samples,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"ALL","ARIT","MIN","MAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, StartTime, RSCMU300_SUBMOD_BIT_MIN, RSCMU300_SUBMOD_BIT_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Samples, RSCMU300_SUBMOD_SAMPLES_MIN, RSCMU300_SUBMOD_SAMPLES_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:MOD:PERR:GMSK:%s %s,%.12f,%ld", Channel_Type[channel]
                                                        , StrMode[StatisticsMode]
                                                        , StartTime
                                                        , Samples);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      CONTROL OF MODULATION MEAS
 *      It contains the functions for general control of the modulation
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start Modulation Measurements
/* Purpose : This function start the modulation measurement,
/*           setting it to the status beyond.
/*           RUN        Start measurement without waiting
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitPerrGm (ViSession instrSession,
                                                                      ViInt32   channel,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE]= "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "INIT:MOD:PERR:GMSK:%s", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort Modulation Measurements
/* Purpose : This function abort the running modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborPerrGm (ViSession instrSession,
                                                                      ViInt32   channel,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE]= "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "ABOR:MOD:PERR:GMSK:%s", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Stop Modulation Measurements
/* Purpose : This function stop measurement after current statistic cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopPerrGm (ViSession instrSession,
                                                                      ViInt32   channel,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE]= "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "STOP:MOD:PERR:GMSK:%s", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Run next measurement step
/* Purpose : This function runs next modulation measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContPerrGm (ViSession instrSession,
                                                                      ViInt32   channel,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE]= "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONT:MOD:PERR:GMSK:%s", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Measurement Status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPerrGmSt (ViSession instrSession,
                                                                        ViInt32   channel,
                                                                        ViPInt32  MeasStatus,
                                                                        ViPInt32  CurrentStatCycleCount,
                                                                        ViPInt32  CurrentEvalPeriodCount,
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Fetch the measurement status:
  sprintf (wrtBuf, "FETC:MOD:PERR:GMSK:%s:STAT?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMeasStatVal(MeasStatus, tab, 0 );

  // Get the counter for current statistics cycle
  if (strcmp (tab[1], "NONE") != 0)
    sscanf (tab[1], "%ld", CurrentStatCycleCount);
  else
    *CurrentStatCycleCount = RSCMU300_OFF;

  // Get the counter for current evaluation period within a cycle
  if (strcmp (tab[2], "NONE") != 0)
    sscanf (tab[2], "%ld", CurrentEvalPeriodCount);
  else *CurrentEvalPeriodCount = RSCMU300_OFF;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrGmErep (ViSession instrSession,
                                                                          ViInt32   channel,
                                                                          ViInt32   Mode,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:PERR:GMSK:%s:EREP %s", Channel_Type[channel]
                                             , StrErep[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      RESULTS: FREQUENCY AND PHASE ERROR
 *      The subsystem MODulation[:RESULT] contains the commands for
 *      measurement and output of the frequency and phase error and
 *      their comparison with the tolerance values.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This function start a measurement and output all scalar,
/*           numeric measurement results.
/*      These are:
/*  Maximum phase error with single-value measurement
/*             => phase error peak current
/*  Maximum phase error with average measurement
/*             => phase error peak average
/*  Maximum phase error with extreme-value measurement
/*             => phase error peak max./min.
/*  Rms phase error with single-value measurement
/*             => phase error RMS current
/*  Rms phase error with average measurement
/*             => phase error RMS average
/*  Rms phase error with extreme-value measurement
/*             => phase error RMS max./min.
/*  Frequency error with single-value measurement
/*             => frequency error current
/*  Frequency error with average measurement
/*             => frequency error average
/*  Frequency error with extreme-value measurement
/*             => frequency error max./min.
/*  Average burst power with single-value measurement
/*             => avg. burst power current
/*  Average burst power of average burst measurement
/*             => avg. burst power average
/*  Relative portion of faulty burst
/*             => bursts out of tolerance
/*
/*      Average measurement means that the results of the single-value
/*      measurement are averaged over several bursts. Extreme-value
/*      measurement means that the extreme value is determined from the
/*      results of the single-value measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadPerrGm (ViSession instrSession,
                                                                      ViInt32   channel,
                                                                      ViInt32   StatisticsMode,
                                                                      ViPReal64 phErrPeak,
                                                                      ViPReal64 phErrRMS,
                                                                      ViPReal64 freqErr,
                                                                      ViPReal64 avgBurstPowerCurr,
                                                                      ViPReal64 avgBurstPowerAvg,
                                                                      ViPReal64 burstOutOfTol,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER3, errorMessage);

  // Sense the current signalling state of the CMU
  sprintf (wrtBuf, "READ:MOD:PERR:GMSK:%s?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  RSCMU300_Status = RSCMU300_ScanPerrGmsk (tab , 0, StatisticsMode, phErrPeak, phErrRMS, freqErr, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This function start a measurement and output all scalar,
/*           numeric measurement results.
/*      These are:
/*  Maximum phase error with single-value measurement
/*             => phase error peak current
/*  Maximum phase error with average measurement
/*             => phase error peak average
/*  Maximum phase error with extreme-value measurement
/*             => phase error peak max./min.
/*  Rms phase error with single-value measurement
/*             => phase error RMS current
/*  Rms phase error with average measurement
/*             => phase error RMS average
/*  Rms phase error with extreme-value measurement
/*             => phase error RMS max./min.
/*  Frequency error with single-value measurement
/*             => frequency error current
/*  Frequency error with average measurement
/*             => frequency error average
/*  Frequency error with extreme-value measurement
/*             => frequency error max./min.
/*  Average burst power with single-value measurement
/*             => avg. burst power current
/*  Average burst power of average burst measurement
/*             => avg. burst power average
/*  Relative portion of faulty burst
/*             => bursts out of tolerance
/*
/*      Average measurement means that the results of the single-value
/*      measurement are averaged over several bursts. Extreme-value
/*      measurement means that the extreme value is determined from the
/*      results of the single-value measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPerrGm (ViSession instrSession,
                                                                      ViInt32   channel,
                                                                      ViInt32   StatisticsMode,
                                                                      ViPReal64 phErrPeak,
                                                                      ViPReal64 phErrRMS,
                                                                      ViPReal64 freqErr,
                                                                      ViPReal64 avgBurstPowerCurr,
                                                                      ViPReal64 avgBurstPowerAvg,
                                                                      ViPReal64 burstOutOfTol,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER3, errorMessage);

  // Sense the current signalling state of the CMU
  sprintf (wrtBuf, "FETC:MOD:PERR:GMSK:%s?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  RSCMU300_Status = RSCMU300_ScanPerrGmsk (tab , 0, StatisticsMode, phErrPeak, phErrRMS, freqErr, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This function start a measurement and output all scalar,
/*           numeric measurement results.
/*      These are:
/*  Maximum phase error with single-value measurement
/*             => phase error peak current
/*  Maximum phase error with average measurement
/*             => phase error peak average
/*  Maximum phase error with extreme-value measurement
/*             => phase error peak max./min.
/*  Rms phase error with single-value measurement
/*             => phase error RMS current
/*  Rms phase error with average measurement
/*             => phase error RMS average
/*  Rms phase error with extreme-value measurement
/*             => phase error RMS max./min.
/*  Frequency error with single-value measurement
/*             => frequency error current
/*  Frequency error with average measurement
/*             => frequency error average
/*  Frequency error with extreme-value measurement
/*             => frequency error max./min.
/*  Average burst power with single-value measurement
/*             => avg. burst power current
/*  Average burst power of average burst measurement
/*             => avg. burst power average
/*  Relative portion of faulty burst
/*             => bursts out of tolerance
/*
/*      Average measurement means that the results of the single-value
/*      measurement are averaged over several bursts. Extreme-value
/*      measurement means that the extreme value is determined from the
/*      results of the single-value measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampPerrGm (ViSession instrSession,
                                                                      ViInt32   channel,
                                                                      ViInt32   StatisticsMode,
                                                                      ViPReal64 phErrPeak,
                                                                      ViPReal64 phErrRMS,
                                                                      ViPReal64 freqErr,
                                                                      ViPReal64 avgBurstPowerCurr,
                                                                      ViPReal64 avgBurstPowerAvg,
                                                                      ViPReal64 burstOutOfTol,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER3, errorMessage);

  // Sense the current signalling state of the CMU
  sprintf (wrtBuf, "SAMP:MOD:PERR:GMSK:%s?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  RSCMU300_Status = RSCMU300_ScanPerrGmsk (tab , 0, StatisticsMode, phErrPeak, phErrRMS, freqErr, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcPerrGmMatcLim (ViSession instrSession,
                                                                             ViInt32   channel,
                                                                             ViInt32   StatisticsMode,
                                                                             ViPInt32  phErrPeak,
                                                                             ViPInt32  phErrRMS,
                                                                             ViPInt32  freqErr,
                                                                             ViPInt32  avgBurstPowerCurr,
                                                                             ViPInt32  avgBurstPowerAvg,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CALC:MOD:PERR:GMSK:%s:MATC:LIM?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  switch (StatisticsMode)
  {
    case RSCMU300_CURRENT:
      // Max phase error with single-value measurement
      RSCMU300_Status = RSCMU300_GetMatchingValue(phErrPeak,tab,0);
      // RMS phase error with single-value measurement
      RSCMU300_Status = RSCMU300_GetMatchingValue(phErrRMS,tab,3);
      // Frequency error with single-value measurement
      RSCMU300_Status = RSCMU300_GetMatchingValue(freqErr,tab,6);
    break;
    case RSCMU300_AVERAGE:
      // Max phase error with average measurement
      RSCMU300_Status = RSCMU300_GetMatchingValue(phErrPeak, tab, 1);
      // RMS phase error with average measurement
      RSCMU300_Status = RSCMU300_GetMatchingValue(phErrRMS, tab, 4);
      // Frequency error with average measurement
      RSCMU300_Status = RSCMU300_GetMatchingValue(freqErr, tab, 7);
    break;
    case RSCMU300_MAXMIN:
      // Max phase error with extreme-value measurement
      RSCMU300_Status = RSCMU300_GetMatchingValue(phErrPeak,tab, 2);
      // RMS phase error with extreme-value measurement
      RSCMU300_Status = RSCMU300_GetMatchingValue(phErrRMS,tab, 5);
      // Frequency error with extreme-value measurement
      RSCMU300_Status = RSCMU300_GetMatchingValue(freqErr,tab, 8);
    break;
  }
  // Average burst power with single-value measurement
  RSCMU300_Status = RSCMU300_GetMatchingValue(avgBurstPowerCurr, tab, 9);
  // Average burst power Average with single-value measurement
  RSCMU300_Status = RSCMU300_GetMatchingValue(avgBurstPowerAvg, tab, 10);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Phase Error in Burst...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 588 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrPerrGm (ViSession instrSession,
                                                                         ViInt32   channel,
                                                                         ViInt32   Mode,
                                                                         ViReal64  PhaseErrorValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      PhaseErrorTmp[588][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "READ:ARR:MOD:PERR:GMSK:%s:%s?", Channel_Type[channel]
                                                  , StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, PhaseErrorTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,PhaseErrorTmp,PhaseErrorValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Phase Error in Burst...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 588 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrPerrGm (ViSession instrSession,
                                                                         ViInt32   channel,
                                                                         ViInt32   Mode,
                                                                         ViReal64  PhaseErrorValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      PhaseErrorTmp[588][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "FETC:ARR:MOD:PERR:GMSK:%s:%s?", Channel_Type[channel]
                                                  , StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, PhaseErrorTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,PhaseErrorTmp,PhaseErrorValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample Phase Error in Burst...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 588 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrPerrGm (ViSession instrSession,
                                                                         ViInt32   channel,
                                                                         ViInt32   Mode,
                                                                         ViReal64  PhaseErrorValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      PhaseErrorTmp[588][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "SAMP:ARR:MOD:PERR:GMSK:%s:%s?", Channel_Type[channel]
                                                  , StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, PhaseErrorTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,PhaseErrorTmp,PhaseErrorValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: This function outputs the phase error versus time in a fixed  Bit
/*           pattern and in the subranges defined by means of the CONFigure:
/*           SUBarrays:MODulation...
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubPerrGm (ViSession instrSession,
                                                                         ViInt32   channel,
                                                                         ViInt32   Mode,
                                                                         ViReal64  PhaseErrorValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      PhaseErrorTmp[588][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "READ:SUB:MOD:PERR:GMSK:%s:%s?", Channel_Type[channel]
                                                  , StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, PhaseErrorTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,PhaseErrorTmp,PhaseErrorValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: This function outputs the phase error versus time in a fixed  Bit
/*           pattern and in the subranges defined by means of the CONFigure:
/*           SUBarrays:MODulation...
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubPerrGm (ViSession instrSession,
                                                                         ViInt32   channel,
                                                                         ViInt32   Mode,
                                                                         ViReal64  PhaseErrorValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      PhaseErrorTmp[588][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "FETC:SUB:MOD:PERR:GMSK:%s:%s?", Channel_Type[channel]
                                                  , StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, PhaseErrorTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,PhaseErrorTmp,PhaseErrorValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: This function outputs the phase error versus time in a fixed  Bit
/*           pattern and in the subranges defined by means of the CONFigure:
/*           SUBarrays:MODulation...
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubPerrGm (ViSession instrSession,
                                                                         ViInt32   channel,
                                                                         ViInt32   Mode,
                                                                         ViReal64  PhaseErrorValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      PhaseErrorTmp[588][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "SAMP:SUB:MOD:PERR:GMSK:%s:%s?", Channel_Type[channel]
                                                  , StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, PhaseErrorTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,PhaseErrorTmp,PhaseErrorValues);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT SPECTRUM/MODULATION
 *    The subsystem SPECtrum:MODulation contains the commands for measuring
 *    the off-carrier power due to the modulation of the GSM signal.
 *-----------------------------------------------------------------------------
 *      CONFIGURATION CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmContDef (ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViBoolean DefaultValues,
                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "DEF:SPEC:MOD:GMSK:%s:CONT %s", Channel_Type[channel]
                                                 , mode_On_Off[DefaultValues]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Averaging Areas
/* Purpose : These function selects one or two 40-bit sections of the burst which
/*           are measured and averaged in order to calculate the Modulation results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SpecModAvgAreas (ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   averaging_area,
                                                    ViChar    errorMessage[])
{
  ViString    list[] = {"A","B","AB", VI_NULL};
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession, RSCMU300_V3_65, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      CHECKRETMSG(RSCMU300_setEnum(instrSession, "CONFigure:SPECtrum:MODulation:CCH:AVGareas",
                                   averaging_area, list,
                                   RSCMU_ERROR_PARAMETER3));
      break;
    case RSCMU300_TCH:
      CHECKRETMSG(RSCMU300_setEnum(instrSession, "CONFigure:SPECtrum:MODulation:TCH:AVGareas",
                                   averaging_area, list,
                                   RSCMU_ERROR_PARAMETER3));
      break;
  }
  return RSCMU300_Status;
}


/*===========================================================================*/
/* Function: Frequency Select f. Time Domain
/* Purpose : These function selects the measurement frequency for the time
/*           domain (power vs. time) measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpecModFSelFTimeD (ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViInt32   select,
                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViString    list[] = {"OFF","N180","N160","N140","N120","N100","N080","N060","N040","N025","N020","N010",
                        "REF","P010","P020","P025","P040","P060","P080","P100","P120","P140","P160","P180",
                        "NV4","NV3","NV2","NV1","PV1","PV2","PV3","PV4", VI_NULL};

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession, RSCMU300_V3_65, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      CHECKRETMSG(RSCMU300_setEnum(instrSession, "CONFigure:SPECtrum:MODulation:CCH:TDFSelect", select, list,
                              RSCMU_ERROR_PARAMETER3));
      break;
    case RSCMU300_TCH:
      CHECKRETMSG(RSCMU300_setEnum(instrSession, "CONFigure:SPECtrum:MODulation:TCH:TDFSelect", select, list,
                              RSCMU_ERROR_PARAMETER3));
      break;
  }
  return RSCMU300_Status;
}


/*===========================================================================*/
/* Function: Scope of measurement
/* Purpose : This function defines the scope of the power measurement,
/*           combining the ...CONTrol:RMODe, ...CONTrol:STATistics, and the
/*           ...CONTrol:REPetition commands.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmScope (ViSession instrSession,
                                                                            ViInt32   channel,
                                                                            ViInt32   MeasuredValuesType,
                                                                            ViInt32   NbBurst,
                                                                            ViInt32   repetition,
                                                                            ViInt32   NbRepetition,
                                                                            ViInt32   StopCondition,
                                                                            ViInt32   StepMode,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, repetition, 0, 2, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER8, errorMessage);

  if (repetition != RSCMU300_MULTIPLE)
    sprintf(wrtBuf, "CONF:SPEC:MOD:GMSK:%s:CONT %s,%ld,%s,%s,%s", Channel_Type[channel]
                                                               , mode_ScopeMeas[MeasuredValuesType]
                                                               , NbBurst
                                                               , repetition_meas[repetition]
                                                               , mode_StopCondition[StopCondition]
                                                               , StrStepMode[StepMode]);
  else
    sprintf(wrtBuf, "CONF:SPEC:MOD:GMSK:%s:CONT %s %ld %ld %s %s", Channel_Type[channel]
                                                               , mode_ScopeMeas[MeasuredValuesType]
                                                               , NbBurst
                                                               , NbRepetition
                                                               , mode_StopCondition[StopCondition]
                                                               , StrStepMode[StepMode]);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}


/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmContRep (ViSession instrSession,
                                                                              ViInt32   channel,
                                                                              ViInt32   Repetition,
                                                                              ViInt32   StopCondition,
                                                                              ViInt32   StepMode,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    Step_Mode[] = {"NONE","STEP"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, Repetition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER5, errorMessage);

  // Configure tests cycles:
  sprintf (wrtBuf, "CONF:SPEC:MOD:GMSK:%s:CONT:REP %s,%s,%s", Channel_Type[channel]
                                                            , repetition_meas[Repetition]
                                                            , mode_StopCondition[StopCondition]
                                                            , StrStepMode[StepMode]);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      LIMITS
 *      The subsystem SPECtrum:MODulation...:LIMit contains the commands for
 *      definition of tolerance values for the spectrum measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default limit Lines
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmLimDef (ViSession instrSession,
                                                                             ViInt32   channel,
                                                                             ViBoolean DefaultValues,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "DEF:SPEC:MOD:GMSK:%s:LIM:LINE %s", Channel_Type[channel]
                                                     , mode_On_Off[DefaultValues]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Reference Power
/* Purpose : This function defines the MS carrier output power domain where
/*           the limit lines are to be determined by linear interpolation
/*           (see Table 1). Below Min. Power, the lower limit line applies,
/*           above Max. Power, the upper limit line applies.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmLimRefp (ViSession instrSession,
                                                                              ViInt32   channel,
                                                                              ViReal64  minPower,
                                                                              ViReal64  maxPower,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, minPower, RSCMU300_GSM_REFMINPOW_LIMMIN, RSCMU300_GSM_REFMINPOW_LIMMAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, maxPower, RSCMU300_GSM_REFMAXPOW_LIMMIN, RSCMU300_GSM_REFMAXPOW_LIMMAX, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD:GMSK:%s:LIM:LINE:SYMM:RPOW %.12f,%.12f", Channel_Type[channel]
                                                                     , minPower
                                                                     , maxPower);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Limit Lines On/Off
/* Purpose : This function switches the limit checking for all measurepoints.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmLimMode (ViSession instrSession,
                                                                              ViInt32   channel,
                                                                              ViBoolean LimitLines,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, LimitLines, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD:GMSK:%s:LIM:LINE:SYMM:ENAB %s", Channel_Type[channel]
                                                                , mode_On_Off[LimitLines]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Limit Lines
/* Purpose : These commands activate and define limit lines for the spectrum
/*           due to modulation measurement.
/*           The limit lines for the spectrum due to modulation as specified
/*           in standard GSM 05.05 depend on the GSM band, the frequency, and
/*           (for frequencies that differ from the carrier frequency by more
/*           than 400 kHz) on the output power of the base station.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmLim (ViSession instrSession,
                                                                          ViInt32   channel,
                                                                          ViInt32   measurePoint,
                                                                          ViBoolean enable,
                                                                          ViReal64  minPower,
                                                                          ViReal64  maxPower,
                                                                          ViReal64  AbsLevel,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, measurePoint, RSCMU300_0_10MHZ, RSCMU300_1_80MHZ, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, enable, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD:GMSK:%s:LIM:LINE:SYMM:FREQ%ld %.12f,%.12f,%.12f,%s", Channel_Type[channel]
                                                                              , measurePoint
                                                                              , minPower
                                                                              , maxPower
                                                                              , AbsLevel
                                                                              , mode_On_Off[enable]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Statistic Count
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmCont (ViSession instrSession,
                                                                           ViInt32   channel,
                                                                           ViInt32   MeasuredValuesType,
                                                                           ViInt32   NbBurst,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD:GMSK:%s:CONT:STAT %ld", Channel_Type[channel]
                                                       , NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  sprintf (wrtBuf, "CONF:SPEC:MOD:GMSK:%s:CONT:RMOD %s", Channel_Type[channel]
                                                       , mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set the number of bursts
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmStat (ViSession instrSession,
                                                                           ViInt32   channel,
                                                                           ViInt32   NbBurst,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD:GMSK:%s:CONT:STAT %ld", Channel_Type[channel]
                                                       , NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set result mode
/* Purpose : This function specifies the type of measured values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmResMode (ViSession instrSession,
                                                                              ViInt32   channel,
                                                                              ViInt32   MeasuredValuesType,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD:GMSK:%s:CONT:RMOD %s", Channel_Type[channel]
                                                       , mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmContRepSt (ViSession instrSession,
                                                                                ViInt32   channel,
                                                                                ViInt32   NbRepetition,
                                                                                ViInt32   StopCondition,
                                                                                ViInt32   StepMode,
                                                                                ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER5, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:SPEC:MOD:GMSK:%s:CONT:REP %ld,%s,%s", Channel_Type[channel]
                                                            , NbRepetition
                                                            , mode_StopCondition[StopCondition]
                                                            , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      MEASUREMENT CONFIGURATION
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Measure Points
/* Purpose : This function permits to select which frequencies a spectrum
/*           modulation measurement is performed. A reduction of the
/*           measurement points enhances the measurement speed.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmContMpo (ViSession instrSession,
                                                                              ViInt32   channel,
                                                                              ViInt32   MeasurePoint,
                                                                              ViBoolean Enable,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, MeasurePoint, RSCMU300_MPO1, RSCMU300_MPO11, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Enable, RSCMU300_OFF, RSCMU300_ON, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD:GMSK:%s:MPO%ld:ENAB %s", Channel_Type[channel]
                                                        , MeasurePoint
                                                        , mode_On_Off[Enable]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Variable Measure Points
/* Purpose : This function sets and enables additional pairs of
/*           measurement points at up to 4 variable offset frequencies
/*           (numbered by the numeric suffix <nr> = 1 to 4).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpecModVarMpo (ViSession instrSession,
                                                      ViInt32 channel,
                                                      ViInt32 nr,
                                                      ViInt32 enable,
                                                      ViReal64 frequencyMHz,
                                                      ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;


  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasSpecVarMeaPoint(instrSession, "CONFigure:SPECtrum:MODulation:CCH:CONTrol:VMPoint", nr, enable, frequencyMHz, errorMessage);
      break;
    case RSCMU300_TCH:
      return RSCMU300_MeasSpecVarMeaPoint(instrSession, "CONFigure:SPECtrum:MODulation:TCH:CONTrol:VMPoint", nr, enable, frequencyMHz, errorMessage);
      break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Definition of Subarrays
/* Purpose : configures the READ:SUBarrays.., FETCh:SUBarrays.., and SAMPle:
/*           SUBarrays:SPECtrum:MODulation[:GMSK] commands. It restricts the
/*           measurement to up to 32 subranges where either all measurement
/*           results (the number of which is given by the second numerical
/*           parameter) or a single statistical value is returned.
/*           The subranges are defined by the start time and the number of
/*           test points which are located at fixed frequencies (see command
/*           CONFigure:SPECtrum:MODulation[:GMSK]:LIMit:LINE<nr>).
/*           The subranges may overlap but must be within the total range of
/*           the spectrum due to modulation measurement. Test points outside
/*           this range are not measured (result NAN) and do not enter into
/*           the ARIThmetical, MINimum and MAXimum values.
/*           By default, only one range corresponding to the total measurement
/*           range is used and all measurement values are returned.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubSpModGmRang (ViSession instrSession,
                                                                              ViInt32   channel,
                                                                              ViInt32   StatisticsMode,
                                                                              ViReal64  StartFrequency,
                                                                              ViInt32   Samples,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"ALL","ARIT","MIN","MAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, StartFrequency, RSCMU300_SUBSPECMOD_FREQ_MIN, RSCMU300_SUBSPECMOD_FREQ_MIN, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Samples, RSCMU300_SUBSPECMOD_NUMBER_MIN, RSCMU300_SUBSPECMOD_NUMBER_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:SPEC:MOD:GMSK:%s %s,%.12f,%ld", Channel_Type[channel]
                                                        , StrMode[StatisticsMode]
                                                        , StartFrequency
                                                        , Samples);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Configure TimeDomain SubRanges
/* Purpose : This function configurates the READ..., FETCh... and
/*           SAMPle:SSUBarrays:SPECtrum:<Application>:TDOMain commands.
/*           If the requested number of results exceeds the measurement
/*           range, the count parameter will be corrected by the system.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubSpecModTime (ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViInt32   mode,
                                                        ViReal64  startTime,
                                                        ViInt32   numberOfSamples,
                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, mode, 0, 4, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, startTime, -30, 175, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, numberOfSamples, 1, 618, RSCMU_ERROR_PARAMETER4, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_ConfSubArr (instrSession, "CONFigure:SUBarrays:SPECtrum:MODulation:CCH:TDOMain", mode, startTime, numberOfSamples, errorMessage);
    break;
    case RSCMU300_TCH:
      return RSCMU300_ConfSubArr (instrSession, "CONFigure:SUBarrays:SPECtrum:MODulation:TCH:TDOMain", mode, startTime, numberOfSamples, errorMessage);
    break;
  }
  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      CONTROL OF SPECTRUM MODULATION MEAS
 *      It contains the functions for general control of the spectrum
 *      modulation measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Init
/* Purpose : Start measurement without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitSpModGm (ViSession instrSession,
                                                                       ViInt32   channel,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "INIT:SPEC:MOD:GMSK:%s", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : Abort measurement and switch off => OFF
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborSpModGm (ViSession instrSession,
                                                                       ViInt32   channel,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "ABOR:SPEC:MOD:GMSK:%s", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : Stop measurement => STOP
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopSpModGm (ViSession instrSession,
                                                                       ViInt32   channel,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "STOP:SPEC:MOD:GMSK:%s", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : Next measurement step (only counting mode) => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContSpModGm (ViSession instrSession,
                                                                       ViInt32   channel,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONT:SPEC:MOD:GMSK:%s", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Status
/* Purpose : This function is always a query. It immediately reads the
/*           measurement status (for polling, see chapters 3 and 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSpModGmSt (ViSession instrSession,
                                                                         ViInt32   channel,
                                                                         ViPInt32  MeasStatus,
                                                                         ViPInt32  CurrentStatCycleCount,
                                                                         ViPInt32  CurrentEvalPeriodCount,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Fetch the measurement status:
  sprintf (wrtBuf, "FETC:SPEC:MOD:GMSK:%s:STAT?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMeasStatVal(MeasStatus, tab, 0 );

  // Get the counter for current statistics cycle
  if (strcmp (tab[1], "NONE") != 0)
    sscanf (tab[1], "%ld", CurrentStatCycleCount);
  else *CurrentStatCycleCount = RSCMU300_OFF;

  // Get the counter for current evaluation period within a cycle
  if (strcmp (tab[2], "NONE") != 0)
    sscanf (tab[2], "%ld", CurrentEvalPeriodCount);
  else
    *CurrentEvalPeriodCount = RSCMU300_OFF;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event Reporting Mode
/* Purpose : This function defines the events to be reported during the
/*           measurement (event reporting, see chapter 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmErep (ViSession instrSession,
                                                                           ViInt32   channel,
                                                                           ViInt32   Mode,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD:GMSK:%s:EREP %s", Channel_Type[channel]
                                                  , StrErep[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      RESULTS: FREQUENCY SPECTRUM
 *      The subsystem SPECtrum:MODulation[:RESULT] contains the commands for
 *      measurement and output of signal spectrum.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start single shot measurement and return results
/* Purpose : This function starts a single shot measurement and returns the
/*           results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSpModGm (ViSession instrSession,
                                                                       ViInt32   channel,
                                                                       ViPReal64 ReferencePower,
                                                                       ViPInt32  Matching,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:SPEC:MOD:GMSK:%s?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the reference power:
  if ((RSCMU300_Status = RSCMU300_GetViReal64Value (tab, 0, ReferencePower)) < 0)
    return RSCMU300_Status;

  // Get the matching value:
  if ((RSCMU300_Status = RSCMU300_GetMatchingValue (Matching, tab, 1)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This function only outputs the results without any care of the
/*           measurement state.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSpModGm (ViSession instrSession,
                                                                       ViInt32   channel,
                                                                       ViPReal64 ReferencePower,
                                                                       ViPInt32  Matching,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:SPEC:MOD:GMSK:%s?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the reference power:
  if ((RSCMU300_Status = RSCMU300_GetViReal64Value (tab, 0, ReferencePower)) < 0)
    return RSCMU300_Status;

  // Get the matching value:
  if ((RSCMU300_Status = RSCMU300_GetMatchingValue (Matching, tab, 1)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This function waits until the results are valid for the first
/*           time (depending on the chosen statistic count) and then outputs
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSpModGm (ViSession instrSession,
                                                                       ViInt32   channel,
                                                                       ViPReal64 ReferencePower,
                                                                       ViPInt32  Matching,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:SPEC:MOD:GMSK:%s?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the reference power:
  if ((RSCMU300_Status = RSCMU300_GetViReal64Value (tab, 0, ReferencePower)) < 0)
    return RSCMU300_Status;

  // Get the matching value:
  if ((RSCMU300_Status = RSCMU300_GetMatchingValue (Matching, tab, 1)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Array
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrSpModGm (ViSession instrSession,
                                                                          ViInt32   channel,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[23][20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:ARR:SPEC:MOD:GMSK:%s?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Array
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrSpModGm (ViSession instrSession,
                                                                          ViInt32   channel,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[23][20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:ARR:SPEC:MOD:GMSK:%s?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample Array
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrSpModGm (ViSession instrSession,
                                                                          ViInt32   channel,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[23][20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:ARR:SPEC:MOD:GMSK:%s?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrVarSpecMod (ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViReal64 burstPower[],
                                                      ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasArray(instrSession, "READ:ARRay:SPECtrum:MODulation:CCH:VMPoint", burstPower, errorMessage);
    break;
    case RSCMU300_TCH:
      return RSCMU300_MeasArray(instrSession, "READ:ARRay:SPECtrum:MODulation:TCH:VMPoint", burstPower, errorMessage);
    break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrVarSpecMod (ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViReal64 burstPower[],
                                                      ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:MODulation:CCH:VMPoint", burstPower, errorMessage);
    break;
    case RSCMU300_TCH:
      return RSCMU300_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:MODulation:TCH:VMPoint", burstPower, errorMessage);
    break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrVarSpecMod (ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViReal64 burstPower[],
                                                      ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasArray(instrSession, "SAMPle:ARRay:SPECtrum:MODulation:CCH:VMPoint", burstPower, errorMessage);
    break;
    case RSCMU300_TCH:
      return RSCMU300_MeasArray(instrSession, "SAMPle:ARRay:SPECtrum:MODulation:TCH:VMPoint", burstPower, errorMessage);
    break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Array Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrSpecModTime (ViSession instrSession,
                                                       ViInt32 channel,
                                                       ViReal64  burstPower[],
                                                       ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasArray(instrSession, "READ:ARRay:SPECtrum:MODulation:CCH:TDOMain", burstPower, errorMessage);
    break;
    case RSCMU300_TCH:
      return RSCMU300_MeasArray(instrSession, "READ:ARRay:SPECtrum:MODulation:TCH:TDOMain", burstPower, errorMessage);
    break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Array Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrSpecModTime (ViSession instrSession,
                                                       ViInt32 channel,
                                                       ViReal64  burstPower[],
                                                       ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:MODulation:CCH:TDOMain", burstPower, errorMessage);
    break;
    case RSCMU300_TCH:
      return RSCMU300_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:MODulation:TCH:TDOMain", burstPower, errorMessage);
    break;
  }
  return RSCMU300_Status;
}


/*===========================================================================*/
/* Function: Sample Array Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrSpecModTime (ViSession instrSession,
                                                       ViInt32 channel,
                                                       ViReal64  burstPower[],
                                                       ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasArray(instrSession, "SAMPle:ARRay:SPECtrum:MODulation:CCH:TDOMain", burstPower, errorMessage);
    break;
    case RSCMU300_TCH:
      return RSCMU300_MeasArray(instrSession, "SAMPle:ARRay:SPECtrum:MODulation:TCH:TDOMain", burstPower, errorMessage);
    break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: area limit matching
/* Purpose : A bit in the output values is set if the corresponding fixed
/*           measurement point exceeds the limit.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcSpecModAreaLimMatc (ViSession  instrSession,
                                                           ViInt32   channel,
                                                           ViInt32   *limitMatching,
                                                           ViChar     errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      CHECKRETMSG(RSCMU300_getViString(instrSession,"CALCulate:ARRay:SPECtrum:MODulation:CCH:AREA:LIMit:MATChing?",rdBuf,RD_BUFFER_SIZE,0));
    break;
    case RSCMU300_TCH:
      CHECKRETMSG(RSCMU300_getViString(instrSession,"CALCulate:ARRay:SPECtrum:MODulation:TCH:AREA:LIMit:MATChing?",rdBuf,RD_BUFFER_SIZE,0));
    break;
  }

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf,"%d", limitMatching);
  else *limitMatching = RSCMU300_NAN_VI_INT32;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read SubArray
/* Purpose : This outputs the off-carrier power due to modulation in the
/*           subranges
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubSpModGm (ViSession instrSession,
                                                                          ViInt32   channel,
                                                                          ViReal64  PowerValues[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[RSCMU300_SUBSPECMOD_NUMBER_MAX][20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:SUB:SPEC:MOD:GMSK:%s?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues, BurstPowerTmp, PowerValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch SubArray
/* Purpose : This outputs the off-carrier power due to modulation in the
/*           subranges
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubSpModGm (ViSession instrSession,
                                                                          ViInt32   channel,
                                                                          ViReal64  PowerValues[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[RSCMU300_SUBSPECMOD_NUMBER_MAX][20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:SUB:SPEC:MOD:GMSK:%s?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues, BurstPowerTmp, PowerValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample SubArray
/* Purpose : This outputs the off-carrier power due to modulation in the
/*           subranges
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubSpModGm (ViSession instrSession,
                                                                          ViInt32   channel,
                                                                          ViReal64  PowerValues[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[RSCMU300_SUBSPECMOD_NUMBER_MAX][20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:SUB:SPEC:MOD:GMSK:%s?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues, BurstPowerTmp, PowerValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read SubArray Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubArrSpecModTime (ViSession instrSession,
                                                          ViInt32 channel,
                                                          ViReal64 burstPower[],
                                                          ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasArray(instrSession, "READ:SUBarrays:SPECtrum:MODulation:CCH:TDOMain", burstPower, errorMessage);
    break;
    case RSCMU300_TCH:
      return RSCMU300_MeasArray(instrSession, "READ:SUBarrays:SPECtrum:MODulation:TCH:TDOMain", burstPower, errorMessage);
    break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch SubArray Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubArrSpecModTime (ViSession instrSession,
                                                          ViInt32 channel,
                                                          ViReal64 burstPower[],
                                                          ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasArray(instrSession, "FETCh:SUBarrays:SPECtrum:MODulation:CCH:TDOMain", burstPower, errorMessage);
    break;
    case RSCMU300_TCH:
      return RSCMU300_MeasArray(instrSession, "FETCh:SUBarrays:SPECtrum:MODulation:TCH:TDOMain", burstPower, errorMessage);
    break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample SubArray Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubArrSpecModTime (ViSession instrSession,
                                                          ViInt32 channel,
                                                          ViReal64 burstPower[],
                                                          ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasArray(instrSession, "SAMPle:SUBarrays:SPECtrum:MODulation:CCH:TDOMain", burstPower, errorMessage);
    break;
    case RSCMU300_TCH:
      return RSCMU300_MeasArray(instrSession, "SAMPle:SUBarrays:SPECtrum:MODulation:TCH:TDOMain", burstPower, errorMessage);
    break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Current Limit Line Template
/* Purpose : These function is always a query and returns the
/*           current limit line template.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensSpecModLimLineUsed (ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViInt32  *currLimLine,
                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      CHECKRETMSG(RSCMU300_getViString(instrSession,"SENSe:SPECtrum:MODulation:CCH:LIMit:LINE:USED?",rdBuf,RD_BUFFER_SIZE,0));
      break;
    case RSCMU300_TCH:
      CHECKRETMSG(RSCMU300_getViString(instrSession,"SENSe:SPECtrum:MODulation:TCH:LIMit:LINE:USED?",rdBuf,RD_BUFFER_SIZE,0));
      break;
  }

  // Extract the CMU response:
  if (strncmp ("GMSK", rdBuf, 4) == 0)
    *currLimLine = RSCMU300_GMSK;
  else if (strncmp ("EPSK", rdBuf, 4) == 0)
    *currLimLine = RSCMU300_EPSK;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT SPECTRUM/SWITCHING
 *    The subsystem SPECtrum:SWITching measures the off-carrier power due to
 *    the bursty nature of the GSM signal.
 *-----------------------------------------------------------------------------
 *      CONFIGURATION CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmContDef (ViSession instrSession,
                                                                             ViInt32   channel,
                                                                             ViBoolean DefaultValues,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "DEF:SPEC:SWIT:GMSK:%s:CONT %s", Channel_Type[channel]
                                                  , mode_On_Off[DefaultValues]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Frequency Select f. Time Domain
/* Purpose : These function selects the measurement frequency for the time
/*           domain (power vs. time) measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpecSwitFSelFTimeD (ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViInt32   select,
                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViString    list[] = {"OFF","N180","N160","N140","N120","N100","N080","N060","N040","N025","N020","N010",
                        "REF","P010","P020","P025","P040","P060","P080","P100","P120","P140","P160","P180",
                        "NV4","NV3","NV2","NV1","PV1","PV2","PV3","PV4", VI_NULL};

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession, RSCMU300_V3_65, RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      CHECKRETMSG(RSCMU300_setEnum(instrSession, "CONFigure:SPECtrum:SWITching:CCH:TDFSelect", select, list,
                              RSCMU_ERROR_PARAMETER3));
      break;
    case RSCMU300_TCH:
      CHECKRETMSG(RSCMU300_setEnum(instrSession, "CONFigure:SPECtrum:SWITching:TCH:TDFSelect", select, list,
                              RSCMU_ERROR_PARAMETER3));
      break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Spectrum Switching continuous statistical mode
/* Purpose : This function defines the continuous statistical mode for the
/*           Spectrum due to Switching measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SpecSwitContStatMod (ViSession instrSession,
                                                        ViInt32 channel,
                                                        ViInt32 continuousStatisticalMode,
                                                        ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViString    list[] = {"PHOL","SCO", VI_NULL};

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  switch (channel)
  {
    case RSCMU300_CCH:
      CHECKRETMSG(RSCMU300_setEnum(instrSession, "CONFigure:SPECtrum:SWITching:CCH:CSMode",
                           continuousStatisticalMode, list,
                           RSCMU_ERROR_PARAMETER2));
    break;
    case RSCMU300_TCH:
      CHECKRETMSG(RSCMU300_setEnum(instrSession, "CONFigure:SPECtrum:SWITching:TCH:CSMode",
                           continuousStatisticalMode, list,
                           RSCMU_ERROR_PARAMETER2));
    break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Nr. of Slots
/* Purpose : This function sets the Number of slots per TDMA frame measured
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SpecSwitNoOfSlot (ViSession instrSession,
                                                     ViInt32 channel,
                                                     ViInt32 nr_ofSlots,
                                                     ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  switch (channel)
  {
    case RSCMU300_CCH:
      CHECKRETMSG(RSCMU300_setViInt32(instrSession,"CONFigure:SPECtrum:SWITching:CCH:NOSLots",
                          nr_ofSlots, 1, 8,
                          RSCMU_ERROR_PARAMETER2));
    break;
    case RSCMU300_TCH:
      CHECKRETMSG(RSCMU300_setViInt32(instrSession,"CONFigure:SPECtrum:SWITching:TCH:NOSLots",
                          nr_ofSlots, 1, 8,
                          RSCMU_ERROR_PARAMETER2));
    break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Scope of measurement
/* Purpose : This function defines the scope of the power measurement,
/*           combining the ...CONTrol:RMODe, ...CONTrol:STATistics, and the
/*           ...CONTrol:REPetition commands.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmScope (ViSession instrSession,
                                                                           ViInt32   channel,
                                                                           ViInt32   MeasuredValuesType,
                                                                           ViInt32   NbBurst,
                                                                           ViInt32   repetition,
                                                                           ViInt32   NbRepetition,
                                                                           ViInt32   StopCondition,
                                                                           ViInt32   StepMode,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, repetition, 0, 2, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER8, errorMessage);

  if (repetition != RSCMU300_MULTIPLE)
    sprintf(wrtBuf, "CONF:SPEC:SWIT:GMSK:%s:CONT %s,%ld,%s,%s,%s", Channel_Type[channel]
                                                                , mode_ScopeMeas[MeasuredValuesType]
                                                                , NbBurst
                                                                , repetition_meas[repetition]
                                                                , mode_StopCondition[StopCondition]
                                                                , StrStepMode[StepMode]);
  else
    sprintf(wrtBuf, "CONF:SPEC:SWIT:GMSK:%s:CONT %s %ld %ld %s %s", Channel_Type[channel]
                                                                , mode_ScopeMeas[MeasuredValuesType]
                                                                , NbBurst
                                                                , NbRepetition
                                                                , mode_StopCondition[StopCondition]
                                                                , StrStepMode[StepMode]);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmContRep (ViSession instrSession,
                                                                             ViInt32   channel,
                                                                             ViInt32   Repetition,
                                                                             ViInt32   StopCondition,
                                                                             ViInt32   StepMode,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, Repetition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER5, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:SPEC:SWIT:GMSK:%s:CONT:REP %s,%s,%s", Channel_Type[channel]
                                                             , repetition_meas[Repetition]
                                                             , mode_StopCondition[StopCondition]
                                                             , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Spectrum Switching Slot Count
/* Purpose : This function defines whether a single timeslot or all timeslots
/*           are considered for the Spectrum due to Switching measurement..
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmSlotCount (ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViInt32   slotCount,
                                                        ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[] = {"SSL","MSL", VI_NULL};
    GET_WRT_BUF(instrSession);

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_22,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    sprintf (wrtBuf, "CONF:SPEC:SWIT:GMSK:%s:SCO", Channel_Type[channel]);

    RETMSG(RSCMU300_setEnum(instrSession, wrtBuf,
                         slotCount, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*-----------------------------------------------------------------------------
 *      LIMITS
 *      The subsystem SPECtrum:SWITching:LIMit contains the commands for
 *      definition of tolerance values for the spectrum measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Limit Lines
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmLimDef (ViSession instrSession,
                                                                            ViInt32   channel,
                                                                            ViBoolean DefaultValues,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "DEF:SPEC:SWIT:GMSK:%s:LIM:LINE %s", Channel_Type[channel]
                                                      , mode_On_Off[DefaultValues]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Limit Lines On/Off
/* Purpose : This function switches the limit checking for all measurepoints.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmLimMode (ViSession instrSession,
                                                                             ViInt32   channel,
                                                                             ViBoolean limitLines,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, limitLines, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:SWIT:GMSK:%s:LIM:LINE:SYMM:ENAB %s", Channel_Type[channel]
                                                                 , mode_On_Off[limitLines]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Limit Lines
/* Purpose : These commands activate and define limit lines for the spectrum
/*           due to switching measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmLim (ViSession instrSession,
                                                  ViInt32 channel,
                                                  ViInt32 MeasurePoint,
                                                  ViBoolean enable,
                                                  ViReal64 minRelativeLimit,
                                                  ViReal64 maxRelativeLimit,
                                                  ViReal64 AbsoluteLimit,
                                                  ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, MeasurePoint, RSCMU300_MPO1, RSCMU300_MPO4, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, enable, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, minRelativeLimit, -99.9, 99.9, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, maxRelativeLimit, -99.9, 99.9, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, AbsoluteLimit, -99.9, 99.9, RSCMU_ERROR_PARAMETER7, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:SWIT:GMSK:%s:LIM:LINE:SYMM:FREQ%ld %.12f,%.12f,%.12f,%s", Channel_Type[channel]
                                                                           , MeasurePoint
                                                                           , minRelativeLimit
                                                                           , maxRelativeLimit
                                                                           , AbsoluteLimit
                                                                           , mode_On_Off[enable]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Statistic Count
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmCont (ViSession instrSession,
                                                                          ViInt32   channel,
                                                                          ViInt32   MeasuredValuesType,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:SWIT:GMSK:%s:CONT:STAT %ld", Channel_Type[channel]
                                                        , NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  sprintf (wrtBuf, "CONF:SPEC:SWIT:GMSK:%s:CONT:RMOD %s", Channel_Type[channel]
                                                        , mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set the number of bursts
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmStat (ViSession instrSession,
                                                                          ViInt32   channel,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:SWIT:GMSK:%s:CONT:STAT %ld", Channel_Type[channel]
                                                        , NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set result mode
/* Purpose : This function specifies the type of measured values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmResMode (ViSession instrSession,
                                                                             ViInt32   channel,
                                                                             ViInt32   MeasuredValuesType,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:SWIT:GMSK:%s:CONT:RMOD %s", Channel_Type[channel]
                                                        , mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmContRepSt (ViSession instrSession,
                                                                               ViInt32   channel,
                                                                               ViInt32   NbRepetition,
                                                                               ViInt32   StopCondition,
                                                                               ViInt32   StepMode,
                                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER5, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:SPEC:SWIT:GMSK:%s:CONT:REP %ld,%s,%s", Channel_Type[channel]
                                                             , NbRepetition
                                                             , mode_StopCondition[StopCondition]
                                                             , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;
  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      MEASUREMENT CONFIGURATION
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Measure Points
/* Purpose : This function permits to select which frequencies a spectrum
/*           switching measurement is performed. A reduction of the
/*           measurement points enhances the measurement speed.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmContMpo (ViSession instrSession,
                                                                             ViInt32   channel,
                                                                             ViInt32   MeasurePoint,
                                                                             ViBoolean Enable,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, MeasurePoint, RSCMU300_MPO1, RSCMU300_MPO4, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, Enable, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:SWIT:GMSK:%s:MPO%ld:ENAB %s", Channel_Type[channel]
                                                         , MeasurePoint
                                                         , mode_On_Off[Enable]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Variable Measure Points
/* Purpose : This function sets and enables additional pairs of
/*           measurement points at up to 4 variable offset frequencies
/*           (numbered by the numeric suffix <nr> = 1 to 4).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpecSwVarMpo (ViSession instrSession,
                                                     ViInt32 channel,
                                                     ViInt32 nr,
                                                     ViInt32 enable,
                                                     ViReal64 frequencyMHz,
                                                     ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasSpecVarMeaPoint(instrSession, "CONFigure:SPECtrum:SWITching:CCH:CONTrol:VMPoint", nr, enable, frequencyMHz, errorMessage);
      break;
    case RSCMU300_TCH:
      return RSCMU300_MeasSpecVarMeaPoint(instrSession, "CONFigure:SPECtrum:SWITching:TCH:CONTrol:VMPoint", nr, enable, frequencyMHz, errorMessage);
      break;
  }
  return RSCMU300_Status;

}

/*===========================================================================*/
/* Function: Definition of Subarrays
/* Purpose : this function configures the READ:SUBarrays.., FETCh:SUBarrays..,
/*           and SAMPle:SUBarrays:SPECtrum:SWITching[:GMSK] commands. It
/*           restricts the measurement to up to 32 subranges where either all
/*           measurement results (the number of which is given by the second
/*           numerical parameter) or a single statistical value is returned.
/*           The subranges are defined by the start time and the number of test
/*           points which are located at fixed frequencies (see command
/*           CONFigure:SPECtrum:SWITching[:GMSK]:LIMit:LINE<nr>).
/*           The subranges may overlap but must be within the total range of
/*           the spectrum due to switching measurement. Test points outside
/*           this range are not measured (result NAN) and do not enter into
/*           the ARIThmetical, MINimum and MAXimum values.
/*           By default, only one range corresponding to the total measurement
/*           range is used and all measurement values are returned.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubSpSwGmRang (ViSession instrSession,
                                                                             ViInt32   channel,
                                                                             ViInt32   StatisticsMode,
                                                                             ViReal64  StartFrequency,
                                                                             ViInt32   Samples,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"ALL","ARIT","MIN","MAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, StartFrequency, RSCMU300_SUBSPECSWITCH_FREQ_MIN, RSCMU300_SUBSPECSWITCH_FREQ_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Samples, RSCMU300_SUBSPECSWITCH_NUMBER_MIN, RSCMU300_SUBSPECSWITCH_NUMBER_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:SPEC:SWIT:GMSK:%s %s,%.12f,%ld", Channel_Type[channel]
                                                         , StrMode[StatisticsMode]
                                                         , StartFrequency
                                                         , Samples);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Configure TimeDomain SubRanges
/* Purpose : This function configurates the READ..., FETCh... and
/*           SAMPle:SSUBarrays:SPECtrum:<Application>:TDOMain commands.
/*           If the requested number of results exceeds the measurement
/*           range, the count parameter will be corrected by the system.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubSpecSwitTime (ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViInt32   mode,
                                                        ViReal64  startTime,
                                                        ViInt32   numberOfSamples,
                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, mode, 0, 4, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, startTime, -30, 175, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, numberOfSamples, 1, 618, RSCMU_ERROR_PARAMETER4, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_ConfSubArr (instrSession, "CONFigure:SUBarrays:SPECtrum:SWITching:CCH:TDOMain", mode, startTime, numberOfSamples, errorMessage);
    break;
    case RSCMU300_TCH:
      return RSCMU300_ConfSubArr (instrSession, "CONFigure:SUBarrays:SPECtrum:SWITching:TCH:TDOMain", mode, startTime, numberOfSamples, errorMessage);
    break;
  }
  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      CONTROL OF SPECTRUM SWITCHING MEAS
 *      It contains the functions for general control of the spectrum switching
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Init
/* Purpose : Start measurement without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitSpSwGm (ViSession instrSession,
                                                                      ViInt32   channel,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "INIT:SPEC:SWIT:GMSK:%s", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : Abort measurement and switch off => OFF
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborSpSwGm (ViSession instrSession,
                                                                      ViInt32   channel,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "ABOR:SPEC:SWIT:GMSK:%s", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : Stop measurement => STOP
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopSpSwGm (ViSession instrSession,
                                                                      ViInt32   channel,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "STOP:SPEC:SWIT:GMSK:%s", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : Next measurement step (only counting mode) => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContSpSwGm (ViSession instrSession,
                                                                      ViInt32   channel,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONT:SPEC:SWIT:GMSK:%s", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Status
/* Purpose : This function is always a query. It immediately reads the
/*           measurement status (for polling, see chapters 3 and 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSpSwGmSt (ViSession instrSession,
                                                                        ViInt32   channel,
                                                                        ViPInt32  MeasStatus,
                                                                        ViPInt32  CurrentStatCycleCount,
                                                                        ViPInt32  CurrentEvalPeriodCount,
                                                                        ViChar   _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Fetch the measurement status:
  sprintf (wrtBuf, "FETC:SPEC:SWIT:GMSK:%s:STAT?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMeasStatVal (MeasStatus, tab, 0);

  // Get the counter for current statistics cycle
  if (strcmp (tab[1], "NONE") != 0)
    sscanf (tab[1], "%ld", CurrentStatCycleCount);
  else *CurrentStatCycleCount = RSCMU300_OFF;

  // Get the counter for current evaluation period within a cycle
  if (strcmp (tab[2], "NONE") != 0)
    sscanf (tab[2], "%ld", CurrentEvalPeriodCount);
  else *CurrentEvalPeriodCount = RSCMU300_OFF;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event Reporting Mode
/* Purpose : This function defines the events to be reported during the
/*           measurement (event reporting, see chapter 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmErep (ViSession instrSession,
                                                                          ViInt32   channel,
                                                                          ViInt32   Mode,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:SWIT:GMSK:%s:EREP %s", Channel_Type[channel]
                                                   , StrErep[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      RESULTS: FREQUENCY SPECTRUM
 *      The subsystem SPECtrum:SWITching[:RESULT] contains the commands for
 *      measurement and output of signal spectrum.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Read
/* Purpose : This function starts the measurement and outputs some results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSpSwGm (ViSession instrSession,
                                                                      ViInt32   channel,
                                                                      ViPReal64 referencePower,
                                                                      ViPInt32  matching,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:SPEC:SWIT:GMSK:%s?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the Average Burst Power
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", referencePower);
  else *referencePower = RSCMU300_NAN;

  // Get the matching
  RSCMU300_Status = RSCMU300_GetMatchingValue(matching,tab, 1);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This function only outputs the results without any care of the
/*           measurement state.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSpSwGm (ViSession instrSession,
                                                                      ViInt32   channel,
                                                                      ViPReal64 referencePower,
                                                                      ViPInt32  matching,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:SPEC:SWIT:GMSK:%s?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the Average Burst Power
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", referencePower);
  else *referencePower = RSCMU300_NAN;

  // Get the matching
  RSCMU300_Status = RSCMU300_GetMatchingValue(matching,tab, 1);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This function waits until the results are valid for the first
/*           time (depending on the chosen statistic count) and then outputs
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSpSwGm (ViSession instrSession,
                                                                      ViInt32   channel,
                                                                      ViPReal64 referencePower,
                                                                      ViPInt32  matching,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:SPEC:SWIT:GMSK:%s?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the Average Burst Power
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", referencePower);
  else *referencePower = RSCMU300_NAN;

  // Get the matching
  RSCMU300_Status = RSCMU300_GetMatchingValue(matching,tab, 1);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Array
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrSpSwGm (ViSession instrSession,
                                                                         ViInt32   channel,
                                                                         ViReal64  BurstPower[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[9][20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:ARR:SPEC:SWIT:GMSK:%s?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Array
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrSpSwGm (ViSession instrSession,
                                                                         ViInt32   channel,
                                                                         ViReal64  BurstPower[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[9][20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:ARR:SPEC:SWIT:GMSK:%s?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample Array
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrSpSwGm (ViSession instrSession,
                                                                         ViInt32   channel,
                                                                         ViReal64  BurstPower[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[9][20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:ARR:SPEC:SWIT:GMSK:%s?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrVarSpecSwit (ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViReal64 burstPower[],
                                                      ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasArray(instrSession, "READ:ARRay:SPECtrum:SWITching:CCH:VMPoint", burstPower, errorMessage);
      break;
    case RSCMU300_TCH:
      return RSCMU300_MeasArray(instrSession, "READ:ARRay:SPECtrum:SWITching:TCH:VMPoint", burstPower, errorMessage);
      break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrVarSpecSwit (ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViReal64 burstPower[],
                                                      ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:SWITching:CCH:VMPoint", burstPower, errorMessage);
      break;
    case RSCMU300_TCH:
      return RSCMU300_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:SWITching:TCH:VMPoint", burstPower, errorMessage);
      break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrVarSpecSwit (ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViReal64 burstPower[],
                                                      ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasArray(instrSession, "SAMPle:ARRay:SPECtrum:SWITching:CCH:VMPoint", burstPower, errorMessage);
      break;
    case RSCMU300_TCH:
      return RSCMU300_MeasArray(instrSession, "SAMPle:ARRay:SPECtrum:SWITching:TCH:VMPoint", burstPower, errorMessage);
      break;
  }
  return RSCMU300_Status;
}


/*===========================================================================*/
/* Function: Read Array Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrSpecSwitTime (ViSession instrSession,
                                                        ViInt32 channel,
                                                        ViReal64  burstPower[],
                                                        ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasArray(instrSession, "READ:ARRay:SPECtrum:SWITching:CCH:TDOMain", burstPower, errorMessage);
      break;
    case RSCMU300_TCH:
      return RSCMU300_MeasArray(instrSession, "READ:ARRay:SPECtrum:SWITching:TCH:TDOMain", burstPower, errorMessage);
      break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Array Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrSpecSwitTime (ViSession instrSession,
                                                        ViInt32 channel,
                                                        ViReal64  burstPower[],
                                                        ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:SWITching:CCH:TDOMain", burstPower, errorMessage);
      break;
    case RSCMU300_TCH:
      return RSCMU300_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:SWITching:TCH:TDOMain", burstPower, errorMessage);
      break;
  }
  return RSCMU300_Status;
}


/*===========================================================================*/
/* Function: Sample Array Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrSpecSwitTime (ViSession instrSession,
                                                        ViInt32 channel,
                                                        ViReal64  burstPower[],
                                                        ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasArray(instrSession, "SAMPle:ARRay:SPECtrum:SWITching:CCH:TDOMain", burstPower, errorMessage);
      break;
    case RSCMU300_TCH:
      return RSCMU300_MeasArray(instrSession, "SAMPle:ARRay:SPECtrum:SWITching:TCH:TDOMain", burstPower, errorMessage);
      break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: area limit matching
/* Purpose : A bit in the output values is set if the corresponding fixed
/*           measurement point exceeds the limit.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcSpecSwiAreaLimMatc (ViSession  instrSession,
                                                           ViInt32   channel,
                                                           ViInt32   *limitMatching,
                                                           ViChar     errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      CHECKRETMSG(RSCMU300_getViString(instrSession,"CALCulate:ARRay:SPECtrum:SWITching:CCH:AREA:LIMit:MATChing?",rdBuf,RD_BUFFER_SIZE,0));
    break;
    case RSCMU300_TCH:
      CHECKRETMSG(RSCMU300_getViString(instrSession,"CALCulate:ARRay:SPECtrum:SWITching:TCH:AREA:LIMit:MATChing?",rdBuf,RD_BUFFER_SIZE,0));
    break;
  }

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf,"%d", limitMatching);
  else *limitMatching = RSCMU300_NAN_VI_INT32;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read SubArray
/* Purpose : This outputs the off-carrier power due to switching in the
/*           subranges
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubSpSwGm (ViSession instrSession,
                                                                         ViInt32   channel,
                                                                         ViReal64  BurstPower[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[RSCMU300_SUBSPECSWITCH_NUMBER_MAX][20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:SUB:SPEC:SWIT:GMSK:%s?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch SubArray
/* Purpose : This outputs the off-carrier power due to switching in the
/*           subranges
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubSpSwGm (ViSession instrSession,
                                                                         ViInt32   channel,
                                                                         ViReal64  BurstPower[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[RSCMU300_SUBSPECSWITCH_NUMBER_MAX][20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:SUB:SPEC:SWIT:GMSK:%s?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample SubArray
/* Purpose : This outputs the off-carrier power due to switching in the
/*           subranges
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubSpSwGm (ViSession instrSession,
                                                                         ViInt32   channel,
                                                                         ViReal64  BurstPower[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[RSCMU300_SUBSPECSWITCH_NUMBER_MAX][20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:SUB:SPEC:SWIT:GMSK:%s?", Channel_Type[channel]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read SubArray Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubArrSpecSwitTime (ViSession instrSession,
                                                           ViInt32 channel,
                                                           ViReal64 burstPower[],
                                                           ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasArray(instrSession, "READ:SUBarrays:SPECtrum:SWITching:CCH:TDOMain", burstPower, errorMessage);
    break;
    case RSCMU300_TCH:
      return RSCMU300_MeasArray(instrSession, "READ:SUBarrays:SPECtrum:SWITching:CCH:TDOMain", burstPower, errorMessage);
    break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch SubArray Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubArrSpecSwitTime (ViSession instrSession,
                                                           ViInt32 channel,
                                                           ViReal64 burstPower[],
                                                           ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasArray(instrSession, "FETCh:SUBarrays:SPECtrum:SWITching:CCH:TDOMain", burstPower, errorMessage);
    break;
    case RSCMU300_TCH:
      return RSCMU300_MeasArray(instrSession, "FETCh:SUBarrays:SPECtrum:SWITching:CCH:TDOMain", burstPower, errorMessage);
    break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample SubArray Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubArrSpecSwitTime (ViSession instrSession,
                                                           ViInt32 channel,
                                                           ViReal64 burstPower[],
                                                           ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasArray(instrSession, "SAMPle:SUBarrays:SPECtrum:SWITching:CCH:TDOMain", burstPower, errorMessage);
    break;
    case RSCMU300_TCH:
      return RSCMU300_MeasArray(instrSession, "SAMPle:SUBarrays:SPECtrum:SWITching:CCH:TDOMain", burstPower, errorMessage);
    break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Current Limit Line Template
/* Purpose : These function is always a query and returns the
/*           current limit line template.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensSpecSwiLimLineUsed (ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViInt32  *currLimLine,
                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      CHECKRETMSG(RSCMU300_getViString(instrSession,"SENSe:SPECtrum:SWITching:CCH:LIMit:LINE:USED?",rdBuf,RD_BUFFER_SIZE,0));
      break;
    case RSCMU300_TCH:
      CHECKRETMSG(RSCMU300_getViString(instrSession,"SENSe:SPECtrum:SWITching:TCH:LIMit:LINE:USED?",rdBuf,RD_BUFFER_SIZE,0));
      break;
  }

  // Extract the CMU response:
  if (strncmp ("GMSK", rdBuf, 4) == 0)
    *currLimLine = RSCMU300_GMSK;
  else if (strncmp ("EPSK", rdBuf, 4) == 0)
    *currLimLine = RSCMU300_EPSK;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT SPECTRUM/Modulation&Switching
 * ----------------------------------------------------------------------------
 */


/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpecMSwContRep (ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViInt32   repetition,
                                                       ViInt32   stopCondition,
                                                       ViInt32   stepMode,
                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, repetition,RSCMU300_CONTINUOUS,RSCMU300_SINGLE_SHOT, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, stopCondition,RSCMU300_NONE,RSCMU300_STOP_ON, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, stepMode,RSCMU300_NONE,RSCMU300_STEP_ON, RSCMU_ERROR_PARAMETER5, errorMessage);

  sprintf (wrtBuf, "CONFigure:SPECtrum:MSWitching:%s:CONTrol:REPetition %s,%s,%s",
                    Channel_Type[channel] ,repetition_meas[repetition], mode_StopCondition_SON[stopCondition], StrStepMode[stepMode]);
  RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Init
/* Purpose : Start measurement without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitSpecMSw (ViSession instrSession,
                                                ViInt32   channel,
                                                ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      CHECKRETMSG(RSCMU300_sendCmd(instrSession, "INITiate:SPECtrum:MSWitching:CCH"));
      break;
    case RSCMU300_TCH:
      CHECKRETMSG(RSCMU300_sendCmd(instrSession, "INITiate:SPECtrum:MSWitching:TCH"));
      break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : Abort measurement and switch off => OFF
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborSpecMSw (ViSession instrSession,
                                                ViInt32   channel,
                                                ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      CHECKRETMSG(RSCMU300_sendCmd(instrSession, "ABORt:SPECtrum:MSWitching:CCH"));
      break;
    case RSCMU300_TCH:
      CHECKRETMSG(RSCMU300_sendCmd(instrSession, "ABORt:SPECtrum:MSWitching:TCH"));
      break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : Stop measurement => STOP
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopSpecMSw (ViSession instrSession,
                                                ViInt32   channel,
                                                ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      CHECKRETMSG(RSCMU300_sendCmd(instrSession, "STOP:SPECtrum:MSWitching:CCH"));
      break;
    case RSCMU300_TCH:
      CHECKRETMSG(RSCMU300_sendCmd(instrSession, "STOP:SPECtrum:MSWitching:TCH"));
      break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : Next measurement step (only counting mode) => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContSpecMSw (ViSession instrSession,
                                                ViInt32   channel,
                                                ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      CHECKRETMSG(RSCMU300_sendCmd(instrSession, "CONTinue:SPECtrum:MSWitching:CCH"));
      break;
    case RSCMU300_TCH:
      CHECKRETMSG(RSCMU300_sendCmd(instrSession, "CONTinue:SPECtrum:MSWitching:TCH"));
      break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Spectrum Modulation Measurement Status
/* Purpose : This function returns the status of the current Spectrum
/*           Modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSpecMSwStat (ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32  *MeasurementStatus,
                                                    ViInt32  *CountingNo,
                                                    ViInt32  *ModStatisticNo,
                                                    ViInt32  *SwitchStatisticNo,
                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_FetcSpecMSwStatus (instrSession, "FETCh:SPECtrum:MSWitching:CCH:STATus", MeasurementStatus, CountingNo, ModStatisticNo, SwitchStatisticNo, errorMessage);
      break;
    case RSCMU300_TCH:
      return RSCMU300_FetcSpecMSwStatus (instrSession, "FETCh:SPECtrum:MSWitching:TCH:STATus", MeasurementStatus, CountingNo, ModStatisticNo, SwitchStatisticNo, errorMessage);
      break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event Reporting Mode
/* Purpose : This function defines the events to be reported during the
/*           measurement (event reporting, see chapter 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpecMSwErep (ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   Mode,
                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_ConfEventReporting (instrSession, "CONFigure:SPECtrum:MSWitching:CCH:EREPorting", Mode, errorMessage);
      break;
    case RSCMU300_TCH:
      return RSCMU300_ConfEventReporting (instrSession, "CONFigure:SPECtrum:MSWitching:TCH:EREPorting", Mode, errorMessage);
      break;
  }
  return RSCMU300_Status;
}


/*===========================================================================*/
/* Function: Start single shot measurement and return results
/* Purpose : This function starts a single shot measurement and returns the
/*           results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSpecMSw (ViSession instrSession,
                                                ViInt32   channel,
                                                ViReal64 *refPowMod,
                                                ViInt32  *matchingMod,
                                                ViReal64 *refPowSwitch,
                                                ViInt32  *matchingSwitch,
                                                ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasSpecModSwitch (instrSession, "READ:SCALar:SPECtrum:MSWitching:CCH", refPowMod, matchingMod, refPowSwitch, matchingSwitch, errorMessage);
      break;
    case RSCMU300_TCH:
      return RSCMU300_MeasSpecModSwitch (instrSession, "READ:SCALar:SPECtrum:MSWitching:TCH", refPowMod, matchingMod, refPowSwitch, matchingSwitch, errorMessage);
      break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This function only outputs the results without any care of the
/*           measurement state.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSpecMSw (ViSession instrSession,
                                                ViInt32   channel,
                                                ViReal64 *refPowMod,
                                                ViInt32  *matchingMod,
                                                ViReal64 *refPowSwitch,
                                                ViInt32  *matchingSwitch,
                                                ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasSpecModSwitch (instrSession, "FETCh:SCALar:SPECtrum:MSWitching:CCH", refPowMod, matchingMod, refPowSwitch, matchingSwitch, errorMessage);
      break;
    case RSCMU300_TCH:
      return RSCMU300_MeasSpecModSwitch (instrSession, "FETCh:SCALar:SPECtrum:MSWitching:TCH", refPowMod, matchingMod, refPowSwitch, matchingSwitch, errorMessage);
      break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This function waits until the results are valid for the first
/*           time (depending on the chosen statistic count) and then outputs
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSpecMSw (ViSession instrSession,
                                                ViInt32   channel,
                                                ViReal64 *refPowMod,
                                                ViInt32  *matchingMod,
                                                ViReal64 *refPowSwitch,
                                                ViInt32  *matchingSwitch,
                                                ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasSpecModSwitch (instrSession, "SAMPle:SCALar:SPECtrum:MSWitching:CCH", refPowMod, matchingMod, refPowSwitch, matchingSwitch, errorMessage);
      break;
    case RSCMU300_TCH:
      return RSCMU300_MeasSpecModSwitch (instrSession, "SAMPle:SCALar:SPECtrum:MSWitching:TCH", refPowMod, matchingMod, refPowSwitch, matchingSwitch, errorMessage);
      break;
  }
  return RSCMU300_Status;
}


/*===========================================================================*/
/* Function: Read
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrSpecMSw (ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViReal64  burstPower[],
                                                   ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasArray(instrSession, "READ:ARRay:SPECtrum:MSWitching:CCH", burstPower, errorMessage);
      break;
    case RSCMU300_TCH:
      return RSCMU300_MeasArray(instrSession, "READ:ARRay:SPECtrum:MSWitching:TCH", burstPower, errorMessage);
      break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrSpecMSw (ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViReal64  burstPower[],
                                                   ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:MSWitching:CCH", burstPower, errorMessage);
      break;
    case RSCMU300_TCH:
      return RSCMU300_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:MSWitching:TCH", burstPower, errorMessage);
      break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrSpecMSw (ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViReal64  burstPower[],
                                                   ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasArray(instrSession, "SAMPle:ARRay:SPECtrum:MSWitching:CCH", burstPower, errorMessage);
      break;
    case RSCMU300_TCH:
      return RSCMU300_MeasArray(instrSession, "SAMPle:ARRay:SPECtrum:MSWitching:TCH", burstPower, errorMessage);
      break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: area limit matching
/* Purpose : A bit in the output values is set if the corresponding fixed
/*           measurement point exceeds the limit.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcSpecMSwAreaLimMatc (ViSession  instrSession,
                                                           ViInt32   channel,
                                                           ViInt32   *modLimit,
                                                           ViInt32   *switLimit,
                                                           ViChar     errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      tab[100][100];
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      CHECKRETMSG(RSCMU300_getViString(instrSession,"CALCulate:ARRay:SPECtrum:MSWitching:CCH:AREA:LIMit:MATChing?",rdBuf,RD_BUFFER_SIZE,0));
      break;
    case RSCMU300_TCH:
      CHECKRETMSG(RSCMU300_getViString(instrSession,"CALCulate:ARRay:SPECtrum:MSWitching:TCH:AREA:LIMit:MATChing?",rdBuf,RD_BUFFER_SIZE,0));
      break;
  }

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%d", modLimit);
  else *modLimit = RSCMU300_NAN;

  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%d", switLimit);
  else *switLimit = RSCMU300_NAN;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrVarSpecMSw (ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViReal64  burstPower[],
                                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasArray(instrSession, "READ:ARRay:SPECtrum:MSWitching:CCH:VMPoint", burstPower, errorMessage);
      break;
    case RSCMU300_TCH:
      return RSCMU300_MeasArray(instrSession, "READ:ARRay:SPECtrum:MSWitching:TCH:VMPoint", burstPower, errorMessage);
      break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrVarSpecMSw (ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViReal64 burstPower[],
                                                      ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:MSWitching:CCH:VMPoint", burstPower, errorMessage);
      break;
    case RSCMU300_TCH:
      return RSCMU300_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:MSWitching:TCH:VMPoint", burstPower, errorMessage);
      break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrVarSpecMSw (ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViReal64 burstPower[],
                                                      ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      return RSCMU300_MeasArray(instrSession, "SAMPle:ARRay:SPECtrum:MSWitching:CCH:VMPoint", burstPower, errorMessage);
      break;
    case RSCMU300_TCH:
      return RSCMU300_MeasArray(instrSession, "SAMPle:ARRay:SPECtrum:MSWitching:TCH:VMPoint", burstPower, errorMessage);
      break;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Current Limit Line Template
/* Purpose : These function is always a query and returns the
/*           current limit line template.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensSpecMswLimLineUsed (ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViInt32  *currLimLine,
                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (channel)
  {
    case RSCMU300_CCH:
      CHECKRETMSG(RSCMU300_getViString(instrSession,"SENSe:SPECtrum:MSWitching:CCH:LIMit:LINE:USED?",rdBuf,RD_BUFFER_SIZE,0));
      break;
    case RSCMU300_TCH:
      CHECKRETMSG(RSCMU300_getViString(instrSession,"SENSe:SPECtrum:MSWitching:TCH:LIMit:LINE:USED?",rdBuf,RD_BUFFER_SIZE,0));
      break;
  }

  // Extract the CMU response:
  if (strncmp ("GMSK", rdBuf, 4) == 0)
    *currLimLine = RSCMU300_GMSK;
  else if (strncmp ("EPSK", rdBuf, 4) == 0)
    *currLimLine = RSCMU300_EPSK;

  return RSCMU300_Status;
}

/*****************************************************************************/
/*****************************************************************************/
/*======== EPSK Functions ===================================================*/
/*****************************************************************************/
/*****************************************************************************/
/*
 * ----------------------------------------------------------------------------
 * GSM MEASUREMENTS WITHOUT SIGNALLING (NON SIGNALLING):
 * ----------------------------------------------------------------------------
 * In the Non Signalling mode, a GSM-specific RF signal can be
 * generated and an RF signal with GSM characteristics analyzed.
 * No signalling parameters are transferred and measured.
 * ----------------------------------------------------------------------------
 */
/*-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT POWER
 *    The subsystem POWer contains the commands for measuring the
 *    signal power.
 *    This subsystem corresponds to the measurement menu Power vs.
 *    Time and the associated popup menu Power vs Time Configuration.
 *-----------------------------------------------------------------------------
 *      TEST CONFIGURATION
 *      The functions of this subsystem determine the parameters of the
 *      signal power measurement. GSM signals are transferred in the
 *      form of bursts, which divided up into various tolerance ranges
 *      defined in the GSM standard.
 * ----------------------------------------------------------------------------
 *        CONFIGURATION CONTROL
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpContDef (ViSession instrSession,
                                                                             ViBoolean DefaultValues,
                                                                             ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowContDef(RSCMU300_EPSK, instrSession, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Scope of measurement
/* Purpose : This function defines the scope of the power measurement,
/*           combining the ...CONTrol:RMODe, ...CONTrol:STATistics, and the
/*           ...CONTrol:REPetition commands.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpScope (ViSession instrSession,
                                                                           ViInt32   MeasuredValuesType,
                                                                           ViInt32   NbBurst,
                                                                           ViInt32   repetition,
                                                                           ViInt32   NbRepetition,
                                                                           ViInt32   StopCondition,
                                                                           ViInt32   StepMode,
                                                                           ViChar    errorMessage[])
{
    return NSig_ConfPowScope(RSCMU300_EPSK, instrSession, MeasuredValuesType, NbBurst, repetition, NbRepetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles, the
/*           stop condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpContRep (ViSession instrSession,
                                                                             ViInt32   repetition,
                                                                             ViInt32   StopCondition,
                                                                             ViInt32   StepMode,
                                                                             ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowContRep (RSCMU300_EPSK, instrSession, repetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Filter
/* Purpose : This function selects the measurement filter.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowgEpFilter (ViSession instrSession,
                                                      ViInt32   filter,
                                                      ViChar    errorMessage[])
{
 ViStatus    RSCMU300_Status = VI_SUCCESS;

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 RETMSG(RSCMU300_setEnum(instrSession, "CONF:POW:NBUR:EPSK:FILT",
                         filter, StrFilter,
                         RSCMU_ERROR_PARAMETER2));
}

/*
 * -----------------------------------------------------------------------------
 *        LIMITS LINES
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Default limit Lines (ON/OFF)
/* Purpose : This function switches the default limit lines on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpLimDef (ViSession instrSession,
                                                                            ViBoolean defaultLimitLines,
                                                                            ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowLimDef(RSCMU300_EPSK, instrSession, defaultLimitLines, errorMessage);
}

/*===========================================================================*/
/* Function: Switches the lower limit lines ON/OFF
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpLimLowMode (ViSession instrSession,
                                                                                ViBoolean mode,
                                                                                ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowLimLowMode(RSCMU300_EPSK, instrSession, mode, errorMessage);
}

/*===========================================================================*/
/* Function: Switches the upper limit lines ON/OFF
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpLimUppMode (ViSession instrSession,
                                                                                ViBoolean mode,
                                                                                ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowLimUppMode(RSCMU300_EPSK, instrSession, mode, errorMessage);
}

/*===========================================================================*/
/* Function: Set Lower limit Lines
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpLimLow (ViSession instrSession,
                                                                            ViInt32   area,
                                                                            ViBoolean enable,
                                                                            ViBoolean StartPointBitON_OFF,
                                                                            ViReal64  StartPointBit,
                                                                            ViBoolean EndPointBitON_OFF,
                                                                            ViReal64  EndPointBit,
                                                                            ViBoolean StartPointRelLevON_OFF,
                                                                            ViReal64  StartPointRelLev,
                                                                            ViBoolean EndPointRelLevON_OFF,
                                                                            ViReal64  EndPointRelLev,
                                                                            ViBoolean StartPointAbsLevON_OFF,
                                                                            ViReal64  StartPointAbsLev,
                                                                            ViBoolean EndPointAbsLevON_OFF,
                                                                            ViReal64  EndPointAbsLev,
                                                                            ViBoolean visibility,
                                                                            ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowLimLow(RSCMU300_EPSK, instrSession, area, enable, StartPointBitON_OFF, StartPointBit,
                            EndPointBitON_OFF, EndPointBit, StartPointRelLevON_OFF, StartPointRelLev, EndPointRelLevON_OFF,
                            EndPointRelLev, StartPointAbsLevON_OFF, StartPointAbsLev, EndPointAbsLevON_OFF, EndPointAbsLev,
                            visibility, errorMessage);
}

/*===========================================================================*/
/* Function: Set Upper limit Lines
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpLimUpp (ViSession instrSession,
                                                                            ViInt32   area,
                                                                            ViBoolean enable,
                                                                            ViBoolean StartPointBitON_OFF,
                                                                            ViReal64  StartPointBit,
                                                                            ViBoolean EndPointBitON_OFF,
                                                                            ViReal64  EndPointBit,
                                                                            ViBoolean StartPointRelLevON_OFF,
                                                                            ViReal64  StartPointRelLev,
                                                                            ViBoolean EndPointRelLevON_OFF,
                                                                            ViReal64  EndPointRelLev,
                                                                            ViBoolean StartPointAbsLevON_OFF,
                                                                            ViReal64  StartPointAbsLev,
                                                                            ViBoolean EndPointAbsLevON_OFF,
                                                                            ViReal64  EndPointAbsLev,
                                                                            ViBoolean visibility,
                                                                            ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowLimUpp(RSCMU300_EPSK, instrSession, area, enable, StartPointBitON_OFF, StartPointBit,
                            EndPointBitON_OFF, EndPointBit, StartPointRelLevON_OFF, StartPointRelLev, EndPointRelLevON_OFF,
                            EndPointRelLev, StartPointAbsLevON_OFF, StartPointAbsLev, EndPointAbsLevON_OFF, EndPointAbsLev,
                            visibility, errorMessage);
}

/*
 * -----------------------------------------------------------------------------
 *        TIME
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Offset on the burst
/* Purpose : This function defines an offset time in  Bit units by which the
/*           burst is shifted relative to the time axis and the tolerance
/*           template.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpTimeBit (ViSession instrSession,
                                                                             ViReal64  timeBit,
                                                                             ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowTimeBit(RSCMU300_EPSK, instrSession, timeBit, errorMessage);
}

/*
 * -----------------------------------------------------------------------------
 *        REFERENCE POWER
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Reference Power Mode
/* Purpose : this function determines the way how the reference power is
/*           calculated in 8PSK modulation.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpRPMode (ViSession instrSession,
                                                                            ViInt32   mode,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"CURR","AVER","DCOM"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:EPSK:RPM %s", StrMode[mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Scope of Measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpCont (ViSession instrSession,
                                                                          ViInt32   MeasuredValuesType,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowCont(RSCMU300_EPSK, instrSession, MeasuredValuesType, NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set the number of bursts
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpStat (ViSession instrSession,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowStat(RSCMU300_EPSK, instrSession, NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set result mode
/* Purpose : This function specifies the type of measured values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpResMode (ViSession instrSession,
                                                                             ViInt32   MeasuredValuesType,
                                                                             ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowResMode(RSCMU300_EPSK, instrSession, MeasuredValuesType, errorMessage);
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles, the
/*           stop condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpContRepSt (ViSession instrSession,
                                                                               ViInt32   NbRepetition,
                                                                               ViInt32   StopCondition,
                                                                               ViInt32   StepMode,
                                                                               ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowContRepSt(RSCMU300_EPSK, instrSession, NbRepetition, StopCondition, StepMode, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      MEASUREMENT
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Definition of Subarrays
/* Purpose : This function configures the READ:SUBarrays:POWer...,
/*           FETCh:SUBarrays:POWer..., and SAMPle:SUBarrays:POWer commands. It
/*           restricts the measurement to up to 32 subranges where either all
/*           measurement results (the number of which is given by the second
/*           numerical parameter) or a single statistical value is returned.
/*           The subranges are defined by the start time and the number of
/*           test points which are located on a fixed, equidistant grid with
/*           a step width of  Bit.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSubPowEpRang (ViSession instrSession,
                                                                             ViInt32   statisticsMode,
                                                                             ViReal64  startTime_bit,
                                                                             ViInt32   number_of_samples,
                                                                             ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSubPowRang(RSCMU300_EPSK, instrSession, statisticsMode, startTime_bit, number_of_samples, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      MEASUREMENT CONTROL
 *      This subsystem contains the functions for general control of the
 *      power measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start new measurement
/* Purpose : This function starts the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitPowEp (ViSession instrSession,
                                                                      ViChar    _VI_FAR errorMessage[])
{
    return NSig_InitPow(RSCMU300_EPSK, instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Abort running measurement and switch off
/* Purpose : This function stops the power measurement, setting it to
/*           the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborPowEp (ViSession instrSession,
                                                                      ViChar    _VI_FAR errorMessage[])
{
    return NSig_AborPow(RSCMU300_EPSK, instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: stop measurement after current statistic cycle
/* Purpose : This function stops the power measurement, setting it to
/*           the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopPowEp (ViSession instrSession,
                                                                      ViChar    _VI_FAR errorMessage[])
{
    return NSig_StopPow(RSCMU300_EPSK, instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Next Measurement Step
/* Purpose : This function continue the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContPowEp (ViSession instrSession,
                                                                      ViChar    _VI_FAR errorMessage[])
{
    return NSig_ContPow(RSCMU300_EPSK, instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch measurement status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcPowEpSt (ViSession instrSession,
                                                                        ViPInt32  MeasStatus,
                                                                        ViPInt32  CurrentStatCycleCount,
                                                                        ViPInt32  CurrentEvalPeriodCount,
                                                                        ViChar    _VI_FAR errorMessage[])
{
    return NSig_FetcPowSt(RSCMU300_EPSK, instrSession, MeasStatus, CurrentStatCycleCount, CurrentEvalPeriodCount, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpErep (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfPowErep(RSCMU300_EPSK, instrSession, Mode, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      MEASURED VALUES
 *      The functions of this subsystem determine and output the results
 *      of the signal power measurement.
 * ----------------------------------------------------------------------------
 *        MEASUREMENT AND BURST POWER
 *        (Subsystem POWer[:RESult])
 *        It contains the functions for measurement and output of the
 *        burst power and its comparison with tolerance values.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function starts a measurement and outputs all scalar measurement
/*           results (see chapter 5). The results are:
/*
/*              Bursts out of tolerance (percentage)
/*              Average power of current burst
/*              Peak power of current burst
/*              Average power of averaged trace
/*              Burst template matching
/*
/*           The calculation of results in an average or peak measurement is
/*           described in chapter 3 (cf. display modes).The following messages
/*           may be output for the value BurstMatching:
/*
/*              MATC matching
/*              NMAT not matching
/*              INV invalid
/*              NTSC no training sequence code
/*              OUT out of range
/*              NTRG not triggered
/*              UFLW underflow
/*              OFLW overflow
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadPowEp (ViSession instrSession,
                                                                      ViPReal64 BurstOutOfTol,
                                                                      ViPReal64 AvgBurstPowerCurrent,
                                                                      ViPReal64 PeakBurstPower,
                                                                      ViPInt32  BurstMatching,
                                                                      ViPReal64 AvgBurstPowerAvg,
                                                                      ViChar    _VI_FAR errorMessage[])
{
    return NSig_ReadPow(RSCMU300_EPSK, instrSession, BurstOutOfTol, AvgBurstPowerCurrent, PeakBurstPower, BurstMatching, AvgBurstPowerAvg, errorMessage);
}

/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function outputs all scalar measurement results (see chapter 5).
/*           The results are:
/*
/*              Bursts out of tolerance (percentage)
/*              Average power of current burst
/*              Peak power of current burst
/*              Average power of averaged trace
/*              Burst template matching
/*
/*           The calculation of results in an average or peak measurement is
/*           described in chapter 3 (cf. display modes).The following messages
/*           may be output for the value BurstMatching:
/*
/*              MATC matching
/*              NMAT not matching
/*              INV invalid
/*              NTSC no training sequence code
/*              OUT out of range
/*              NTRG not triggered
/*              UFLW underflow
/*              OFLW overflow
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcPowEp (ViSession instrSession,
                                                                      ViPReal64 BurstOutOfTol,
                                                                      ViPReal64 AvgBurstPowerCurrent,
                                                                      ViPReal64 PeakBurstPower,
                                                                      ViPInt32  BurstMatching,
                                                                      ViPReal64 AvgBurstPowerAvg,
                                                                      ViChar    _VI_FAR errorMessage[])
{
    return NSig_FetcPow(RSCMU300_EPSK, instrSession, BurstOutOfTol, AvgBurstPowerCurrent, PeakBurstPower, BurstMatching, AvgBurstPowerAvg, errorMessage);
}

/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function starts a measurement and outputs all scalar measurement
/*           results (see chapter 5). The results are:
/*
/*              Bursts out of tolerance (percentage)
/*              Average power of current burst
/*              Peak power of current burst
/*              Average power of averaged trace
/*              Burst template matching
/*
/*           The calculation of results in an average or peak measurement is
/*           described in chapter 3 (cf. display modes).The following messages
/*           may be output for the value BurstMatching:
/*
/*              MATC matching
/*              NMAT not matching
/*              INV invalid
/*              NTSC no training sequence code
/*              OUT out of range
/*              NTRG not triggered
/*              UFLW underflow
/*              OFLW overflow
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampPowEp (ViSession instrSession,
                                                                      ViPReal64 BurstOutOfTol,
                                                                      ViPReal64 AvgBurstPowerCurrent,
                                                                      ViPReal64 PeakBurstPower,
                                                                      ViPInt32  BurstMatching,
                                                                      ViPReal64 AvgBurstPowerAvg,
                                                                      ViChar    _VI_FAR errorMessage[])
{
    return NSig_SampPow(RSCMU300_EPSK, instrSession, BurstOutOfTol, AvgBurstPowerCurrent, PeakBurstPower, BurstMatching, AvgBurstPowerAvg, errorMessage);
}

/*===========================================================================*/
/* Function: Request Tolerance On Values
/* Purpose : This function indicates whether and in which way the per-
/*           missible tolerances for the scalar measured values  have
/*           been exceeded.
/*
/*           The following messages may be output for the values
/*           AvgBurstPower, AvgBurstPowerAvg and PeakBurst-Power:
/*
/*              NMAU Tolerance value underflow not matching, underflow
/*              NMAL Tolerance value exceeded not matching, overflow
/*              INV  Measurement invalid invalid
/*              OK   Tolerance value matched
/*
/*           The following messages may be output for the value
/*           BurstMatching:
/*
/*              MATC matching
/*              NMAT not matching
/*              INV  invalid
/*              NTSC no training sequence code
/*              OUT  out of range
/*
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcPowEpMatcLim (ViSession instrSession,
                                                                             ViPInt32  AvgBurstPowerCurrent,
                                                                             ViPInt32  PeakBurstPower,
                                                                             ViPInt32  BurstTemplateMatching,
                                                                             ViPInt32  AvgBurstPowerAvg,
                                                                             ViChar    _VI_FAR errorMessage[])
{
    return NSig_CalcPowMatcLim(RSCMU300_EPSK, instrSession, AvgBurstPowerCurrent, PeakBurstPower, BurstTemplateMatching, AvgBurstPowerAvg, errorMessage);
}

/*===========================================================================*/
/* Function: Burst power measured values
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrPowEp (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  BurstPower[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
    return NSig_ReadArrPow(RSCMU300_EPSK, instrSession, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetc Burst Power...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrPowEp (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  BurstPower[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
    return NSig_FetcArrPow(RSCMU300_EPSK, instrSession, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Burst Power...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrPowEp (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  BurstPower[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
    return NSig_SampArrPow(RSCMU300_EPSK, instrSession, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Tolerance error of power measurement
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcArrPowEpMatcLim (ViSession instrSession,
                                                                                ViInt32   statisticsMode,
                                                                                ViPInt32  burstMatching,
                                                                                ViChar    _VI_FAR errorMessage[])
{
    return NSig_CalcArrPowMatcLim(RSCMU300_EPSK, instrSession, statisticsMode, burstMatching, errorMessage);
}

/*===========================================================================*/
/* Function: indicates that the corresponding area of the limit lines is
/*           violated.
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcArrPowEpAreaMatc (ViSession instrSession,
                                                                                 ViInt32   statisticsMode,
                                                                                 ViPUInt32 upperLimit,
                                                                                 ViPUInt32 lowerLimit,
                                                                                 ViChar    _VI_FAR errorMessage[])
{
    return NSig_CalcArrPowAreaMatc(RSCMU300_EPSK, instrSession, statisticsMode, upperLimit, lowerLimit, errorMessage);
}

/*===========================================================================*/
/* Function: This function outputs the burst power versus time in a fixed
/*           -Bit pattern and in the subranges defined by means of the
/*           CONFigure:SUBarrays:POWer command.
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSubPowEp (ViSession instrSession,
                                                                         ViInt32   statisticsMode,
                                                                         ViReal64  burstPowerValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
    return NSig_ReadSubPow(RSCMU300_EPSK, instrSession, statisticsMode, burstPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: This function outputs the burst power versus time in a fixed
/*           -Bit pattern and in the subranges defined by means of the
/*           CONFigure:SUBarrays:POWer command.
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSubPowEp (ViSession instrSession,
                                                                         ViInt32   statisticsMode,
                                                                         ViReal64  burstPowerValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
    return NSig_FetcSubPow(RSCMU300_EPSK, instrSession, statisticsMode, burstPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: This function outputs the burst power versus time in a fixed
/*           -Bit pattern and in the subranges defined by means of the
/*           CONFigure:SUBarrays:POWer command.
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSubPowEp (ViSession instrSession,
                                                                         ViInt32   statisticsMode,
                                                                         ViReal64  burstPowerValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
    return NSig_SampSubPow(RSCMU300_EPSK, instrSession, statisticsMode, burstPowerValues, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT MODULATION OEMP
 *
 *    The subsystem MODulation:OEMP:EPSK:LIMit defines tolerance values
 *    for the modulation measurement in all four 8PSK applications. The
 *    subsystem corresponds to the Limits tab in the popup menu Modulation
 *    Configuration.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Default limit Lines (ON/OFF)
/* Purpose : This function switches the default limit lines on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfOempEpLimDef (ViSession instrSession,
                                                                             ViBoolean DefaultLimitLines,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultLimitLines, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DEF:MOD:OEMP:EPSK:LIM %s", mode_On_Off[DefaultLimitLines]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Upper Limit Lines
/* Purpose : This function defines upper limits for the Current, Max./Min and
/*           Average traces and for the scalar modulation parameters derived
/*           from them.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfOempEpUppLim (ViSession instrSession,
                                                                             ViInt32   Limits,
                                                                             ViReal64  EVMErrorPeak,
                                                                             ViReal64  EVMErrorRMS,
                                                                             ViReal64  magnErrorPeak,
                                                                             ViReal64  magnErrorRMS,
                                                                             ViReal64  phaseErrorPeak,
                                                                             ViReal64  phaseErrorRMS,
                                                                             ViReal64  originOffset,
                                                                             ViReal64  IQImBalance,
                                                                             ViInt32   frequencyError,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrLimits[] = {"CMM","AVER"};
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;


  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, Limits, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, EVMErrorPeak, 0, 50, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, EVMErrorRMS, 0, 50, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, magnErrorPeak, 0, 50, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, magnErrorRMS, 0, 50, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, phaseErrorPeak, 0, 180, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, phaseErrorRMS, 0, 180, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, originOffset, -100, 0, RSCMU_ERROR_PARAMETER9, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, IQImBalance, -100, 0, RSCMU_ERROR_PARAMETER10, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, frequencyError, 0, 999, RSCMU_ERROR_PARAMETER11, errorMessage);

if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
  sprintf (wrtBuf, "CONF:MOD:OEMP:EPSK:%s:LIM:SYMM:VAL %.12f,%.12f,%.12f,%.12f,%.12f,%.12f,%.12f,%.12f,%ld", StrLimits[Limits]
                                                                                          , EVMErrorPeak
                                                                                          , EVMErrorRMS
                                                                                          , magnErrorPeak
                                                                                          , magnErrorRMS
                                                                                          , phaseErrorPeak
                                                                                          , phaseErrorRMS
                                                                                          , originOffset
                                                                                          , IQImBalance
                                                                                          , frequencyError);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;
}
 //IQ Imbalance are not supported in Version >= V3.06
if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
  sprintf (wrtBuf, "CONF:MOD:OEMP:EPSK:%s:LIM:SYMM:VAL %.12f,%.12f,%.12f,%.12f,%.12f,%.12f,%.12f,%ld", StrLimits[Limits]
                                                                                          , EVMErrorPeak
                                                                                          , EVMErrorRMS
                                                                                          , magnErrorPeak
                                                                                          , magnErrorRMS
                                                                                          , phaseErrorPeak
                                                                                          , phaseErrorRMS
                                                                                          , originOffset
                                                                                          , frequencyError);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;
}

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: 95% Upper Limits
/* Purpose : This function defines upper limits for the 95 th percentile of
/*           the three quantities error vector magnitude, modulation error,
/*           and phase error. The 95 th percentile is the limit below which
/*           95% of the measured errors are located.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfOempUppLim95 (ViSession instrSession,
                                                                             ViReal64  EVM95,
                                                                             ViReal64  modulationError95,
                                                                             ViReal64  phaseError95,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_REAL64_RANGE(instrSession, EVM95, 0, 50, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, modulationError95, 0, 100, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, phaseError95, 0, 180, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:OEMP:EPSK:P95T:LIM:SYMM:VAL %.12f,%.12f,%.12f", EVM95
                                                                     , modulationError95
                                                                     , phaseError95);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Reference Power Mode
/* Purpose : this function determines the way how the reference power is
/*           calculated in 8PSK modulation.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfModEpRPMode (ViSession instrSession,
                                                     ViInt32   mode,
                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViString    list[] = {"CURR","AVER","DCOM",VI_NULL};

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_22,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  RETMSG(RSCMU300_setEnum(instrSession, "CONF:MOD:OEMP:EPSK:RPM",
                         mode, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT MODULATION OVERview
 *
 *    The subsystem MODulation[:OVERview]:EPSK measures general scalar
 *    modulation parameters in 8PSK modulation. The subsystem corresponds to
 *    the measurement menu Modulation, application Overview 8PSK, and the
 *    associated popup menu Modulation Error Config.
 * ----------------------------------------------------------------------------
 *      CONFIGURATION CONTROL
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfOverEpContDef (ViSession instrSession,
                                                                              ViBoolean DefaultValues,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DEF:MOD:OVER:EPSK:CONT %s", mode_On_Off[DefaultValues]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Scope of measurement
/* Purpose : This function defines the scope of the power measurement,
/*           combining the ...CONTrol:RMODe, ...CONTrol:STATistics, and the
/*           ...CONTrol:REPetition commands.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfOverEpScope (ViSession instrSession,
                                                                            ViInt32   MeasuredValuesType,
                                                                            ViInt32   NbBurst,
                                                                            ViInt32   repetition,
                                                                            ViInt32   NbRepetition,
                                                                            ViInt32   StopCondition,
                                                                            ViInt32   StepMode,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, repetition, 0, 2, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER7, errorMessage);

  if (repetition != RSCMU300_MULTIPLE)
    sprintf(wrtBuf, "CONF:MOD:OVER:EPSK:CONT %s,%ld,%s,%s,%s", mode_ScopeMeas[MeasuredValuesType]
                                                            , NbBurst
                                                            , repetition_meas[repetition]
                                                            , mode_StopCondition[StopCondition]
                                                            , StrStepMode[StepMode]);
  else
    sprintf(wrtBuf, "CONF:MOD:OVER:EPSK:CONT %s %ld %ld %s %s", mode_ScopeMeas[MeasuredValuesType]
                                                            , NbBurst
                                                            , NbRepetition
                                                            , mode_StopCondition[StopCondition]
                                                            , StrStepMode[StepMode]);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfOverEpContRep (ViSession instrSession,
                                                                              ViInt32   Repetition,
                                                                              ViInt32   StopCondition,
                                                                              ViInt32   StepMode,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, Repetition, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:MOD:OVER:EPSK:CONT:REP %s,%s,%s", repetition_meas[Repetition]
                                                         , mode_StopCondition[StopCondition]
                                                         , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      STATISTICS
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set statistics count and result mode
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfOverEpCont (ViSession instrSession,
                                                                           ViInt32   MeasuredValuesType,
                                                                           ViInt32   NbBurst,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:OVER:EPSK:CONT:RMOD %s", mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  sprintf (wrtBuf, "CONF:MOD:OVER:EPSK:CONT:STAT %ld", NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set the number of bursts
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfOverEpStat (ViSession instrSession,
                                                                           ViInt32   NbBurst,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:OVER:EPSK:CONT:STAT %ld", NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set result mode
/* Purpose : This function specifies the type of measured values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfOverEpResMode (ViSession instrSession,
                                                                              ViInt32   MeasuredValuesType,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:OVER:EPSK:CONT:RMOD %s", mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfOverEpContRepSt (ViSession instrSession,
                                                                                ViInt32   NbRepetition,
                                                                                ViInt32   StopCondition,
                                                                                ViInt32   StepMode,
                                                                                ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:MOD:OVER:EPSK:CONT:REP %ld,%s,%s", NbRepetition
                                                         , mode_StopCondition[StopCondition]
                                                         , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      CONTROL OF MODULATION MEAS
 *      It contains the functions for general control of the modulation
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start Modulation Measurements
/* Purpose : This function start the modulation measurement,
/*           setting it to the status beyond.
/*           RUN        Start measurement without waiting
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitOverEp (ViSession instrSession,
                                                                       ViChar _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "INIT:MOD:OVER:EPSK", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort Modulation Measurements
/* Purpose : This function abort the running modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborOverEp (ViSession instrSession,
                                                                       ViChar _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "ABOR:MOD:OVER:EPSK", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Stop Modulation Measurements
/* Purpose : This function stop measurement after current statistic cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopOverEp (ViSession instrSession,
                                                                       ViChar _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "STOP:MOD:OVER:EPSK", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Run next measurement step
/* Purpose : This function runs next modulation measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContOverEp (ViSession instrSession,
                                                                       ViChar _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CONT:MOD:OVER:EPSK", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Measurement Status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcOverEpSt (ViSession instrSession,
                                                                         ViPInt32  MeasStatus,
                                                                         ViPInt32  CurrentStatCycleCount,
                                                                         ViPInt32  CurrentEvalPeriodCount,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Fetch the measurement status:
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:MOD:OVER:EPSK:STAT?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMeasStatVal(MeasStatus, tab, 0);

  // Get the counter for current statistics cycle
  if (strcmp (tab[1], "NONE") != 0)
    sscanf (tab[1], "%ld", CurrentStatCycleCount);
  else
    *CurrentStatCycleCount = RSCMU300_OFF;

  // Get the counter for current evaluation period within a cycle
  if (strcmp (tab[2], "NONE") != 0)
    sscanf (tab[2], "%ld", CurrentEvalPeriodCount);
  else *CurrentEvalPeriodCount = RSCMU300_OFF;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfOverEpErep (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:OVER:EPSK:EREP %s", StrErep[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      Subsystem MODulation[:OVERview]:EPSK[:TCH][:RESult]
 *      The subsystem MODulation[:OVERview]:EPSK[:TCH][:RESULT] measures and
 *      returns the modulation parameters and compares them with the tolerance
 *      values. The subsystem corresponds to the various output elements in
 *      the measurement menu MODulation, application Overview 8PSK.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all
/*           scalar measurement results (see chapter 4). The calculation of
/*           results in an average or peak measurement is described in chapter
/*           3 (see calculation of statistical quantities). The symbol (x3)
/*           behind a value indicates that the list contains three results
/*           corresponding to the Current, the Average, and the MMax value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadOverEp (ViSession instrSession,
                                                                       ViInt32   StatisticsMode,
                                                                       ViPReal64 EVM95,
                                                                       ViPReal64 MagErr95,
                                                                       ViPReal64 PhaseErr95,
                                                                       ViPReal64 EVMPeak,
                                                                       ViPReal64 EVMRMS,
                                                                       ViPReal64 magnErrorPeak,
                                                                       ViPReal64 magnErrorRMS,
                                                                       ViPReal64 phaseErrorPeak,
                                                                       ViPReal64 phaseErrorRMS,
                                                                       ViPReal64 originOffset,
                                                                       ViPReal64 IQIm_balance,
                                                                       ViPReal64 frequencyError,
                                                                       ViPReal64 avgBurstPowerCurr,
                                                                       ViPReal64 burstOutOfTol,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:MOD:OVER:EPSK?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanOverEpsk (tab, 0, StatisticsMode, EVM95, MagErr95, PhaseErr95, EVMPeak, EVMRMS, magnErrorPeak,
                                 magnErrorRMS, phaseErrorPeak, phaseErrorRMS, originOffset, IQIm_balance, frequencyError,
                                 avgBurstPowerCurr, burstOutOfTol);
    }
 //IQ Imbalance are not supported in Version >= V3.06
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
      RSCMU300_Status = RSCMU300_ScanOverEpskV306 (tab, 0, StatisticsMode, EVM95, MagErr95, PhaseErr95, EVMPeak, EVMRMS, magnErrorPeak,
                                 magnErrorRMS, phaseErrorPeak, phaseErrorRMS, originOffset, IQIm_balance, frequencyError,
                                 avgBurstPowerCurr, burstOutOfTol);
    }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all
/*           scalar measurement results (see chapter 4). The calculation of
/*           results in an average or peak measurement is described in chapter
/*           3 (see calculation of statistical quantities). The symbol (x3)
/*           behind a value indicates that the list contains three results
/*           corresponding to the Current, the Average, and the MMax value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcOverEp (ViSession instrSession,
                                                                       ViInt32   StatisticsMode,
                                                                       ViPReal64 EVM95,
                                                                       ViPReal64 MagErr95,
                                                                       ViPReal64 PhaseErr95,
                                                                       ViPReal64 EVMPeak,
                                                                       ViPReal64 EVMRMS,
                                                                       ViPReal64 magnErrorPeak,
                                                                       ViPReal64 magnErrorRMS,
                                                                       ViPReal64 phaseErrorPeak,
                                                                       ViPReal64 phaseErrorRMS,
                                                                       ViPReal64 originOffset,
                                                                       ViPReal64 IQIm_balance,
                                                                       ViPReal64 frequencyError,
                                                                       ViPReal64 avgBurstPowerCurr,
                                                                       ViPReal64 burstOutOfTol,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:MOD:OVER:EPSK?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanOverEpsk (tab, 0, StatisticsMode, EVM95, MagErr95, PhaseErr95, EVMPeak, EVMRMS, magnErrorPeak,
                                 magnErrorRMS, phaseErrorPeak, phaseErrorRMS, originOffset, IQIm_balance, frequencyError,
                                 avgBurstPowerCurr, burstOutOfTol);
    }
 //IQ Imbalance are not supported in Version >= V3.06
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
      RSCMU300_Status = RSCMU300_ScanOverEpskV306 (tab, 0, StatisticsMode, EVM95, MagErr95, PhaseErr95, EVMPeak, EVMRMS, magnErrorPeak,
                                 magnErrorRMS, phaseErrorPeak, phaseErrorRMS, originOffset, IQIm_balance, frequencyError,
                                 avgBurstPowerCurr, burstOutOfTol);
    }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all
/*           scalar measurement results (see chapter 4). The calculation of
/*           results in an average or peak measurement is described in chapter
/*           3 (see calculation of statistical quantities). The symbol (x3)
/*           behind a value indicates that the list contains three results
/*           corresponding to the Current, the Average, and the MMax value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampOverEp (ViSession instrSession,
                                                                       ViInt32   StatisticsMode,
                                                                       ViPReal64 EVM95,
                                                                       ViPReal64 MagErr95,
                                                                       ViPReal64 PhaseErr95,
                                                                       ViPReal64 EVMPeak,
                                                                       ViPReal64 EVMRMS,
                                                                       ViPReal64 magnErrorPeak,
                                                                       ViPReal64 magnErrorRMS,
                                                                       ViPReal64 phaseErrorPeak,
                                                                       ViPReal64 phaseErrorRMS,
                                                                       ViPReal64 originOffset,
                                                                       ViPReal64 IQIm_balance,
                                                                       ViPReal64 frequencyError,
                                                                       ViPReal64 avgBurstPowerCurr,
                                                                       ViPReal64 burstOutOfTol,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:MOD:OVER:EPSK?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanOverEpsk (tab, 0, StatisticsMode, EVM95, MagErr95, PhaseErr95, EVMPeak, EVMRMS, magnErrorPeak,
                                 magnErrorRMS, phaseErrorPeak, phaseErrorRMS, originOffset, IQIm_balance, frequencyError,
                                 avgBurstPowerCurr, burstOutOfTol);
    }
 //IQ Imbalance are not supported in Version >= V3.06
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
      RSCMU300_Status = RSCMU300_ScanOverEpskV306 (tab, 0, StatisticsMode, EVM95, MagErr95, PhaseErr95, EVMPeak, EVMRMS, magnErrorPeak,
                                 magnErrorRMS, phaseErrorPeak, phaseErrorRMS, originOffset, IQIm_balance, frequencyError,
                                 avgBurstPowerCurr, burstOutOfTol);
    }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcOverEpMatcLim (ViSession instrSession,
                                                                              ViInt32   StatisticsMode,
                                                                              ViPInt32  EVM95,
                                                                              ViPInt32  MagErr95,
                                                                              ViPInt32  PhaseErr95,
                                                                              ViPInt32  EVMPeak,
                                                                              ViPInt32  EVMRMS,
                                                                              ViPInt32  magnErrorPeak,
                                                                              ViPInt32  magnErrorRMS,
                                                                              ViPInt32  phaseErrorPeak,
                                                                              ViPInt32  phaseErrorRMS,
                                                                              ViPInt32  originOffset,
                                                                              ViPInt32  IQIm_balance,
                                                                              ViPInt32  frequencyError,
                                                                              ViPInt32  avgBurstPowerCurr,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CALC:MOD:OVER:EPSK:MATC:LIM?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // 95% EVM with single-value measurement
  RSCMU300_Status = RSCMU300_GetMatchingValue(EVM95,tab,0);

  // 95% Magnitude Error with single-value measurement
  RSCMU300_Status = RSCMU300_GetMatchingValue(MagErr95,tab,1);

  // 95% Phase Error with single-value measurement
  RSCMU300_Status = RSCMU300_GetMatchingValue(PhaseErr95,tab,2);

  switch (StatisticsMode)
  {
    case RSCMU300_CURRENT:
        // EVM peak with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(EVMPeak,tab,3);

        // EVM RMS with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(EVMRMS,tab,6);

        // Magnitude Error Peak with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(magnErrorPeak,tab,9);

        // Magnitude Error RMS with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(magnErrorRMS,tab,12);

        // Phase Error Peak with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorPeak,tab,15);

        // Phase Error RMS with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorRMS,tab,18);

        // Origin Offset with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(originOffset,tab,21);

        if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
            {
            // IQ/IM Balance with single-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(IQIm_balance,tab,24);

            // Frequency Error with single-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,27);
            }
        else
            {
            // IQ/IM Balance with single-value measurement
            *IQIm_balance= RSCMU300_INV;

            // Frequency Error with single-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,24);
            }
    break;

    case RSCMU300_AVERAGE:
        // EVM peak with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(EVMPeak,tab,4);

        // EVM RMS with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(EVMRMS,tab,7);

        // Magnitude Error Peak with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(magnErrorPeak,tab,10);

        // Magnitude Error RMS with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(magnErrorRMS,tab,13);

        // Phase Error Peak with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorPeak,tab,16);

        // Phase Error RMS with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorRMS,tab,19);

        // Origin Offset with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(originOffset,tab,22);

        if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
            {
            // IQ/IM Balance with average measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(IQIm_balance,tab,25);

            // Frequency Error with average measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,28);
            }
        else
            {
            // IQ/IM Balance with average measurement
            *IQIm_balance= RSCMU300_INV;

            // Frequency Error with average measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,25);
            }
    break;

    case RSCMU300_MAXMIN:
        // EVM peak with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(EVMPeak,tab,5);

        // EVM RMS with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(EVMRMS,tab,7);

        // Magnitude Error Peak with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(magnErrorPeak,tab,11);

        // Magnitude Error RMS with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(magnErrorRMS,tab,14);

        // Phase Error Peak with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorPeak,tab,17);

        // Phase Error RMS with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorRMS,tab,20);

        // Origin Offset with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(originOffset,tab,23);

        if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
            {
            // IQ/IM Balance with extreme-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(IQIm_balance,tab,26);

            // Frequency Error with extreme-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,29);
            }
        else
            {
            // IQ/IM Balance with extreme-value measurement
            *IQIm_balance= RSCMU300_INV;

            // Frequency Error with extreme-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,26);
            }
    break;
  }

    if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
        {
        // Average Burst Power Current with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(avgBurstPowerCurr,tab,30);
        }
    else
        {
        // Average Burst Power Current with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(avgBurstPowerCurr,tab,27);
        }
  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT MODULATION EVMagnitude
 *
 *    The subsystem MODulation:EVMagnitude measures the error vector magnitude
 *    as well as general scalar modulation parameters. The subsystem corresponds
 *    to the measurement menu Modulation, application Error Vect. Magn. 8PSK,
 *    and the associated popup menu Modulation Error Config.
 * ----------------------------------------------------------------------------
 *      CONFIGURATION CONTROL
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfEvmEpContDef (ViSession instrSession,
                                                                             ViBoolean DefaultValues,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DEF:MOD:EVM:EPSK:CONT %s", mode_On_Off[DefaultValues]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Scope of measurement
/* Purpose : This function defines the scope of the power measurement,
/*           combining the ...CONTrol:RMODe, ...CONTrol:STATistics, and the
/*           ...CONTrol:REPetition commands.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfEvmEpScope (ViSession instrSession,
                                                                           ViInt32   MeasuredValuesType,
                                                                           ViInt32   NbBurst,
                                                                           ViInt32   repetition,
                                                                           ViInt32   NbRepetition,
                                                                           ViInt32   StopCondition,
                                                                           ViInt32   StepMode,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, repetition, 0, 2, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER7, errorMessage);

  if (repetition != RSCMU300_MULTIPLE)
    sprintf(wrtBuf, "CONF:MOD:EVM:EPSK:CONT %s,%ld,%s,%s,%s", mode_ScopeMeas[MeasuredValuesType]
                                                           , NbBurst
                                                           , repetition_meas[repetition]
                                                           , mode_StopCondition[StopCondition]
                                                           , StrStepMode[StepMode]);
  else
    sprintf(wrtBuf, "CONF:MOD:EVM:EPSK:CONT %s %ld %ld %s %s", mode_ScopeMeas[MeasuredValuesType]
                                                           , NbBurst
                                                           , NbRepetition
                                                           , mode_StopCondition[StopCondition]
                                                           , StrStepMode[StepMode]);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfEvmEpContRep (ViSession instrSession,
                                                                             ViInt32   Repetition,
                                                                             ViInt32   StopCondition,
                                                                             ViInt32   StepMode,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, Repetition, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:MOD:EVM:EPSK:CONT:REP %s,%s,%s", repetition_meas[Repetition]
                                                        , mode_StopCondition[StopCondition]
                                                        , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      STATISTICS
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set statistics count and result mode
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfEvmEpCont (ViSession instrSession,
                                                                          ViInt32   MeasuredValuesType,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:EVM:EPSK:CONT:RMOD %s", mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  sprintf (wrtBuf, "CONF:MOD:EVM:EPSK:CONT:STAT %ld", NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set the number of bursts
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfEvmEpStat (ViSession instrSession,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:EVM:EPSK:CONT:STAT %ld", NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set result mode
/* Purpose : This function specifies the type of measured values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfEvmEpResMode (ViSession instrSession,
                                                                             ViInt32   MeasuredValuesType,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:EVM:EPSK:CONT:RMOD %s", mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfEvmEpContRepSt (ViSession instrSession,
                                                                               ViInt32   NbRepetition,
                                                                               ViInt32   StopCondition,
                                                                               ViInt32   StepMode,
                                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:MOD:EVM:EPSK:CONT:REP %ld,%s,%s", NbRepetition
                                                        , mode_StopCondition[StopCondition]
                                                        , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Definition of Subarrays
/* Purpose : This function configures the READ:SUBarrays.., FETCh:SUBarrays..,
/*           and SAMPle:SUBarrays:MODulation:EVMagnitude:EPSK[:TCH] commands.
/*           It restricts the measurement to up to 32 subranges where either
/*           all measurement results (the number of which is given by the
/*           second numerical parameter) or a single statistical value is
/*           returned. The subranges are defined by the start time and the
/*           number of test points which are located on a fixed, equidistant
/*           grid with a step width of  Bit.
/*           The subranges may overlap but must be within the total range of
/*           the Modulation measurement. Test points outside this range are
/*           not measured (result NAN) and do not enter into the ARIThmetical,
/*           MINimum and MAXimum values.
/*           By default, only one range corresponding to the total measurement
/*           range is used and all measurement values are returned.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSubEvmEpRang (ViSession instrSession,
                                                                             ViInt32   StatisticsMode,
                                                                             ViInt32   StartTime,
                                                                             ViInt32   Samples,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"ALL","ARIT","MIN","MAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, StartTime, RSCMU300_SUBMOD_SYMB_MIN, RSCMU300_SUBMOD_SYMB_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Samples, RSCMU300_SUBMOD_EPSK_SAMPLES_MIN, RSCMU300_SUBMOD_EPSK_SAMPLES_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:MOD:EVM:EPSK %s,%ld,%ld", StrMode[StatisticsMode]
                                                   , StartTime
                                                   , Samples);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      CONTROL OF MODULATION MEAS
 *      It contains the functions for general control of the modulation
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start Modulation Measurements
/* Purpose : This function start the modulation measurement,
/*           setting it to the status beyond.
/*           RUN        Start measurement without waiting
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitEvmEp (ViSession instrSession,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "INIT:MOD:EVM:EPSK", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort Modulation Measurements
/* Purpose : This function abort the running modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborEvmEp (ViSession instrSession,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "ABOR:MOD:EVM:EPSK", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Stop Modulation Measurements
/* Purpose : This function stop measurement after current statistic cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopEvmEp (ViSession instrSession,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "STOP:MOD:EVM:EPSK", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Run next measurement step
/* Purpose : This function runs next modulation measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContEvmEp (ViSession instrSession,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CONT:MOD:EVM:EPSK", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Measurement Status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcEvmEpSt (ViSession instrSession,
                                                                        ViPInt32  MeasStatus,
                                                                        ViPInt32  CurrentStatCycleCount,
                                                                        ViPInt32  CurrentEvalPeriodCount,
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Fetch the measurement status:
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:MOD:EVM:EPSK:STAT?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMeasStatVal(MeasStatus, tab, 0);

  // Get the counter for current statistics cycle
  if (strcmp (tab[1], "NONE") != 0)
    sscanf (tab[1], "%ld", CurrentStatCycleCount);
  else
    *CurrentStatCycleCount = RSCMU300_OFF;

  // Get the counter for current evaluation period within a cycle
  if (strcmp (tab[2], "NONE") != 0)
    sscanf (tab[2], "%ld", CurrentEvalPeriodCount);
  else *CurrentEvalPeriodCount = RSCMU300_OFF;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfEvmEpErep (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:EVM:EPSK:EREP %s", StrErep[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      Subsystem MODulation[:EVMagnitude]:EPSK[:TCH][:RESult]
 *
 *      The subsystem MODulation:EVMagnitude:EPSK[:TCH][:RESULT] measures and
 *      returns the modulation parameters and compares them with the tolerance
 *      values. The subsystem corresponds to the various output elements in the
 *      measurement menu MODulation, application EVM 8PSK.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all
/*           scalar measurement results (see chapter 4). The calculation of
/*           results in an average or peak measurement is described in chapter
/*           3 (see calculation of statistical quantities). The symbol (x3)
/*           behind a value indicates that the list contains three results
/*           corresponding to the Current, the Average, and the MMax value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadEvmEp (ViSession instrSession,
                                                                      ViInt32   StatisticsMode,
                                                                      ViPReal64 EVM95,
                                                                      ViPReal64 EVMPeak,
                                                                      ViPReal64 EVMRMS,
                                                                      ViPReal64 originOffset,
                                                                      ViPReal64 IQImBalance,
                                                                      ViPReal64 frequencyError,
                                                                      ViPReal64 avgBurstPowerCurr,
                                                                      ViPReal64 avgBurstPowerAvg,
                                                                      ViPReal64 burstOutOfTol,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:MOD:EVM:EPSK?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanEvmEpsk (tab, 0, StatisticsMode, EVM95, EVMPeak, EVMRMS, originOffset, IQImBalance, frequencyError,
                                    avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }
 //IQ Imbalance are not supported in Version >= V3.06
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanEvmEpskV306 (tab, 0, StatisticsMode, EVM95, EVMPeak, EVMRMS, originOffset, IQImBalance, frequencyError,
                                    avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all
/*           scalar measurement results (see chapter 4). The calculation of
/*           results in an average or peak measurement is described in chapter
/*           3 (see calculation of statistical quantities). The symbol (x3)
/*           behind a value indicates that the list contains three results
/*           corresponding to the Current, the Average, and the MMax value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcEvmEp (ViSession instrSession,
                                                                      ViInt32   StatisticsMode,
                                                                      ViPReal64 EVM95,
                                                                      ViPReal64 EVMPeak,
                                                                      ViPReal64 EVMRMS,
                                                                      ViPReal64 originOffset,
                                                                      ViPReal64 IQImBalance,
                                                                      ViPReal64 frequencyError,
                                                                      ViPReal64 avgBurstPowerCurr,
                                                                      ViPReal64 avgBurstPowerAvg,
                                                                      ViPReal64 burstOutOfTol,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:MOD:EVM:EPSK?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanEvmEpsk (tab, 0, StatisticsMode, EVM95, EVMPeak, EVMRMS, originOffset, IQImBalance, frequencyError,
                                    avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }
 //IQ Imbalance are not supported in Version >= V3.06
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanEvmEpskV306 (tab, 0, StatisticsMode, EVM95, EVMPeak, EVMRMS, originOffset, IQImBalance, frequencyError,
                                    avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all
/*           scalar measurement results (see chapter 4). The calculation of
/*           results in an average or peak measurement is described in chapter
/*           3 (see calculation of statistical quantities). The symbol (x3)
/*           behind a value indicates that the list contains three results
/*           corresponding to the Current, the Average, and the MMax value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampEvmEp (ViSession instrSession,
                                                                      ViInt32   StatisticsMode,
                                                                      ViPReal64 EVM95,
                                                                      ViPReal64 EVMPeak,
                                                                      ViPReal64 EVMRMS,
                                                                      ViPReal64 originOffset,
                                                                      ViPReal64 IQImBalance,
                                                                      ViPReal64 frequencyError,
                                                                      ViPReal64 avgBurstPowerCurr,
                                                                      ViPReal64 avgBurstPowerAvg,
                                                                      ViPReal64 burstOutOfTol,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:MOD:EVM:EPSK?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanEvmEpsk (tab, 0, StatisticsMode, EVM95, EVMPeak, EVMRMS, originOffset, IQImBalance, frequencyError,
                                    avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }
 //IQ Imbalance are not supported in Version >= V3.06
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanEvmEpskV306 (tab, 0, StatisticsMode, EVM95, EVMPeak, EVMRMS, originOffset, IQImBalance, frequencyError,
                                    avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcEvmEpMatcLim (ViSession instrSession,
                                                                             ViInt32   StatisticsMode,
                                                                             ViPInt32  EVM95,
                                                                             ViPInt32  phaseErrorPeak,
                                                                             ViPInt32  phaseErrorRMS,
                                                                             ViPInt32  originOffset,
                                                                             ViPInt32  IQImBalance,
                                                                             ViPInt32  frequencyError,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CALC:MOD:EVM:EPSK:MATC:LIM?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // 95% EVM with single-value measurement
  RSCMU300_Status = RSCMU300_GetMatchingValue(EVM95,tab,0);

  switch (StatisticsMode)
  {
    case RSCMU300_CURRENT:
        // Phase Error Peak with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorPeak,tab,1);

        // Phase Error RMS with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorRMS,tab,4);

        // Origin Offset with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(originOffset,tab,7);

        if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
            {
            // IQ/Im Balance with single-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(IQImBalance,tab,10);

            // Frequency Error with single-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,13);
            }
        else
            {
            // IQ/Im Balance with single-value measurement
            *IQImBalance= RSCMU300_INV;

            // Frequency Error with single-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,10);
            }
    break;

    case RSCMU300_AVERAGE:
        // Phase Error Peak with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorPeak,tab,2);

        // Phase Error RMS with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorRMS,tab,5);

        // Origin Offset with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(originOffset,tab,8);

        if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
            {
            // IQ/Im Balance with average measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(IQImBalance,tab,11);

            // Frequency Error with average measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,14);
            }
        else
            {
            // IQ/Im Balance with average measurement
            *IQImBalance= RSCMU300_INV;

            // Frequency Error with average measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,11);
            }
    break;

    case RSCMU300_MAXMIN:
        // Phase Error Peak with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorPeak,tab,3);

        // Phase Error RMS with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorRMS,tab,6);

        // Origin Offset with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(originOffset,tab,9);

        if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
            {
            // IQ/Im Balance with extreme-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(IQImBalance,tab,12);

            // Frequency Error with extreme-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,15);
            }
        else
            {
            // IQ/Im Balance with extreme-value measurement
            *IQImBalance= RSCMU300_INV;

            // Frequency Error with extreme-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,12);
            }
    break;
  }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Phase Error in Burst...
/* Purpose : This function returns the error vector magnitude vs. time at
/*           fixed, equidistant test points. The number of measured values is
/*           142, corresponding to a time range of 3 symb to 144 symb. The
/*           calculation of Current, Average, and MMax (Min./Max.) results is
/*           explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrEvmEp (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  EVMValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      EVMValuesTmp[143][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:ARR:MOD:EVM:EPSK:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, EVMValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,EVMValuesTmp,EVMValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Phase Error in Burst...
/* Purpose : This function returns the error vector magnitude vs. time at
/*           fixed, equidistant test points. The number of measured values is
/*           142, corresponding to a time range of 3 symb to 144 symb. The
/*           calculation of Current, Average, and MMax (Min./Max.) results is
/*           explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrEvmEp (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  EVMValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      EVMValuesTmp[143][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:ARR:MOD:EVM:EPSK:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, EVMValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,EVMValuesTmp,EVMValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample Phase Error in Burst...
/* Purpose : This function returns the error vector magnitude vs. time at
/*           fixed, equidistant test points. The number of measured values is
/*           142, corresponding to a time range of 3 symb to 144 symb. The
/*           calculation of Current, Average, and MMax (Min./Max.) results is
/*           explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrEvmEp (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  EVMValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      EVMValuesTmp[143][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:ARR:MOD:EVM:EPSK:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, EVMValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,EVMValuesTmp,EVMValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Subarray
/* Purpose : this function measures and returns the error vector magnitude
/*           versus time in the subranges defined by means of the CONFigure:
/*           SUBarrays:MODulation:EVMagnitude:EPSK[:TCH] command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSubEvmEp (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  EVMValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      EVMValuesTmp[143][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:SUB:MOD:EVM:EPSK:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, EVMValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,EVMValuesTmp,EVMValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Subarray
/* Purpose : this function measures and returns the error vector magnitude
/*           versus time in the subranges defined by means of the CONFigure:
/*           SUBarrays:MODulation:EVMagnitude:EPSK[:TCH] command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSubEvmEp (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  EVMValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      EVMValuesTmp[143][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:SUB:MOD:EVM:EPSK:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, EVMValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,EVMValuesTmp,EVMValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample Subarray
/* Purpose : this function measures and returns the error vector magnitude
/*           versus time in the subranges defined by means of the CONFigure:
/*           SUBarrays:MODulation:EVMagnitude:EPSK[:TCH] command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSubEvmEp (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  EVMValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      EVMValuesTmp[143][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:SUB:MOD:EVM:EPSK:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, EVMValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,EVMValuesTmp,EVMValues);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT MODULATION PERRor
 *
 *    The subsystem MODulation:PERRor measures the phase error as well as
 *    general scalar modulation parameters. The subsystem corresponds to the
 *    measurement menu Modulation, application Phase Error 8PSK, and the
 *    associated popup menu Modulation Error Config.
 * ----------------------------------------------------------------------------
 *      CONFIGURATION CONTROL
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrEpContDef (ViSession instrSession,
                                                                              ViBoolean DefaultValues,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DEF:MOD:PERR:EPSK:CONT %s", mode_On_Off[DefaultValues]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Scope of measurement
/* Purpose : This function defines the scope of the power measurement,
/*           combining the ...CONTrol:RMODe, ...CONTrol:STATistics, and the
/*           ...CONTrol:REPetition commands.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrEpScope (ViSession instrSession,
                                                                            ViInt32   MeasuredValuesType,
                                                                            ViInt32   NbBurst,
                                                                            ViInt32   repetition,
                                                                            ViInt32   NbRepetition,
                                                                            ViInt32   StopCondition,
                                                                            ViInt32   StepMode,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, repetition, 0, 2, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER7, errorMessage);

  if (repetition != RSCMU300_MULTIPLE)
    sprintf(wrtBuf, "CONF:MOD:PERR:EPSK:CONT %s,%ld,%s,%s,%s", mode_ScopeMeas[MeasuredValuesType]
                                                            , NbBurst
                                                            , repetition_meas[repetition]
                                                            , mode_StopCondition[StopCondition]
                                                            , StrStepMode[StepMode]);
  else
    sprintf(wrtBuf, "CONF:MOD:PERR:EPSK:CONT %s %ld %ld %s %s", mode_ScopeMeas[MeasuredValuesType]
                                                            , NbBurst
                                                            , NbRepetition
                                                            , mode_StopCondition[StopCondition]
                                                            , StrStepMode[StepMode]);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrEpContRep (ViSession instrSession,
                                                                              ViInt32   Repetition,
                                                                              ViInt32   StopCondition,
                                                                              ViInt32   StepMode,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, Repetition, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:MOD:PERR:EPSK:CONT:REP %s,%s,%s", repetition_meas[Repetition]
                                                         , mode_StopCondition[StopCondition]
                                                         , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      STATISTICS
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set statistics count and result mode
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrEpCont (ViSession instrSession,
                                                                           ViInt32   MeasuredValuesType,
                                                                           ViInt32   NbBurst,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:PERR:EPSK:CONT:RMOD %s", mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  sprintf (wrtBuf, "CONF:MOD:PERR:EPSK:CONT:STAT %ld", NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set the number of bursts
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrEpStat (ViSession instrSession,
                                                                           ViInt32   NbBurst,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:PERR:EPSK:CONT:STAT %ld", NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set result mode
/* Purpose : This function specifies the type of measured values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrEpResMode (ViSession instrSession,
                                                                              ViInt32   MeasuredValuesType,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:PERR:EPSK:CONT:RMOD %s", mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrEpContRepSt (ViSession instrSession,
                                                                                ViInt32   NbRepetition,
                                                                                ViInt32   StopCondition,
                                                                                ViInt32   StepMode,
                                                                                ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:MOD:PERR:EPSK:CONT:REP %ld,%s,%s", NbRepetition
                                                         , mode_StopCondition[StopCondition]
                                                         , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Definition of Subarrays
/* Purpose : This function configures the READ:SUBarrays.., FETCh:SUBarrays..,
/*           and SAMPle:SUBarrays:MODulation:PERRor:EPSK[:TCH] commands. It
/*           restricts the measurement to up to 32 subranges where either all
/*           measurement results (the number of which is given by the second
/*           numerical parameter) or a single statistical value is returned.
/*           The subranges are defined by the start time and the number of
/*           test points which are located on a fixed, equidistant grid with
/*           a step width of  Bit. The subranges may overlap but must be
/*           within the total range of the Modulation measurement. Test
/*           points outside this range are not measured (result NAN) and do
/*           not enter into the ARIThmetical, MINimum and MAXimum values.
/*           By default, only one range corresponding to the total measurement
/*           range is used and all measurement values are returned.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSubPerrEpRang (ViSession instrSession,
                                                                              ViInt32   StatisticsMode,
                                                                              ViInt32   StartTime,
                                                                              ViInt32   Samples,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"ALL","ARIT","MIN","MAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, StartTime, RSCMU300_SUBMOD_SYMB_MIN, RSCMU300_SUBMOD_SYMB_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Samples, RSCMU300_SUBMOD_EPSK_SAMPLES_MIN, RSCMU300_SUBMOD_EPSK_SAMPLES_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:MOD:PERR:EPSK %s,%ld,%ld", StrMode[StatisticsMode]
                                                    , StartTime
                                                    , Samples);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      CONTROL OF MODULATION MEAS
 *      It contains the functions for general control of the modulation
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start Modulation Measurements
/* Purpose : This function start the modulation measurement,
/*           setting it to the status beyond.
/*           RUN        Start measurement without waiting
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitPerrEp (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "INIT:MOD:PERR:EPSK", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort Modulation Measurements
/* Purpose : This function abort the running modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborPerrEp (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "ABOR:MOD:PERR:EPSK", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Stop Modulation Measurements
/* Purpose : This function stop measurement after current statistic cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopPerrEp (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "STOP:MOD:PERR:EPSK", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Run next measurement step
/* Purpose : This function runs next modulation measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContPerrEp (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CONT:MOD:PERR:EPSK", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Measurement Status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcPerrEpSt (ViSession instrSession,
                                                                         ViPInt32  MeasStatus,
                                                                         ViPInt32  CurrentStatCycleCount,
                                                                         ViPInt32  CurrentEvalPeriodCount,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Fetch the measurement status:
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:MOD:PERR:EPSK:STAT?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMeasStatVal(MeasStatus, tab, 0);

  // Get the counter for current statistics cycle
  if (strcmp (tab[1], "NONE") != 0)
    sscanf (tab[1], "%ld", CurrentStatCycleCount);
  else
    *CurrentStatCycleCount = RSCMU300_OFF;

  // Get the counter for current evaluation period within a cycle
  if (strcmp (tab[2], "NONE") != 0)
    sscanf (tab[2], "%ld", CurrentEvalPeriodCount);
  else *CurrentEvalPeriodCount = RSCMU300_OFF;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrEpErep (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:PERR:EPSK:EREP %s", StrErep[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      Subsystem MODulation:PERRor:EPSK[:TCH][:RESult]
 *
 *      The subsystem MODulation:PERRor:EPSK[:TCH][:RESULT] measures and returns
 *      the modulation parameters and compares them with the tolerance values.
 *      The subsystem corresponds to the various output elements in the
 *      measurement menu MODulation, application Phase Error 8PSK.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadPerrEp (ViSession instrSession,
                                                                       ViInt32   StatisticsMode,
                                                                       ViPReal64 PhaseError95,
                                                                       ViPReal64 phaseErrorPeak,
                                                                       ViPReal64 phaseErrorRMS,
                                                                       ViPReal64 originOffset,
                                                                       ViPReal64 IQImBalance,
                                                                       ViPReal64 frequencyError,
                                                                       ViPReal64 avgBurstPowerCurr,
                                                                       ViPReal64 avgBurstPowerAvg,
                                                                       ViPReal64 burstOutOfTol,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:MOD:PERR:EPSK?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanPerrEpsk (tab, 0, StatisticsMode, PhaseError95, phaseErrorPeak, phaseErrorRMS, originOffset,
                                     IQImBalance, frequencyError, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }
 //IQ Imbalance are not supported in Version >= V3.06
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanPerrEpskV306 (tab, 0, StatisticsMode, PhaseError95, phaseErrorPeak, phaseErrorRMS, originOffset,
                                     IQImBalance, frequencyError, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcPerrEp (ViSession instrSession,
                                                                       ViInt32   StatisticsMode,
                                                                       ViPReal64 PhaseError95,
                                                                       ViPReal64 phaseErrorPeak,
                                                                       ViPReal64 phaseErrorRMS,
                                                                       ViPReal64 originOffset,
                                                                       ViPReal64 IQImBalance,
                                                                       ViPReal64 frequencyError,
                                                                       ViPReal64 avgBurstPowerCurr,
                                                                       ViPReal64 avgBurstPowerAvg,
                                                                       ViPReal64 burstOutOfTol,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:MOD:PERR:EPSK?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanPerrEpsk (tab, 0, StatisticsMode, PhaseError95, phaseErrorPeak, phaseErrorRMS, originOffset,
                                     IQImBalance, frequencyError, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }
 //IQ Imbalance are not supported in Version >= V3.06
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanPerrEpskV306 (tab, 0, StatisticsMode, PhaseError95, phaseErrorPeak, phaseErrorRMS, originOffset,
                                     IQImBalance, frequencyError, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampPerrEp (ViSession instrSession,
                                                                       ViInt32   StatisticsMode,
                                                                       ViPReal64 PhaseError95,
                                                                       ViPReal64 phaseErrorPeak,
                                                                       ViPReal64 phaseErrorRMS,
                                                                       ViPReal64 originOffset,
                                                                       ViPReal64 IQImBalance,
                                                                       ViPReal64 frequencyError,
                                                                       ViPReal64 avgBurstPowerCurr,
                                                                       ViPReal64 avgBurstPowerAvg,
                                                                       ViPReal64 burstOutOfTol,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:MOD:PERR:EPSK?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanPerrEpsk (tab, 0, StatisticsMode, PhaseError95, phaseErrorPeak, phaseErrorRMS, originOffset,
                                     IQImBalance, frequencyError, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }
 //IQ Imbalance are not supported in Version >= V3.06
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanPerrEpskV306 (tab, 0, StatisticsMode, PhaseError95, phaseErrorPeak, phaseErrorRMS, originOffset,
                                     IQImBalance, frequencyError, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcPerrEpMatcLim (ViSession instrSession,
                                                                              ViInt32   StatisticsMode,
                                                                              ViPInt32  PhaseError95,
                                                                              ViPInt32  phaseErrorPeak,
                                                                              ViPInt32  phaseErrorRMS,
                                                                              ViPInt32  originOffset,
                                                                              ViPInt32  IQImBalance,
                                                                              ViPInt32  frequencyError,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CALC:MOD:PERR:EPSK:MATC:LIM?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // 95% Phase Error with single-value measurement
  RSCMU300_Status = RSCMU300_GetMatchingValue(PhaseError95,tab,0);

  switch (StatisticsMode)
  {
    case RSCMU300_CURRENT:
        // Phase Error Peak with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorPeak,tab,1);

        // Phase Error RMS with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorRMS,tab,4);

        // Origin Offset with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(originOffset,tab,7);

        if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
            {
            // IQ/Im Balance with single-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(IQImBalance,tab,10);

            // Frequency Error with single-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,13);
            }
        else
            {
            // IQ/Im Balance with single-value measurement
            *IQImBalance= RSCMU300_INV;

            // Frequency Error with single-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,10);
            }
    break;

    case RSCMU300_AVERAGE:
        // Phase Error Peak with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorPeak,tab,2);

        // Phase Error RMS with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorRMS,tab,5);

        // Origin Offset with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(originOffset,tab,8);

        if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
            {
            // IQ/Im Balance with average measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(IQImBalance,tab,11);

            // Frequency Error with average measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,14);
            }
        else
            {
            // IQ/Im Balance with average measurement
            *IQImBalance= RSCMU300_INV;

            // Frequency Error with average measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,11);
            }
    break;

    case RSCMU300_MAXMIN:
        // Phase Error Peak with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorPeak,tab,3);

        // Phase Error RMS with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorRMS,tab,6);

        // Origin Offset with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(originOffset,tab,9);

        if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
            {
            // IQ/Im Balance with extreme-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(IQImBalance,tab,12);

            // Frequency Error with extreme-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,15);
            }
        else
            {
            // IQ/Im Balance with extreme-value measurement
            *IQImBalance= RSCMU300_INV;

            // Frequency Error with extreme-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,12);
            }
    break;
  }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Phase Error in Burst...
/* Purpose : This function returns the the phase error vs. time at fixed,
/*           equidistant test points. The number of measured values is 142,
/*           corresponding to a time range of 3 symb to 144 symb.
/*           The calculation of CURRent, AVERage, and MMAX (Min./Max.)
/*           results is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrPerrEp (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViReal64  phaseErrorValues[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      phaseErrorValuesTmp[143][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:ARR:MOD:PERR:EPSK:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, phaseErrorValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,phaseErrorValuesTmp,phaseErrorValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Phase Error in Burst...
/* Purpose : This function returns the the phase error vs. time at fixed,
/*           equidistant test points. The number of measured values is 142,
/*           corresponding to a time range of 3 symb to 144 symb.
/*           The calculation of CURRent, AVERage, and MMAX (Min./Max.)
/*           results is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrPerrEp (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViReal64  phaseErrorValues[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      phaseErrorValuesTmp[143][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:ARR:MOD:PERR:EPSK:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, phaseErrorValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,phaseErrorValuesTmp,phaseErrorValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample Phase Error in Burst...
/* Purpose : This function returns the the phase error vs. time at fixed,
/*           equidistant test points. The number of measured values is 142,
/*           corresponding to a time range of 3 symb to 144 symb.
/*           The calculation of CURRent, AVERage, and MMAX (Min./Max.)
/*           results is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrPerrEp (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViReal64  phaseErrorValues[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      phaseErrorValuesTmp[143][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:ARR:MOD:PERR:EPSK:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, phaseErrorValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,phaseErrorValuesTmp,phaseErrorValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Subarray
/* Purpose : This function measures and returns the phase error versus time
/*           in the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:PERRor:EPSK[:TCH] command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSubPerrEp (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViReal64  phaseErrorValues[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      phaseErrorValuesTmp[143][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:SUB:MOD:PERR:EPSK:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, phaseErrorValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,phaseErrorValuesTmp,phaseErrorValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Subarray
/* Purpose : This function measures and returns the phase error versus time
/*           in the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:PERRor:EPSK[:TCH] command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSubPerrEp (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViReal64  phaseErrorValues[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      phaseErrorValuesTmp[143][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:SUB:MOD:PERR:EPSK:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, phaseErrorValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,phaseErrorValuesTmp,phaseErrorValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample Subarray
/* Purpose : This function measures and returns the phase error versus time
/*           in the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:PERRor:EPSK[:TCH] command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSubPerrEp (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViReal64  phaseErrorValues[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      phaseErrorValuesTmp[143][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:SUB:MOD:PERR:EPSK:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, phaseErrorValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,phaseErrorValuesTmp,phaseErrorValues);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT MODULATION MERRor
 *
 *    The subsystem MODulation:MERRor controls the modulation measurement.
 *    It corresponds to the softkey Magn. Error 8PSK in the measurement menu
 *    Modulation.
 * ----------------------------------------------------------------------------
 *      CONFIGURATION CONTROL
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfMerrEpContDef (ViSession instrSession,
                                                                              ViBoolean DefaultValues,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DEF:MOD:MERR:EPSK:CONT %s", mode_On_Off[DefaultValues]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Scope of measurement
/* Purpose : This function defines the scope of the power measurement,
/*           combining the ...CONTrol:RMODe, ...CONTrol:STATistics, and the
/*           ...CONTrol:REPetition commands.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfMerrEpScope (ViSession instrSession,
                                                                            ViInt32   MeasuredValuesType,
                                                                            ViInt32   NbBurst,
                                                                            ViInt32   repetition,
                                                                            ViInt32   NbRepetition,
                                                                            ViInt32   StopCondition,
                                                                            ViInt32   StepMode,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, repetition, 0, 2, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER7, errorMessage);

  if (repetition != RSCMU300_MULTIPLE)
    sprintf(wrtBuf, "CONF:MOD:MERR:EPSK:CONT %s,%ld,%s,%s,%s", mode_ScopeMeas[MeasuredValuesType]
                                                            , NbBurst
                                                            , repetition_meas[repetition]
                                                            , mode_StopCondition[StopCondition]
                                                            , StrStepMode[StepMode]);
  else
    sprintf(wrtBuf, "CONF:MOD:MERR:EPSK:CONT %s %ld %ld %s %s", mode_ScopeMeas[MeasuredValuesType]
                                                            , NbBurst
                                                            , NbRepetition
                                                            , mode_StopCondition[StopCondition]
                                                            , StrStepMode[StepMode]);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfMerrEpContRep (ViSession instrSession,
                                                                             ViInt32   Repetition,
                                                                             ViInt32   StopCondition,
                                                                             ViInt32   StepMode,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, Repetition, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:MOD:MERR:EPSK:CONT:REP %s,%s,%s", repetition_meas[Repetition]
                                                         , mode_StopCondition[StopCondition]
                                                         , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      STATISTICS
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set statistics count and result mode
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfMerrEpCont (ViSession instrSession,
                                                                           ViInt32   MeasuredValuesType,
                                                                           ViInt32   NbBurst,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:MERR:EPSK:CONT:RMOD %s", mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  sprintf (wrtBuf, "CONF:MOD:MERR:EPSK:CONT:STAT %ld", NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set the number of bursts
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfMerrEpStat (ViSession instrSession,
                                                                           ViInt32   NbBurst,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:MERR:EPSK:CONT:STAT %ld", NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set result mode
/* Purpose : This function specifies the type of measured values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfMerrEpResMode (ViSession instrSession,
                                                                              ViInt32   MeasuredValuesType,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:MERR:EPSK:CONT:RMOD %s", mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfMerrEpContRepSt (ViSession instrSession,
                                                                                ViInt32   NbRepetition,
                                                                                ViInt32   StopCondition,
                                                                                ViInt32   StepMode,
                                                                                ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:MOD:MERR:EPSK:CONT:REP %ld,%s,%s", NbRepetition
                                                         , mode_StopCondition[StopCondition]
                                                         , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Definition of Subarrays
/* Purpose : This function configures the READ:SUBarrays.., FETCh:SUBarrays..,
/*           and SAMPle:SUBarrays:MODulation:MERRor:EPSK[:TCH] commands. It
/*           restricts the measurement to up to 32 subranges where either all
/*           measurement results (the number of which is given by the second
/*           numerical parameter) or a single statistical value is returned.
/*           The subranges are defined by the start time and the number of
/*           test points which are located on a fixed, equidistant grid with
/*           a step width of  Bit. The subranges may overlap but must be
/*           within the total range of the Modulation measurement. Test
/*           points outside this range are not measured (result NAN) and do
/*           not enter into the ARIThmetical, MINimum and MAXimum values.
/*           By default, only one range corresponding to the total measurement
/*           range is used and all measurement values are returned.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSubMerrEpRang (ViSession instrSession,
                                                                              ViInt32   StatisticsMode,
                                                                              ViInt32   StartTime,
                                                                              ViInt32   Samples,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"ALL","ARIT","MIN","MAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, StartTime, RSCMU300_SUBMOD_SYMB_MIN, RSCMU300_SUBMOD_SYMB_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Samples, RSCMU300_SUBMOD_EPSK_SAMPLES_MIN, RSCMU300_SUBMOD_EPSK_SAMPLES_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:MOD:MERR:EPSK %s,%ld,%ld", StrMode[StatisticsMode]
                                                    , StartTime
                                                    , Samples);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      CONTROL OF MODULATION MEAS
 *      It contains the functions for general control of the modulation
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start Modulation Measurements
/* Purpose : This function start the modulation measurement,
/*           setting it to the status beyond.
/*           RUN        Start measurement without waiting
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitMerrEp (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "INIT:MOD:MERR:EPSK", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort Modulation Measurements
/* Purpose : This function abort the running modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborMerrEp (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "ABOR:MOD:MERR:EPSK", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Stop Modulation Measurements
/* Purpose : This function stop measurement after current statistic cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopMerrEp (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "STOP:MOD:MERR:EPSK", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Run next measurement step
/* Purpose : This function runs next modulation measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContMerrEp (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CONT:MOD:MERR:EPSK", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Measurement Status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcMerrEpSt (ViSession instrSession,
                                                                         ViPInt32  MeasStatus,
                                                                         ViPInt32  CurrentStatCycleCount,
                                                                         ViPInt32  CurrentEvalPeriodCount,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Fetch the measurement status:
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:MOD:MERR:EPSK:STAT?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMeasStatVal(MeasStatus, tab, 0);

  // Get the counter for current statistics cycle
  if (strcmp (tab[1], "NONE") != 0)
    sscanf (tab[1], "%ld", CurrentStatCycleCount);
  else
    *CurrentStatCycleCount = RSCMU300_OFF;

  // Get the counter for current evaluation period within a cycle
  if (strcmp (tab[2], "NONE") != 0)
    sscanf (tab[2], "%ld", CurrentEvalPeriodCount);
  else *CurrentEvalPeriodCount = RSCMU300_OFF;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfMerrEpErep (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:MERR:EPSK:EREP %s", StrErep[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      Subsystem MODulation:MERRor:EPSK[:TCH][:RESult]
 *
 *      The subsystem MODulation:MERRor:EPSK[:TCH][:RESULT] measures and returns
 *      the modulation parameters and compares them with the tolerance values.
 *      The subsystem corresponds to the various output elements in the
 *      measurement menu MODulation, application Magn. Error 8PSK.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities). The symbol (x3) behind
/*           a value indicates that the list contains three results corresponding
/*           to the Current, the Average, and the MMax value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadMerrEp (ViSession instrSession,
                                                                       ViInt32   StatisticsMode,
                                                                       ViPReal64 Merr95,
                                                                       ViPReal64 merrPeak,
                                                                       ViPReal64 merrRMS,
                                                                       ViPReal64 originOffset,
                                                                       ViPReal64 IQImBalance,
                                                                       ViPReal64 frequencyError,
                                                                       ViPReal64 avgBurstPowerCurr,
                                                                       ViPReal64 avgBurstPowerAvg,
                                                                       ViPReal64 burstOutOfTol,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:MOD:MERR:EPSK?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanMerrEpsk (tab, 0, StatisticsMode, Merr95, merrPeak, merrRMS, originOffset,
                                     IQImBalance, frequencyError, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }
 //IQ Imbalance are not supported in Version >= V3.06
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanMerrEpskV306 (tab, 0, StatisticsMode, Merr95, merrPeak, merrRMS, originOffset,
                                     IQImBalance, frequencyError, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities). The symbol (x3) behind
/*           a value indicates that the list contains three results corresponding
/*           to the Current, the Average, and the MMax value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcMerrEp (ViSession instrSession,
                                                                       ViInt32   StatisticsMode,
                                                                       ViPReal64 Merr95,
                                                                       ViPReal64 merrPeak,
                                                                       ViPReal64 merrRMS,
                                                                       ViPReal64 originOffset,
                                                                       ViPReal64 IQImBalance,
                                                                       ViPReal64 frequencyError,
                                                                       ViPReal64 avgBurstPowerCurr,
                                                                       ViPReal64 avgBurstPowerAvg,
                                                                       ViPReal64 burstOutOfTol,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:MOD:MERR:EPSK?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanMerrEpsk (tab, 0, StatisticsMode, Merr95, merrPeak, merrRMS, originOffset,
                                     IQImBalance, frequencyError, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }
 //IQ Imbalance are not supported in Version >= V3.06
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanMerrEpskV306 (tab, 0, StatisticsMode, Merr95, merrPeak, merrRMS, originOffset,
                                     IQImBalance, frequencyError, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities). The symbol (x3) behind
/*           a value indicates that the list contains three results corresponding
/*           to the Current, the Average, and the MMax value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampMerrEp (ViSession instrSession,
                                                                       ViInt32   StatisticsMode,
                                                                       ViPReal64 Merr95,
                                                                       ViPReal64 merrPeak,
                                                                       ViPReal64 merrRMS,
                                                                       ViPReal64 originOffset,
                                                                       ViPReal64 IQImBalance,
                                                                       ViPReal64 frequencyError,
                                                                       ViPReal64 avgBurstPowerCurr,
                                                                       ViPReal64 avgBurstPowerAvg,
                                                                       ViPReal64 burstOutOfTol,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:MOD:MERR:EPSK?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanMerrEpsk (tab, 0, StatisticsMode, Merr95, merrPeak, merrRMS, originOffset,
                                     IQImBalance, frequencyError, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }
 //IQ Imbalance are not supported in Version >= V3.06
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanMerrEpskV306 (tab, 0, StatisticsMode, Merr95, merrPeak, merrRMS, originOffset,
                                     IQImBalance, frequencyError, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcMerrEpMatcLim (ViSession instrSession,
                                                                              ViInt32   StatisticsMode,
                                                                              ViPInt32  merr95,
                                                                              ViPInt32  merrPeak,
                                                                              ViPInt32  merrRMS,
                                                                              ViPInt32  originOffset,
                                                                              ViPInt32  IQImBalance,
                                                                              ViPInt32  frequencyError,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CALC:MOD:MERR:EPSK:MATC:LIM?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // 95% Magnitude Error with single-value measurement
  RSCMU300_Status = RSCMU300_GetMatchingValue(merr95,tab,0);

  switch (StatisticsMode)
  {
    case RSCMU300_CURRENT:
        // Magnitude Error Peak with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(merrPeak,tab,1);

        // Magnitude Error RMS with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(merrRMS,tab,4);

        // Origin Offset with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(originOffset,tab,7);

        if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
            {
            // IQ/Im Balance with single-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(IQImBalance,tab,10);

            // Frequency Error with single-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,13);
            }
        else
            {
            // IQ/Im Balance with single-value measurement
            *IQImBalance= RSCMU300_INV;

            // Frequency Error with single-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,10);
            }
    break;

    case RSCMU300_AVERAGE:
        // Magnitude Error Peak with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(merrPeak,tab,2);

        // Magnitude Error RMS with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(merrRMS,tab,5);

        // Origin Offset with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(originOffset,tab,8);

        if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
            {
            // IQ/Im Balance with average measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(IQImBalance,tab,11);

            // Frequency Error with average measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,14);
            }
        else
            {
            // IQ/Im Balance with average measurement
            *IQImBalance= RSCMU300_INV;

            // Frequency Error with average measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,11);
            }
    break;

    case RSCMU300_MAXMIN:
        // Magnitude Error Peak with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(merrPeak,tab,3);

        // Magnitude Error RMS with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(merrRMS,tab,6);

        // Origin Offset with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(originOffset,tab,9);

        if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
            {
            // IQ/Im Balance with extreme-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(IQImBalance,tab,12);

            // Frequency Error with extreme-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,15);
            }
        else
            {
            // IQ/Im Balance with extreme-value measurement
            *IQImBalance= RSCMU300_INV;

            // Frequency Error with extreme-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,12);
            }
    break;
  }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Magnitude Error in Burst...
/* Purpose : This function returns the magnitude error vs. time at fixed,
/*           equidistant test points. The number of measured values is 142,
/*           corresponding to a time range of 3 symb to 144 symb.
/*           The calculation of current, average, and mmax (Min./Max.)
/*           results is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrMerrEp (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViReal64  merrValues[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      merrValuesTmp[143][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:ARR:MOD:MERR:EPSK:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, merrValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,merrValuesTmp,merrValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Magnitude Error in Burst...
/* Purpose : This function returns the magnitude error vs. time at fixed,
/*           equidistant test points. The number of measured values is 142,
/*           corresponding to a time range of 3 symb to 144 symb.
/*           The calculation of current, average, and mmax (Min./Max.)
/*           results is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrMerrEp (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViReal64  merrValues[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      merrValuesTmp[143][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:ARR:MOD:MERR:EPSK:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, merrValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,merrValuesTmp,merrValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample Magnitude Error in Burst...
/* Purpose : This function returns the magnitude error vs. time at fixed,
/*           equidistant test points. The number of measured values is 142,
/*           corresponding to a time range of 3 symb to 144 symb.
/*           The calculation of current, average, and mmax (Min./Max.)
/*           results is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrMerrEp (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViReal64  merrValues[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      merrValuesTmp[143][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:ARR:MOD:MERR:EPSK:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, merrValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,merrValuesTmp,merrValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Subarray
/* Purpose : This function measures and returns the phase error versus time
/*           in the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:MERRor:EPSK[:TCH] command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSubMerrEp (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViReal64  merrValues[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      merrValuesTmp[143][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:SUB:MOD:MERR:EPSK:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, merrValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,merrValuesTmp,merrValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Subarray
/* Purpose : This function measures and returns the phase error versus time
/*           in the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:MERRor:EPSK[:TCH] command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSubMerrEp (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViReal64  merrValues[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      merrValuesTmp[143][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:SUB:MOD:MERR:EPSK:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, merrValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,merrValuesTmp,merrValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample Subarray
/* Purpose : This function measures and returns the phase error versus time
/*           in the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:MERRor:EPSK[:TCH] command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSubMerrEp (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViReal64  merrValues[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      merrValuesTmp[143][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:SUB:MOD:MERR:EPSK:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, merrValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,merrValuesTmp,merrValues);

  return RSCMU300_Status;
}
















/*********************************************************************************
** Demod Bits
*********************************************************************************/


/*===========================================================================*/
/* Configure Demod Bits
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfModDemodBits (ViSession instrSession,
                                                    ViInt32   edgeModMeasurement,
                                                    ViInt32   demodBits,
                                                    ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "CONFigure:MODulation:%s:EPSK:DBITs", list[edgeModMeasurement]);

    RETMSG(RSCMU300_setViString(instrSession, wrtBuf,
                             mode_On_Off[demodBits],
                             RSCMU_ERROR_PARAMETER2));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfModDemodBits (ViSession instrSession,
                                                    ViInt32   edgeModMeasurement,
                                                    ViInt32   demodBits,
                                                    ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "CONFigure:MODulation:%s:EPSK:TCH:DBITs", list[edgeModMeasurement]);

    RETMSG(RSCMU300_setViString(instrSession, wrtBuf,
                             mode_On_Off[demodBits],
                             RSCMU_ERROR_PARAMETER2));
}


/*===========================================================================*/
/* Read Array Demod Bits
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrModDemodBits (ViSession instrSession,
                                                       ViInt32   edgeModMeasurement,
                                                       ViInt32   demodBits[],
                                                       ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "READ:ARRay:MODulation:%s:EPSK:DBITs", list[edgeModMeasurement]);

    RETMSG(RSCMU300_MeasArrayInt( instrSession, wrtBuf
                               ,demodBits, errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrModDemodBits (ViSession instrSession,
                                                       ViInt32   edgeModMeasurement,
                                                       ViInt32   demodBits[],
                                                       ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "READ:ARRay:MODulation:%s:EPSK:TCH:DBITs", list[edgeModMeasurement]);

    RETMSG(RSCMU300_MeasArrayInt( instrSession, wrtBuf
                               ,demodBits, errorMessage));
}

/*===========================================================================*/
/* Fetch Array Demod Bits
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrModDemodBits (ViSession instrSession,
                                                       ViInt32   edgeModMeasurement,
                                                       ViInt32   demodBits[],
                                                       ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "FETCh:ARRay:MODulation:%s:EPSK:DBITs", list[edgeModMeasurement]);

    RETMSG(RSCMU300_MeasArrayInt( instrSession, wrtBuf
                               ,demodBits, errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrModDemodBits (ViSession instrSession,
                                                       ViInt32   edgeModMeasurement,
                                                       ViInt32   demodBits[],
                                                       ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "FETCh:ARRay:MODulation:%s:EPSK:TCH:DBITs", list[edgeModMeasurement]);

    RETMSG(RSCMU300_MeasArrayInt( instrSession, wrtBuf
                               ,demodBits, errorMessage));
}

/*===========================================================================*/
/* Sample Array Demod Bits
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrModDemodBits (ViSession instrSession,
                                                       ViInt32   edgeModMeasurement,
                                                       ViInt32   demodBits[],
                                                       ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "SAMPle:ARRay:MODulation:%s:EPSK:DBITs", list[edgeModMeasurement]);

    RETMSG(RSCMU300_MeasArrayInt( instrSession, wrtBuf
                               ,demodBits, errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrModDemodBits (ViSession instrSession,
                                                       ViInt32   edgeModMeasurement,
                                                       ViInt32   demodBits[],
                                                       ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "SAMPle:ARRay:MODulation:%s:EPSK:TCH:DBITs", list[edgeModMeasurement]);

    RETMSG(RSCMU300_MeasArrayInt( instrSession, wrtBuf
                               ,demodBits, errorMessage));
}

/*===========================================================================*/
/* Read Scalar Demod Bits
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadScalModDemodBits (ViSession instrSession,
                                                        ViInt32   edgeModMeasurement,
                                                        ViInt32   measPointSym,
                                                        ViInt32   *demodulation,
                                                        ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "READ:SCALar:MODulation:%s:EPSK:DBITs? %d", list[edgeModMeasurement],measPointSym);

    RETMSG(RSCMU300_MeasSclarDemodBit( instrSession, wrtBuf
                                    ,demodulation, errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadScalModDemodBits (ViSession instrSession,
                                                        ViInt32   edgeModMeasurement,
                                                        ViInt32   measPointSym,
                                                        ViInt32   *demodulation,
                                                        ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "READ:SCALar:MODulation:%s:EPSK:TCH:DBITs? %d", list[edgeModMeasurement],measPointSym);

    RETMSG(RSCMU300_MeasSclarDemodBit( instrSession, wrtBuf
                                    ,demodulation, errorMessage));
}

/*===========================================================================*/
/* Fetch Scalar Demod Bits
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcScalModDemodBits (ViSession instrSession,
                                                        ViInt32   edgeModMeasurement,
                                                        ViInt32   measPointSym,
                                                        ViInt32   *demodulation,
                                                        ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "FETCh:SCALar:MODulation:%s:EPSK:DBITs? %d", list[edgeModMeasurement],measPointSym);

    RETMSG(RSCMU300_MeasSclarDemodBit( instrSession, wrtBuf
                                    ,demodulation, errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcScalModDemodBits (ViSession instrSession,
                                                        ViInt32   edgeModMeasurement,
                                                        ViInt32   measPointSym,
                                                        ViInt32   *demodulation,
                                                        ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "FETCh:SCALar:MODulation:%s:EPSK:TCH:DBITs? %d", list[edgeModMeasurement],measPointSym);

    RETMSG(RSCMU300_MeasSclarDemodBit( instrSession, wrtBuf
                                    ,demodulation, errorMessage));
}


/*===========================================================================*/
/* Sample Scalar Demod Bits
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampScalModDemodBits (ViSession instrSession,
                                                        ViInt32   edgeModMeasurement,
                                                        ViInt32   measPointSym,
                                                        ViInt32   *demodulation,
                                                        ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "SAMPle:SCALar:MODulation:%s:EPSK:DBITs? %d", list[edgeModMeasurement],measPointSym);

    RETMSG(RSCMU300_MeasSclarDemodBit( instrSession, wrtBuf
                                    ,demodulation, errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampScalModDemodBits (ViSession instrSession,
                                                        ViInt32   edgeModMeasurement,
                                                        ViInt32   measPointSym,
                                                        ViInt32   *demodulation,
                                                        ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "SAMPle:SCALar:MODulation:%s:EPSK:TCH:DBITs? %d", list[edgeModMeasurement],measPointSym);

    RETMSG(RSCMU300_MeasSclarDemodBit( instrSession, wrtBuf
                                    ,demodulation, errorMessage));
}




/*===========================================================================*/
/* Read Peak Demod Bits
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadPeakModDemodBits (ViSession instrSession,
                                                        ViInt32   edgeModMeasurement,
                                                        ViInt32   *measPointSym,
                                                        ViInt32   *demodulation,
                                                        ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "READ:SCALar:MODulation:%s:EPSK:DBITs:PEAK?", list[edgeModMeasurement]);

    RETMSG(RSCMU300_MeasPeakDemodBit( instrSession, wrtBuf
                                  ,measPointSym,demodulation,errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadPeakModDemodBits (ViSession instrSession,
                                                        ViInt32   edgeModMeasurement,
                                                        ViInt32   *measPointSym,
                                                        ViInt32   *demodulation,
                                                        ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "READ:SCALar:MODulation:%s:EPSK:TCH:DBITs:PEAK?", list[edgeModMeasurement]);

    RETMSG(RSCMU300_MeasPeakDemodBit( instrSession, wrtBuf
                                  ,measPointSym,demodulation,errorMessage));
}

/*===========================================================================*/
/* Fetch Peak Demod Bits
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcPeakModDemodBits (ViSession instrSession,
                                                        ViInt32   edgeModMeasurement,
                                                        ViInt32   *measPointSym,
                                                        ViInt32   *demodulation,
                                                        ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "FETCh:SCALar:MODulation:%s:EPSK:DBITs:PEAK?", list[edgeModMeasurement]);

    RETMSG(RSCMU300_MeasPeakDemodBit( instrSession, wrtBuf
                                  ,measPointSym,demodulation,errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPeakModDemodBits (ViSession instrSession,
                                                        ViInt32   edgeModMeasurement,
                                                        ViInt32   *measPointSym,
                                                        ViInt32   *demodulation,
                                                        ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "FETCh:SCALar:MODulation:%s:EPSK:TCH:DBITs:PEAK?", list[edgeModMeasurement]);

    RETMSG(RSCMU300_MeasPeakDemodBit( instrSession, wrtBuf
                                  ,measPointSym,demodulation,errorMessage));
}

/*===========================================================================*/
/* Sample Peak Demod Bits
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampPeakModDemodBits (ViSession instrSession,
                                                        ViInt32   edgeModMeasurement,
                                                        ViInt32   *measPointSym,
                                                        ViInt32   *demodulation,
                                                        ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "SAMPle:SCALar:MODulation:%s:EPSK:DBITs:PEAK?", list[edgeModMeasurement]);

    RETMSG(RSCMU300_MeasPeakDemodBit( instrSession, wrtBuf
                                  ,measPointSym,demodulation,errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampPeakModDemodBits (ViSession instrSession,
                                                        ViInt32   edgeModMeasurement,
                                                        ViInt32   *measPointSym,
                                                        ViInt32   *demodulation,
                                                        ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "SAMPle:SCALar:MODulation:%s:EPSK:TCH:DBITs:PEAK?", list[edgeModMeasurement]);

    RETMSG(RSCMU300_MeasPeakDemodBit( instrSession, wrtBuf
                                  ,measPointSym,demodulation,errorMessage));
}



/*-----------------------------------------------------------------------------
 * Modulation IQAN (IQAnalyzer)
 *
 * The subsystem MODulation:IQANalyzer analyzes the I/Q modulation signals as
 * well as measures general scalar modulation parameters. The subsystem corresponds
 * to the measurement menu Modulation, application IQAnalyzer 8PSK, and the
 * sections in the popup menu Modulation Configuration that are related to the
 * IQAnalyzer... applications.
 * ----------------------------------------------------------------------------
 * CONFIGURATION:
 * The commands of the following subsystems configure the Modulation measurement.
 * They correspond to the sections in the Modulation Configuration menu that
 * are related to the IQAnalyzer applications.
 * ----------------------------------------------------------------------------
 * CONTROL:
 * The subsystem MODulation:IQANalyzer...:CONTrol configures the scope of the
 * modulation measurement. It corresponds to the Control tab in the popup menu
 * Modulation Configuration.
 * ----------------------------------------------------------------------------
 */


/*===========================================================================*/
/* Function: Result Mode
/* Purpose : This function restricts the type of measured values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfIqanContRmod (ViSession  instrSession,
                                                    ViInt32    ValuesType,
                                                    ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_setEnum(instrSession, "CONFigure:MODulation:IQANalyzer:EPSK:CONTrol:RMODe",
                         ValuesType, mode_ScopeMeas,
                         RSCMU_ERROR_PARAMETER2));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfIqanContRmod (ViSession  instrSession,
                                                   ViInt32    ValuesType,
                                                   ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_setEnum(instrSession, "CONFigure:MODulation:IQANalyzer:EPSK:TCH:CONTrol:RMODe",
                         ValuesType, mode_ScopeMeas,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function sets the number of statistics cycles, the stop
/*           condition and the stepping mode for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfIqanContRep (ViSession  instrSession,
                                                   ViInt32    Repetition,
                                                   ViInt32    NbRepetition,
                                                   ViInt32    StepMode,
                                                   ViChar     errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Repetition, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, 1, 10000, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4,errorMessage);

  if(Repetition != RSCMU300_MULTIPLE)
    sprintf(wrtBuf, "CONFigure:MODulation:IQANalyzer:EPSK:CONTrol:REPetition %s,NONE,%s", repetition_meas[Repetition]
                                                                                   , StrStepMode[StepMode]);
  else
    sprintf(wrtBuf, "CONFigure:MODulation:IQANalyzer:EPSK:CONTrol:REPetition %d,NONE,%s", NbRepetition
                                                                                   , StrStepMode[StepMode]);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfIqanContRep (ViSession  instrSession,
                                                  ViInt32    Repetition,
                                                  ViInt32    NbRepetition,
                                                  ViInt32    StepMode,
                                                  ViChar     errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Repetition, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, 1, 10000, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4,errorMessage);

  if(Repetition != RSCMU300_MULTIPLE)
    sprintf(wrtBuf, "CONFigure:MODulation:IQANalyzer:EPSK:TCH:CONTrol:REPetition %s,NONE,%s", repetition_meas[Repetition]
                                                                                   , StrStepMode[StepMode]);
  else
    sprintf(wrtBuf, "CONFigure:MODulation:IQANalyzer:EPSK:TCH:CONTrol:REPetition %d,NONE,%s", NbRepetition
                                                                                   , StrStepMode[StepMode]);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: IQ Filter
/* Purpose : This function selects ....
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfIqanIQFilter (ViSession  instrSession,
                                                    ViInt32    IQFilter,
                                                    ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[]= {"ISIRemoved", "UNFiltered", VI_NULL};

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_setEnum(instrSession, "CONFigure:MODulation:IQANalyzer:EPSK:IQFilter",
                         IQFilter, list,
                         RSCMU_ERROR_PARAMETER2));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfIqanIQFilter (ViSession  instrSession,
                                                   ViInt32    IQFilter,
                                                   ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[]= {"ISIRemoved", "UNFiltered", VI_NULL};

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_setEnum(instrSession, "CONFigure:MODulation:IQANalyzer:EPSK:TCH:IQFilter",
                         IQFilter, list,
                         RSCMU_ERROR_PARAMETER2));
}


/*===========================================================================*/
/* Function: Rotation
/* Purpose : This function selects ....
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfIqanRotation (ViSession instrSession,
                                                    ViInt32   rotation,
                                                    ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[]= {"P38", "P38Removed", VI_NULL};

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_setEnum(instrSession, "CONFigure:MODulation:IQANalyzer:EPSK:ROTation",
                         rotation, list,
                         RSCMU_ERROR_PARAMETER2));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfIqanRotation (ViSession instrSession,
                                                   ViInt32   rotation,
                                                   ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[]= {"P38", "P38Removed", VI_NULL};

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_setEnum(instrSession, "CONFigure:MODulation:IQANalyzer:EPSK:TCH:ROTation",
                         rotation, list,
                         RSCMU_ERROR_PARAMETER2));
}


/* ----------------------------------------------------------------------------
 * CONTROL:
 * The subsystem MODulation:EVMagnitude controls the modulation measurement.
 * It corresponds to the softkey EVM 8PSK in the measurement menu Modulation.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Starts Modulation IQAN Measurements
/* Purpose : This function starts a new modulation IQAN measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitIqan (ViSession  instrSession,
                                            ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_sendCmd(instrSession, "INITiate:MODulation:IQANalyzer:EPSK"));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitIqan (ViSession  instrSession,
                                            ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_sendCmd(instrSession, "INITiate:MODulation:IQANalyzer:EPSK:TCH"));
}

/*===========================================================================*/
/* Function: Aborts Modulation IQAN Measurements
/* Purpose : This function aborts running Modulation IQAN measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborIqan (ViSession  instrSession,
                                            ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_sendCmd(instrSession, "ABORt:MODulation:IQANalyzer:EPSK"));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborIqan (ViSession  instrSession,
                                           ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_sendCmd(instrSession, "ABORt:MODulation:IQANalyzer:EPSK:TCH"));
}

/*===========================================================================*/
/* Function: Stops Modulation IQAN Measurements
/* Purpose : This function stops measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopIqan (ViSession  instrSession,
                                            ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_sendCmd(instrSession, "STOP:MODulation:IQANalyzer:EPSK"));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopIqan (ViSession  instrSession,
                                           ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_sendCmd(instrSession, "STOP:MODulation:IQANalyzer:EPSK:TCH"));
}

/*===========================================================================*/
/* Function: Continues Modulation IQAN Measurements
/* Purpose : This function runs next Modulation IQAN measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContIqan (ViSession  instrSession,
                                            ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_sendCmd(instrSession, "CONTinue:MODulation:IQANalyzer:EPSK"));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContIqan (ViSession  instrSession,
                                           ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_sendCmd(instrSession, "CONTinue:MODulation:IQANalyzer:EPSK:TCH"));
}

/*===========================================================================*/
/* Function: Modulation IQAN Measurement Status
/* Purpose : This function returns the status of measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcIqanStat (ViSession  instrSession,
                                                ViInt32   *MeasurementStatus,
                                                ViInt32   *CountingNo,
                                                ViInt32   *StatisticNo,
                                                ViChar     errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      Tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETCh:MODulation:IQANalyzer:EPSK:STATus?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Split the multiple data values separated by a comma:
  RSCMU300_SeparateDataValues (rdBuf, ",", Tab);

  // Gets the status of the measurement:
  if ((RSCMU300_Status = RSCMU300_GetMeasStatVal (MeasurementStatus, Tab, 0)) < 0)
    return RSCMU300_Status;

  // Gets the current value of the statistics counter (the number of the current statistics cycle):
  if ((RSCMU300_Status = RSCMU300_GetCountingNo (CountingNo, Tab, 1)) < 0)
    return RSCMU300_Status;

  // Gets the current evaluation period within a statistics cycle:
  if ((RSCMU300_Status = RSCMU300_GetStatisticNo (StatisticNo, Tab, 2)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcIqanStat (ViSession  instrSession,
                                               ViInt32   *MeasurementStatus,
                                               ViInt32   *CountingNo,
                                               ViInt32   *StatisticNo,
                                               ViChar     errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      Tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETCh:MODulation:IQANalyzer:EPSK:TCH:STATus?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Split the multiple data values separated by a comma:
  RSCMU300_SeparateDataValues (rdBuf, ",", Tab);

  // Gets the status of the measurement:
  if ((RSCMU300_Status = RSCMU300_GetMeasStatVal (MeasurementStatus, Tab, 0)) < 0)
    return RSCMU300_Status;

  // Gets the current value of the statistics counter (the number of the current statistics cycle):
  if ((RSCMU300_Status = RSCMU300_GetCountingNo (CountingNo, Tab, 1)) < 0)
    return RSCMU300_Status;

  // Gets the current evaluation period within a statistics cycle:
  if ((RSCMU300_Status = RSCMU300_GetStatisticNo (StatisticNo, Tab, 2)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event Report
/* Purpose : This function defines the events generated when the measurement
/*           is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfIqanErep (ViSession  instrSession,
                                                ViInt32    EventReport,
                                                ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    StrMode[] = {"OFF","SRQ","SOPC","SRSQ", VI_NULL};

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_setEnum(instrSession, "CONFigure:MODulation:IQANalyzer:EPSK:EREPorting",
                         EventReport, StrMode, RSCMU_ERROR_PARAMETER2));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfIqanErep (ViSession  instrSession,
                                               ViInt32    EventReport,
                                               ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    StrMode[] = {"OFF","SRQ","SOPC","SRSQ", VI_NULL};

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_setEnum(instrSession, "CONFigure:MODulation:IQANalyzer:EPSK:TCH:EREPorting",
                         EventReport, StrMode, RSCMU_ERROR_PARAMETER2));
}

/* ----------------------------------------------------------------------------
 * RESULTS:
 * The subsystem MODulation:IQANalyzer:...? measures and returns the modulation
 * parameters and compares them with the tolerance values. The subsystem
 * corresponds to the various output elements in the measurement menu MODulation,
 * application IQAN .
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Read Scalar
/* Purpose : This function starts a single shot measurement and returns
/*           results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadIqan (ViSession  instrSession,
                                            ViReal64  *EvmRMS,
                                            ViReal64  *MerrRMS,
                                            ViReal64  *PerrRMS,
                                            ViReal64  *AvgBurstPow,
                                            ViChar     errorMessage[])
{
    RETMSG(RSCMU300_MeasIqanScalarNSig( instrSession, "READ:SCALar:MODulation:IQANalyzer:EPSK",
                                 EvmRMS, MerrRMS, PerrRMS, AvgBurstPow, errorMessage));
}
/* ----------------------------
   ... for Signalling Mode
   ----------------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadIqan (ViSession  instrSession,
                                            ViReal64  *EvmRMS,
                                            ViReal64  *MerrRMS,
                                            ViReal64  *PerrRMS,
                                            ViReal64  *TimeErr,
                                            ViReal64  *AvgBurstPow,
                                            ViChar     errorMessage[])
{
    RETMSG(RSCMU300_MeasIqanScalarSig( instrSession, "READ:SCALar:MODulation:IQANalyzer:EPSK:TCH",
                                 EvmRMS, MerrRMS, PerrRMS, TimeErr, AvgBurstPow, errorMessage));
}

/*===========================================================================*/
/* Function: Fetch Scalar
/* Purpose : This function reads out measurement results (unsynchronized).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcIqan (ViSession  instrSession,
                                            ViReal64  *EvmRMS,
                                            ViReal64  *MerrRMS,
                                            ViReal64  *PerrRMS,
                                            ViReal64  *AvgBurstPow,
                                            ViChar     errorMessage[])
{
    RETMSG(RSCMU300_MeasIqanScalarNSig( instrSession, "FETCh:SCALar:MODulation:IQANalyzer:EPSK",
                                 EvmRMS, MerrRMS, PerrRMS, AvgBurstPow, errorMessage));
}
/* ----------------------------
   ... for Signalling Mode
   ----------------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcIqan (ViSession  instrSession,
                                            ViReal64  *EvmRMS,
                                            ViReal64  *MerrRMS,
                                            ViReal64  *PerrRMS,
                                            ViReal64  *TimeErr,
                                            ViReal64  *AvgBurstPow,
                                            ViChar     errorMessage[])
{
    RETMSG(RSCMU300_MeasIqanScalarSig( instrSession, "FETCh:SCALar:MODulation:IQANalyzer:EPSK:TCH",
                                 EvmRMS, MerrRMS, PerrRMS, TimeErr, AvgBurstPow, errorMessage));
}

/*===========================================================================*/
/* Function: Sample Scalar
/* Purpose : This function reads out measurement results (synchronized).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampIqan (ViSession  instrSession,
                                            ViReal64  *EvmRMS,
                                            ViReal64  *MerrRMS,
                                            ViReal64  *PerrRMS,
                                            ViReal64  *AvgBurstPow,
                                            ViChar     errorMessage[])
{
    RETMSG(RSCMU300_MeasIqanScalarNSig( instrSession, "SAMPle:SCALar:MODulation:IQANalyzer:EPSK",
                                 EvmRMS, MerrRMS, PerrRMS, AvgBurstPow, errorMessage));
}
/* ----------------------------
   ... for Signalling Mode
   ----------------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampIqan (ViSession  instrSession,
                                            ViReal64  *EvmRMS,
                                            ViReal64  *MerrRMS,
                                            ViReal64  *PerrRMS,
                                            ViReal64  *TimeErr,
                                            ViReal64  *AvgBurstPow,
                                            ViChar     errorMessage[])
{
    RETMSG(RSCMU300_MeasIqanScalarSig( instrSession, "SAMPle:SCALar:MODulation:IQANalyzer:EPSK:TCH",
                                 EvmRMS, MerrRMS, PerrRMS, TimeErr, AvgBurstPow, errorMessage));
}

/*===========================================================================*/
/* Function: Read Array
/* Purpose : This function starts a single shot measurement and returns the
/*           I-signal values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrIqanIPh (ViSession  instrSession,
                                                  ViReal64   IqanValues[],
                                                  ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_MeasArray( instrSession, "READ:ARRay:MODulation:IQANalyzer:EPSK:IPHase"
                           ,IqanValues, errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrIqanIPh (ViSession  instrSession,
                                                  ViReal64   IqanValues[],
                                                  ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_MeasArray( instrSession, "READ:ARRay:MODulation:IQANalyzer:EPSK:TCH:IPHase"
                           ,IqanValues, errorMessage));
}

/*===========================================================================*/
/* Function: Fetch Array
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrIqanIPh (ViSession  instrSession,
                                                  ViReal64   IqanValues[],
                                                  ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_MeasArray( instrSession, "FETCh:ARRay:MODulation:IQANalyzer:EPSK:IPHase"
                           ,IqanValues, errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrIqanIPh (ViSession  instrSession,
                                                 ViReal64   IqanValues[],
                                                 ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_MeasArray( instrSession, "FETCh:ARRay:MODulation:IQANalyzer:EPSK:TCH:IPHase"
                           ,IqanValues, errorMessage));
}

/*===========================================================================*/
/* Function: Sample Array
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrIqanIPh (ViSession  instrSession,
                                                  ViReal64   IqanValues[],
                                                  ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_MeasArray( instrSession, "SAMPle:ARRay:MODulation:IQANalyzer:EPSK:IPHase"
                           ,IqanValues, errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrIqanIPh (ViSession  instrSession,
                                                 ViReal64   IqanValues[],
                                                 ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_MeasArray( instrSession, "SAMPle:ARRay:MODulation:IQANalyzer:EPSK:TCH:IPHase"
                           ,IqanValues, errorMessage));
}


/*===========================================================================*/
/* Function: Read Array
/* Purpose : This function starts a single shot measurement and returns the
/*           Q-signal values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrIqanQPh (ViSession  instrSession,
                                                  ViReal64   IqanValues[],
                                                  ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_MeasArray( instrSession, "READ:ARRay:MODulation:IQANalyzer:EPSK:QPHase"
                           ,IqanValues, errorMessage));
}


/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrIqanQPh (ViSession  instrSession,
                                                 ViReal64   IqanValues[],
                                                 ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_MeasArray( instrSession, "READ:ARRay:MODulation:IQANalyzer:EPSK:TCH:QPHase"
                           ,IqanValues, errorMessage));
}

/*===========================================================================*/
/* Function: Fetch Array
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrIqanQPh (ViSession  instrSession,
                                                  ViReal64   IqanValues[],
                                                  ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_MeasArray( instrSession, "FETCh:ARRay:MODulation:IQANalyzer:EPSK:QPHase"
                           ,IqanValues, errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrIqanQPh (ViSession  instrSession,
                                                 ViReal64   IqanValues[],
                                                 ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_MeasArray( instrSession, "FETCh:ARRay:MODulation:IQANalyzer:EPSK:TCH:QPHase"
                           ,IqanValues, errorMessage));
}

/*===========================================================================*/
/* Function: Sample Array
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrIqanQPh (ViSession  instrSession,
                                                  ViReal64   IqanValues[],
                                                  ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_MeasArray( instrSession, "SAMPle:ARRay:MODulation:IQANalyzer:EPSK:QPHase"
                           ,IqanValues, errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrIqanQPh (ViSession  instrSession,
                                                 ViReal64   IqanValues[],
                                                 ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_82,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_MeasArray( instrSession, "SAMPle:ARRay:MODulation:IQANalyzer:EPSK:TCH:QPHase"
                           ,IqanValues, errorMessage));
}


/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT SPECTRUM/MODULATION
 *    The subsystem SPECtrum:MODulation contains the commands for measuring
 *    the off-carrier power due to the modulation of the GSM signal.
 *-----------------------------------------------------------------------------
 *      CONFIGURATION CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpContDef (ViSession instrSession,
                                                                               ViBoolean DefaultValues,
                                                                               ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpModContDef (RSCMU300_EPSK, instrSession, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Scope of measurement
/* Purpose : This function defines the scope of the power measurement,
/*           combining the ...CONTrol:RMODe, ...CONTrol:STATistics, and the
/*           ...CONTrol:REPetition commands.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpScope (ViSession instrSession,
                                                                             ViInt32   MeasuredValuesType,
                                                                             ViInt32   NbBurst,
                                                                             ViInt32   repetition,
                                                                             ViInt32   NbRepetition,
                                                                             ViInt32   StopCondition,
                                                                             ViInt32   StepMode,
                                                                             ViChar    errorMessage[])
{
    return NSig_ConfSpModScope (RSCMU300_EPSK, instrSession, MeasuredValuesType, NbBurst, repetition, NbRepetition,
                                StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpContRep (ViSession instrSession,
                                                                               ViInt32   Repetition,
                                                                               ViInt32   StopCondition,
                                                                               ViInt32   StepMode,
                                                                               ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpModContRep (RSCMU300_EPSK, instrSession, Repetition, StopCondition, StepMode, errorMessage);
}

/*-----------------------------------------------------------------------------
 *      LIMITS
 *      The subsystem SPECtrum:MODulation:LIMit contains the commands for
 *      definition of tolerance values for the spectrum measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default limit Lines
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpLimDef (ViSession instrSession,
                                                                              ViBoolean DefaultValues,
                                                                              ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpModLimDef (RSCMU300_EPSK, instrSession, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Reference Power
/* Purpose : This function defines the MS carrier output power domain where
/*           the limit lines are to be determined by linear interpolation
/*           (see Table 1). Below Min. Power, the lower limit line applies,
/*           above Max. Power, the upper limit line applies.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpLimRefp (ViSession instrSession,
                                                                               ViReal64  minPower,
                                                                               ViReal64  maxPower,
                                                                               ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpModLimRefp (RSCMU300_EPSK, instrSession, minPower, maxPower, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lines On/Off
/* Purpose : This function switches the limit checking for all measurepoints.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpLimMode (ViSession instrSession,
                                                                               ViBoolean limitLines,
                                                                               ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpModLimMode (RSCMU300_EPSK, instrSession, limitLines, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lines
/* Purpose : These commands activate and define limit lines for the spectrum
/*           due to modulation measurement.
/*           The limit lines for the spectrum due to modulation as specified
/*           in standard GSM 05.05 depend on the GSM band, the frequency, and
/*           (for frequencies that differ from the carrier frequency by more
/*           than 400 kHz) on the output power of the base station.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpLim (ViSession instrSession,
                                                                           ViInt32   measurePoint,
                                                                           ViBoolean enable,
                                                                           ViReal64  minPower,
                                                                           ViReal64  maxPower,
                                                                           ViReal64  AbsLevel,
                                                                           ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpModLim (RSCMU300_EPSK, instrSession, measurePoint, enable, minPower, maxPower, AbsLevel, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Statistic Count
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpCont (ViSession instrSession,
                                                                            ViInt32   MeasuredValuesType,
                                                                            ViInt32   NbBurst,
                                                                            ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpModCont (RSCMU300_EPSK, instrSession, MeasuredValuesType, NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set the number of bursts
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpStat (ViSession instrSession,
                                                                            ViInt32   NbBurst,
                                                                            ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpModStat (RSCMU300_EPSK, instrSession, NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set result mode
/* Purpose : This function specifies the type of measured values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpResMode (ViSession instrSession,
                                                                               ViInt32   MeasuredValuesType,
                                                                               ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpModResMode (RSCMU300_EPSK, instrSession, MeasuredValuesType, errorMessage);
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpContRepSt (ViSession instrSession,
                                                                                 ViInt32   NbRepetition,
                                                                                 ViInt32   StopCondition,
                                                                                 ViInt32   StepMode,
                                                                                 ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpModContRepSt (RSCMU300_EPSK, instrSession, NbRepetition, StopCondition, StepMode, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      MEASUREMENT CONFIGURATION
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Measure Points
/* Purpose : This function permits to select which frequencies a spectrum
/*           modulation measurement is performed. A reduction of the
/*           measurement points enhances the measurement speed.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpContMpo (ViSession instrSession,
                                                                               ViInt32   MeasurePoint,
                                                                               ViBoolean Enable,
                                                                               ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpModContMpo (RSCMU300_EPSK, instrSession, MeasurePoint, Enable, errorMessage);
}

/*===========================================================================*/
/* Function: Definition of Subarrays
/* Purpose : This function configures the READ:SUBarrays.., FETCh:SUBarrays..,
/*           and SAMPle:SUBarrays:SPECtrum:MODulation[:GMSK] commands. It
/*           restricts the measurement to up to 32 subranges where either all
/*           measurement results (the number of which is given by the second
/*           numerical parameter) or a single statistical value is returned.
/*           The subranges are defined by the start time and the number of
/*           test points which are located at fixed frequencies (see command
/*           CONFigure:SPECtrum:MODulation[:GMSK]:LIMit:LINE<nr>).
/*           The subranges may overlap but must be within the total range of
/*           the spectrum due to modulation measurement. Test points outside
/*           this range are not measured (result NAN) and do not enter into
/*           the ARIThmetical, MINimum and MAXimum values.
/*           By default, only one range corresponding to the total measurement
/*           range is used and all measurement values are returned.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSubSpModEpRang (ViSession instrSession,
                                                                               ViInt32   StatisticsMode,
                                                                               ViReal64  StartFrequency,
                                                                               ViInt32   Samples,
                                                                               ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSubSpModRang (RSCMU300_EPSK, instrSession, StatisticsMode, StartFrequency, Samples, errorMessage);
}

/*-----------------------------------------------------------------------------
 *      CONTROL OF SPECTRUM MODULATION MEAS
 *      It contains the functions for general control of the spectrum
 *      modulation measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Init
/* Purpose : Start measurement without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitSpModEp (ViSession instrSession,
                                                                        ViChar    _VI_FAR errorMessage[])
{
    return NSig_InitSpMod (RSCMU300_EPSK, instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : Abort measurement and switch off => OFF
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborSpModEp (ViSession instrSession,
                                                                        ViChar    _VI_FAR errorMessage[])
{
    return NSig_AborSpMod (RSCMU300_EPSK, instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : Stop measurement => STOP
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopSpModEp (ViSession instrSession,
                                                                        ViChar    _VI_FAR errorMessage[])
{
    return NSig_StopSpMod (RSCMU300_EPSK, instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : Next measurement step (only counting mode) => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContSpModEp (ViSession instrSession,
                                                                        ViChar    _VI_FAR errorMessage[])
{
    return NSig_ContSpMod (RSCMU300_EPSK, instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Status
/* Purpose : This function is always a query. It immediately reads the
/*           measurement status (for polling, see chapters 3 and 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSpModEpSt (ViSession instrSession,
                                                                          ViPInt32  MeasStatus,
                                                                          ViPInt32  CurrentStatCycleCount,
                                                                          ViPInt32  CurrentEvalPeriodCount,
                                                                          ViChar    _VI_FAR errorMessage[])
{
    return NSig_FetcSpModSt (RSCMU300_EPSK, instrSession, MeasStatus, CurrentStatCycleCount, CurrentEvalPeriodCount, errorMessage);
}

/*===========================================================================*/
/* Function: Event Reporting Mode
/* Purpose : This function defines the events to be reported during the
/*           measurement (event reporting, see chapter 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpErep (ViSession instrSession,
                                                                            ViInt32   Mode,
                                                                            ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpModErep (RSCMU300_EPSK, instrSession, Mode, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      RESULTS: FREQUENCY SPECTRUM
 *      The subsystem SPECtrum:MODulation[:RESULT] contains the commands for
 *      measurement and output of signal spectrum.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start single shot measurement and return results
/* Purpose : This function starts a single shot measurement and returns the
/*           results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSpModEp (ViSession instrSession,
                                                                        ViPReal64 referencePower,
                                                                        ViPInt32  matching,
                                                                        ViChar    _VI_FAR errorMessage[])
{
    return NSig_ReadSpMod (RSCMU300_EPSK, instrSession, referencePower, matching, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This function only outputs the results without any care of the
/*           measurement state.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSpModEp (ViSession instrSession,
                                                                        ViPReal64 referencePower,
                                                                        ViPInt32  matching,
                                                                        ViChar    _VI_FAR errorMessage[])
{
    return NSig_FetcSpMod (RSCMU300_EPSK, instrSession, referencePower, matching, errorMessage);
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This function waits until the results are valid for the first
/*           time (depending on the chosen statistic count) and then outputs
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSpModEp (ViSession instrSession,
                                                                        ViPReal64 referencePower,
                                                                        ViPInt32  matching,
                                                                        ViChar    _VI_FAR errorMessage[])
{
    return NSig_SampSpMod (RSCMU300_EPSK, instrSession, referencePower, matching, errorMessage);
}

/*===========================================================================*/
/* Function: Read Array
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrSpModEp (ViSession instrSession,
                                                                           ViReal64  BurstPower[],
                                                                           ViChar    _VI_FAR errorMessage[])
{
    return NSig_ReadArrSpMod (RSCMU300_EPSK, instrSession, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Array
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrSpModEp (ViSession instrSession,
                                                                           ViReal64  BurstPower[],
                                                                           ViChar    _VI_FAR errorMessage[])
{
    return NSig_FetcArrSpMod (RSCMU300_EPSK, instrSession, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Array
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrSpModEp (ViSession instrSession,
                                                                           ViReal64  BurstPower[],
                                                                           ViChar    _VI_FAR errorMessage[])
{
    return NSig_SampArrSpMod (RSCMU300_EPSK, instrSession, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Read SubArray
/* Purpose : This outputs the off-carrier power due to modulation in the
/*           subranges
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSubSpModEp (ViSession instrSession,
                                                                           ViReal64  PowerValues[],
                                                                           ViChar    _VI_FAR errorMessage[])
{
    return NSig_ReadSubSpMod (RSCMU300_EPSK, instrSession, PowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch SubArray
/* Purpose : This outputs the off-carrier power due to modulation in the
/*           subranges
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSubSpModEp (ViSession instrSession,
                                                                           ViReal64  PowerValues[],
                                                                           ViChar    _VI_FAR errorMessage[])
{
    return NSig_FetcSubSpMod (RSCMU300_EPSK, instrSession, PowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch SubArray
/* Purpose : This outputs the off-carrier power due to modulation in the
/*           subranges
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSubSpModEp (ViSession instrSession,
                                                                           ViReal64  PowerValues[],
                                                                           ViChar    _VI_FAR errorMessage[])
{
    return NSig_SampSubSpMod (RSCMU300_EPSK, instrSession, PowerValues, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT SPECTRUM/SWITCHING
 *    The subsystem SPECtrum:SWITching contains the commands for measuring
 *    the frequency spectrum.
 *-----------------------------------------------------------------------------
 *      CONFIGURATION CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpContDef (ViSession instrSession,
                                                                              ViBoolean DefaultValues,
                                                                              ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpSwContDef (RSCMU300_EPSK, instrSession, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Scope of measurement
/* Purpose : This function defines the scope of the power measurement,
/*           combining the ...CONTrol:RMODe, ...CONTrol:STATistics, and the
/*           ...CONTrol:REPetition commands.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpScope (ViSession instrSession,
                                                                            ViInt32   MeasuredValuesType,
                                                                            ViInt32   NbBurst,
                                                                            ViInt32   repetition,
                                                                            ViInt32   NbRepetition,
                                                                            ViInt32   StopCondition,
                                                                            ViInt32   StepMode,
                                                                            ViChar    errorMessage[])
{
    return NSig_ConfSpSwScope (RSCMU300_EPSK, instrSession, MeasuredValuesType, NbBurst, repetition, NbRepetition,
                               StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpContRep (ViSession instrSession,
                                                                              ViInt32   repetition,
                                                                              ViInt32   StopCondition,
                                                                              ViInt32   StepMode,
                                                                              ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpSwContRep (RSCMU300_EPSK, instrSession, repetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Spectrum Switching Slot Count
/* Purpose : This function defines whether a single timeslot or all timeslots
/*           are considered for the Spectrum due to Switching measurement..
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpSlotCount (ViSession instrSession,
                                                         ViInt32   slotCount,
                                                         ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[] = {"SSL","MSL", VI_NULL};

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_22,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_setEnum(instrSession, "CONF:SPEC:SWIT:EPSK:SCO",
                         slotCount, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*-----------------------------------------------------------------------------
 *      LIMITS
 *      The subsystem SPECtrum:SWITching:LIMit contains the commands for
 *      definition of tolerance values for the spectrum measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Limit Lines
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpLimDef (ViSession instrSession,
                                                                             ViBoolean DefaultValues,
                                                                             ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpSwLimDef (RSCMU300_EPSK, instrSession, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lines On/Off
/* Purpose : This function switches the limit checking for all measurepoints.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpLimMode (ViSession instrSession,
                                                                              ViBoolean limitLines,
                                                                              ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpSwLimMode (RSCMU300_EPSK, instrSession, limitLines, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lines
/* Purpose : These commands activate and define limit lines for the spectrum
/*           due to switching measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpLim (ViSession instrSession,
                                                   ViInt32 measurePoint,
                                                   ViBoolean enable,
                                                   ViReal64 minRelativeLimit,
                                                   ViReal64 maxRelativeLimit,
                                                   ViReal64 absoluteLimit,
                                                   ViChar errorMessage[])
{
    return NSig_ConfSpSwLim (RSCMU300_EPSK, instrSession, measurePoint, enable, minRelativeLimit, maxRelativeLimit, absoluteLimit, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Statistic Count
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpCont (ViSession instrSession,
                                                                           ViInt32   measuredValuesType,
                                                                           ViInt32   NbBurst,
                                                                           ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpSwCont (RSCMU300_EPSK, instrSession, measuredValuesType, NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set the number of bursts
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpStat (ViSession instrSession,
                                                                           ViInt32   NbBurst,
                                                                           ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpSwStat (RSCMU300_EPSK, instrSession, NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set result mode
/* Purpose : This function specifies the type of measured values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpResMode (ViSession instrSession,
                                                                              ViInt32   MeasuredValuesType,
                                                                              ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpSwResMode (RSCMU300_EPSK, instrSession, MeasuredValuesType, errorMessage);
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpContRepSt (ViSession instrSession,
                                                                                ViInt32   NbRepetition,
                                                                                ViInt32   StopCondition,
                                                                                ViInt32   StepMode,
                                                                                ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpSwContRepSt (RSCMU300_EPSK, instrSession, NbRepetition, StopCondition, StepMode, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      MEASUREMENT CONFIGURATION
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Measure Points
/* Purpose : This function permits to select which frequencies a spectrum
/*           switching measurement is performed. A reduction of the
/*           measurement points enhances the measurement speed.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpContMpo (ViSession instrSession,
                                                                              ViInt32   measurePoint,
                                                                              ViBoolean enable,
                                                                              ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpSwContMpo (RSCMU300_EPSK, instrSession, measurePoint, enable, errorMessage);
}

/*===========================================================================*/
/* Function: Definition of Subarrays
/* Purpose : This function configures the READ:SUBarrays.., FETCh:SUBarrays..,
/*           and SAMPle:SUBarrays:SPECtrum:SWITching[:GMSK] commands. It
/*           restricts the measurement to up to 32 subranges where either all
/*           measurement results (the number of which is given by the second
/*           numerical parameter) or a single statistical value is returned.
/*           The subranges are defined by the start time and the number of
/*           test points which are located at fixed frequencies (see command
/*           CONFigure:SPECtrum:SWITching[:GMSK]:LIMit:LINE<nr>).
/*           The subranges may overlap but must be within the total range of
/*           the spectrum due to switching measurement. Test points outside
/*           this range are not measured (result NAN) and do not enter into
/*           the ARIThmetical, MINimum and MAXimum values.
/*           By default, only one range corresponding to the total measurement
/*           range is used and all measurement values are returned.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSubSpSwEpRang (ViSession instrSession,
                                                                              ViInt32   StatisticsMode,
                                                                              ViReal64  StartFrequency,
                                                                              ViInt32   Samples,
                                                                              ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSubSpSwRang (RSCMU300_EPSK, instrSession, StatisticsMode, StartFrequency, Samples, errorMessage);
}

/*-----------------------------------------------------------------------------
 *      CONTROL OF SPECTRUM SWITCHING MEAS
 *      It contains the functions for general control of the spectrum switching
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Init
/* Purpose : Start measurement without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitSpSwEp (ViSession instrSession,
                                                                       ViChar _VI_FAR errorMessage[])
{
    return NSig_InitSpSw (RSCMU300_EPSK, instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : Abort measurement and switch off => OFF
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborSpSwEp (ViSession instrSession,
                                                                       ViChar _VI_FAR errorMessage[])
{
    return NSig_AborSpSw (RSCMU300_EPSK, instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : Stop measurement => STOP
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopSpSwEp (ViSession instrSession,
                                                                       ViChar _VI_FAR errorMessage[])
{
    return NSig_StopSpSw (RSCMU300_EPSK, instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : Next measurement step (only counting mode) => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContSpSwEp (ViSession instrSession,
                                                                       ViChar _VI_FAR errorMessage[])
{
    return NSig_ContSpSw (RSCMU300_EPSK, instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Status
/* Purpose : This function is always a query. It immediately reads the
/*           measurement status (for polling, see chapters 3 and 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSpSwEpSt (ViSession instrSession,
                                                                         ViPInt32  MeasStatus,
                                                                         ViPInt32  CurrentStatCycleCount,
                                                                         ViPInt32  CurrentEvalPeriodCount,
                                                                         ViChar    _VI_FAR errorMessage[])
{
    return NSig_FetcSpSwSt (RSCMU300_EPSK, instrSession, MeasStatus, CurrentStatCycleCount, CurrentEvalPeriodCount, errorMessage);
}

/*===========================================================================*/
/* Function: Event Reporting Mode
/* Purpose : This function defines the events to be reported during the
/*           measurement (event reporting, see chapter 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpErep (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViChar    _VI_FAR errorMessage[])
{
    return NSig_ConfSpSwErep (RSCMU300_EPSK, instrSession, Mode, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      RESULTS: FREQUENCY SPECTRUM
 *      The subsystem SPECtrum:SWITching[:RESULT] contains the commands for
 *      measurement and output of signal spectrum.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Read
/* Purpose : This function starts the measurement and outputs some results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSpSwEp (ViSession instrSession,
                                                                       ViPReal64 referencePower,
                                                                       ViPInt32  matching,
                                                                       ViChar    _VI_FAR errorMessage[])
{
    return NSig_ReadSpSw (RSCMU300_EPSK, instrSession, referencePower, matching, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This function only outputs the results without any care of the
/*           measurement state.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSpSwEp (ViSession instrSession,
                                                                       ViPReal64 referencePower,
                                                                       ViPInt32  matching,
                                                                       ViChar    _VI_FAR errorMessage[])
{
    return NSig_ReadSpSw (RSCMU300_EPSK, instrSession, referencePower, matching, errorMessage);
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This function waits until the results are valid for the first
/*           time (depending on the chosen statistic count) and then outputs
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSpSwEp (ViSession instrSession,
                                                                       ViPReal64 referencePower,
                                                                       ViPInt32  matching,
                                                                       ViChar    _VI_FAR errorMessage[])
{
    return NSig_SampSpSw (RSCMU300_EPSK, instrSession, referencePower, matching, errorMessage);
}

/*===========================================================================*/
/* Function: Read Array
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrSpSwEp (ViSession instrSession,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
    return NSig_ReadArrSpSw (RSCMU300_EPSK, instrSession, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Array
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrSpSwEp (ViSession instrSession,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
    return NSig_FetcArrSpSw (RSCMU300_EPSK, instrSession, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Array
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrSpSwEp (ViSession instrSession,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
    return NSig_SampArrSpSw (RSCMU300_EPSK, instrSession, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Read SubArray
/* Purpose : This outputs the off-carrier power due to switching in the
/*           subranges
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSubSpSwEp (ViSession instrSession,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
    return NSig_ReadSubSpSw (RSCMU300_EPSK, instrSession, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch SubArray
/* Purpose : This outputs the off-carrier power due to switching in the
/*           subranges
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSubSpSwEp (ViSession instrSession,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
    return NSig_FetcSubSpSw (RSCMU300_EPSK, instrSession, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample SubArray
/* Purpose : This outputs the off-carrier power due to switching in the
/*           subranges
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSubSpSwEp (ViSession instrSession,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
    return NSig_SampSubSpSw (RSCMU300_EPSK, instrSession, BurstPower, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 * GSM MEASUREMENTS WITH SIGNALLING (SIGNALLING):
 * ----------------------------------------------------------------------------
 */
/*-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT POWER
 *    The subsystem POWer contains the commands for measuring the
 *    signal power.
 *    This subsystem corresponds to the measurement menu Power vs.
 *    Time and the associated popup menu Power vs Time Configuration.
 *-----------------------------------------------------------------------------
 *      TEST CONFIGURATION
 *      The functions of this subsystem determine the parameters of the
 *      signal power measurement. GSM signals are transferred in the
 *      form of bursts, which divided up into various tolerance ranges
 *      defined in the GSM standard.
 * ----------------------------------------------------------------------------
 *        CONFIGURATION CONTROL
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpContDef (ViSession instrSession,
                                                                            ViBoolean DefaultValues,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (DefaultValues == 1)
  {
    sprintf (wrtBuf, "DEF:POW:NBUR:EPSK:TCH:CONT %s", mode_On_Off[DefaultValues]);
    if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
      return RSCMU300_Status;
  }
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Scope of measurement
/* Purpose : This function defines the scope of the power measurement,
/*           combining the ...CONTrol:RMODe, ...CONTrol:STATistics, and the
/*           ...CONTrol:REPetition commands.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpScope (ViSession instrSession,
                                                                          ViInt32   MeasuredValuesType,
                                                                          ViInt32   NbBurst,
                                                                          ViInt32   repetition,
                                                                          ViInt32   NbRepetition,
                                                                          ViInt32   StopCondition,
                                                                          ViInt32   StepMode,
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, repetition, 0, 2, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER7, errorMessage);

  if (repetition != RSCMU300_MULTIPLE)
    sprintf(wrtBuf, "CONF:POW:NBUR:EPSK:TCH:CONT %s,%ld,%s,%s,%s", mode_ScopeMeas[MeasuredValuesType]
                                                                , NbBurst
                                                                , repetition_meas[repetition]
                                                                , mode_StopCondition[StopCondition]
                                                                , StrStepMode[StepMode]);
  else
    sprintf(wrtBuf, "CONF:POW:NBUR:EPSK:TCH:CONT %s %ld %ld %s %s", mode_ScopeMeas[MeasuredValuesType]
                                                                , NbBurst
                                                                , NbRepetition
                                                                , mode_StopCondition[StopCondition]
                                                                , StrStepMode[StepMode]);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles, the
/*           stop condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpContRep (ViSession instrSession,
                                                                            ViInt32   RepetitionMode,
                                                                            ViInt32   StopCondition,
                                                                            ViInt32   StepMode,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, RepetitionMode, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:EPSK:TCH:CONT:REP %s,%s,%s", repetition_meas[RepetitionMode]
                                                        , mode_StopCondition[StopCondition]
                                                        , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Filter
/* Purpose : This function selects the measurement filter.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowgEpFilter (ViSession instrSession,
                                                      ViInt32   filter,
                                                      ViChar    errorMessage[])
{
 ViStatus    RSCMU300_Status = VI_SUCCESS;

 // Version manager
 CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

 RETMSG(RSCMU300_setEnum(instrSession, "CONF:POW:NBUR:EPSK:TCH:FILT",
                         filter, StrFilter,
                         RSCMU_ERROR_PARAMETER2));
}

/*
 * -----------------------------------------------------------------------------
 *        LIMITS LINES
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Default limit Lines (ON/OFF)
/* Purpose : This function switches the default limit lines on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpLimDef (ViSession instrSession,
                                                                           ViBoolean DefaultLimitLines,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultLimitLines, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DEF:POW:NBUR:EPSK:TCH:LIM:LINE %s", mode_On_Off[DefaultLimitLines]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
   return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Switches the lower limit lines ON/OFF
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpLimLowMode (ViSession instrSession,
                                                                               ViBoolean enable,
                                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, enable, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:EPSK:TCH:LIM:LINE:ASYM:LOW:ENAB %s", mode_On_Off[enable]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Switches the upper limit lines ON/OFF
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpLimUppMode (ViSession instrSession,
                                                                               ViBoolean enable,
                                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, enable, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:EPSK:TCH:LIM:LINE:ASYM:UPP:ENAB %s", mode_On_Off[enable]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Lower limit Lines
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpLimLow (ViSession instrSession,
                                                                           ViInt32   area,
                                                                           ViBoolean enable,
                                                                           ViBoolean StartPointBitON_OFF,
                                                                           ViReal64  StartPointBit,
                                                                           ViBoolean EndPointBitON_OFF,
                                                                           ViReal64  EndPointBit,
                                                                           ViBoolean StartPointRelLevON_OFF,
                                                                           ViReal64  StartPointRelLev,
                                                                           ViBoolean EndPointRelLevON_OFF,
                                                                           ViReal64  EndPointRelLev,
                                                                           ViBoolean StartPointAbsLevON_OFF,
                                                                           ViReal64  StartPointAbsLev,
                                                                           ViBoolean EndPointAbsLevON_OFF,
                                                                           ViReal64  EndPointAbsLev,
                                                                           ViBoolean visibility,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      StartPointBitBuf[64]= "",
              EndPointBitBuf[64]= "",
              StartPointRelLevBuf[64]= "",
              EndPointRelLevBuf[64]= "",
              StartPointAbsLevBuf[64]= "",
              EndPointAbsLevBuf[64]= "";

  if (StartPointBitON_OFF == RSCMU300_ON)
    sprintf(StartPointBitBuf, "%.12f", StartPointBit);
  else sprintf(StartPointBitBuf, "%s", "OFF");

  if (EndPointBitON_OFF == RSCMU300_ON)
    sprintf(EndPointBitBuf, "%.12f", EndPointBit);
  else sprintf(EndPointBitBuf, "%s", "OFF");

  if (StartPointRelLevON_OFF == RSCMU300_ON)
    sprintf(StartPointRelLevBuf, "%.12f", StartPointRelLev);
  else sprintf(StartPointRelLevBuf, "%s", "OFF");

  if (EndPointRelLevON_OFF == RSCMU300_ON)
    sprintf(EndPointRelLevBuf, "%.12f", EndPointRelLev);
  else sprintf(EndPointRelLevBuf, "%s", "OFF");

  if (StartPointAbsLevON_OFF == RSCMU300_ON)
    sprintf(StartPointAbsLevBuf, "%.12f", StartPointAbsLev);
  else sprintf(StartPointAbsLevBuf, "%s", "OFF");

  if (EndPointAbsLevON_OFF == RSCMU300_ON)
    sprintf(EndPointAbsLevBuf, "%.12f", EndPointAbsLev);
  else sprintf(EndPointAbsLevBuf, "%s", "OFF");

  sprintf (wrtBuf, "CONF:POW:NBUR:EPSK:TCH:LIM:LINE:ASYM:LOW:AREA%ld:ENABle %s", area
                                                                              , mode_On_Off[enable]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  sprintf (wrtBuf, "CONF:POW:NBUR:EPSK:TCH:LIM:LINE:ASYM:LOW:AREA%ld %s,%s,%s,%s,%s,%s,%s", area
                                                                                         , StartPointBitBuf
                                                                                         , EndPointBitBuf
                                                                                         , StartPointRelLevBuf
                                                                                         , EndPointRelLevBuf
                                                                                         , StartPointAbsLevBuf
                                                                                         , EndPointAbsLevBuf
                                                                                         , mode_On_Off[visibility]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Upper limit Lines
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpLimUpp (ViSession instrSession,
                                                                           ViInt32   area,
                                                                           ViBoolean enable,
                                                                           ViBoolean StartPointBitON_OFF,
                                                                           ViReal64  StartPointBit,
                                                                           ViBoolean EndPointBitON_OFF,
                                                                           ViReal64  EndPointBit,
                                                                           ViBoolean StartPointRelLevON_OFF,
                                                                           ViReal64  StartPointRelLev,
                                                                           ViBoolean EndPointRelLevON_OFF,
                                                                           ViReal64  EndPointRelLev,
                                                                           ViBoolean StartPointAbsLevON_OFF,
                                                                           ViReal64  StartPointAbsLev,
                                                                           ViBoolean EndPointAbsLevON_OFF,
                                                                           ViReal64  EndPointAbsLev,
                                                                           ViBoolean visibility,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      StartPointBitBuf[64]= "",
              EndPointBitBuf[64]= "",
              StartPointRelLevBuf[64]= "",
              EndPointRelLevBuf[64]= "",
              StartPointAbsLevBuf[64]= "",
              EndPointAbsLevBuf[64]= "";

  if (StartPointBitON_OFF == RSCMU300_ON)
    sprintf(StartPointBitBuf, "%.12f", StartPointBit);
  else sprintf(StartPointBitBuf, "%s", "OFF");

  if (EndPointBitON_OFF == RSCMU300_ON)
    sprintf(EndPointBitBuf, "%.12f", EndPointBit);
  else sprintf(EndPointBitBuf, "%s", "OFF");

  if (StartPointRelLevON_OFF == RSCMU300_ON)
    sprintf(StartPointRelLevBuf, "%.12f", StartPointRelLev);
  else sprintf(StartPointRelLevBuf, "%s", "OFF");

  if (EndPointRelLevON_OFF == RSCMU300_ON)
    sprintf(EndPointRelLevBuf, "%.12f", EndPointRelLev);
  else sprintf(EndPointRelLevBuf, "%s", "OFF");

  if (StartPointAbsLevON_OFF == RSCMU300_ON)
    sprintf(StartPointAbsLevBuf, "%.12f", StartPointAbsLev);
  else sprintf(StartPointAbsLevBuf, "%s", "OFF");

  if (EndPointAbsLevON_OFF == RSCMU300_ON)
    sprintf(EndPointAbsLevBuf, "%.12f", EndPointAbsLev);
  else sprintf(EndPointAbsLevBuf, "%s", "OFF");

  sprintf (wrtBuf, "CONF:POW:NBUR:EPSK:TCH:LIM:LINE:ASYM:UPP:AREA%ld:ENABle %s", area
                                                                              , mode_On_Off[enable]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  sprintf (wrtBuf, "CONF:POW:NBUR:EPSK:TCH:LIM:LINE:ASYM:UPP:AREA%ld %s,%s,%s,%s,%s,%s,%s", area
                                                                                         , StartPointBitBuf
                                                                                         , EndPointBitBuf
                                                                                         , StartPointRelLevBuf
                                                                                         , EndPointRelLevBuf
                                                                                         , StartPointAbsLevBuf
                                                                                         , EndPointAbsLevBuf
                                                                                         , mode_On_Off[visibility]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * -----------------------------------------------------------------------------
 *        TIME
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Offset on the burst
/* Purpose : This function defines an offset time in  Bit units by which the
/*           burst is shifted relative to the time axis and the tolerance
/*           template.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpTimeBit (ViSession instrSession,
                                                     ViReal64  TimeBit,
                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Queries the specified attribute:
  CHECKRET(viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase));


    // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, TimeBit, RSCMU300_TIMEBIT_MIN, RSCMU300_TIMEBIT_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
    sprintf (wrtBuf, "CONF:POW:NBUR:EPSK:TCH:TIME:BOFF %.12f", TimeBit);
    }
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
    sprintf (wrtBuf, "CONF:POW:NBUR:EPSK:TCH:TOFF %.12f", TimeBit);
    }

  RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*
 * -----------------------------------------------------------------------------
 *        REFERENCE POWER
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Reference Power Mode
/* Purpose : this function determines the way how the reference power is
/*           calculated in 8PSK modulation.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpRPMode (ViSession instrSession,
                                                                           ViInt32   mode,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"CURR","AVER","DCOM"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:EPSK:TCH:RPM %s", StrMode[mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Scope of Measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpCont (ViSession instrSession,
                                                                         ViInt32   MeasuredValuesType,
                                                                         ViInt32   NbBurst,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:EPSK:TCH:CONT:STAT %ld", NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  sprintf (wrtBuf, "CONF:POW:NBUR:EPSK:TCH:CONT:RMOD %s", mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set the number of bursts
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpStat (ViSession instrSession,
                                                                         ViInt32   NbBurst,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:EPSK:TCH:CONT:STAT %ld", NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set result mode
/* Purpose : This function specifies the type of measured values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpResMode (ViSession instrSession,
                                                                            ViInt32   MeasuredValuesType,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:EPSK:TCH:CONT:RMOD %s", mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles, the
/*           stop condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpContRepSt (ViSession instrSession,
                                                                              ViInt32   NbRepetition,
                                                                              ViInt32   StopCondition,
                                                                              ViInt32   StepMode,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:EPSK:TCH:CONT:REP %ld,%s,%s", NbRepetition
                                                             , mode_StopCondition[StopCondition]
                                                             , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      MEASUREMENT
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Definition of Subarrays
/* Purpose : This function configures the READ:SUBarrays:POWer...,
/*           FETCh:SUBarrays:POWer..., and SAMPle:SUBarrays:POWer commands. It
/*           restricts the measurement to up to 32 subranges where either all
/*           measurement results (the number of which is given by the second
/*           numerical parameter) or a single statistical value is returned.
/*           The subranges are defined by the start time and the number of
/*           test points which are located on a fixed, equidistant grid with
/*           a step width of  Bit.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubPowEpRang (ViSession instrSession,
                                                                            ViInt32   StatisticsMode,
                                                                            ViReal64  StartTime,
                                                                            ViInt32   Samples,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"ALL","ARIT","MIN","MAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, StartTime, RSCMU300_SUBPOW_BIT_MIN, RSCMU300_SUBPOW_BIT_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Samples, RSCMU300_SUBPOW_SAMPLES_MIN, RSCMU300_SUBPOW_SAMPLES_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:POW:NBUR:EPSK:TCH %s,%.12f,%ld", StrMode[StatisticsMode]
                                                         , StartTime
                                                         , Samples);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      MEASUREMENT CONTROL
 *      This subsystem contains the functions for general control of the
 *      power measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start new measurement
/* Purpose : This function starts the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitPowEp (ViSession instrSession,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViUInt32    retCnt = 0;

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "INIT:POW:NBUR:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort running measurement and switch off
/* Purpose : This function stops the power measurement, setting it to
/*           the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborPowEp (ViSession instrSession,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViUInt32    retCnt = 0;

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "ABOR:POW:NBUR:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: stop measurement after current statistic cycle
/* Purpose : This function stops the power measurement, setting it to
/*           the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopPowEp (ViSession instrSession,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViUInt32    retCnt = 0;

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "STOP:POW:NBUR:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Next Measurement Step
/* Purpose : This function continue the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContPowEp (ViSession instrSession,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViUInt32    retCnt = 0;

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CONT:POW:NBUR:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch measurement status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPowEpSt (ViSession instrSession,
                                                                       ViPInt32  MeasStatus,
                                                                       ViPInt32  CurrentStatCycleCount,
                                                                       ViPInt32  CurrentEvalPeriodCount,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  // Fetch the measurement status:
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:POW:NBUR:EPSK:TCH:STAT?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMeasStatVal(MeasStatus, tab, 0 );

  // Get the counter for current statistics cycle
  if (strcmp (tab[1], "NONE") != 0)
    sscanf (tab[1], "%ld", CurrentStatCycleCount);
  else *CurrentStatCycleCount = RSCMU300_OFF;

  // Get the counter for current evaluation period within a cycle
  if (strcmp (tab[2], "NONE") != 0)
    sscanf (tab[2], "%ld", CurrentEvalPeriodCount);
  else *CurrentEvalPeriodCount = RSCMU300_OFF;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpErep (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:EPSK:TCH:EREP %s", StrErep[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      MEASURED VALUES
 *      The functions of this subsystem determine and output the results
 *      of the signal power measurement.
 * ----------------------------------------------------------------------------
 *        MEASUREMENT AND BURST POWER
 *        (Subsystem POWer[:RESult])
 *        It contains the functions for measurement and output of the
 *        burst power and its comparison with tolerance values.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function starts the power measurement and outputs the result.
/*           For details refer to the description of measurement control in
/*           chapter 5 of the CMU200 operating manual. The results are:
/*
/*              Bursts out of tolerance (percentage)
/*              Average power of current burst
/*              Peak power of current burst
/*              Average power of averaged trace
/*              Burst template matching
/*
/*           The calculation of results in an average or peak measurement is
/*           described in chapter 3 (cf. display modes).The following messages
/*           may be output for the value BurstMatching:
/*
/*              MATC matching
/*              NMAT not matching
/*              INV invalid
/*              NTSC no training sequence code
/*              OUT out of range
/*              NTRG not triggered
/*              UFLW underflow
/*              OFLW overflow
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadPowEp (ViSession instrSession,
                                                                     ViPReal64 BurstOutOfTol,
                                                                     ViPReal64 AvgBurstPowerCurrent,
                                                                     ViPReal64 PeakBurstPower,
                                                                     ViPInt32  BurstMatching,
                                                                     ViPReal64 AvgBurstPowerAvg,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:POW:NBUR:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  RSCMU300_Status = RSCMU300_ScanPow (tab, 0, BurstOutOfTol, AvgBurstPowerCurrent, PeakBurstPower, BurstMatching, AvgBurstPowerAvg);
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function outputs the result.
/*           For details refer to the description of measurement control in
/*           chapter 5 of the CMU200 operating manual. The results are:
/*
/*              Bursts out of tolerance (percentage)
/*              Average power of current burst
/*              Peak power of current burst
/*              Average power of averaged trace
/*              Burst template matching
/*
/*           The calculation of results in an average or peak measurement is
/*           described in chapter 3 (cf. display modes).The following messages
/*           may be output for the value BurstMatching:
/*
/*              MATC matching
/*              NMAT not matching
/*              INV invalid
/*              NTSC no training sequence code
/*              OUT out of range
/*              NTRG not triggered
/*              UFLW underflow
/*              OFLW overflow
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPowEp (ViSession instrSession,
                                                                     ViPReal64 BurstOutOfTol,
                                                                     ViPReal64 AvgBurstPowerCurrent,
                                                                     ViPReal64 PeakBurstPower,
                                                                     ViPInt32  BurstMatching,
                                                                     ViPReal64 AvgBurstPowerAvg,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:POW:NBUR:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  RSCMU300_Status = RSCMU300_ScanPow (tab, 0, BurstOutOfTol, AvgBurstPowerCurrent, PeakBurstPower, BurstMatching, AvgBurstPowerAvg);
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function starts the power measurement and outputs the result.
/*           For details refer to the description of measurement control in
/*           chapter 5 of the CMU200 operating manual. The results are:
/*
/*              Bursts out of tolerance (percentage)
/*              Average power of current burst
/*              Peak power of current burst
/*              Average power of averaged trace
/*              Burst template matching
/*
/*           The calculation of results in an average or peak measurement is
/*           described in chapter 3 (cf. display modes).The following messages
/*           may be output for the value BurstMatching:
/*
/*              MATC matching
/*              NMAT not matching
/*              INV invalid
/*              NTSC no training sequence code
/*              OUT out of range
/*              NTRG not triggered
/*              UFLW underflow
/*              OFLW overflow
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampPowEp (ViSession instrSession,
                                                                     ViPReal64 BurstOutOfTol,
                                                                     ViPReal64 AvgBurstPowerCurrent,
                                                                     ViPReal64 PeakBurstPower,
                                                                     ViPInt32  BurstMatching,
                                                                     ViPReal64 AvgBurstPowerAvg,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:POW:NBUR:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  RSCMU300_Status = RSCMU300_ScanPow (tab, 0, BurstOutOfTol, AvgBurstPowerCurrent, PeakBurstPower, BurstMatching, AvgBurstPowerAvg);
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Request Tolerance On Values
/* Purpose : This function indicates whether and in which way the per-
/*           missible tolerances for the scalar measured values  have
/*           been exceeded.
/*
/*           The following messages may be output for the values
/*           AvgBurstPower, AvgBurstPowerAvg and PeakBurstPower:
/*
/*              NMAU Tolerance value underflow not matching, underflow
/*              NMAL Tolerance value exceeded not matching, overflow
/*              INV  Measurement invalid invalid
/*              OK   Tolerance value matched
/*
/*           The following messages may be output for the value
/*           BurstMatching:
/*
/*              MATC matching
/*              NMAT not matching
/*              INV  invalid
/*              NTSC no training sequence code
/*              OUT  out of range
/*
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcPowEpMatcLim (ViSession instrSession,
                                                                            ViPInt32  AvgBurstPowerCurrent,
                                                                            ViPInt32  PeakBurstPower,
                                                                            ViPInt32  BurstTemplateMatching,
                                                                            ViPInt32  AvgBurstPowerAvg,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CALC:POW:NBUR:EPSK:TCH:MATC:LIM?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Average Burst Power
  RSCMU300_Status = RSCMU300_GetMatchingValue(AvgBurstPowerCurrent,tab, 0);

  // Peak Burst Power
  RSCMU300_Status = RSCMU300_GetMatchingValue(PeakBurstPower,tab, 1);

  // Burst Matching
  RSCMU300_Status = RSCMU300_GetMatchingValue(BurstTemplateMatching,tab, 2);

    // Average Burst Power Average
  RSCMU300_Status = RSCMU300_GetMatchingValue(AvgBurstPowerAvg,tab, 3);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Burst power measured values
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrPowEp (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  BurstPower[],
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:ARR:POW:NBUR:EPSK:TCH:%s?", StrStatMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Burst power measured values
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrPowEp (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  BurstPower[],
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:ARR:POW:NBUR:EPSK:TCH:%s?", StrStatMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Burst power measured values
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrPowEp (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  BurstPower[],
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:ARR:POW:NBUR:EPSK:TCH:%s?", StrStatMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Tolerance error of power measurement
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcArrPowEpMatcLim (ViSession instrSession,
                                                                               ViInt32   StatisticsMode,
                                                                               ViPInt32  ToleranceError,
                                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (StatisticsMode)
  {
    case RSCMU300_AVERAGE:
      sprintf (wrtBuf, "CALC:ARR:POW:NBUR:EPSK:TCH:AVER:MATC:LIM?");
      break;
    case RSCMU300_CURRENT:
      sprintf (wrtBuf, "CALC:ARR:POW:NBUR:EPSK:TCH:CURR:MATC:LIM?");
      break;
    case RSCMU300_MAXIMUM:
      sprintf (wrtBuf, "CALC:ARR:POW:NBUR:EPSK:TCH:MAX:MATC:LIM?");
      break;
    case RSCMU300_MINIMUM:
      sprintf (wrtBuf, "CALC:ARR:POW:NBUR:EPSK:TCH:MIN:MATC:LIM?");
      break;
  }

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Get the matching value:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);
  RSCMU300_GetMatchingValue (ToleranceError, tab, 0);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: indicates that the corresponding area of the limit lines is
/*           violated.
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcArrPowEpAreaMatc (ViSession instrSession,
                                                                                ViInt32   StatisticsMode,
                                                                                ViPInt32  UpperLimit,
                                                                                ViPInt32  LowerLimit,
                                                                                ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (StatisticsMode)
  {
    case RSCMU300_AVERAGE:
      sprintf (wrtBuf, "CALC:ARR:POW:NBUR:EPSK:TCH:AVER:MATC:AREA?");
      break;
    case RSCMU300_CURRENT:
      sprintf (wrtBuf, "CALC:ARR:POW:NBUR:EPSK:TCH:CURR:MATC:AREA?");
      break;
    case RSCMU300_MAXIMUM:
      sprintf (wrtBuf, "CALC:ARR:POW:NBUR:EPSK:TCH:MAX:MATC:AREA?");
      break;
    case RSCMU300_MINIMUM:
      sprintf (wrtBuf, "CALC:ARR:POW:NBUR:EPSK:TCH:MIN:MATC:AREA?");
      break;
  }
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the upper Limit Matching
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%ld", UpperLimit);
  else *UpperLimit = RSCMU300_NAN_VI_INT32;

  // Get the lower Limit Matching
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%ld", LowerLimit);
  else *LowerLimit = RSCMU300_NAN_VI_INT32;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: This function outputs the burst power versus time in a fixed
/*           -Bit pattern and in the subranges defined by means of the
/*           CONFigure:SUBarrays:POWer command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubPowEp (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  BurstPower[],
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[RSCMU300_SUBPOW_SAMPLES_MAX+1][20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:SUB:POW:NBUR:EPSK:TCH:%s?", StrStatMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: This function outputs the burst power versus time in a fixed
/*           -Bit pattern and in the subranges defined by means of the
/*           CONFigure:SUBarrays:POWer command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubPowEp (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  BurstPower[],
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[RSCMU300_SUBPOW_SAMPLES_MAX+1][20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:SUB:POW:NBUR:EPSK:TCH:%s?", StrStatMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: This function outputs the burst power versus time in a fixed
/*           -Bit pattern and in the subranges defined by means of the
/*           CONFigure:SUBarrays:POWer command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubPowEp (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  BurstPower[],
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[RSCMU300_SUBPOW_SAMPLES_MAX+1][20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:SUB:POW:NBUR:EPSK:TCH:%s?", StrStatMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT MODULATION OEMP
 *
 *    The subsystem MODulation:OEMP:EPSK[:TCH]:LIMit defines tolerance values
 *    for the modulation measurement in all four 8PSK applications. The
 *    subsystem corresponds to the Limits tab in the popup menu Modulation
 *    Configuration.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Default limit Lines (ON/OFF)
/* Purpose : This function switches the default limit lines on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfOempEpLimDef (ViSession instrSession,
                                                                            ViBoolean defaultLimitLines,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, defaultLimitLines, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DEF:MOD:OEMP:EPSK:TCH:LIM %s", mode_On_Off[defaultLimitLines]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Upper Limit Lines
/* Purpose : This function defines upper limits for the Current, Max./Min and
/*           Average traces and for the scalar modulation parameters derived
/*           from them.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfOempEpUppLim (ViSession instrSession,
                                                                            ViInt32   Limits,
                                                                            ViReal64  EVMErrorPeak,
                                                                            ViReal64  EVMErrorRMS,
                                                                            ViReal64  magnErrorPeak,
                                                                            ViReal64  magnErrorRMS,
                                                                            ViReal64  phaseErrorPeak,
                                                                            ViReal64  phaseErrorRMS,
                                                                            ViReal64  originOffset,
                                                                            ViReal64  IQImBalance,
                                                                            ViInt32   frequencyError,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrLimits[] = {"CMM","AVER"};
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, Limits, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, EVMErrorPeak, 0, 50, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, EVMErrorRMS, 0, 50, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, magnErrorPeak, 0, 50, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, magnErrorRMS, 0, 50, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, phaseErrorPeak, 0, 180, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, phaseErrorRMS, 0, 180, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, originOffset, -100, 0, RSCMU_ERROR_PARAMETER9, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, IQImBalance, -100, 0, RSCMU_ERROR_PARAMETER10, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, frequencyError, 0, 999, RSCMU_ERROR_PARAMETER11, errorMessage);


if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
    sprintf (wrtBuf, "CONF:MOD:OEMP:EPSK:TCH:%s:LIM:SYMM:VAL %.12f,%.12f,%.12f,%.12f,%.12f,%.12f,%.12f,%.12f,%ld", StrLimits[Limits]
                                                                                                , EVMErrorPeak
                                                                                                , EVMErrorRMS
                                                                                                , magnErrorPeak
                                                                                                , magnErrorRMS
                                                                                                , phaseErrorPeak
                                                                                                , phaseErrorRMS
                                                                                                , originOffset
                                                                                                , IQImBalance
                                                                                                , frequencyError);
    if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
      return RSCMU300_Status;
}
 //IQ Imbalance are not supported in Version >= V3.06
if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
    sprintf (wrtBuf, "CONF:MOD:OEMP:EPSK:TCH:%s:LIM:SYMM:VAL %.12f,%.12f,%.12f,%.12f,%.12f,%.12f,%.12f,%ld", StrLimits[Limits]
                                                                                                , EVMErrorPeak
                                                                                                , EVMErrorRMS
                                                                                                , magnErrorPeak
                                                                                                , magnErrorRMS
                                                                                                , phaseErrorPeak
                                                                                                , phaseErrorRMS
                                                                                                , originOffset
                                                                                                , frequencyError);
    if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
      return RSCMU300_Status;
}

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: 95% Upper Limits
/* Purpose : This function defines upper limits for the 95 th percentile of
/*           the three quantities error vector magnitude, modulation error,
/*           and phase error. The 95 th percentile is the limit below which
/*           95% of the measured errors are located.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfOempUppLim95 (ViSession instrSession,
                                                                            ViReal64  EVM95,
                                                                            ViReal64  modulationError95,
                                                                            ViReal64  phaseError95,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_REAL64_RANGE(instrSession, EVM95, 0, 50, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, modulationError95, 0, 100, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, phaseError95, 0, 180, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:OEMP:EPSK:TCH:P95T:LIM:SYMM:VAL %.12f,%.12f,%.12f", EVM95
                                                                         , modulationError95
                                                                         , phaseError95);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Reference Power Mode
/* Purpose : this function determines the way how the reference power is
/*           calculated in 8PSK modulation.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfModEpRPMode (ViSession instrSession,
                                                    ViInt32   mode,
                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViString    list[] = {"CURR","AVER","DCOM",VI_NULL};

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_22,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  RETMSG(RSCMU300_setEnum(instrSession, "CONF:MOD:OEMP:EPSK:TCH:RPM",
                         mode, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT MODULATION OVERview
 *
 *    The subsystem MODulation[:OVERview]:EPSK measures general scalar
 *    modulation parameters in 8PSK modulation. The subsystem corresponds to
 *    the measurement menu Modulation, application Overview 8PSK, and the
 *    associated popup menu Modulation Error Config.
 * ----------------------------------------------------------------------------
 *      CONFIGURATION CONTROL
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfOverEpContDef (ViSession instrSession,
                                                                             ViBoolean DefaultValues,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DEF:MOD:OVER:EPSK:TCH:CONT %s", mode_On_Off[DefaultValues]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Scope of measurement
/* Purpose : This function defines the scope of the power measurement,
/*           combining the ...CONTrol:RMODe, ...CONTrol:STATistics, and the
/*           ...CONTrol:REPetition commands.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfOverEpScope (ViSession instrSession,
                                                                           ViInt32   MeasuredValuesType,
                                                                           ViInt32   NbBurst,
                                                                           ViInt32   repetition,
                                                                           ViInt32   NbRepetition,
                                                                           ViInt32   StopCondition,
                                                                           ViInt32   StepMode,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, repetition, 0, 2, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER7, errorMessage);

  if (repetition != RSCMU300_MULTIPLE)
    sprintf(wrtBuf, "CONF:MOD:OVER:EPSK:TCH:CONT %s,%ld,%s,%s,%s", mode_ScopeMeas[MeasuredValuesType]
                                                                , NbBurst
                                                                , repetition_meas[repetition]
                                                                , mode_StopCondition[StopCondition]
                                                                , StrStepMode[StepMode]);
  else
    sprintf(wrtBuf, "CONF:MOD:OVER:EPSK:TCH:CONT %s %ld %ld %s %s", mode_ScopeMeas[MeasuredValuesType]
                                                                , NbBurst
                                                                , NbRepetition
                                                                , mode_StopCondition[StopCondition]
                                                                , StrStepMode[StepMode]);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfOverEpContRep (ViSession instrSession,
                                                                             ViInt32   Repetition,
                                                                             ViInt32   StopCondition,
                                                                             ViInt32   StepMode,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, Repetition, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:MOD:OVER:EPSK:TCH:CONT:REP %s,%s,%s", repetition_meas[Repetition]
                                                             , mode_StopCondition[StopCondition]
                                                             , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      STATISTICS
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set statistics count and result mode
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfOverEpCont (ViSession instrSession,
                                                                          ViInt32   MeasuredValuesType,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:OVER:EPSK:TCH:CONT:RMOD %s", mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  sprintf (wrtBuf, "CONF:MOD:OVER:EPSK:TCH:CONT:STAT %ld", NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set the number of bursts
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfOverEpStat (ViSession instrSession,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:OVER:EPSK:TCH:CONT:STAT %ld", NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set result mode
/* Purpose : This function specifies the type of measured values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfOverEpResMode (ViSession instrSession,
                                                                             ViInt32   MeasuredValuesType,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:OVER:EPSK:TCH:CONT:RMOD %s", mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfOverEpContRepSt (ViSession instrSession,
                                                                               ViInt32   NbRepetition,
                                                                               ViInt32   StopCondition,
                                                                               ViInt32   StepMode,
                                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:MOD:OVER:EPSK:TCH:CONT:REP %ld,%s,%s", NbRepetition
                                                             , mode_StopCondition[StopCondition]
                                                             , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      CONTROL OF MODULATION MEAS
 *      It contains the functions for general control of the modulation
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start Modulation Measurements
/* Purpose : This function start the modulation measurement,
/*           setting it to the status beyond.
/*           RUN        Start measurement without waiting
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitOverEp (ViSession instrSession,
                                                                      ViChar _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "INIT:MOD:OVER:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort Modulation Measurements
/* Purpose : This function abort the running modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborOverEp (ViSession instrSession,
                                                                      ViChar _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "ABOR:MOD:OVER:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Stop Modulation Measurements
/* Purpose : This function stop measurement after current statistic cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopOverEp (ViSession instrSession,
                                                                      ViChar _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "STOP:MOD:OVER:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Run next measurement step
/* Purpose : This function runs next modulation measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContOverEp (ViSession instrSession,
                                                                      ViChar _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CONT:MOD:OVER:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Measurement Status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcOverEpSt (ViSession instrSession,
                                                                        ViPInt32  MeasStatus,
                                                                        ViPInt32  CurrentStatCycleCount,
                                                                        ViPInt32  CurrentEvalPeriodCount,
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Fetch the measurement status:
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:MOD:OVER:EPSK:TCH:STAT?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMeasStatVal(MeasStatus, tab, 0);

  // Get the counter for current statistics cycle
  if (strcmp (tab[1], "NONE") != 0)
    sscanf (tab[1], "%ld", CurrentStatCycleCount);
  else
    *CurrentStatCycleCount = RSCMU300_OFF;

  // Get the counter for current evaluation period within a cycle
  if (strcmp (tab[2], "NONE") != 0)
    sscanf (tab[2], "%ld", CurrentEvalPeriodCount);
  else *CurrentEvalPeriodCount = RSCMU300_OFF;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfOverEpErep (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:OVER:EPSK:TCH:EREP %s", StrErep[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      Subsystem MODulation[:OVERview]:EPSK[:TCH][:RESult]
 *      The subsystem MODulation[:OVERview]:EPSK:[:TCH][:RESULT] measures and
 *      returns the modulation parameters and compares them with the tolerance
 *      values. The subsystem corresponds to the various output elements in
 *      the measurement menu MODulation, application Overview 8PSK.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all
/*           scalar measurement results (see chapter 4). The calculation of
/*           results in an average or peak measurement is described in chapter
/*           3 (see calculation of statistical quantities). The symbol (x3)
/*           behind a value indicates that the list contains three results
/*           corresponding to the Current, the Average, and the MMax value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadOverEp (ViSession instrSession,
                                                                      ViInt32   StatisticsMode,
                                                                      ViPReal64 EVM95,
                                                                      ViPReal64 MagErr95,
                                                                      ViPReal64 PhaseErr95,
                                                                      ViPReal64 EVMPeak,
                                                                      ViPReal64 EVMRMS,
                                                                      ViPReal64 magnErrorPeak,
                                                                      ViPReal64 magnErrorRMS,
                                                                      ViPReal64 phaseErrorPeak,
                                                                      ViPReal64 phaseErrorRMS,
                                                                      ViPReal64 originOffset,
                                                                      ViPReal64 IQIm_balance,
                                                                      ViPReal64 frequencyError,
                                                                      ViPReal64 avgBurstPowerCurr,
                                                                      ViPReal64 burstOutOfTol,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;


  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:MOD:OVER:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
      RSCMU300_Status = RSCMU300_ScanOverEpsk (tab, 0, StatisticsMode, EVM95, MagErr95, PhaseErr95, EVMPeak, EVMRMS, magnErrorPeak,
                                 magnErrorRMS, phaseErrorPeak, phaseErrorRMS, originOffset, IQIm_balance, frequencyError,
                                 avgBurstPowerCurr, burstOutOfTol);
    }
 //IQ Imbalance are not supported in Version >= V3.06
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
      RSCMU300_Status = RSCMU300_ScanOverEpskV306 (tab, 0, StatisticsMode, EVM95, MagErr95, PhaseErr95, EVMPeak, EVMRMS, magnErrorPeak,
                                 magnErrorRMS, phaseErrorPeak, phaseErrorRMS, originOffset, IQIm_balance, frequencyError,
                                 avgBurstPowerCurr, burstOutOfTol);
    }

return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all
/*           scalar measurement results (see chapter 4). The calculation of
/*           results in an average or peak measurement is described in chapter
/*           3 (see calculation of statistical quantities). The symbol (x3)
/*           behind a value indicates that the list contains three results
/*           corresponding to the Current, the Average, and the MMax value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcOverEp (ViSession instrSession,
                                                                      ViInt32   StatisticsMode,
                                                                      ViPReal64 EVM95,
                                                                      ViPReal64 MagErr95,
                                                                      ViPReal64 PhaseErr95,
                                                                      ViPReal64 EVMPeak,
                                                                      ViPReal64 EVMRMS,
                                                                      ViPReal64 magnErrorPeak,
                                                                      ViPReal64 magnErrorRMS,
                                                                      ViPReal64 phaseErrorPeak,
                                                                      ViPReal64 phaseErrorRMS,
                                                                      ViPReal64 originOffset,
                                                                      ViPReal64 IQIm_balance,
                                                                      ViPReal64 frequencyError,
                                                                      ViPReal64 avgBurstPowerCurr,
                                                                      ViPReal64 burstOutOfTol,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:MOD:OVER:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanOverEpsk (tab, 0, StatisticsMode, EVM95, MagErr95, PhaseErr95, EVMPeak, EVMRMS, magnErrorPeak,
                                 magnErrorRMS, phaseErrorPeak, phaseErrorRMS, originOffset, IQIm_balance, frequencyError,
                                 avgBurstPowerCurr, burstOutOfTol);
    }
 //IQ Imbalance are not supported in Version >= V3.06
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
      RSCMU300_Status = RSCMU300_ScanOverEpskV306 (tab, 0, StatisticsMode, EVM95, MagErr95, PhaseErr95, EVMPeak, EVMRMS, magnErrorPeak,
                                 magnErrorRMS, phaseErrorPeak, phaseErrorRMS, originOffset, IQIm_balance, frequencyError,
                                 avgBurstPowerCurr, burstOutOfTol);
    }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all
/*           scalar measurement results (see chapter 4). The calculation of
/*           results in an average or peak measurement is described in chapter
/*           3 (see calculation of statistical quantities). The symbol (x3)
/*           behind a value indicates that the list contains three results
/*           corresponding to the Current, the Average, and the MMax value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampOverEp (ViSession instrSession,
                                                                      ViInt32   StatisticsMode,
                                                                      ViPReal64 EVM95,
                                                                      ViPReal64 MagErr95,
                                                                      ViPReal64 PhaseErr95,
                                                                      ViPReal64 EVMPeak,
                                                                      ViPReal64 EVMRMS,
                                                                      ViPReal64 magnErrorPeak,
                                                                      ViPReal64 magnErrorRMS,
                                                                      ViPReal64 phaseErrorPeak,
                                                                      ViPReal64 phaseErrorRMS,
                                                                      ViPReal64 originOffset,
                                                                      ViPReal64 IQIm_balance,
                                                                      ViPReal64 frequencyError,
                                                                      ViPReal64 avgBurstPowerCurr,
                                                                      ViPReal64 burstOutOfTol,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:MOD:OVER:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanOverEpsk (tab, 0, StatisticsMode, EVM95, MagErr95, PhaseErr95, EVMPeak, EVMRMS, magnErrorPeak,
                                 magnErrorRMS, phaseErrorPeak, phaseErrorRMS, originOffset, IQIm_balance, frequencyError,
                                 avgBurstPowerCurr, burstOutOfTol);
    }
 //IQ Imbalance are not supported in Version >= V3.06
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
      RSCMU300_Status = RSCMU300_ScanOverEpskV306 (tab, 0, StatisticsMode, EVM95, MagErr95, PhaseErr95, EVMPeak, EVMRMS, magnErrorPeak,
                                 magnErrorRMS, phaseErrorPeak, phaseErrorRMS, originOffset, IQIm_balance, frequencyError,
                                 avgBurstPowerCurr, burstOutOfTol);
    }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcOverEpMatcLim (ViSession instrSession,
                                                                             ViInt32   StatisticsMode,
                                                                             ViPInt32  EVM95,
                                                                             ViPInt32  MagErr95,
                                                                             ViPInt32  PhaseErr95,
                                                                             ViPInt32  EVMPeak,
                                                                             ViPInt32  EVMRMS,
                                                                             ViPInt32  magnErrorPeak,
                                                                             ViPInt32  magnErrorRMS,
                                                                             ViPInt32  phaseErrorPeak,
                                                                             ViPInt32  phaseErrorRMS,
                                                                             ViPInt32  originOffset,
                                                                             ViPInt32  IQIm_balance,
                                                                             ViPInt32  frequencyError,
                                                                             ViPInt32  avgBurstPowerCurr,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CALC:MOD:OVER:EPSK:TCH:MATC:LIM?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // 95% EVM with single-value measurement
  RSCMU300_Status = RSCMU300_GetMatchingValue(EVM95,tab,0);

  // 95% Magnitude Error with single-value measurement
  RSCMU300_Status = RSCMU300_GetMatchingValue(MagErr95,tab,1);

  // 95% Phase Error with single-value measurement
  RSCMU300_Status = RSCMU300_GetMatchingValue(PhaseErr95,tab,2);

  switch (StatisticsMode)
  {
    case RSCMU300_CURRENT:
        // EVM peak with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(EVMPeak,tab,3);

        // EVM RMS with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(EVMRMS,tab,6);

        // Magnitude Error Peak with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(magnErrorPeak,tab,9);

        // Magnitude Error RMS with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(magnErrorRMS,tab,12);

        // Phase Error Peak with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorPeak,tab,15);

        // Phase Error RMS with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorRMS,tab,18);

        // Origin Offset with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(originOffset,tab,21);

        if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
            {
            // IQ/IM Balance with single-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(IQIm_balance,tab,24);

            // Frequency Error with single-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,27);
            }
        else
            {
            // IQ/IM Balance with single-value measurement
            *IQIm_balance= RSCMU300_INV;

            // Frequency Error with single-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,24);
            }
    break;

    case RSCMU300_AVERAGE:
        // EVM peak with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(EVMPeak,tab,4);

        // EVM RMS with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(EVMRMS,tab,7);

        // Magnitude Error Peak with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(magnErrorPeak,tab,10);

        // Magnitude Error RMS with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(magnErrorRMS,tab,13);

        // Phase Error Peak with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorPeak,tab,16);

        // Phase Error RMS with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorRMS,tab,19);

        // Origin Offset with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(originOffset,tab,22);

        if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
            {
            // IQ/IM Balance with average measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(IQIm_balance,tab,25);

            // Frequency Error with average measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,28);
            }
        else
            {
            // IQ/IM Balance with average measurement
            *IQIm_balance= RSCMU300_INV;

            // Frequency Error with average measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,25);
            }
    break;

    case RSCMU300_MAXMIN:
        // EVM peak with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(EVMPeak,tab,5);

        // EVM RMS with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(EVMRMS,tab,7);

        // Magnitude Error Peak with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(magnErrorPeak,tab,11);

        // Magnitude Error RMS with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(magnErrorRMS,tab,14);

        // Phase Error Peak with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorPeak,tab,17);

        // Phase Error RMS with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorRMS,tab,20);

        // Origin Offset with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(originOffset,tab,23);

        if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
            {
            // IQ/IM Balance with extreme-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(IQIm_balance,tab,26);

            // Frequency Error with extreme-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,29);
            }
        else
            {
            // IQ/IM Balance with extreme-value measurement
            *IQIm_balance= RSCMU300_INV;

            // Frequency Error with extreme-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,26);
            }

    break;
  }

    if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
        {
         // Average Burst Power Current with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(avgBurstPowerCurr,tab,30);
        }
    else
        {
         // Average Burst Power Current with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(avgBurstPowerCurr,tab,27);
        }
  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT MODULATION EVMagnitude
 *
 *    The subsystem MODulation:EVMagnitude measures the error vector magnitude
 *    as well as general scalar modulation parameters. The subsystem corresponds
 *    to the measurement menu Modulation, application Error Vect. Magn. 8PSK,
 *    and the associated popup menu Modulation Error Config.
 * ----------------------------------------------------------------------------
 *      CONFIGURATION CONTROL
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfEvmEpContDef (ViSession instrSession,
                                                                            ViBoolean DefaultValues,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DEF:MOD:EVM:EPSK:TCH:CONT %s", mode_On_Off[DefaultValues]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Scope of measurement
/* Purpose : This function defines the scope of the power measurement,
/*           combining the ...CONTrol:RMODe, ...CONTrol:STATistics, and the
/*           ...CONTrol:REPetition commands.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfEvmEpScope (ViSession instrSession,
                                                                          ViInt32   MeasuredValuesType,
                                                                          ViInt32   NbBurst,
                                                                          ViInt32   repetition,
                                                                          ViInt32   NbRepetition,
                                                                          ViInt32   StopCondition,
                                                                          ViInt32   StepMode,
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, repetition, 0, 2, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER7, errorMessage);

  if (repetition != RSCMU300_MULTIPLE)
    sprintf(wrtBuf, "CONF:MOD:EVM:EPSK:TCH:CONT %s,%ld,%s,%s,%s", mode_ScopeMeas[MeasuredValuesType]
                                                               , NbBurst
                                                               , repetition_meas[repetition]
                                                               , mode_StopCondition[StopCondition]
                                                               , StrStepMode[StepMode]);
  else
    sprintf(wrtBuf, "CONF:MOD:EVM:EPSK:TCH:CONT %s %ld %ld %s %s", mode_ScopeMeas[MeasuredValuesType]
                                                               , NbBurst
                                                               , NbRepetition
                                                               , mode_StopCondition[StopCondition]
                                                               , StrStepMode[StepMode]);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfEvmEpContRep (ViSession instrSession,
                                                                            ViInt32   Repetition,
                                                                            ViInt32   StopCondition,
                                                                            ViInt32   StepMode,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, Repetition, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:MOD:EVM:EPSK:TCH:CONT:REP %s,%s,%s", repetition_meas[Repetition]
                                                            , mode_StopCondition[StopCondition]
                                                            , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      STATISTICS
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set statistics count and result mode
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfEvmEpCont (ViSession instrSession,
                                                                         ViInt32   MeasuredValuesType,
                                                                         ViInt32   NbBurst,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:EVM:EPSK:TCH:CONT:RMOD %s", mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  sprintf (wrtBuf, "CONF:MOD:EVM:EPSK:TCH:CONT:STAT %ld", NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set the number of bursts
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfEvmEpStat (ViSession instrSession,
                                                                         ViInt32   NbBurst,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:EVM:EPSK:TCH:CONT:STAT %ld", NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set result mode
/* Purpose : This function specifies the type of measured values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfEvmEpResMode (ViSession instrSession,
                                                                            ViInt32   MeasuredValuesType,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:EVM:EPSK:TCH:CONT:RMOD %s", mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfEvmEpContRepSt (ViSession instrSession,
                                                                              ViInt32   NbRepetition,
                                                                              ViInt32   StopCondition,
                                                                              ViInt32   StepMode,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:MOD:EVM:EPSK:TCH:CONT:REP %ld,%s,%s", NbRepetition
                                                            , mode_StopCondition[StopCondition]
                                                            , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Definition of Subarrays
/* Purpose : This function configures the READ:SUBarrays.., FETCh:SUBarrays..,
/*           and SAMPle:SUBarrays:MODulation:EVMagnitude:EPSK[:TCH] commands.
/*           It restricts the measurement to up to 32 subranges where either
/*           all measurement results (the number of which is given by the
/*           second numerical parameter) or a single statistical value is
/*           returned. The subranges are defined by the start time and the
/*           number of test points which are located on a fixed, equidistant
/*           grid with a step width of  Bit.
/*           The subranges may overlap but must be within the total range of
/*           the Modulation measurement. Test points outside this range are
/*           not measured (result NAN) and do not enter into the ARIThmetical,
/*           MINimum and MAXimum values.
/*           By default, only one range corresponding to the total measurement
/*           range is used and all measurement values are returned.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubEvmEpRang (ViSession instrSession,
                                                                            ViInt32   StatisticsMode,
                                                                            ViInt32   StartTime,
                                                                            ViInt32   Samples,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"ALL","ARIT","MIN","MAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, StartTime, RSCMU300_SUBMOD_SYMB_MIN, RSCMU300_SUBMOD_SYMB_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Samples, RSCMU300_SUBMOD_EPSK_SAMPLES_MIN, RSCMU300_SUBMOD_EPSK_SAMPLES_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:MOD:EVM:EPSK:TCH %s,%ld,%ld", StrMode[StatisticsMode]
                                                       , StartTime
                                                       , Samples);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      CONTROL OF MODULATION MEAS
 *      It contains the functions for general control of the modulation
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start Modulation Measurements
/* Purpose : This function start the modulation measurement,
/*           setting it to the status beyond.
/*           RUN        Start measurement without waiting
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitEvmEp (ViSession instrSession,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "INIT:MOD:EVM:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort Modulation Measurements
/* Purpose : This function abort the running modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborEvmEp (ViSession instrSession,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "ABOR:MOD:EVM:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Stop Modulation Measurements
/* Purpose : This function stop measurement after current statistic cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopEvmEp (ViSession instrSession,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "STOP:MOD:EVM:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Run next measurement step
/* Purpose : This function runs next modulation measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContEvmEp (ViSession instrSession,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CONT:MOD:EVM:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Measurement Status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcEvmEpSt (ViSession instrSession,
                                                                       ViPInt32  MeasStatus,
                                                                       ViPInt32  CurrentStatCycleCount,
                                                                       ViPInt32  CurrentEvalPeriodCount,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Fetch the measurement status:
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:MOD:EVM:EPSK:TCH:STAT?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMeasStatVal(MeasStatus, tab, 0);

  // Get the counter for current statistics cycle
  if (strcmp (tab[1], "NONE") != 0)
    sscanf (tab[1], "%ld", CurrentStatCycleCount);
  else
    *CurrentStatCycleCount = RSCMU300_OFF;

  // Get the counter for current evaluation period within a cycle
  if (strcmp (tab[2], "NONE") != 0)
    sscanf (tab[2], "%ld", CurrentEvalPeriodCount);
  else *CurrentEvalPeriodCount = RSCMU300_OFF;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfEvmEpErep (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:EVM:EPSK:TCH:EREP %s", StrErep[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      Subsystem MODulation[:EVMagnitude]:EPSK[:TCH][:RESult]
 *
 *      The subsystem MODulation:EVMagnitude:EPSK:TCH[:TCH][:RESULT] measures and
 *      returns the modulation parameters and compares them with the tolerance
 *      values. The subsystem corresponds to the various output elements in the
 *      measurement menu MODulation, application EVM 8PSK.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all
/*           scalar measurement results (see chapter 4). The calculation of
/*           results in an average or peak measurement is described in chapter
/*           3 (see calculation of statistical quantities). The symbol (x3)
/*           behind a value indicates that the list contains three results
/*           corresponding to the Current, the Average, and the MMax value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadEvmEp (ViSession instrSession,
                                                                     ViInt32   StatisticsMode,
                                                                     ViPReal64 EVM95,
                                                                     ViPReal64 EVMPeak,
                                                                     ViPReal64 EVMRMS,
                                                                     ViPReal64 originOffset,
                                                                     ViPReal64 IQImBalance,
                                                                     ViPReal64 frequencyError,
                                                                     ViPReal64 avgBurstPowerCurr,
                                                                     ViPReal64 avgBurstPowerAvg,
                                                                     ViPReal64 burstOutOfTol,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:MOD:EVM:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanEvmEpsk (tab, 0, StatisticsMode, EVM95, EVMPeak, EVMRMS, originOffset, IQImBalance, frequencyError,
                                    avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }
 //IQ Imbalance are not supported in Version >= V3.06
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanEvmEpskV306 (tab, 0, StatisticsMode, EVM95, EVMPeak, EVMRMS, originOffset, IQImBalance, frequencyError,
                                    avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all
/*           scalar measurement results (see chapter 4). The calculation of
/*           results in an average or peak measurement is described in chapter
/*           3 (see calculation of statistical quantities). The symbol (x3)
/*           behind a value indicates that the list contains three results
/*           corresponding to the Current, the Average, and the MMax value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcEvmEp (ViSession instrSession,
                                                                     ViInt32   StatisticsMode,
                                                                     ViPReal64 EVM95,
                                                                     ViPReal64 EVMPeak,
                                                                     ViPReal64 EVMRMS,
                                                                     ViPReal64 originOffset,
                                                                     ViPReal64 IQImBalance,
                                                                     ViPReal64 frequencyError,
                                                                     ViPReal64 avgBurstPowerCurr,
                                                                     ViPReal64 avgBurstPowerAvg,
                                                                     ViPReal64 burstOutOfTol,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:MOD:EVM:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanEvmEpsk (tab, 0, StatisticsMode, EVM95, EVMPeak, EVMRMS, originOffset, IQImBalance, frequencyError,
                                    avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }
 //IQ Imbalance are not supported in Version >= V3.06
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanEvmEpskV306 (tab, 0, StatisticsMode, EVM95, EVMPeak, EVMRMS, originOffset, IQImBalance, frequencyError,
                                    avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all
/*           scalar measurement results (see chapter 4). The calculation of
/*           results in an average or peak measurement is described in chapter
/*           3 (see calculation of statistical quantities). The symbol (x3)
/*           behind a value indicates that the list contains three results
/*           corresponding to the Current, the Average, and the MMax value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampEvmEp (ViSession instrSession,
                                                                     ViInt32   StatisticsMode,
                                                                     ViPReal64 EVM95,
                                                                     ViPReal64 EVMPeak,
                                                                     ViPReal64 EVMRMS,
                                                                     ViPReal64 originOffset,
                                                                     ViPReal64 IQImBalance,
                                                                     ViPReal64 frequencyError,
                                                                     ViPReal64 avgBurstPowerCurr,
                                                                     ViPReal64 avgBurstPowerAvg,
                                                                     ViPReal64 burstOutOfTol,
                                                                     ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:MOD:EVM:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanEvmEpsk (tab, 0, StatisticsMode, EVM95, EVMPeak, EVMRMS, originOffset, IQImBalance, frequencyError,
                                    avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }
 //IQ Imbalance are not supported in Version >= V3.06
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanEvmEpskV306 (tab, 0, StatisticsMode, EVM95, EVMPeak, EVMRMS, originOffset, IQImBalance, frequencyError,
                                    avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcEvmEpMatcLim (ViSession instrSession,
                                                                            ViInt32   StatisticsMode,
                                                                            ViPInt32  EVM95,
                                                                            ViPInt32  phaseErrorPeak,
                                                                            ViPInt32  phaseErrorRMS,
                                                                            ViPInt32  originOffset,
                                                                            ViPInt32  IQImBalance,
                                                                            ViPInt32  frequencyError,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CALC:MOD:EVM:EPSK:TCH:MATC:LIM?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // 95% EVM with single-value measurement
  RSCMU300_Status = RSCMU300_GetMatchingValue(EVM95,tab,0);

  switch (StatisticsMode)
  {
    case RSCMU300_CURRENT:
        // Phase Error Peak with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorPeak,tab,1);

        // Phase Error RMS with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorRMS,tab,4);

        // Origin Offset with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(originOffset,tab,7);

        if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
            {
            // IQ/Im Balance with single-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(IQImBalance,tab,10);

            // Frequency Error with single-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,13);
            }
        else
            {
            // IQ/Im Balance with single-value measurement
            *IQImBalance= RSCMU300_INV;

            // Frequency Error with single-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,10);
            }
    break;

    case RSCMU300_AVERAGE:
        // Phase Error Peak with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorPeak,tab,2);

        // Phase Error RMS with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorRMS,tab,5);

        // Origin Offset with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(originOffset,tab,8);

        if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
            {
            // IQ/Im Balance with average measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(IQImBalance,tab,11);

            // Frequency Error with average measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,14);
            }
        else
            {
            // IQ/Im Balance with average measurement
            *IQImBalance= RSCMU300_INV;

            // Frequency Error with average measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,11);
            }
    break;

    case RSCMU300_MAXMIN:
        // Phase Error Peak with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorPeak,tab,3);

        // Phase Error RMS with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorRMS,tab,6);

        // Origin Offset with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(originOffset,tab,9);

        if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
            {
            // IQ/Im Balance with extreme-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(IQImBalance,tab,12);

            // Frequency Error with extreme-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,15);
            }
        else
            {
            // IQ/Im Balance with extreme-value measurement
            *IQImBalance= RSCMU300_INV;

            // Frequency Error with extreme-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,12);
            }
    break;
  }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Phase Error in Burst...
/* Purpose : This function returns the error vector magnitude vs. time at
/*           fixed, equidistant test points. The number of measured values is
/*           142, corresponding to a time range of 3 symb to 144 symb. The
/*           calculation of Current, Average, and MMax (Min./Max.) results is
/*           explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrEvmEp (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  EVMValues[],
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      EVMValuesTmp[142][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:ARR:MOD:EVM:EPSK:TCH:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, EVMValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,EVMValuesTmp,EVMValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Phase Error in Burst...
/* Purpose : This function returns the error vector magnitude vs. time at
/*           fixed, equidistant test points. The number of measured values is
/*           142, corresponding to a time range of 3 symb to 144 symb. The
/*           calculation of Current, Average, and MMax (Min./Max.) results is
/*           explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrEvmEp (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  EVMValues[],
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      EVMValuesTmp[142][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:ARR:MOD:EVM:EPSK:TCH:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, EVMValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,EVMValuesTmp,EVMValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample Phase Error in Burst...
/* Purpose : This function returns the error vector magnitude vs. time at
/*           fixed, equidistant test points. The number of measured values is
/*           142, corresponding to a time range of 3 symb to 144 symb. The
/*           calculation of Current, Average, and MMax (Min./Max.) results is
/*           explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrEvmEp (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  EVMValues[],
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      EVMValuesTmp[142][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:ARR:MOD:EVM:EPSK:TCH:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, EVMValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,EVMValuesTmp,EVMValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Subarray
/* Purpose : this function measures and returns the error vector magnitude
/*           versus time in the subranges defined by means of the CONFigure:
/*           SUBarrays:MODulation:EVMagnitude:EPSK[:TCH] command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubEvmEp (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  EVMValues[],
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      EVMValuesTmp[32][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:SUB:MOD:EVM:EPSK:TCH:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, EVMValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,EVMValuesTmp,EVMValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Subarray
/* Purpose : this function measures and returns the error vector magnitude
/*           versus time in the subranges defined by means of the CONFigure:
/*           SUBarrays:MODulation:EVMagnitude:EPSK[:TCH] command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubEvmEp (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  EVMValues[],
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      EVMValuesTmp[32][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:SUB:MOD:EVM:EPSK:TCH:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, EVMValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,EVMValuesTmp,EVMValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample Subarray
/* Purpose : this function measures and returns the error vector magnitude
/*           versus time in the subranges defined by means of the CONFigure:
/*           SUBarrays:MODulation:EVMagnitude:EPSK[:TCH] command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubEvmEp (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  EVMValues[],
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      EVMValuesTmp[32][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:SUB:MOD:EVM:EPSK:TCH:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, EVMValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,EVMValuesTmp,EVMValues);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT MODULATION PERRor
 *
 *    The subsystem MODulation:PERRor measures the phase error as well as
 *    general scalar modulation parameters. The subsystem corresponds to the
 *    measurement menu Modulation, application Phase Error 8PSK, and the
 *    associated popup menu Modulation Error Config.
 * ----------------------------------------------------------------------------
 *      CONFIGURATION CONTROL
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrEpContDef (ViSession instrSession,
                                                                             ViBoolean DefaultValues,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DEF:MOD:PERR:EPSK:TCH:CONT %s", mode_On_Off[DefaultValues]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Scope of measurement
/* Purpose : This function defines the scope of the power measurement,
/*           combining the ...CONTrol:RMODe, ...CONTrol:STATistics, and the
/*           ...CONTrol:REPetition commands.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrEpScope (ViSession instrSession,
                                                                           ViInt32   MeasuredValuesType,
                                                                           ViInt32   NbBurst,
                                                                           ViInt32   repetition,
                                                                           ViInt32   NbRepetition,
                                                                           ViInt32   StopCondition,
                                                                           ViInt32   StepMode,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, repetition, 0, 2, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER7, errorMessage);

  if (repetition != RSCMU300_MULTIPLE)
    sprintf(wrtBuf, "CONF:MOD:PERR:EPSK:TCH:CONT %s,%ld,%s,%s,%s", mode_ScopeMeas[MeasuredValuesType]
                                                                , NbBurst
                                                                , repetition_meas[repetition]
                                                                , mode_StopCondition[StopCondition]
                                                                , StrStepMode[StepMode]);
  else
    sprintf(wrtBuf, "CONF:MOD:PERR:EPSK:TCH:CONT %s %ld %ld %s %s", mode_ScopeMeas[MeasuredValuesType]
                                                                , NbBurst
                                                                , NbRepetition
                                                                , mode_StopCondition[StopCondition]
                                                                , StrStepMode[StepMode]);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrEpContRep (ViSession instrSession,
                                                                             ViInt32   Repetition,
                                                                             ViInt32   StopCondition,
                                                                             ViInt32   StepMode,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, Repetition, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:MOD:PERR:EPSK:TCH:CONT:REP %s,%s,%s", repetition_meas[Repetition]
                                                             , mode_StopCondition[StopCondition]
                                                             , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      STATISTICS
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set statistics count and result mode
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrEpCont (ViSession instrSession,
                                                                          ViInt32   MeasuredValuesType,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:PERR:EPSK:TCH:CONT:RMOD %s", mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  sprintf (wrtBuf, "CONF:MOD:PERR:EPSK:TCH:CONT:STAT %ld", NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set the number of bursts
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrEpStat (ViSession instrSession,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:PERR:EPSK:TCH:CONT:STAT %ld", NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set result mode
/* Purpose : This function specifies the type of measured values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrEpResMode (ViSession instrSession,
                                                                             ViInt32   MeasuredValuesType,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:PERR:EPSK:TCH:CONT:RMOD %s", mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrEpContRepSt (ViSession instrSession,
                                                                               ViInt32   NbRepetition,
                                                                               ViInt32   StopCondition,
                                                                               ViInt32   StepMode,
                                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:MOD:PERR:EPSK:TCH:CONT:REP %ld,%s,%s", NbRepetition
                                                             , mode_StopCondition[StopCondition]
                                                             , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Definition of Subarrays
/* Purpose : This function configures the READ:SUBarrays.., FETCh:SUBarrays..,
/*           and SAMPle:SUBarrays:MODulation:PERRor:EPSK[:TCH] commands. It
/*           restricts the measurement to up to 32 subranges where either all
/*           measurement results (the number of which is given by the second
/*           numerical parameter) or a single statistical value is returned.
/*           The subranges are defined by the start time and the number of
/*           test points which are located on a fixed, equidistant grid with
/*           a step width of  Bit. The subranges may overlap but must be
/*           within the total range of the Modulation measurement. Test
/*           points outside this range are not measured (result NAN) and do
/*           not enter into the ARIThmetical, MINimum and MAXimum values.
/*           By default, only one range corresponding to the total measurement
/*           range is used and all measurement values are returned.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubPerrEpRang (ViSession instrSession,
                                                                             ViInt32   StatisticsMode,
                                                                             ViInt32   StartTime,
                                                                             ViInt32   Samples,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"ALL","ARIT","MIN","MAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, StartTime, RSCMU300_SUBMOD_SYMB_MIN, RSCMU300_SUBMOD_SYMB_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Samples, RSCMU300_SUBMOD_EPSK_SAMPLES_MIN, RSCMU300_SUBMOD_EPSK_SAMPLES_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:MOD:PERR:EPSK:TCH %s,%ld,%ld", StrMode[StatisticsMode]
                                                        , StartTime
                                                        , Samples);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      CONTROL OF MODULATION MEAS
 *      It contains the functions for general control of the modulation
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start Modulation Measurements
/* Purpose : This function start the modulation measurement,
/*           setting it to the status beyond.
/*           RUN        Start measurement without waiting
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitPerrEp (ViSession instrSession,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "INIT:MOD:PERR:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort Modulation Measurements
/* Purpose : This function abort the running modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborPerrEp (ViSession instrSession,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "ABOR:MOD:PERR:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Stop Modulation Measurements
/* Purpose : This function stop measurement after current statistic cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopPerrEp (ViSession instrSession,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "STOP:MOD:PERR:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Run next measurement step
/* Purpose : This function runs next modulation measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContPerrEp (ViSession instrSession,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CONT:MOD:PERR:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Measurement Status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPerrEpSt (ViSession instrSession,
                                                                        ViPInt32  MeasStatus,
                                                                        ViPInt32  CurrentStatCycleCount,
                                                                        ViPInt32  CurrentEvalPeriodCount,
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Fetch the measurement status:
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:MOD:PERR:EPSK:TCH:STAT?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMeasStatVal(MeasStatus, tab, 0);

  // Get the counter for current statistics cycle
  if (strcmp (tab[1], "NONE") != 0)
    sscanf (tab[1], "%ld", CurrentStatCycleCount);
  else
    *CurrentStatCycleCount = RSCMU300_OFF;

  // Get the counter for current evaluation period within a cycle
  if (strcmp (tab[2], "NONE") != 0)
    sscanf (tab[2], "%ld", CurrentEvalPeriodCount);
  else *CurrentEvalPeriodCount = RSCMU300_OFF;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrEpErep (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:PERR:EPSK:TCH:EREP %s", StrErep[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      Subsystem MODulation:PERRor:EPSK[:TCH][:RESult]
 *
 *      The subsystem MODulation:PERRor:EPSK[:TCH][:RESULT] measures and returns
 *      the modulation parameters and compares them with the tolerance values.
 *      The subsystem corresponds to the various output elements in the
 *      measurement menu MODulation, application Phase Error 8PSK.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadPerrEp (ViSession instrSession,
                                                                      ViInt32   StatisticsMode,
                                                                      ViPReal64 PhaseError95,
                                                                      ViPReal64 phaseErrorPeak,
                                                                      ViPReal64 phaseErrorRMS,
                                                                      ViPReal64 originOffset,
                                                                      ViPReal64 IQImBalance,
                                                                      ViPReal64 frequencyError,
                                                                      ViPReal64 avgBurstPowerCurr,
                                                                      ViPReal64 avgBurstPowerAvg,
                                                                      ViPReal64 burstOutOfTol,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:MOD:PERR:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanPerrEpsk (tab, 0, StatisticsMode, PhaseError95, phaseErrorPeak, phaseErrorRMS, originOffset,
                                     IQImBalance, frequencyError, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }
 //IQ Imbalance are not supported in Version >= V3.06
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanPerrEpskV306 (tab, 0, StatisticsMode, PhaseError95, phaseErrorPeak, phaseErrorRMS, originOffset,
                                     IQImBalance, frequencyError, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPerrEp (ViSession instrSession,
                                                                      ViInt32   StatisticsMode,
                                                                      ViPReal64 PhaseError95,
                                                                      ViPReal64 phaseErrorPeak,
                                                                      ViPReal64 phaseErrorRMS,
                                                                      ViPReal64 originOffset,
                                                                      ViPReal64 IQImBalance,
                                                                      ViPReal64 frequencyError,
                                                                      ViPReal64 avgBurstPowerCurr,
                                                                      ViPReal64 avgBurstPowerAvg,
                                                                      ViPReal64 burstOutOfTol,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:MOD:PERR:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanPerrEpsk (tab, 0, StatisticsMode, PhaseError95, phaseErrorPeak, phaseErrorRMS, originOffset,
                                     IQImBalance, frequencyError, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }
 //IQ Imbalance are not supported in Version >= V3.06
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanPerrEpskV306 (tab, 0, StatisticsMode, PhaseError95, phaseErrorPeak, phaseErrorRMS, originOffset,
                                     IQImBalance, frequencyError, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampPerrEp (ViSession instrSession,
                                                                      ViInt32   StatisticsMode,
                                                                      ViPReal64 PhaseError95,
                                                                      ViPReal64 phaseErrorPeak,
                                                                      ViPReal64 phaseErrorRMS,
                                                                      ViPReal64 originOffset,
                                                                      ViPReal64 IQImBalance,
                                                                      ViPReal64 frequencyError,
                                                                      ViPReal64 avgBurstPowerCurr,
                                                                      ViPReal64 avgBurstPowerAvg,
                                                                      ViPReal64 burstOutOfTol,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:MOD:PERR:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanPerrEpsk (tab, 0, StatisticsMode, PhaseError95, phaseErrorPeak, phaseErrorRMS, originOffset,
                                     IQImBalance, frequencyError, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }
 //IQ Imbalance are not supported in Version >= V3.06
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanPerrEpskV306 (tab, 0, StatisticsMode, PhaseError95, phaseErrorPeak, phaseErrorRMS, originOffset,
                                     IQImBalance, frequencyError, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcPerrEpMatcLim (ViSession instrSession,
                                                                             ViInt32   StatisticsMode,
                                                                             ViPInt32  PhaseError95,
                                                                             ViPInt32  phaseErrorPeak,
                                                                             ViPInt32  phaseErrorRMS,
                                                                             ViPInt32  originOffset,
                                                                             ViPInt32  IQImBalance,
                                                                             ViPInt32  frequencyError,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CALC:MOD:PERR:EPSK:TCH:MATC:LIM?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // 95% Phase Error with single-value measurement
  RSCMU300_Status = RSCMU300_GetMatchingValue(PhaseError95,tab,0);

  switch (StatisticsMode)
  {
    case RSCMU300_CURRENT:
        // Phase Error Peak with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorPeak,tab,1);

        // Phase Error RMS with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorRMS,tab,4);

        // Origin Offset with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(originOffset,tab,7);

        if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
            {
            // IQ/Im Balance with single-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(IQImBalance,tab,10);

            // Frequency Error with single-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,13);
            }
        else
            {
            // IQ/Im Balance with single-value measurement
            *IQImBalance= RSCMU300_INV;

            // Frequency Error with single-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,10);
            }
    break;

    case RSCMU300_AVERAGE:
        // Phase Error Peak with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorPeak,tab,2);

        // Phase Error RMS with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorRMS,tab,5);

        // Origin Offset with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(originOffset,tab,8);

        if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
            {
            // IQ/Im Balance with average measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(IQImBalance,tab,11);

            // Frequency Error with average measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,14);
            }
        else
            {
            // IQ/Im Balance with average measurement
            *IQImBalance= RSCMU300_INV;

            // Frequency Error with average measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,11);
            }
    break;

    case RSCMU300_MAXMIN:
        // Phase Error Peak with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorPeak,tab,3);

        // Phase Error RMS with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(phaseErrorRMS,tab,6);

        // Origin Offset with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(originOffset,tab,9);

        if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
            {
            // IQ/Im Balance with extreme-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(IQImBalance,tab,12);

            // Frequency Error with extreme-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,15);
            }
        else
            {
            // IQ/Im Balance with extreme-value measurement
            *IQImBalance= RSCMU300_INV;

            // Frequency Error with extreme-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,12);
            }
    break;
  }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Phase Error in Burst...
/* Purpose : This function returns the the phase error vs. time at fixed,
/*           equidistant test points. The number of measured values is 142,
/*           corresponding to a time range of 3 symb to 144 symb.
/*           The calculation of CURRent, AVERage, and MMAX (Min./Max.)
/*           results is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrPerrEp (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  phaseErrorValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      phaseErrorValuesTmp[142][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:ARR:MOD:PERR:EPSK:TCH:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, phaseErrorValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,phaseErrorValuesTmp,phaseErrorValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Phase Error in Burst...
/* Purpose : This function returns the the phase error vs. time at fixed,
/*           equidistant test points. The number of measured values is 142,
/*           corresponding to a time range of 3 symb to 144 symb.
/*           The calculation of CURRent, AVERage, and MMAX (Min./Max.)
/*           results is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrPerrEp (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  phaseErrorValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      phaseErrorValuesTmp[142][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:ARR:MOD:PERR:EPSK:TCH:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, phaseErrorValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,phaseErrorValuesTmp,phaseErrorValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample Phase Error in Burst...
/* Purpose : This function returns the the phase error vs. time at fixed,
/*           equidistant test points. The number of measured values is 142,
/*           corresponding to a time range of 3 symb to 144 symb.
/*           The calculation of CURRent, AVERage, and MMAX (Min./Max.)
/*           results is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrPerrEp (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  phaseErrorValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      phaseErrorValuesTmp[142][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:ARR:MOD:PERR:EPSK:TCH:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, phaseErrorValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,phaseErrorValuesTmp,phaseErrorValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Subarray
/* Purpose : This function measures and returns the phase error versus time
/*           in the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:PERRor:EPSK:TCH[:TCH] command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubPerrEp (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  phaseErrorValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      phaseErrorValuesTmp[32][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:SUB:MOD:PERR:EPSK:TCH:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, phaseErrorValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,phaseErrorValuesTmp,phaseErrorValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Subarray
/* Purpose : This function measures and returns the phase error versus time
/*           in the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:PERRor:EPSK[:TCH] command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubPerrEp (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  phaseErrorValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      phaseErrorValuesTmp[32][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:SUB:MOD:PERR:EPSK:TCH:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, phaseErrorValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,phaseErrorValuesTmp,phaseErrorValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample Subarray
/* Purpose : This function measures and returns the phase error versus time
/*           in the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:PERRor:EPSK[:TCH] command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubPerrEp (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  phaseErrorValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      phaseErrorValuesTmp[32][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:SUB:MOD:PERR:EPSK:TCH:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, phaseErrorValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,phaseErrorValuesTmp,phaseErrorValues);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT MODULATION MERRor
 *
 *    The subsystem MODulation:MERRor controls the modulation measurement.
 *    It corresponds to the softkey Magn. Error 8PSK in the measurement menu
 *    Modulation.
 * ----------------------------------------------------------------------------
 *      CONFIGURATION CONTROL
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMerrEpContDef (ViSession instrSession,
                                                                             ViBoolean DefaultValues,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DEF:MOD:MERR:EPSK:TCH:CONT %s", mode_On_Off[DefaultValues]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Scope of measurement
/* Purpose : This function defines the scope of the power measurement,
/*           combining the ...CONTrol:RMODe, ...CONTrol:STATistics, and the
/*           ...CONTrol:REPetition commands.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMerrEpScope (ViSession instrSession,
                                                                           ViInt32   MeasuredValuesType,
                                                                           ViInt32   NbBurst,
                                                                           ViInt32   repetition,
                                                                           ViInt32   NbRepetition,
                                                                           ViInt32   StopCondition,
                                                                           ViInt32   StepMode,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, repetition, 0, 2, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER7, errorMessage);

  if (repetition != RSCMU300_MULTIPLE)
    sprintf(wrtBuf, "CONF:MOD:MERR:EPSK:TCH:CONT %s,%ld,%s,%s,%s", mode_ScopeMeas[MeasuredValuesType]
                                                                , NbBurst
                                                                , repetition_meas[repetition]
                                                                , mode_StopCondition[StopCondition]
                                                                , StrStepMode[StepMode]);
  else
    sprintf(wrtBuf, "CONF:MOD:MERR:EPSK:TCH:CONT %s %ld %ld %s %s", mode_ScopeMeas[MeasuredValuesType]
                                                                , NbBurst
                                                                , NbRepetition
                                                                , mode_StopCondition[StopCondition]
                                                                , StrStepMode[StepMode]);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMerrEpContRep (ViSession instrSession,
                                                                             ViInt32   Repetition,
                                                                             ViInt32   StopCondition,
                                                                             ViInt32   StepMode,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, Repetition, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:MOD:MERR:EPSK:TCH:CONT:REP %s,%s,%s", repetition_meas[Repetition]
                                                             , mode_StopCondition[StopCondition]
                                                             , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      STATISTICS
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set statistics count and result mode
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMerrEpCont (ViSession instrSession,
                                                                          ViInt32   MeasuredValuesType,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:MERR:EPSK:TCH:CONT:RMOD %s", mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  sprintf (wrtBuf, "CONF:MOD:MERR:EPSK:TCH:CONT:STAT %ld", NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set the number of bursts
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMerrEpStat (ViSession instrSession,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:MERR:EPSK:TCH:CONT:STAT %ld", NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set result mode
/* Purpose : This function specifies the type of measured values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMerrEpResMode (ViSession instrSession,
                                                                             ViInt32   MeasuredValuesType,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:MERR:EPSK:TCH:CONT:RMOD %s", mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMerrEpContRepSt (ViSession instrSession,
                                                                               ViInt32   NbRepetition,
                                                                               ViInt32   StopCondition,
                                                                               ViInt32   StepMode,
                                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:MOD:MERR:EPSK:TCH:CONT:REP %ld,%s,%s", NbRepetition
                                                             , mode_StopCondition[StopCondition]
                                                             , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Definition of Subarrays
/* Purpose : This function configures the READ:SUBarrays.., FETCh:SUBarrays..,
/*           and SAMPle:SUBarrays:MODulation:MERRor:EPSK[:TCH] commands. It
/*           restricts the measurement to up to 32 subranges where either all
/*           measurement results (the number of which is given by the second
/*           numerical parameter) or a single statistical value is returned.
/*           The subranges are defined by the start time and the number of
/*           test points which are located on a fixed, equidistant grid with
/*           a step width of  Bit. The subranges may overlap but must be
/*           within the total range of the Modulation measurement. Test
/*           points outside this range are not measured (result NAN) and do
/*           not enter into the ARIThmetical, MINimum and MAXimum values.
/*           By default, only one range corresponding to the total measurement
/*           range is used and all measurement values are returned.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubMerrEpRang (ViSession instrSession,
                                                                             ViInt32   StatisticsMode,
                                                                             ViInt32   StartTime,
                                                                             ViInt32   Samples,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"ALL","ARIT","MIN","MAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, StartTime, RSCMU300_SUBMOD_SYMB_MIN, RSCMU300_SUBMOD_SYMB_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Samples, RSCMU300_SUBMOD_EPSK_SAMPLES_MIN, RSCMU300_SUBMOD_EPSK_SAMPLES_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:MOD:MERR:EPSK:TCH %s,%ld,%ld", StrMode[StatisticsMode]
                                                        , StartTime
                                                        , Samples);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      CONTROL OF MODULATION MEAS
 *      It contains the functions for general control of the modulation
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start Modulation Measurements
/* Purpose : This function start the modulation measurement,
/*           setting it to the status beyond.
/*           RUN        Start measurement without waiting
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitMerrEp (ViSession instrSession,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "INIT:MOD:MERR:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort Modulation Measurements
/* Purpose : This function abort the running modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborMerrEp (ViSession instrSession,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "ABOR:MOD:MERR:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Stop Modulation Measurements
/* Purpose : This function stop measurement after current statistic cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopMerrEp (ViSession instrSession,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "STOP:MOD:MERR:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Run next measurement step
/* Purpose : This function runs next modulation measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContMerrEp (ViSession instrSession,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CONT:MOD:MERR:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Measurement Status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcMerrEpSt (ViSession instrSession,
                                                                        ViPInt32  MeasStatus,
                                                                        ViPInt32  CurrentStatCycleCount,
                                                                        ViPInt32  CurrentEvalPeriodCount,
                                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Fetch the measurement status:
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:MOD:MERR:EPSK:TCH:STAT?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMeasStatVal(MeasStatus, tab, 0);

  // Get the counter for current statistics cycle
  if (strcmp (tab[1], "NONE") != 0)
    sscanf (tab[1], "%ld", CurrentStatCycleCount);
  else
    *CurrentStatCycleCount = RSCMU300_OFF;

  // Get the counter for current evaluation period within a cycle
  if (strcmp (tab[2], "NONE") != 0)
    sscanf (tab[2], "%ld", CurrentEvalPeriodCount);
  else *CurrentEvalPeriodCount = RSCMU300_OFF;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMerrEpErep (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:MERR:EPSK:TCH:EREP %s", StrErep[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      Subsystem MODulation:MERRor:EPSK[:TCH][:RESult]
 *
 *      The subsystem MODulation:MERRor:EPSK[:TCH][:RESULT] measures and returns
 *      the modulation parameters and compares them with the tolerance values.
 *      The subsystem corresponds to the various output elements in the
 *      measurement menu MODulation, application Magn. Error 8PSK.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities). The symbol (x3) behind
/*           a value indicates that the list contains three results corresponding
/*           to the Current, the Average, and the MMax value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadMerrEp (ViSession instrSession,
                                                                      ViInt32   StatisticsMode,
                                                                      ViPReal64 Merr95,
                                                                      ViPReal64 merrPeak,
                                                                      ViPReal64 merrRMS,
                                                                      ViPReal64 originOffset,
                                                                      ViPReal64 IQImBalance,
                                                                      ViPReal64 frequencyError,
                                                                      ViPReal64 avgBurstPowerCurr,
                                                                      ViPReal64 avgBurstPowerAvg,
                                                                      ViPReal64 burstOutOfTol,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:MOD:MERR:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanMerrEpsk (tab, 0, StatisticsMode, Merr95, merrPeak, merrRMS, originOffset,
                                     IQImBalance, frequencyError, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }
 //IQ Imbalance are not supported in Version >= V3.06
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanMerrEpskV306 (tab, 0, StatisticsMode, Merr95, merrPeak, merrRMS, originOffset,
                                     IQImBalance, frequencyError, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities). The symbol (x3) behind
/*           a value indicates that the list contains three results corresponding
/*           to the Current, the Average, and the MMax value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcMerrEp (ViSession instrSession,
                                                                      ViInt32   StatisticsMode,
                                                                      ViPReal64 Merr95,
                                                                      ViPReal64 merrPeak,
                                                                      ViPReal64 merrRMS,
                                                                      ViPReal64 originOffset,
                                                                      ViPReal64 IQImBalance,
                                                                      ViPReal64 frequencyError,
                                                                      ViPReal64 avgBurstPowerCurr,
                                                                      ViPReal64 avgBurstPowerAvg,
                                                                      ViPReal64 burstOutOfTol,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:MOD:MERR:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanMerrEpsk (tab, 0, StatisticsMode, Merr95, merrPeak, merrRMS, originOffset,
                                     IQImBalance, frequencyError, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }
 //IQ Imbalance are not supported in Version >= V3.06
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanMerrEpskV306 (tab, 0, StatisticsMode, Merr95, merrPeak, merrRMS, originOffset,
                                     IQImBalance, frequencyError, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities). The symbol (x3) behind
/*           a value indicates that the list contains three results corresponding
/*           to the Current, the Average, and the MMax value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampMerrEp (ViSession instrSession,
                                                                      ViInt32   StatisticsMode,
                                                                      ViPReal64 Merr95,
                                                                      ViPReal64 merrPeak,
                                                                      ViPReal64 merrRMS,
                                                                      ViPReal64 originOffset,
                                                                      ViPReal64 IQImBalance,
                                                                      ViPReal64 frequencyError,
                                                                      ViPReal64 avgBurstPowerCurr,
                                                                      ViPReal64 avgBurstPowerAvg,
                                                                      ViPReal64 burstOutOfTol,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:MOD:MERR:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanMerrEpsk (tab, 0, StatisticsMode, Merr95, merrPeak, merrRMS, originOffset,
                                     IQImBalance, frequencyError, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }
 //IQ Imbalance are not supported in Version >= V3.06
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
  RSCMU300_Status = RSCMU300_ScanMerrEpskV306 (tab, 0, StatisticsMode, Merr95, merrPeak, merrRMS, originOffset,
                                     IQImBalance, frequencyError, avgBurstPowerCurr, avgBurstPowerAvg, burstOutOfTol);
    }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcMerrEpMatcLim (ViSession instrSession,
                                                                             ViInt32   StatisticsMode,
                                                                             ViPInt32  merr95,
                                                                             ViPInt32  merrPeak,
                                                                             ViPInt32  merrRMS,
                                                                             ViPInt32  originOffset,
                                                                             ViPInt32  IQImBalance,
                                                                             ViPInt32  frequencyError,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

// Version manager
if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
  return RSCMU300_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CALC:MOD:MERR:EPSK:TCH:MATC:LIM?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // 95% Magnitude Error with single-value measurement
  RSCMU300_Status = RSCMU300_GetMatchingValue(merr95,tab,0);

  switch (StatisticsMode)
  {
    case RSCMU300_CURRENT:
        // Magnitude Error Peak with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(merrPeak,tab,1);

        // Magnitude Error RMS with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(merrRMS,tab,4);

        // Origin Offset with single-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(originOffset,tab,7);

        if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
            {
            // IQ/Im Balance with single-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(IQImBalance,tab,10);

            // Frequency Error with single-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,13);
            }
        else
            {
            // IQ/Im Balance with extreme-value measurement
            *IQImBalance= RSCMU300_INV;

            // Frequency Error with single-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,10);
            }
    break;

    case RSCMU300_AVERAGE:
        // Magnitude Error Peak with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(merrPeak,tab,2);

        // Magnitude Error RMS with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(merrRMS,tab,5);

        // Origin Offset with average measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(originOffset,tab,8);

        if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
            {
            // IQ/Im Balance with average measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(IQImBalance,tab,11);

            // Frequency Error with average measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,14);
            }
        else
            {
            // IQ/Im Balance with average measurement
            *IQImBalance= RSCMU300_INV;

            // Frequency Error with average measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,11);
        }
    break;

    case RSCMU300_MAXMIN:
        // Magnitude Error Peak with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(merrPeak,tab,3);

        // Magnitude Error RMS with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(merrRMS,tab,6);

        // Origin Offset with extreme-value measurement
        RSCMU300_Status = RSCMU300_GetMatchingValue(originOffset,tab,9);

        if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
            {
            // IQ/Im Balance with extreme-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(IQImBalance,tab,12);

            // Frequency Error with extreme-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,15);
            }
        else
            {
            // IQ/Im Balance with extreme-value measurement
            *IQImBalance= RSCMU300_INV;

            // Frequency Error with extreme-value measurement
            RSCMU300_Status = RSCMU300_GetMatchingValue(frequencyError,tab,12);
            }
    break;
  }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Magnitude Error in Burst...
/* Purpose : This function returns the magnitude error vs. time at fixed,
/*           equidistant test points. The number of measured values is 142,
/*           corresponding to a time range of 3 symb to 144 symb.
/*           The calculation of current, average, and mmax (Min./Max.)
/*           results is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrMerrEp (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  merrValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      merrValuesTmp[142][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:ARR:MOD:MERR:EPSK:TCH:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, merrValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,merrValuesTmp,merrValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Magnitude Error in Burst...
/* Purpose : This function returns the magnitude error vs. time at fixed,
/*           equidistant test points. The number of measured values is 142,
/*           corresponding to a time range of 3 symb to 144 symb.
/*           The calculation of current, average, and mmax (Min./Max.)
/*           results is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrMerrEp (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  merrValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      merrValuesTmp[142][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:ARR:MOD:MERR:EPSK:TCH:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, merrValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,merrValuesTmp,merrValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample Magnitude Error in Burst...
/* Purpose : This function returns the magnitude error vs. time at fixed,
/*           equidistant test points. The number of measured values is 142,
/*           corresponding to a time range of 3 symb to 144 symb.
/*           The calculation of current, average, and mmax (Min./Max.)
/*           results is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrMerrEp (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  merrValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      merrValuesTmp[142][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:ARR:MOD:MERR:EPSK:TCH:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, merrValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,merrValuesTmp,merrValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Subarray
/* Purpose : This function measures and returns the phase error versus time
/*           in the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:MERRor:EPSK:TCH[:TCH] command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubMerrEp (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  merrValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      merrValuesTmp[32][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:SUB:MOD:MERR:EPSK:TCH:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, merrValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,merrValuesTmp,merrValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Subarray
/* Purpose : This function measures and returns the phase error versus time
/*           in the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:MERRor:EPSK:TCH[:TCH] command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubMerrEp (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  merrValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      merrValuesTmp[32][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:SUB:MOD:MERR:EPSK:TCH:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, merrValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,merrValuesTmp,merrValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample Subarray
/* Purpose : This function measures and returns the phase error versus time
/*           in the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:MERRor:EPSK[:TCH] command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubMerrEp (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  merrValues[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      merrValuesTmp[32][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:SUB:MOD:MERR:EPSK:TCH:%s?", StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, merrValuesTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,merrValuesTmp,merrValues);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT SPECTRUM/MODULATION
 *    The subsystem SPECtrum:MODulation contains the commands for measuring
 *    the off-carrier power due to the modulation of the GSM signal.
 *-----------------------------------------------------------------------------
 *      CONFIGURATION CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpContDef (ViSession instrSession,
                                                                              ViBoolean DefaultValues,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DEF:SPEC:MOD:EPSK:TCH:CONT %s", mode_On_Off[DefaultValues]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Scope of measurement
/* Purpose : This function defines the scope of the power measurement,
/*           combining the ...CONTrol:RMODe, ...CONTrol:STATistics, and the
/*           ...CONTrol:REPetition commands.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpScope (ViSession instrSession,
                                                                            ViInt32   MeasuredValuesType,
                                                                            ViInt32   NbBurst,
                                                                            ViInt32   repetition,
                                                                            ViInt32   NbRepetition,
                                                                            ViInt32   StopCondition,
                                                                            ViInt32   StepMode,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, repetition, 0, 2, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER7, errorMessage);

  if (repetition != RSCMU300_MULTIPLE)
    sprintf(wrtBuf, "CONF:SPEC:MOD:EPSK:TCH:CONT %s,%ld,%s,%s,%s", mode_ScopeMeas[MeasuredValuesType]
                                                                , NbBurst
                                                                , repetition_meas[repetition]
                                                                , mode_StopCondition[StopCondition]
                                                                , StrStepMode[StepMode]);
  else
    sprintf(wrtBuf, "CONF:SPEC:MOD:EPSK:TCH:CONT %s %ld %ld %s %s", mode_ScopeMeas[MeasuredValuesType]
                                                                , NbBurst
                                                                , NbRepetition
                                                                , mode_StopCondition[StopCondition]
                                                                , StrStepMode[StepMode]);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpContRep (ViSession instrSession,
                                                                              ViInt32   Repetition,
                                                                              ViInt32   StopCondition,
                                                                              ViInt32   StepMode,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    Step_Mode[] = {"NONE","STEP"};

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, Repetition, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure tests cycles:
  sprintf (wrtBuf, "CONF:SPEC:MOD:EPSK:TCH:CONT:REP %s,%s,%s", repetition_meas[Repetition]
                                                             , mode_StopCondition[StopCondition]
                                                             , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      LIMITS
 *      The subsystem SPECtrum:MODulation...:LIMit contains the commands for
 *      definition of tolerance values for the spectrum measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default limit Lines
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpLimDef (ViSession instrSession,
                                                                             ViBoolean DefaultValues,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DEF:SPEC:MOD:EPSK:TCH:LIM:LINE %s", mode_On_Off[DefaultValues]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Reference Power
/* Purpose : This function defines the MS carrier output power domain where
/*           the limit lines are to be determined by linear interpolation
/*           (see Table 1). Below Min. Power, the lower limit line applies,
/*           above Max. Power, the upper limit line applies.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpLimRefp (ViSession instrSession,
                                                                              ViReal64  minPower,
                                                                              ViReal64  maxPower,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, minPower, RSCMU300_GSM_REFMINPOW_LIMMIN, RSCMU300_GSM_REFMINPOW_LIMMAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, maxPower, RSCMU300_GSM_REFMAXPOW_LIMMIN, RSCMU300_GSM_REFMAXPOW_LIMMAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD:EPSK:TCH:LIM:LINE:SYMM:RPOW %.12f,%.12f", minPower
                                                                      , maxPower);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Limit Lines On/Off
/* Purpose : This function switches the limit checking for all measurepoints.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpLimMode (ViSession instrSession,
                                                                              ViBoolean LimitLines,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, LimitLines, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD:EPSK:TCH:LIM:LINE:SYMM:ENAB %s", mode_On_Off[LimitLines]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Limit Lines
/* Purpose : These commands activate and define limit lines for the spectrum
/*           due to modulation measurement.
/*           The limit lines for the spectrum due to modulation as specified
/*           in standard GSM 05.05 depend on the GSM band, the frequency, and
/*           (for frequencies that differ from the carrier frequency by more
/*           than 400 kHz) on the output power of the base station.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpLim (ViSession instrSession,
                                                                          ViInt32   measurePoint,
                                                                          ViBoolean enable,
                                                                          ViReal64  minPower,
                                                                          ViReal64  maxPower,
                                                                          ViReal64  AbsLevel,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, measurePoint, RSCMU300_0_10MHZ, RSCMU300_1_80MHZ, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, enable, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD:EPSK:TCH:LIM:LINE:SYMM:FREQ%ld %.12f,%.12f,%.12f,%s", measurePoint
                                                                               , minPower
                                                                               , maxPower
                                                                               , AbsLevel
                                                                               , mode_On_Off[enable]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Statistic Count
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpCont (ViSession instrSession,
                                                                           ViInt32   MeasuredValuesType,
                                                                           ViInt32   NbBurst,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD:EPSK:TCH:CONT:STAT %ld", NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  sprintf (wrtBuf, "CONF:SPEC:MOD:EPSK:TCH:CONT:RMOD %s", mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set the number of bursts
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpStat (ViSession instrSession,
                                                                           ViInt32   NbBurst,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD:EPSK:TCH:CONT:STAT %ld", NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set result mode
/* Purpose : This function specifies the type of measured values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpResMode (ViSession instrSession,
                                                                              ViInt32   MeasuredValuesType,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD:EPSK:TCH:CONT:RMOD %s", mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpContRepSt (ViSession instrSession,
                                                                                ViInt32   NbRepetition,
                                                                                ViInt32   StopCondition,
                                                                                ViInt32   StepMode,
                                                                                ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:SPEC:MOD:EPSK:TCH:CONT:REP %ld,%s,%s", NbRepetition
                                                             , mode_StopCondition[StopCondition]
                                                             , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      MEASUREMENT CONFIGURATION
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Measure Points
/* Purpose : This function permits to select which frequencies a spectrum
/*           modulation measurement is performed. A reduction of the
/*           measurement points enhances the measurement speed.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpContMpo (ViSession instrSession,
                                                                              ViInt32   MeasurePoint,
                                                                              ViBoolean Enable,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, MeasurePoint, RSCMU300_MPO1, RSCMU300_MPO11, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Enable, RSCMU300_OFF, RSCMU300_ON, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD:EPSK:TCH:MPO%ld:ENAB %s", MeasurePoint
                                                              , mode_On_Off[Enable]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Definition of Subarrays
/* Purpose : configures the READ:SUBarrays.., FETCh:SUBarrays.., and SAMPle:
/*           SUBarrays:SPECtrum:MODulation[:EPSK] commands. It restricts the
/*           measurement to up to 32 subranges where either all measurement
/*           results (the number of which is given by the second numerical
/*           parameter) or a single statistical value is returned.
/*           The subranges are defined by the start time and the number of
/*           test points which are located at fixed frequencies (see command
/*           CONFigure:SPECtrum:MODulation[:EPSK]:LIMit:LINE<nr>).
/*           The subranges may overlap but must be within the total range of
/*           the spectrum due to modulation measurement. Test points outside
/*           this range are not measured (result NAN) and do not enter into
/*           the ARIThmetical, MINimum and MAXimum values.
/*           By default, only one range corresponding to the total measurement
/*           range is used and all measurement values are returned.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubSpModEpRang (ViSession instrSession,
                                                                              ViInt32   StatisticsMode,
                                                                              ViReal64  StartFrequency,
                                                                              ViInt32   Samples,
                                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"ALL","ARIT","MIN","MAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, StartFrequency, RSCMU300_SUBSPECMOD_FREQ_MIN, RSCMU300_SUBSPECMOD_FREQ_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Samples, RSCMU300_SUBSPECMOD_NUMBER_MIN, RSCMU300_SUBSPECMOD_NUMBER_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:SPEC:MOD:EPSK:TCH %s,%.12f,%ld", StrMode[StatisticsMode]
                                                         , StartFrequency
                                                         , Samples);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      CONTROL OF SPECTRUM MODULATION MEAS
 *      It contains the functions for general control of the spectrum
 *      modulation measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Init
/* Purpose : Start measurement without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitSpModEp (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "INIT:SPEC:MOD:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : Abort measurement and switch off => OFF
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborSpModEp (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "ABOR:SPEC:MOD:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : Stop measurement => STOP
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopSpModEp (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "STOP:SPEC:MOD:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : Next measurement step (only counting mode) => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContSpModEp (ViSession instrSession,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CONT:SPEC:MOD:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Status
/* Purpose : This function is always a query. It immediately reads the
/*           measurement status (for polling, see chapters 3 and 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSpModEpSt (ViSession instrSession,
                                                                         ViPInt32  MeasStatus,
                                                                         ViPInt32  CurrentStatCycleCount,
                                                                         ViPInt32  CurrentEvalPeriodCount,
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  // Fetch the measurement status:
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:SPEC:MOD:EPSK:TCH:STAT?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMeasStatVal(MeasStatus, tab, 0 );

  // Get the counter for current statistics cycle
  if (strcmp (tab[1], "NONE") != 0)
    sscanf (tab[1], "%ld", CurrentStatCycleCount);
  else *CurrentStatCycleCount = RSCMU300_OFF;

  // Get the counter for current evaluation period within a cycle
  if (strcmp (tab[2], "NONE") != 0)
    sscanf (tab[2], "%ld", CurrentEvalPeriodCount);
  else
    *CurrentEvalPeriodCount = RSCMU300_OFF;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event Reporting Mode
/* Purpose : This function defines the events to be reported during the
/*           measurement (event reporting, see chapter 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpErep (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD:EPSK:TCH:EREP %s", StrErep[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      RESULTS: FREQUENCY SPECTRUM
 *      The subsystem SPECtrum:MODulation[:RESULT] contains the commands for
 *      measurement and output of signal spectrum.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start single shot measurement and return results
/* Purpose : This function starts a single shot measurement and returns the
/*           results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSpModEp (ViSession instrSession,
                                                                       ViPReal64 ReferencePower,
                                                                       ViPInt32  Matching,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:SPEC:MOD:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the reference power:
  if ((RSCMU300_Status = RSCMU300_GetViReal64Value (tab, 0, ReferencePower)) < 0)
    return RSCMU300_Status;

  // Get the matching value:
  if ((RSCMU300_Status = RSCMU300_GetMatchingValue (Matching, tab, 1)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This function only outputs the results without any care of the
/*           measurement state.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSpModEp (ViSession instrSession,
                                                                       ViPReal64 ReferencePower,
                                                                       ViPInt32  Matching,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:SPEC:MOD:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the reference power:
  if ((RSCMU300_Status = RSCMU300_GetViReal64Value (tab, 0, ReferencePower)) < 0)
    return RSCMU300_Status;

  // Get the matching value:
  if ((RSCMU300_Status = RSCMU300_GetMatchingValue (Matching, tab, 1)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This function waits until the results are valid for the first
/*           time (depending on the chosen statistic count) and then outputs
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSpModEp (ViSession instrSession,
                                                                       ViPReal64 ReferencePower,
                                                                       ViPInt32  Matching,
                                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:SPEC:MOD:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the reference power:
  if ((RSCMU300_Status = RSCMU300_GetViReal64Value (tab, 0, ReferencePower)) < 0)
    return RSCMU300_Status;

  // Get the matching value:
  if ((RSCMU300_Status = RSCMU300_GetMatchingValue (Matching, tab, 1)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Array
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrSpModEp (ViSession instrSession,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, "READ:ARR:SPEC:MOD:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Array
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrSpModEp (ViSession instrSession,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, "FETC:ARR:SPEC:MOD:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample Array
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrSpModEp (ViSession instrSession,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, "SAMP:ARR:SPEC:MOD:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read SubArray
/* Purpose : This outputs the off-carrier power due to modulation in the
/*           subranges
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubSpModEp (ViSession instrSession,
                                                                          ViReal64  PowerValues[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[RSCMU300_SUBSPECMOD_NUMBER_MAX][20];

  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, "READ:SUB:SPEC:MOD:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues, BurstPowerTmp, PowerValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch SubArray
/* Purpose : This outputs the off-carrier power due to modulation in the
/*           subranges
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubSpModEp (ViSession instrSession,
                                                                          ViReal64  PowerValues[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[RSCMU300_SUBSPECMOD_NUMBER_MAX][20];

  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, "FETC:SUB:SPEC:MOD:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues, BurstPowerTmp, PowerValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample SubArray
/* Purpose : This outputs the off-carrier power due to modulation in the
/*           subranges
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubSpModEp (ViSession instrSession,
                                                                          ViReal64  PowerValues[],
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[RSCMU300_SUBSPECMOD_NUMBER_MAX][20];

  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, "SAMP:SUB:SPEC:MOD:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues, BurstPowerTmp, PowerValues);

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT SPECTRUM/SWITCHING
 *    The subsystem SPECtrum:SWITching measures the off-carrier power due to
 *    the bursty nature of the GSM signal.
 *-----------------------------------------------------------------------------
 *      CONFIGURATION CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpContDef (ViSession instrSession,
                                                                             ViBoolean DefaultValues,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "DEF:SPEC:SWIT:EPSK:TCH:CONT %s", mode_On_Off[DefaultValues]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Scope of measurement
/* Purpose : This function defines the scope of the power measurement,
/*           combining the ...CONTrol:RMODe, ...CONTrol:STATistics, and the
/*           ...CONTrol:REPetition commands.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpScope (ViSession instrSession,
                                                                           ViInt32   MeasuredValuesType,
                                                                           ViInt32   NbBurst,
                                                                           ViInt32   repetition,
                                                                           ViInt32   NbRepetition,
                                                                           ViInt32   StopCondition,
                                                                           ViInt32   StepMode,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, repetition, 0, 2, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER7, errorMessage);

  if (repetition != RSCMU300_MULTIPLE)
    sprintf(wrtBuf, "CONF:SPEC:SWIT:EPSK:TCH:CONT %s,%ld,%s,%s,%s", mode_ScopeMeas[MeasuredValuesType]
                                                                 , NbBurst
                                                                 , repetition_meas[repetition]
                                                                 , mode_StopCondition[StopCondition]
                                                                 , StrStepMode[StepMode]);
  else
    sprintf(wrtBuf, "CONF:SPEC:SWIT:EPSK:TCH:CONT %s %ld %ld %s %s", mode_ScopeMeas[MeasuredValuesType]
                                                                 , NbBurst
                                                                 , NbRepetition
                                                                 , mode_StopCondition[StopCondition]
                                                                 , StrStepMode[StepMode]);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpContRep (ViSession instrSession,
                                                                             ViInt32   Repetition,
                                                                             ViInt32   StopCondition,
                                                                             ViInt32   StepMode,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, Repetition, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:SPEC:SWIT:EPSK:TCH:CONT:REP %s,%s,%s", repetition_meas[Repetition]
                                                              , mode_StopCondition[StopCondition]
                                                              , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Spectrum Switching Slot Count
/* Purpose : This function defines whether a single timeslot or all timeslots
/*           are considered for the Spectrum due to Switching measurement..
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpSlotCount (ViSession instrSession,
                                                        ViInt32   slotCount,
                                                        ViChar    errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViString    list[] = {"SSL","MSL", VI_NULL};

    // Version manager
    CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_22,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

    RETMSG(RSCMU300_setEnum(instrSession, "CONF:SPEC:SWIT:EPSK:TCH:SCO",
                         slotCount, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*-----------------------------------------------------------------------------
 *      LIMITS
 *      The subsystem SPECtrum:SWITching:LIMit contains the commands for
 *      definition of tolerance values for the spectrum measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Limit Lines
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpLimDef (ViSession instrSession,
                                                                            ViBoolean DefaultValues,
                                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DEF:SPEC:SWIT:EPSK:TCH:LIM:LINE %s", mode_On_Off[DefaultValues]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Limit Lines On/Off
/* Purpose : This function switches the limit checking for all measurepoints.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpLimMode (ViSession instrSession,
                                                                             ViBoolean limitLines,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, limitLines, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:SWIT:EPSK:TCH:LIM:LINE:SYMM:ENAB %s", mode_On_Off[limitLines]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Limit Lines
/* Purpose : These commands activate and define limit lines for the spectrum
/*           due to switching measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpLim (ViSession instrSession,
                                                  ViInt32 MeasurePoint,
                                                  ViBoolean enable,
                                                  ViReal64 minRelativeLimit,
                                                  ViReal64 maxRelativeLimit,
                                                  ViReal64 AbsoluteLimit,
                                                  ViChar errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, MeasurePoint, RSCMU300_MPO1, RSCMU300_MPO4, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, enable, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, minRelativeLimit, -99.9, 99.9, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, maxRelativeLimit, -99.9, 99.9, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, AbsoluteLimit, -99.9, 99.9, RSCMU_ERROR_PARAMETER6, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:SWIT:EPSK:TCH:LIM:LINE:SYMM:FREQ%ld %.12f,%.12f,%.12f,%s", MeasurePoint
                                                                            , minRelativeLimit
                                                                            , maxRelativeLimit
                                                                            , AbsoluteLimit
                                                                            , mode_On_Off[enable]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Statistic Count
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpCont (ViSession instrSession,
                                                                          ViInt32   MeasuredValuesType,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:SWIT:EPSK:TCH:CONT:STAT %ld", NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  sprintf (wrtBuf, "CONF:SPEC:SWIT:EPSK:TCH:CONT:RMOD %s", mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set the number of bursts
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpStat (ViSession instrSession,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:SWIT:EPSK:TCH:CONT:STAT %ld", NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set result mode
/* Purpose : This function specifies the type of measured values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpResMode (ViSession instrSession,
                                                                             ViInt32   MeasuredValuesType,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:SWIT:EPSK:TCH:CONT:RMOD %s", mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpContRepSt (ViSession instrSession,
                                                                               ViInt32   NbRepetition,
                                                                               ViInt32   StopCondition,
                                                                               ViInt32   StepMode,
                                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:SPEC:SWIT:EPSK:TCH:CONT:REP %ld,%s,%s", NbRepetition
                                                              , mode_StopCondition[StopCondition]
                                                              , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;
  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      MEASUREMENT CONFIGURATION
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Measure Points
/* Purpose : This function permits to select which frequencies a spectrum
/*           switching measurement is performed. A reduction of the
/*           measurement points enhances the measurement speed.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpContMpo (ViSession instrSession,
                                                                             ViInt32   MeasurePoint,
                                                                             ViBoolean Enable,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, MeasurePoint, RSCMU300_MPO1, RSCMU300_MPO4, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, Enable, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:SWIT:EPSK:TCH:MPO%ld:ENAB %s", MeasurePoint
                                                          , mode_On_Off[Enable]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Definition of Subarrays
/* Purpose : this function configures the READ:SUBarrays.., FETCh:SUBarrays..,
/*           and SAMPle:SUBarrays:SPECtrum:SWITching[:EPSK] commands. It
/*           restricts the measurement to up to 32 subranges where either all
/*           measurement results (the number of which is given by the second
/*           numerical parameter) or a single statistical value is returned.
/*           The subranges are defined by the start time and the number of test
/*           points which are located at fixed frequencies (see command
/*           CONFigure:SPECtrum:SWITching[:EPSK]:LIMit:LINE<nr>).
/*           The subranges may overlap but must be within the total range of
/*           the spectrum due to switching measurement. Test points outside
/*           this range are not measured (result NAN) and do not enter into
/*           the ARIThmetical, MINimum and MAXimum values.
/*           By default, only one range corresponding to the total measurement
/*           range is used and all measurement values are returned.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubSpSwEpRang (ViSession instrSession,
                                                                             ViInt32   StatisticsMode,
                                                                             ViReal64  StartFrequency,
                                                                             ViInt32   Samples,
                                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"ALL","ARIT","MIN","MAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, StartFrequency, RSCMU300_SUBSPECSWITCH_FREQ_MIN, RSCMU300_SUBSPECSWITCH_FREQ_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Samples, RSCMU300_SUBSPECSWITCH_NUMBER_MIN, RSCMU300_SUBSPECSWITCH_NUMBER_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:SPEC:SWIT:EPSK:TCH %s,%.12f,%ld", StrMode[StatisticsMode]
                                                          , StartFrequency
                                                          , Samples);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*-----------------------------------------------------------------------------
 *      CONTROL OF SPECTRUM SWITCHING MEAS
 *      It contains the functions for general control of the spectrum switching
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Init
/* Purpose : Start measurement without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitSpSwEp (ViSession instrSession,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "INIT:SPEC:SWIT:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : Abort measurement and switch off => OFF
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborSpSwEp (ViSession instrSession,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "ABOR:SPEC:SWIT:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : Stop measurement => STOP
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopSpSwEp (ViSession instrSession,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "STOP:SPEC:SWIT:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : Next measurement step (only counting mode) => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContSpSwEp (ViSession instrSession,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "CONT:SPEC:SWIT:EPSK:TCH", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Status
/* Purpose : This function is always a query. It immediately reads the
/*           measurement status (for polling, see chapters 3 and 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSpSwEpSt (ViSession instrSession,
                                                                        ViPInt32  MeasStatus,
                                                                        ViPInt32  CurrentStatCycleCount,
                                                                        ViPInt32  CurrentEvalPeriodCount,
                                                                        ViChar   _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  // Fetch the measurement status:
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:SPEC:SWIT:EPSK:TCH:STAT?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMeasStatVal (MeasStatus, tab, 0);

  // Get the counter for current statistics cycle
  if (strcmp (tab[1], "NONE") != 0)
    sscanf (tab[1], "%ld", CurrentStatCycleCount);
  else *CurrentStatCycleCount = RSCMU300_OFF;

  // Get the counter for current evaluation period within a cycle
  if (strcmp (tab[2], "NONE") != 0)
    sscanf (tab[2], "%ld", CurrentEvalPeriodCount);
  else *CurrentEvalPeriodCount = RSCMU300_OFF;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event Reporting Mode
/* Purpose : This function defines the events to be reported during the
/*           measurement (event reporting, see chapter 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpErep (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:SWIT:EPSK:TCH:EREP %s", StrErep[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      RESULTS: FREQUENCY SPECTRUM
 *      The subsystem SPECtrum:SWITching[:RESULT] contains the commands for
 *      measurement and output of signal spectrum.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Read
/* Purpose : This function starts the measurement and outputs some results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSpSwEp (ViSession instrSession,
                                                                      ViPReal64 referencePower,
                                                                      ViPInt32  matching,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "READ:SPEC:SWIT:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the Average Burst Power
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", referencePower);
  else *referencePower = RSCMU300_NAN;

  // Get the matching
  RSCMU300_Status = RSCMU300_GetMatchingValue(matching,tab, 1);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This function only outputs the results without any care of the
/*           measurement state.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSpSwEp (ViSession instrSession,
                                                                      ViPReal64 referencePower,
                                                                      ViPInt32  matching,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "FETC:SPEC:SWIT:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the Average Burst Power
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", referencePower);
  else *referencePower = RSCMU300_NAN;

  // Get the matching
  RSCMU300_Status = RSCMU300_GetMatchingValue(matching,tab, 1);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This function waits until the results are valid for the first
/*           time (depending on the chosen statistic count) and then outputs
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSpSwEp (ViSession instrSession,
                                                                      ViPReal64 referencePower,
                                                                      ViPInt32  matching,
                                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, "SAMP:SPEC:SWIT:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the Average Burst Power
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", referencePower);
  else *referencePower = RSCMU300_NAN;

  // Get the matching
  RSCMU300_Status = RSCMU300_GetMatchingValue(matching,tab, 1);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Array
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrSpSwEp (ViSession instrSession,
                                                                         ViReal64  BurstPower[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, "READ:ARR:SPEC:SWIT:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Array
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrSpSwEp (ViSession instrSession,
                                                                         ViReal64  BurstPower[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, "FETC:ARR:SPEC:SWIT:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample Array
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrSpSwEp (ViSession instrSession,
                                                                         ViReal64  BurstPower[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, "SAMP:ARR:SPEC:SWIT:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read SubArray
/* Purpose : This outputs the off-carrier power due to switching in the
/*           subranges
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubSpSwEp (ViSession instrSession,
                                                                         ViReal64  BurstPower[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[RSCMU300_SUBSPECSWITCH_NUMBER_MAX][20];

  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, "READ:SUB:SPEC:SWIT:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch SubArray
/* Purpose : This outputs the off-carrier power due to switching in the
/*           subranges
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubSpSwEp (ViSession instrSession,
                                                                         ViReal64  BurstPower[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[RSCMU300_SUBSPECSWITCH_NUMBER_MAX][20];

  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, "FETC:SUB:SPEC:SWIT:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample SubArray
/* Purpose : This outputs the off-carrier power due to switching in the
/*           subranges
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubSpSwEp (ViSession instrSession,
                                                                         ViReal64  BurstPower[],
                                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[RSCMU300_SUBSPECSWITCH_NUMBER_MAX][20];

  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, "SAMP:SUB:SPEC:SWIT:EPSK:TCH?", rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}


/*****************************************************************************/
/*****************************************************************************/
/*========== LOCAL FUNCTIONS ================================================*/
/*****************************************************************************/
/*****************************************************************************/

/*===========================================================================*/
/* Function: RSCMU300_ScanPow
/* Purpose : This function scans a Power Result string in GMSK and EPSK.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_ScanPow (ViChar    tab [100][100],
                                                           ViInt32   i_StartingIndex,
                                                           ViPReal64 burstOutOfTolerance,
                                                           ViPReal64 averBurstPower,
                                                           ViPReal64 peakburstPower,
                                                           ViPInt32  burstTemplateMatching,
                                                           ViPReal64 AvgBurstPowerAvg)
{
  // Get the Burst Out Of Tolerance
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", burstOutOfTolerance);
  else *burstOutOfTolerance = RSCMU300_NAN;

  // Get the Average Burst Power Current
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%le", averBurstPower);
  else *averBurstPower = RSCMU300_NAN;

  // Get the peak burst power
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%le", peakburstPower);
  else *peakburstPower = RSCMU300_NAN;

  RSCMU300_GetMatchingValue (burstTemplateMatching, tab, 3);

  if (strcmp (tab[4], "NAN") != 0)
    sscanf (tab[4], "%le", AvgBurstPowerAvg);
  else *AvgBurstPowerAvg = RSCMU300_NAN;

  return 0;
}

/*===========================================================================*/
/* Function: RSCMU300_ScanPerrGmsk
/* Purpose : Extracts the scalar results in modulation PERRor:GMSK
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_ScanPerrGmsk (ViChar    tab [100][100],
                                                                ViInt32   i_StartingIndex,
                                                                ViInt32   i_selectBurst,
                                                                ViPReal64 phErrPeak,
                                                                ViPReal64 phErrRMS,
                                                                ViPReal64 freqErr,
                                                                ViPReal64 averBurstPowerCurrent,
                                                                ViPReal64 averBurstPowerAverage,
                                                                ViPReal64 burstOutOfTolerance)
{
  switch (i_selectBurst)
  {
    case RSCMU300_CURRENT:
      // Get max phase error with single-value measurement
      if (strcmp (tab[i_StartingIndex], "NAN") != 0)
        sscanf (tab[i_StartingIndex], "%le", phErrPeak);
      else *phErrPeak = RSCMU300_NAN;

      // Get RMS phase error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 3], "%le", phErrRMS);
      else *phErrRMS = RSCMU300_NAN;

      // Get frequency error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 6], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 6], "%le", freqErr);
      else *freqErr = RSCMU300_NAN;
      break;

    case RSCMU300_AVERAGE:
      // Get max phase error with average measurement
      if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 1], "%le", phErrPeak);
      else *phErrPeak = RSCMU300_NAN;

      // Get RMS phase error with average measurement
      if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 4], "%le", phErrRMS);
      else *phErrRMS = RSCMU300_NAN;

      // Get frequency error with average measurement
      if (strcmp (tab[i_StartingIndex + 7], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 7], "%le", freqErr);
      else *freqErr = RSCMU300_NAN;
      break;

    case RSCMU300_MAXMIN:
      // Get max phase error with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 2], "%le", phErrPeak);
      else *phErrPeak = RSCMU300_NAN;

      // Get RMS phase error with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 5], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 5], "%le", phErrRMS);
      else *phErrRMS = RSCMU300_NAN;

      // Get frequency error with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 8], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 8], "%le", freqErr);
      else *freqErr = RSCMU300_NAN;
      break;
  }

  // Get Average burst power with single-value measurement
  if (strcmp (tab[i_StartingIndex + 9], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 9], "%le", averBurstPowerCurrent);
  else *averBurstPowerCurrent = RSCMU300_NAN;

  // Get Average burst power of the average burst
  if (strcmp (tab[i_StartingIndex + 10], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 10], "%le", averBurstPowerAverage);
  else *averBurstPowerAverage = RSCMU300_NAN;

  // Get relative portion of faulty burst
  if (strcmp (tab[i_StartingIndex + 11], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 11], "%le", burstOutOfTolerance);
  else *burstOutOfTolerance = RSCMU300_NAN;

  return 0;
}

/*===========================================================================*/
/* Function: RSCMU300_ScanOverEpsk
/* Purpose : Extracts the scalar results in modulation OVERview:EPSK
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_ScanOverEpsk (ViChar    tab [100][100],
                                                                ViInt32   i_StartingIndex,
                                                                ViInt32   i_selectBurst,
                                                                ViPReal64 EVM95,
                                                                ViPReal64 MagErr95,
                                                                ViPReal64 PhaseErr95,
                                                                ViPReal64 EVMPeak,
                                                                ViPReal64 EVMRMS,
                                                                ViPReal64 magnErrorPeak,
                                                                ViPReal64 magnErrorRMS,
                                                                ViPReal64 phaseErrorPeak,
                                                                ViPReal64 phaseErrorRMS,
                                                                ViPReal64 originOffset,
                                                                ViPReal64 IQIm_balance,
                                                                ViPReal64 frequencyError,
                                                                ViPReal64 avgBurstPowerCurr,
                                                                ViPReal64 burstOutOfTol)
{
  // Get the 95% EVM
  if (strcmp (tab[i_StartingIndex], "NAN") != 0)
    sscanf (tab[i_StartingIndex], "%le", EVM95);
  else *EVM95 = RSCMU300_NAN;

  // Get the 95% Magnitude Error
  if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 1], "%le", MagErr95);
  else *MagErr95 = RSCMU300_NAN;

  // Get the 95% Phase Error
  if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 2], "%le", PhaseErr95);
  else *PhaseErr95 = RSCMU300_NAN;

  switch (i_selectBurst)
  {
    case RSCMU300_CURRENT:
      // Get the EVM peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 3], "%le", EVMPeak);
      else *EVMPeak = RSCMU300_NAN;

      // Get the EVM RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 6], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 6], "%le", EVMRMS);
      else *EVMRMS = RSCMU300_NAN;

      // Get the Magnitude Error Peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 9], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 9], "%le", magnErrorPeak);
      else *magnErrorPeak = RSCMU300_NAN;

      // Get the Magnitude Error RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 12], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 12], "%le", magnErrorRMS);
      else *magnErrorRMS = RSCMU300_NAN;

      // Get the Phase Error Peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 15], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 15], "%le", phaseErrorPeak);
      else *magnErrorPeak = RSCMU300_NAN;

      // Get the Phase Error RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 18], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 18], "%le", phaseErrorRMS);
      else *magnErrorRMS = RSCMU300_NAN;

      // Get the Origin Offset with single-value measurement
      if (strcmp (tab[i_StartingIndex + 21], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 21], "%le", originOffset);
      else *originOffset = RSCMU300_NAN;

      // Get the IQ/IM balance with single-value measurement
      if (strcmp (tab[i_StartingIndex + 24], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 24], "%le", IQIm_balance);
      else *IQIm_balance = RSCMU300_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 27], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 27], "%le", frequencyError);
      else *frequencyError = RSCMU300_NAN;
      break;

    case RSCMU300_AVERAGE:
      // Get the EVM peak with average measurement
      if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 4], "%le", EVMPeak);
      else *EVMPeak = RSCMU300_NAN;

      // Get the EVM RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 7], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 7], "%le", EVMRMS);
      else *EVMRMS = RSCMU300_NAN;

      // Get the Magnitude Error Peak with average measurement
      if (strcmp (tab[i_StartingIndex + 10], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 10], "%le", magnErrorPeak);
      else *magnErrorPeak = RSCMU300_NAN;

      // Get the Magnitude Error RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 13], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 13], "%le", magnErrorRMS);
      else *magnErrorRMS = RSCMU300_NAN;

      // Get the Phase Error Peak with average measurement
      if (strcmp (tab[i_StartingIndex + 16], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 16], "%le", phaseErrorPeak);
      else *magnErrorPeak = RSCMU300_NAN;

      // Get the Phase Error RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 19], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 19], "%le", phaseErrorRMS);
      else *magnErrorRMS = RSCMU300_NAN;

      // Get the Origin Offset with average measurement
      if (strcmp (tab[i_StartingIndex + 22], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 22], "%le", originOffset);
      else *originOffset = RSCMU300_NAN;

      // Get the IQ/IM balance with average measurement
      if (strcmp (tab[i_StartingIndex + 25], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 25], "%le", IQIm_balance);
      else *IQIm_balance = RSCMU300_NAN;

      // Get the Frequency Error with average measurement
      if (strcmp (tab[i_StartingIndex + 28], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 28], "%le", frequencyError);
      else *frequencyError = RSCMU300_NAN;
      break;

    case RSCMU300_MAXMIN:
      // Get the EVM peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 5], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 5], "%le", EVMPeak);
      else *EVMPeak = RSCMU300_NAN;

      // Get the EVM RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 8], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 8], "%le", EVMRMS);
      else *EVMRMS = RSCMU300_NAN;

      // Get the Magnitude Error Peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 11], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 11], "%le", magnErrorPeak);
      else *magnErrorPeak = RSCMU300_NAN;

      // Get the Magnitude Error RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 14], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 14], "%le", magnErrorRMS);
      else *magnErrorRMS = RSCMU300_NAN;

      // Get the Phase Error Peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 17], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 17], "%le", phaseErrorPeak);
      else *magnErrorPeak = RSCMU300_NAN;

      // Get the Phase Error RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 20], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 20], "%le", phaseErrorRMS);
      else *magnErrorRMS = RSCMU300_NAN;

      // Get the Origin Offset with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 23], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 23], "%le", originOffset);
      else *originOffset = RSCMU300_NAN;

      // Get the IQ/IM balance with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 26], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 26], "%le", IQIm_balance);
      else *IQIm_balance = RSCMU300_NAN;

      // Get the Frequency Error with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 29], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 29], "%le", frequencyError);
      else *frequencyError = RSCMU300_NAN;
      break;
  }

  // Get the Average Burst Power Current
  if (strcmp (tab[i_StartingIndex + 30], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 30], "%le", avgBurstPowerCurr);
  else *avgBurstPowerCurr = RSCMU300_NAN;

  // Get the Burst Out Of Tolerance
  if (strcmp (tab[i_StartingIndex + 31], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 31], "%le", burstOutOfTol);
  else *burstOutOfTol = RSCMU300_NAN;

  return 0;
}

/*===========================================================================*/
/* Function: RSCMU300_ScanOverEpskV306
/* Purpose : Extracts the scalar results in modulation OVERview:EPSK
/*           for Version >= V3.06 IQ Imbalance are not supported (Set to NAN)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_ScanOverEpskV306 (ViChar    tab [100][100],
                                                                ViInt32   i_StartingIndex,
                                                                ViInt32   i_selectBurst,
                                                                ViPReal64 EVM95,
                                                                ViPReal64 MagErr95,
                                                                ViPReal64 PhaseErr95,
                                                                ViPReal64 EVMPeak,
                                                                ViPReal64 EVMRMS,
                                                                ViPReal64 magnErrorPeak,
                                                                ViPReal64 magnErrorRMS,
                                                                ViPReal64 phaseErrorPeak,
                                                                ViPReal64 phaseErrorRMS,
                                                                ViPReal64 originOffset,
                                                                ViPReal64 IQIm_balance,
                                                                ViPReal64 frequencyError,
                                                                ViPReal64 avgBurstPowerCurr,
                                                                ViPReal64 burstOutOfTol)
{
  // Get the 95% EVM
  if (strcmp (tab[i_StartingIndex], "NAN") != 0)
    sscanf (tab[i_StartingIndex], "%le", EVM95);
  else *EVM95 = RSCMU300_NAN;

  // Get the 95% Magnitude Error
  if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 1], "%le", MagErr95);
  else *MagErr95 = RSCMU300_NAN;

  // Get the 95% Phase Error
  if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 2], "%le", PhaseErr95);
  else *PhaseErr95 = RSCMU300_NAN;

  switch (i_selectBurst)
  {
    case RSCMU300_CURRENT:
      // Get the EVM peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 3], "%le", EVMPeak);
      else *EVMPeak = RSCMU300_NAN;

      // Get the EVM RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 6], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 6], "%le", EVMRMS);
      else *EVMRMS = RSCMU300_NAN;

      // Get the Magnitude Error Peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 9], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 9], "%le", magnErrorPeak);
      else *magnErrorPeak = RSCMU300_NAN;

      // Get the Magnitude Error RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 12], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 12], "%le", magnErrorRMS);
      else *magnErrorRMS = RSCMU300_NAN;

      // Get the Phase Error Peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 15], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 15], "%le", phaseErrorPeak);
      else *magnErrorPeak = RSCMU300_NAN;

      // Get the Phase Error RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 18], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 18], "%le", phaseErrorRMS);
      else *magnErrorRMS = RSCMU300_NAN;

      // Get the Origin Offset with single-value measurement
      if (strcmp (tab[i_StartingIndex + 21], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 21], "%le", originOffset);
      else *originOffset = RSCMU300_NAN;

      // Get the IQ/IM balance with single-value measurement
      *IQIm_balance = RSCMU300_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 24], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 24], "%le", frequencyError);
      else *frequencyError = RSCMU300_NAN;
      break;

    case RSCMU300_AVERAGE:
      // Get the EVM peak with average measurement
      if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 4], "%le", EVMPeak);
      else *EVMPeak = RSCMU300_NAN;

      // Get the EVM RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 7], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 7], "%le", EVMRMS);
      else *EVMRMS = RSCMU300_NAN;

      // Get the Magnitude Error Peak with average measurement
      if (strcmp (tab[i_StartingIndex + 10], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 10], "%le", magnErrorPeak);
      else *magnErrorPeak = RSCMU300_NAN;

      // Get the Magnitude Error RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 13], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 13], "%le", magnErrorRMS);
      else *magnErrorRMS = RSCMU300_NAN;

      // Get the Phase Error Peak with average measurement
      if (strcmp (tab[i_StartingIndex + 16], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 16], "%le", phaseErrorPeak);
      else *magnErrorPeak = RSCMU300_NAN;

      // Get the Phase Error RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 19], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 19], "%le", phaseErrorRMS);
      else *magnErrorRMS = RSCMU300_NAN;

      // Get the Origin Offset with average measurement
      if (strcmp (tab[i_StartingIndex + 22], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 22], "%le", originOffset);
      else *originOffset = RSCMU300_NAN;

      // Get the IQ/IM balance with average measurement
      *IQIm_balance = RSCMU300_NAN;

      // Get the Frequency Error with average measurement
      if (strcmp (tab[i_StartingIndex + 25], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 25], "%le", frequencyError);
      else *frequencyError = RSCMU300_NAN;
      break;

    case RSCMU300_MAXMIN:
      // Get the EVM peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 5], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 5], "%le", EVMPeak);
      else *EVMPeak = RSCMU300_NAN;

      // Get the EVM RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 8], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 8], "%le", EVMRMS);
      else *EVMRMS = RSCMU300_NAN;

      // Get the Magnitude Error Peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 11], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 11], "%le", magnErrorPeak);
      else *magnErrorPeak = RSCMU300_NAN;

      // Get the Magnitude Error RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 14], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 14], "%le", magnErrorRMS);
      else *magnErrorRMS = RSCMU300_NAN;

      // Get the Phase Error Peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 17], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 17], "%le", phaseErrorPeak);
      else *magnErrorPeak = RSCMU300_NAN;

      // Get the Phase Error RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 20], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 20], "%le", phaseErrorRMS);
      else *magnErrorRMS = RSCMU300_NAN;

      // Get the Origin Offset with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 23], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 23], "%le", originOffset);
      else *originOffset = RSCMU300_NAN;

      // Get the IQ/IM balance with extreme-value measurement
      *IQIm_balance = RSCMU300_NAN;

      // Get the Frequency Error with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 26], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 26], "%le", frequencyError);
      else *frequencyError = RSCMU300_NAN;
      break;
  }

  // Get the Average Burst Power Current
  if (strcmp (tab[i_StartingIndex + 27], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 27], "%le", avgBurstPowerCurr);
  else *avgBurstPowerCurr = RSCMU300_NAN;

  // Get the Burst Out Of Tolerance
  if (strcmp (tab[i_StartingIndex + 28], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 28], "%le", burstOutOfTol);
  else *burstOutOfTol = RSCMU300_NAN;

  return 0;
}

/*===========================================================================*/
/* Function: RSCMU300_ScanEvmEpsk
/* Purpose : Extracts the scalar results in modulation EVMagnitude:EPSK
:/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_ScanEvmEpsk (ViChar    tab [100][100],
                                                               ViInt32   i_StartingIndex,
                                                               ViInt32   i_selectBurst,
                                                               ViPReal64 EVM95,
                                                               ViPReal64 EVMPeak,
                                                               ViPReal64 EVMRMS,
                                                               ViPReal64 originOffset,
                                                               ViPReal64 IQImBalance,
                                                               ViPReal64 frequencyError,
                                                               ViPReal64 avgBurstPowerCurr,
                                                               ViPReal64 avgBurstPowerAvg,
                                                               ViPReal64 burstOutOfTol)
{
  // Get the 95% EVM
  if (strcmp (tab[i_StartingIndex], "NAN") != 0)
    sscanf (tab[i_StartingIndex], "%le", EVM95);
  else *EVM95 = RSCMU300_NAN;

  switch (i_selectBurst)
  {
    case RSCMU300_CURRENT:
      // Get the EVM peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 1], "%le", EVMPeak);
      else *EVMPeak = RSCMU300_NAN;

      // Get the EVM RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 4], "%le", EVMRMS);
      else *EVMRMS = RSCMU300_NAN;

      // Get the Origin Offset with single-value measurement
      if (strcmp (tab[i_StartingIndex + 7], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 7], "%le", originOffset);
      else *originOffset = RSCMU300_NAN;

      // Get the IQ/Im Balance with single-value measurement
      if (strcmp (tab[i_StartingIndex + 10], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 10], "%le", IQImBalance);
      else *IQImBalance = RSCMU300_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 13], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 13], "%le", frequencyError);
      else *frequencyError = RSCMU300_NAN;
      break;

    case RSCMU300_AVERAGE:
      // Get the EVM peak with average measurement
      if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 2], "%le", EVMPeak);
      else *EVMPeak = RSCMU300_NAN;

      // Get the EVM RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 5], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 5], "%le", EVMRMS);
      else *EVMRMS = RSCMU300_NAN;

      // Get the Origin Offset with average measurement
      if (strcmp (tab[i_StartingIndex + 8], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 8], "%le", originOffset);
      else *originOffset = RSCMU300_NAN;

      // Get the IQ/Im Balance with average measurement
      if (strcmp (tab[i_StartingIndex + 11], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 11], "%le", IQImBalance);
      else *IQImBalance = RSCMU300_NAN;

      // Get the Frequency Error with average measurement
      if (strcmp (tab[i_StartingIndex + 14], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 14], "%le", frequencyError);
      else *frequencyError = RSCMU300_NAN;
      break;

    case RSCMU300_MAXMIN:
      // Get the EVM peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 3], "%le", EVMPeak);
      else *EVMPeak = RSCMU300_NAN;

      // Get the EVM RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 6], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 6], "%le", EVMRMS);
      else *EVMRMS = RSCMU300_NAN;

      // Get the Origin Offset with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 9], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 9], "%le", originOffset);
      else *originOffset = RSCMU300_NAN;

      // Get the IQ/Im Balance with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 12], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 12], "%le", IQImBalance);
      else *IQImBalance = RSCMU300_NAN;

      // Get the Frequency Error with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 15], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 15], "%le", frequencyError);
      else *frequencyError = RSCMU300_NAN;
      break;
  }

  // Get the Average Burst Power Current
  if (strcmp (tab[i_StartingIndex + 16], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 16], "%le", avgBurstPowerCurr);
  else *avgBurstPowerCurr = RSCMU300_NAN;

  // Get the Average Burst Power Average
  if (strcmp (tab[i_StartingIndex + 17], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 17], "%le", avgBurstPowerAvg);
  else *avgBurstPowerAvg = RSCMU300_NAN;

  // Get the Burst Out Of Tolerance
  if (strcmp (tab[i_StartingIndex + 18], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 18], "%le", burstOutOfTol);
  else *burstOutOfTol = RSCMU300_NAN;

  return 0;
}

/*===========================================================================*/
/* Function: RSCMU300_ScanEvmEpskV306
/* Purpose : Extracts the scalar results in modulation EVMagnitude:EPSK
/*           for Version >= V3.06 IQ Imbalance are not supported (Set to NAN)
:/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_ScanEvmEpskV306 (ViChar    tab [100][100],
                                                               ViInt32   i_StartingIndex,
                                                               ViInt32   i_selectBurst,
                                                               ViPReal64 EVM95,
                                                               ViPReal64 EVMPeak,
                                                               ViPReal64 EVMRMS,
                                                               ViPReal64 originOffset,
                                                               ViPReal64 IQImBalance,
                                                               ViPReal64 frequencyError,
                                                               ViPReal64 avgBurstPowerCurr,
                                                               ViPReal64 avgBurstPowerAvg,
                                                               ViPReal64 burstOutOfTol)
{
  // Get the 95% EVM
  if (strcmp (tab[i_StartingIndex], "NAN") != 0)
    sscanf (tab[i_StartingIndex], "%le", EVM95);
  else *EVM95 = RSCMU300_NAN;

  switch (i_selectBurst)
  {
    case RSCMU300_CURRENT:
      // Get the EVM peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 1], "%le", EVMPeak);
      else *EVMPeak = RSCMU300_NAN;

      // Get the EVM RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 4], "%le", EVMRMS);
      else *EVMRMS = RSCMU300_NAN;

      // Get the Origin Offset with single-value measurement
      if (strcmp (tab[i_StartingIndex + 7], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 7], "%le", originOffset);
      else *originOffset = RSCMU300_NAN;

      // Get the IQ/Im Balance with single-value measurement
      *IQImBalance = RSCMU300_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 10], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 10], "%le", frequencyError);
      else *frequencyError = RSCMU300_NAN;
      break;

    case RSCMU300_AVERAGE:
      // Get the EVM peak with average measurement
      if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 2], "%le", EVMPeak);
      else *EVMPeak = RSCMU300_NAN;

      // Get the EVM RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 5], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 5], "%le", EVMRMS);
      else *EVMRMS = RSCMU300_NAN;

      // Get the Origin Offset with average measurement
      if (strcmp (tab[i_StartingIndex + 8], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 8], "%le", originOffset);
      else *originOffset = RSCMU300_NAN;

      // Get the IQ/Im Balance with average measurement
      *IQImBalance = RSCMU300_NAN;

      // Get the Frequency Error with average measurement
      if (strcmp (tab[i_StartingIndex + 11], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 11], "%le", frequencyError);
      else *frequencyError = RSCMU300_NAN;
      break;

    case RSCMU300_MAXMIN:
      // Get the EVM peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 3], "%le", EVMPeak);
      else *EVMPeak = RSCMU300_NAN;

      // Get the EVM RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 6], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 6], "%le", EVMRMS);
      else *EVMRMS = RSCMU300_NAN;

      // Get the Origin Offset with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 9], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 9], "%le", originOffset);
      else *originOffset = RSCMU300_NAN;

      // Get the IQ/Im Balance with extreme-value measurement
      *IQImBalance = RSCMU300_NAN;

      // Get the Frequency Error with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 12], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 12], "%le", frequencyError);
      else *frequencyError = RSCMU300_NAN;
      break;
  }

  // Get the Average Burst Power Current
  if (strcmp (tab[i_StartingIndex + 13], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 13], "%le", avgBurstPowerCurr);
  else *avgBurstPowerCurr = RSCMU300_NAN;

  // Get the Average Burst Power Average
  if (strcmp (tab[i_StartingIndex + 14], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 14], "%le", avgBurstPowerAvg);
  else *avgBurstPowerAvg = RSCMU300_NAN;

  // Get the Burst Out Of Tolerance
  if (strcmp (tab[i_StartingIndex + 15], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 15], "%le", burstOutOfTol);
  else *burstOutOfTol = RSCMU300_NAN;

  return 0;
}

/*===========================================================================*/
/* Function: RSCMU300_ScanPerrEpsk
/* Purpose : Extracts the scalar results in modulation PERRor:EPSK
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_ScanPerrEpsk (ViChar    tab [100][100],
                                                                ViInt32   i_StartingIndex,
                                                                ViInt32   i_selectBurst,
                                                                ViPReal64 PhaseError95,
                                                                ViPReal64 phaseErrorPeak,
                                                                ViPReal64 phaseErrorRMS,
                                                                ViPReal64 originOffset,
                                                                ViPReal64 IQImBalance,
                                                                ViPReal64 frequencyError,
                                                                ViPReal64 avgBurstPowerCurr,
                                                                ViPReal64 avgBurstPowerAvg,
                                                                ViPReal64 burstOutOfTol)
{
  // Get the 95% Phase Error
  if (strcmp (tab[i_StartingIndex], "NAN") != 0)
    sscanf (tab[i_StartingIndex], "%le", PhaseError95);
  else *PhaseError95 = RSCMU300_NAN;

  switch (i_selectBurst)
  {
    case RSCMU300_CURRENT:
      // Get the Phase Error peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 1], "%le", phaseErrorPeak);
      else *phaseErrorPeak = RSCMU300_NAN;

      // Get the Phase Error RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 4], "%le", phaseErrorRMS);
      else *phaseErrorRMS = RSCMU300_NAN;

      // Get the Origin Offset with single-value measurement
      if (strcmp (tab[i_StartingIndex + 7], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 7], "%le", originOffset);
      else *originOffset = RSCMU300_NAN;

      // Get the IQ/IM Balance with single-value measurement
      if (strcmp (tab[i_StartingIndex + 10], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 10], "%le", IQImBalance);
      else *IQImBalance = RSCMU300_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 13], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 13], "%le", frequencyError);
      else *frequencyError = RSCMU300_NAN;
      break;

    case RSCMU300_AVERAGE:
      // Get the Phase Error peak with average measurement
      if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 2], "%le", phaseErrorPeak);
      else *phaseErrorPeak = RSCMU300_NAN;

      // Get the Phase Error RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 5], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 5], "%le", phaseErrorRMS);
      else *phaseErrorRMS = RSCMU300_NAN;

      // Get the Origin Offset with average measurement
      if (strcmp (tab[i_StartingIndex + 8], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 8], "%le", originOffset);
      else *originOffset = RSCMU300_NAN;

      // Get the IQ/IM Balance with average measurement
      if (strcmp (tab[i_StartingIndex + 11], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 11], "%le", IQImBalance);
      else *IQImBalance = RSCMU300_NAN;

      // Get the Frequency Error with average measurement
      if (strcmp (tab[i_StartingIndex + 14], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 14], "%le", frequencyError);
      else *frequencyError = RSCMU300_NAN;
      break;

    case RSCMU300_MAXMIN:
      // Get the Phase Error peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 3], "%le", phaseErrorPeak);
      else *phaseErrorPeak = RSCMU300_NAN;

      // Get the Phase Error RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 6], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 6], "%le", phaseErrorRMS);
      else *phaseErrorRMS = RSCMU300_NAN;

      // Get the Origin Offset with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 9], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 9], "%le", originOffset);
      else *originOffset = RSCMU300_NAN;

      // Get the IQ/IM Balance with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 12], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 12], "%le", IQImBalance);
      else *IQImBalance = RSCMU300_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 15], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 15], "%le", frequencyError);
      else *frequencyError = RSCMU300_NAN;
      break;
  }

  // Get the Average Burst Power Current
  if (strcmp (tab[i_StartingIndex + 16], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 16], "%le", avgBurstPowerCurr);
  else *avgBurstPowerCurr = RSCMU300_NAN;

  // Get the Average Burst Power Average
  if (strcmp (tab[i_StartingIndex + 17], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 17], "%le", avgBurstPowerAvg);
  else *avgBurstPowerAvg = RSCMU300_NAN;

  // Get the Burst Out Of Tolerance
  if (strcmp (tab[i_StartingIndex + 18], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 18], "%le", burstOutOfTol);
  else *burstOutOfTol = RSCMU300_NAN;

  return 0;
}

/*===========================================================================*/
/* Function: RSCMU300_ScanPerrEpskV306
/* Purpose : Extracts the scalar results in modulation PERRor:EPSK
/*           for Version >= V3.06 IQ Imbalance are not supported (Set to NAN)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_ScanPerrEpskV306 (ViChar    tab [100][100],
                                                                ViInt32   i_StartingIndex,
                                                                ViInt32   i_selectBurst,
                                                                ViPReal64 PhaseError95,
                                                                ViPReal64 phaseErrorPeak,
                                                                ViPReal64 phaseErrorRMS,
                                                                ViPReal64 originOffset,
                                                                ViPReal64 IQImBalance,
                                                                ViPReal64 frequencyError,
                                                                ViPReal64 avgBurstPowerCurr,
                                                                ViPReal64 avgBurstPowerAvg,
                                                                ViPReal64 burstOutOfTol)
{
  // Get the 95% Phase Error
  if (strcmp (tab[i_StartingIndex], "NAN") != 0)
    sscanf (tab[i_StartingIndex], "%le", PhaseError95);
  else *PhaseError95 = RSCMU300_NAN;

  switch (i_selectBurst)
  {
    case RSCMU300_CURRENT:
      // Get the Phase Error peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 1], "%le", phaseErrorPeak);
      else *phaseErrorPeak = RSCMU300_NAN;

      // Get the Phase Error RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 4], "%le", phaseErrorRMS);
      else *phaseErrorRMS = RSCMU300_NAN;

      // Get the Origin Offset with single-value measurement
      if (strcmp (tab[i_StartingIndex + 7], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 7], "%le", originOffset);
      else *originOffset = RSCMU300_NAN;

      // Get the IQ/IM Balance with single-value measurement
      *IQImBalance = RSCMU300_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 10], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 10], "%le", frequencyError);
      else *frequencyError = RSCMU300_NAN;
      break;

    case RSCMU300_AVERAGE:
      // Get the Phase Error peak with average measurement
      if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 2], "%le", phaseErrorPeak);
      else *phaseErrorPeak = RSCMU300_NAN;

      // Get the Phase Error RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 5], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 5], "%le", phaseErrorRMS);
      else *phaseErrorRMS = RSCMU300_NAN;

      // Get the Origin Offset with average measurement
      if (strcmp (tab[i_StartingIndex + 8], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 8], "%le", originOffset);
      else *originOffset = RSCMU300_NAN;

      // Get the IQ/IM Balance with average measurement
      *IQImBalance = RSCMU300_NAN;

      // Get the Frequency Error with average measurement
      if (strcmp (tab[i_StartingIndex + 11], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 11], "%le", frequencyError);
      else *frequencyError = RSCMU300_NAN;
      break;

    case RSCMU300_MAXMIN:
      // Get the Phase Error peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 3], "%le", phaseErrorPeak);
      else *phaseErrorPeak = RSCMU300_NAN;

      // Get the Phase Error RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 6], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 6], "%le", phaseErrorRMS);
      else *phaseErrorRMS = RSCMU300_NAN;

      // Get the Origin Offset with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 9], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 9], "%le", originOffset);
      else *originOffset = RSCMU300_NAN;

      // Get the IQ/IM Balance with extreme-value measurement
      *IQImBalance = RSCMU300_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 12], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 12], "%le", frequencyError);
      else *frequencyError = RSCMU300_NAN;
      break;
  }

  // Get the Average Burst Power Current
  if (strcmp (tab[i_StartingIndex + 13], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 13], "%le", avgBurstPowerCurr);
  else *avgBurstPowerCurr = RSCMU300_NAN;

  // Get the Average Burst Power Average
  if (strcmp (tab[i_StartingIndex + 14], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 14], "%le", avgBurstPowerAvg);
  else *avgBurstPowerAvg = RSCMU300_NAN;

  // Get the Burst Out Of Tolerance
  if (strcmp (tab[i_StartingIndex + 15], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 15], "%le", burstOutOfTol);
  else *burstOutOfTol = RSCMU300_NAN;

  return 0;
}

/*===========================================================================*/
/* Function: RSCMU300_ScanMerrEpsk
/* Purpose : Extracts the scalar results in modulation MERRor:EPSK
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_ScanMerrEpsk (ViChar    tab [100][100],
                                                                ViInt32   i_StartingIndex,
                                                                ViInt32   i_selectBurst,
                                                                ViPReal64 merr95,
                                                                ViPReal64 merrPeak,
                                                                ViPReal64 merrRMS,
                                                                ViPReal64 originOffset,
                                                                ViPReal64 IQImBalance,
                                                                ViPReal64 frequencyError,
                                                                ViPReal64 avgBurstPowerCurr,
                                                                ViPReal64 avgBurstPowerAvg,
                                                                ViPReal64 burstOutOfTol)
{
  // Get the 95% Magnitude Error
  if (strcmp (tab[i_StartingIndex], "NAN") != 0)
    sscanf (tab[i_StartingIndex], "%le", merr95);
  else *merr95 = RSCMU300_NAN;

  switch (i_selectBurst)
  {
    case RSCMU300_CURRENT:
      // Get the Magnitude Error peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 1], "%le", merrPeak);
      else *merrPeak = RSCMU300_NAN;

      // Get the Magnitude Error RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 4], "%le", merrRMS);
      else *merrRMS = RSCMU300_NAN;

      // Get the Origin Offset with single-value measurement
      if (strcmp (tab[i_StartingIndex + 7], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 7], "%le", originOffset);
      else *originOffset = RSCMU300_NAN;

      // Get the IQ/IM Balance with single-value measurement
      if (strcmp (tab[i_StartingIndex + 10], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 10], "%le", IQImBalance);
      else *IQImBalance = RSCMU300_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 13], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 13], "%le", frequencyError);
      else *frequencyError = RSCMU300_NAN;
      break;

    case RSCMU300_AVERAGE:
      // Get the Magnitude Error peak with average measurement
      if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 2], "%le", merrPeak);
      else *merrPeak = RSCMU300_NAN;

      // Get the Magnitude Error RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 5], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 5], "%le", merrRMS);
      else *merrRMS = RSCMU300_NAN;

      // Get the Origin Offset with average measurement
      if (strcmp (tab[i_StartingIndex + 8], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 8], "%le", originOffset);
      else *originOffset = RSCMU300_NAN;

      // Get the IQ/IM Balance with average measurement
      if (strcmp (tab[i_StartingIndex + 11], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 11], "%le", IQImBalance);
      else *IQImBalance = RSCMU300_NAN;

      // Get the Frequency Error with average measurement
      if (strcmp (tab[i_StartingIndex + 14], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 14], "%le", frequencyError);
      else *frequencyError = RSCMU300_NAN;
      break;

    case RSCMU300_MAXMIN:
      // Get the Magnitude Error peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 3], "%le", merrPeak);
      else *merrPeak = RSCMU300_NAN;

      // Get the Magnitude Error RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 6], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 6], "%le", merrRMS);
      else *merrRMS = RSCMU300_NAN;

      // Get the Origin Offset with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 9], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 9], "%le", originOffset);
      else *originOffset = RSCMU300_NAN;

      // Get the IQ/IM Balance with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 12], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 12], "%le", IQImBalance);
      else *IQImBalance = RSCMU300_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 15], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 15], "%le", frequencyError);
      else *frequencyError = RSCMU300_NAN;
      break;
  }

  // Get the Average Burst Power Current
  if (strcmp (tab[i_StartingIndex + 16], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 16], "%le", avgBurstPowerCurr);
  else *avgBurstPowerCurr = RSCMU300_NAN;

  // Get the Average Burst Power Average
  if (strcmp (tab[i_StartingIndex + 17], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 17], "%le", avgBurstPowerAvg);
  else *avgBurstPowerAvg = RSCMU300_NAN;

  // Get the Burst Out Of Tolerance
  if (strcmp (tab[i_StartingIndex + 18], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 18], "%le", burstOutOfTol);
  else *burstOutOfTol = RSCMU300_NAN;

  return 0;
}

/*===========================================================================*/
/* Function: RSCMU300_ScanMerrEpskV306
/* Purpose : Extracts the scalar results in modulation MERRor:EPSK
/*           for Version >= V3.06 IQ Imbalance are not supported (Set to NAN)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_ScanMerrEpskV306 (ViChar    tab [100][100],
                                                                ViInt32   i_StartingIndex,
                                                                ViInt32   i_selectBurst,
                                                                ViPReal64 merr95,
                                                                ViPReal64 merrPeak,
                                                                ViPReal64 merrRMS,
                                                                ViPReal64 originOffset,
                                                                ViPReal64 IQImBalance,
                                                                ViPReal64 frequencyError,
                                                                ViPReal64 avgBurstPowerCurr,
                                                                ViPReal64 avgBurstPowerAvg,
                                                                ViPReal64 burstOutOfTol)
{
  // Get the 95% Magnitude Error
  if (strcmp (tab[i_StartingIndex], "NAN") != 0)
    sscanf (tab[i_StartingIndex], "%le", merr95);
  else *merr95 = RSCMU300_NAN;

  switch (i_selectBurst)
  {
    case RSCMU300_CURRENT:
      // Get the Magnitude Error peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 1], "%le", merrPeak);
      else *merrPeak = RSCMU300_NAN;

      // Get the Magnitude Error RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 4], "%le", merrRMS);
      else *merrRMS = RSCMU300_NAN;

      // Get the Origin Offset with single-value measurement
      if (strcmp (tab[i_StartingIndex + 7], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 7], "%le", originOffset);
      else *originOffset = RSCMU300_NAN;

      // Get the IQ/IM Balance with single-value measurement
      *IQImBalance = RSCMU300_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 10], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 10], "%le", frequencyError);
      else *frequencyError = RSCMU300_NAN;
      break;

    case RSCMU300_AVERAGE:
      // Get the Magnitude Error peak with average measurement
      if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 2], "%le", merrPeak);
      else *merrPeak = RSCMU300_NAN;

      // Get the Magnitude Error RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 5], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 5], "%le", merrRMS);
      else *merrRMS = RSCMU300_NAN;

      // Get the Origin Offset with average measurement
      if (strcmp (tab[i_StartingIndex + 8], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 8], "%le", originOffset);
      else *originOffset = RSCMU300_NAN;

      // Get the IQ/IM Balance with average measurement
      *IQImBalance = RSCMU300_NAN;

      // Get the Frequency Error with average measurement
      if (strcmp (tab[i_StartingIndex + 11], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 11], "%le", frequencyError);
      else *frequencyError = RSCMU300_NAN;
      break;

    case RSCMU300_MAXMIN:
      // Get the Magnitude Error peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 3], "%le", merrPeak);
      else *merrPeak = RSCMU300_NAN;

      // Get the Magnitude Error RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 6], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 6], "%le", merrRMS);
      else *merrRMS = RSCMU300_NAN;

      // Get the Origin Offset with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 9], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 9], "%le", originOffset);
      else *originOffset = RSCMU300_NAN;

      // Get the IQ/IM Balance with extreme-value measurement
      *IQImBalance = RSCMU300_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 12], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 12], "%le", frequencyError);
      else *frequencyError = RSCMU300_NAN;
      break;
  }

  // Get the Average Burst Power Current
  if (strcmp (tab[i_StartingIndex + 13], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 13], "%le", avgBurstPowerCurr);
  else *avgBurstPowerCurr = RSCMU300_NAN;

  // Get the Average Burst Power Average
  if (strcmp (tab[i_StartingIndex + 14], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 14], "%le", avgBurstPowerAvg);
  else *avgBurstPowerAvg = RSCMU300_NAN;

  // Get the Burst Out Of Tolerance
  if (strcmp (tab[i_StartingIndex + 15], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 15], "%le", burstOutOfTol);
  else *burstOutOfTol = RSCMU300_NAN;

  return 0;
}

/*****************************************************************************/
/* TEST OBJECT POWER IN NON SIGNALLING
/*****************************************************************************/
/*===========================================================================*/
/* Function: Default Settings
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfPowContDef (ViInt32   modulation,
                                                              ViSession instrSession,
                                                              ViBoolean DefaultValues,
                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DEF:POW:NBUR:%s:CONT %s", modulation_type[modulation]
                                            , mode_On_Off[DefaultValues]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Scope of measurement
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfPowScope (ViInt32   modulation,
                                                            ViSession instrSession,
                                                            ViInt32   MeasuredValuesType,
                                                            ViInt32   NbBurst,
                                                            ViInt32   repetition,
                                                            ViInt32   NbRepetition,
                                                            ViInt32   StopCondition,
                                                            ViInt32   StepMode,
                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, repetition, 0, 2, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER7, errorMessage);

  if (repetition != RSCMU300_MULTIPLE)
    sprintf(wrtBuf, "CONF:POW:NBUR:%s:CONT %s,%ld,%s,%s,%s", modulation_type[modulation]
                                                          , mode_ScopeMeas[MeasuredValuesType]
                                                          , NbBurst
                                                          , repetition_meas[repetition]
                                                          , mode_StopCondition[StopCondition]
                                                          , StrStepMode[StepMode]);
  else
    sprintf(wrtBuf, "CONF:POW:NBUR:%s:CONT %s %ld %ld %s %s", modulation_type[modulation]
                                                          , mode_ScopeMeas[MeasuredValuesType]
                                                          , NbBurst
                                                          , NbRepetition
                                                          , mode_StopCondition[StopCondition]
                                                          , StrStepMode[StepMode]);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfPowContRep (ViInt32   modulation,
                                                              ViSession instrSession,
                                                              ViInt32   NbRepetition,
                                                              ViInt32   StopCondition,
                                                              ViInt32   StepMode,
                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, NbRepetition, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:%s:CONT:REP %s,%s,%s", modulation_type[modulation]
                                                       , repetition_meas[NbRepetition]
                                                       , mode_StopCondition[StopCondition]
                                                       , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Default limit Lines (ON/OFF)
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfPowLimDef (ViInt32   modulation,
                                                             ViSession instrSession,
                                                             ViBoolean DefaultLimitLines,
                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultLimitLines, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DEF:POW:NBUR:%s:LIM:LINE %s", modulation_type[modulation]
                                                , mode_On_Off[DefaultLimitLines]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Switches the lower limit lines ON/OFF
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfPowLimLowMode (ViInt32   modulation,
                                                                 ViSession instrSession,
                                                                 ViBoolean enable,
                                                                 ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, enable, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:%s:LIM:LINE:ASYM:LOW:ENAB %s", modulation_type[modulation]
                                                               , mode_On_Off[enable]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Switches the upper limit lines ON/OFF
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfPowLimUppMode (ViInt32   modulation,
                                                                 ViSession instrSession,
                                                                 ViBoolean enable,
                                                                 ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, enable, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:%s:LIM:LINE:ASYM:UPP:ENAB %s", modulation_type[modulation]
                                                               , mode_On_Off[enable]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Lower limit Lines
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfPowLimLow (ViInt32   modulation,
                                                             ViSession instrSession,
                                                             ViInt32   area,
                                                             ViBoolean enable,
                                                             ViBoolean StartPointBitON_OFF,
                                                             ViReal64  StartPointBit,
                                                             ViBoolean EndPointBitON_OFF,
                                                             ViReal64  EndPointBit,
                                                             ViBoolean StartPointRelLevON_OFF,
                                                             ViReal64  StartPointRelLev,
                                                             ViBoolean EndPointRelLevON_OFF,
                                                             ViReal64  EndPointRelLev,
                                                             ViBoolean StartPointAbsLevON_OFF,
                                                             ViReal64  StartPointAbsLev,
                                                             ViBoolean EndPointAbsLevON_OFF,
                                                             ViReal64  EndPointAbsLev,
                                                             ViBoolean visibility,
                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      StartPointBitBuf[64]= "",
              EndPointBitBuf[64]= "",
              StartPointRelLevBuf[64]= "",
              EndPointRelLevBuf[64]= "",
              StartPointAbsLevBuf[64]= "",
              EndPointAbsLevBuf[64]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, area, 1, 16, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (StartPointBitON_OFF == RSCMU300_ON)
    sprintf(StartPointBitBuf, "%.12f", StartPointBit);
  else sprintf(StartPointBitBuf, "%s", "OFF");

  if (EndPointBitON_OFF == RSCMU300_ON)
    sprintf(EndPointBitBuf, "%.12f", EndPointBit);
  else sprintf(EndPointBitBuf, "%s", "OFF");

  if (StartPointRelLevON_OFF == RSCMU300_ON)
    sprintf(StartPointRelLevBuf, "%.12f", StartPointRelLev);
  else sprintf(StartPointRelLevBuf, "%s", "OFF");

  if (EndPointRelLevON_OFF == RSCMU300_ON)
    sprintf(EndPointRelLevBuf, "%.12f", EndPointRelLev);
  else sprintf(EndPointRelLevBuf, "%s", "OFF");

  if (StartPointAbsLevON_OFF == RSCMU300_ON)
    sprintf(StartPointAbsLevBuf, "%.12f", StartPointAbsLev);
  else sprintf(StartPointAbsLevBuf, "%s", "OFF");

  if (EndPointAbsLevON_OFF == RSCMU300_ON)
    sprintf(EndPointAbsLevBuf, "%.12f", EndPointAbsLev);
  else sprintf(EndPointAbsLevBuf, "%s", "OFF");

  sprintf (wrtBuf, "CONF:POW:NBUR:%s:LIM:LINE:ASYM:LOW:AREA%ld:ENAB %s", modulation_type[modulation]
                                                                      , area
                                                                      , mode_On_Off[enable]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  sprintf (wrtBuf, "CONF:POW:NBUR:%s:LIM:LINE:ASYM:LOW:AREA%ld %s,%s,%s,%s,%s,%s,%s", modulation_type[modulation]
                                                                                   , area
                                                                                   , StartPointBitBuf
                                                                                   , EndPointBitBuf
                                                                                   , StartPointRelLevBuf
                                                                                   , EndPointRelLevBuf
                                                                                   , StartPointAbsLevBuf
                                                                                   , EndPointAbsLevBuf
                                                                                   , mode_On_Off[visibility]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Upper limit Lines
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfPowLimUpp (ViInt32   modulation,
                                                             ViSession instrSession,
                                                             ViInt32   area,
                                                             ViBoolean enable,
                                                             ViBoolean StartPointBitON_OFF,
                                                             ViReal64  StartPointBit,
                                                             ViBoolean EndPointBitON_OFF,
                                                             ViReal64  EndPointBit,
                                                             ViBoolean StartPointRelLevON_OFF,
                                                             ViReal64  StartPointRelLev,
                                                             ViBoolean EndPointRelLevON_OFF,
                                                             ViReal64  EndPointRelLev,
                                                             ViBoolean StartPointAbsLevON_OFF,
                                                             ViReal64  StartPointAbsLev,
                                                             ViBoolean EndPointAbsLevON_OFF,
                                                             ViReal64  EndPointAbsLev,
                                                             ViBoolean visibility,
                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      StartPointBitBuf[64]= "",
              EndPointBitBuf[64]= "",
              StartPointRelLevBuf[64]= "",
              EndPointRelLevBuf[64]= "",
              StartPointAbsLevBuf[64]= "",
              EndPointAbsLevBuf[64]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, area, 1, 16, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (StartPointBitON_OFF == RSCMU300_ON)
    sprintf(StartPointBitBuf, "%.12f", StartPointBit);
  else sprintf(StartPointBitBuf, "%s", "OFF");

  if (EndPointBitON_OFF == RSCMU300_ON)
    sprintf(EndPointBitBuf, "%.12f", EndPointBit);
  else sprintf(EndPointBitBuf, "%s", "OFF");

  if (StartPointRelLevON_OFF == RSCMU300_ON)
    sprintf(StartPointRelLevBuf, "%.12f", StartPointRelLev);
  else sprintf(StartPointRelLevBuf, "%s", "OFF");

  if (EndPointRelLevON_OFF == RSCMU300_ON)
    sprintf(EndPointRelLevBuf, "%.12f", EndPointRelLev);
  else sprintf(EndPointRelLevBuf, "%s", "OFF");

  if (StartPointAbsLevON_OFF == RSCMU300_ON)
    sprintf(StartPointAbsLevBuf, "%.12f", StartPointAbsLev);
  else sprintf(StartPointAbsLevBuf, "%s", "OFF");

  if (EndPointAbsLevON_OFF == RSCMU300_ON)
    sprintf(EndPointAbsLevBuf, "%.12f", EndPointAbsLev);
  else sprintf(EndPointAbsLevBuf, "%s", "OFF");

  sprintf (wrtBuf, "CONF:POW:NBUR:%s:LIM:LINE:ASYM:UPP:AREA%ld:ENAB %s", modulation_type[modulation]
                                                                      , area
                                                                      , mode_On_Off[enable]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  sprintf (wrtBuf, "CONF:POW:NBUR:%s:LIM:LINE:ASYM:UPP:AREA%ld %s,%s,%s,%s,%s,%s,%s", modulation_type[modulation]
                                                                                   , area
                                                                                   , StartPointBitBuf
                                                                                   , EndPointBitBuf
                                                                                   , StartPointRelLevBuf
                                                                                   , EndPointRelLevBuf
                                                                                   , StartPointAbsLevBuf
                                                                                   , EndPointAbsLevBuf
                                                                                   , mode_On_Off[visibility]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Offset on the burst
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfPowTimeBit (ViInt32   modulation,
                                       ViSession instrSession,
                                       ViReal64  TimeBit,
                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  struct      RSCMU300_SESSION_Globals    *p_globalvarBase;

  // Queries the specified attribute:
  CHECKRET(viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase));


  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_REAL64_RANGE(instrSession, TimeBit, RSCMU300_TIMEBIT_MIN, RSCMU300_TIMEBIT_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

   if (p_globalvarBase->RSCMU300_FW_Version < RSCMU300_V3_06)
    {
    sprintf (wrtBuf, "CONF:POW:NBUR:%s:TIME:BOFF %.12f", modulation_type[modulation]
                                                     , TimeBit);
    }
  if (p_globalvarBase->RSCMU300_FW_Version >= RSCMU300_V3_06)
    {
    sprintf (wrtBuf, "CONF:POW:NBUR:%s:TOFF %.12f", modulation_type[modulation]
                                                   , TimeBit);
    }

    RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Set Statistics count and Result Mode
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfPowCont (ViInt32   modulation,
                                                           ViSession instrSession,
                                                           ViInt32   MeasuredValuesType,
                                                           ViInt32   NbBurst,
                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:%s:CONT:STAT %ld", modulation_type[modulation]
                                                  , NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  sprintf (wrtBuf, "CONF:POW:NBUR:%s:CONT:RMOD %s", modulation_type[modulation]
                                                  , mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Number of bursts
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfPowStat (ViInt32   modulation,
                                                           ViSession instrSession,
                                                           ViInt32   NbBurst,
                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:%s:CONT:STAT %ld", modulation_type[modulation]
                                                  , NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Result Mode
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfPowResMode (ViInt32   modulation,
                                                              ViSession instrSession,
                                                              ViInt32   MeasuredValuesType,
                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:%s:CONT:RMOD %s", modulation_type[modulation]
                                                  , mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfPowContRepSt (ViInt32   modulation,
                                                                ViSession instrSession,
                                                                ViInt32   NbRepetition,
                                                                ViInt32   StopCondition,
                                                                ViInt32   StepMode,
                                                                ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:%s:CONT:REP %ld,%s,%s", modulation_type[modulation]
                                                       , NbRepetition
                                                       , mode_StopCondition[StopCondition]
                                                       , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Definition of Subarrays
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSubPowRang (ViInt32   modulation,
                                       ViSession instrSession,
                                       ViInt32   StatisticsMode,
                                       ViReal64  StartTime,
                                       ViInt32   Samples,
                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 4, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, StartTime, RSCMU300_SUBPOW_BIT_MIN, RSCMU300_SUBPOW_BIT_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Samples, RSCMU300_SUBPOW_SAMPLES_MIN, RSCMU300_SUBPOW_SAMPLES_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:POW:NBUR:%s %s,%.12f,%ld", modulation_type[modulation]
                                                   , StrSubArr[StatisticsMode]
                                                   , StartTime
                                                   , Samples);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Start new measurement
/*===========================================================================*/
ViStatus _VI_FUNC NSig_InitPow (ViInt32   modulation,
                                                       ViSession instrSession,
                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  sprintf (wrtBuf, "INIT:POW:NBUR:%s", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort running measurement and switch off
/*===========================================================================*/
ViStatus _VI_FUNC NSig_AborPow (ViInt32   modulation,
                                                       ViSession instrSession,
                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  sprintf (wrtBuf, "ABOR:POW:NBUR:%s", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: stop measurement after current statistic cycle
/*===========================================================================*/
ViStatus _VI_FUNC NSig_StopPow (ViInt32   modulation,
                                                       ViSession instrSession,
                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  sprintf (wrtBuf, "STOP:POW:NBUR:%s", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Next Measurement Step
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ContPow (ViInt32   modulation,
                                                       ViSession instrSession,
                                                      ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  sprintf (wrtBuf, "CONT:POW:NBUR:%s", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch measurement status
/*===========================================================================*/
ViStatus _VI_FUNC NSig_FetcPowSt (ViInt32   modulation,
                                                         ViSession instrSession,
                                                         ViPInt32  MeasStatus,
                                                         ViPInt32  CurrentStatCycleCount,
                                                         ViPInt32  CurrentEvalPeriodCount,
                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  // Fetch the measurement status:
  sprintf (wrtBuf, "FETC:POW:NBUR:%s:STAT?", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMeasStatVal (MeasStatus, tab, 0);

  // Get the counter for current statistics cycle
  if (strcmp (tab[1], "NONE") != 0)
    sscanf (tab[1], "%ld", CurrentStatCycleCount);
  else *CurrentStatCycleCount = RSCMU300_OFF;

  // Get the counter for current evaluation period within a cycle
  if (strcmp (tab[2], "NONE") != 0)
    sscanf (tab[2], "%ld", CurrentEvalPeriodCount);
  else *CurrentEvalPeriodCount = RSCMU300_OFF;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfPowErep (ViInt32   modulation,
                                                           ViSession instrSession,
                                                           ViInt32   Mode,
                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:POW:NBUR:%s:EREP %s", modulation_type[modulation]
                                             , StrErep[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All scalar measured values
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ReadPow (ViInt32   modulation,
                                                       ViSession instrSession,
                                                       ViPReal64 BurstOutOfTol,
                                                       ViPReal64 AvgBurstPowerCurrent,
                                                       ViPReal64 PeakBurstPower,
                                                       ViPInt32  BurstMatching,
                                                       ViPReal64 AvgBurstPowerAvg,
                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  sprintf (wrtBuf, "READ:POW:NBUR:%s?", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  RSCMU300_ScanPow (tab, 0, BurstOutOfTol, AvgBurstPowerCurrent, PeakBurstPower, BurstMatching, AvgBurstPowerAvg);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All scalar measured values
/*===========================================================================*/
ViStatus _VI_FUNC NSig_FetcPow (ViInt32   modulation,
                                                       ViSession instrSession,
                                                       ViPReal64 BurstOutOfTol,
                                                       ViPReal64 AvgBurstPowerCurrent,
                                                       ViPReal64 PeakBurstPower,
                                                       ViPInt32  BurstMatching,
                                                       ViPReal64 AvgBurstPowerAvg,
                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  sprintf (wrtBuf, "FETC:POW:NBUR:%s?", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  RSCMU300_ScanPow (tab, 0, BurstOutOfTol, AvgBurstPowerCurrent, PeakBurstPower, BurstMatching, AvgBurstPowerAvg);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: All scalar measured values
/*===========================================================================*/
ViStatus _VI_FUNC NSig_SampPow (ViInt32   modulation,
                                                       ViSession instrSession,
                                                       ViPReal64 BurstOutOfTol,
                                                       ViPReal64 AvgBurstPowerCurrent,
                                                       ViPReal64 PeakBurstPower,
                                                       ViPInt32  BurstMatching,
                                                       ViPReal64 AvgBurstPowerAvg,
                                                       ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  sprintf (wrtBuf, "SAMP:POW:NBUR:%s?", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  RSCMU300_ScanPow (tab, 0, BurstOutOfTol, AvgBurstPowerCurrent, PeakBurstPower, BurstMatching, AvgBurstPowerAvg);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Request Tolerance On Values
/*===========================================================================*/
ViStatus _VI_FUNC NSig_CalcPowMatcLim (ViInt32   modulation,
                                                              ViSession instrSession,
                                                              ViPInt32  AverBurstPow,
                                                              ViPInt32  PeakBurstPow,
                                                              ViPInt32  BurstMatching,
                                                              ViPInt32  AvgBurstPowerAvg,
                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  sprintf (wrtBuf, "CALC:POW:NBUR:%s:MATC:LIM?", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Average Burst Power
  RSCMU300_Status = RSCMU300_GetMatchingValue(AverBurstPow,tab, 0);

  // Peak Burst Power
  RSCMU300_Status = RSCMU300_GetMatchingValue(PeakBurstPow,tab, 1);

  // Burst Matching
  RSCMU300_Status = RSCMU300_GetMatchingValue(BurstMatching,tab, 2);

    // Average Burst Power Average
  RSCMU300_Status = RSCMU300_GetMatchingValue(AvgBurstPowerAvg,tab, 3);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Burst power measured values
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ReadArrPow (ViInt32   modulation,
                                                          ViSession instrSession,
                                                          ViInt32   Mode,
                                                          ViReal64  BurstPower[],
                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  ViString    StrMode[] = {"CURR", "AVER", "MAX", "MIN"};

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:ARR:POW:NBUR:%s:%s?", modulation_type[modulation]
                                             , StrMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Burst power measured values
/*===========================================================================*/
ViStatus _VI_FUNC NSig_FetcArrPow (ViInt32   modulation,
                                                          ViSession instrSession,
                                                          ViInt32   Mode,
                                                          ViReal64  BurstPower[],
                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];


  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:ARR:POW:NBUR:%s:%s?", modulation_type[modulation]
                                             , StrStatMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Burst power measured values
/*===========================================================================*/
ViStatus _VI_FUNC NSig_SampArrPow (ViInt32   modulation,
                                                          ViSession instrSession,
                                                          ViInt32   Mode,
                                                          ViReal64  BurstPower[],
                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];


  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:ARR:POW:NBUR:%s:%s?", modulation_type[modulation]
                                             , StrStatMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Tolerance error of power measurement
/*===========================================================================*/
ViStatus _VI_FUNC NSig_CalcArrPowMatcLim (ViInt32 modulation,
                                                                 ViSession instrSession,
                                                                 ViInt32   StatisticsMode,
                                                                 ViPInt32  ToleranceError,
                                                                 ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (StatisticsMode)
  {
    case RSCMU300_AVERAGE:
      sprintf (wrtBuf, "CALC:ARR:POW:NBUR:%s:AVER:MATC:LIM?", modulation_type[modulation]);
      break;
    case RSCMU300_CURRENT:
      sprintf (wrtBuf, "CALC:ARR:POW:NBUR:%s:CURR:MATC:LIM?", modulation_type[modulation]);
      break;
    case RSCMU300_MAXIMUM:
      sprintf (wrtBuf, "CALC:ARR:POW:NBUR:%s:MAX:MATC:LIM?", modulation_type[modulation]);
      break;
    case RSCMU300_MINIMUM:
      sprintf (wrtBuf, "CALC:ARR:POW:NBUR:%s:MIN:MATC:LIM?", modulation_type[modulation]);
      break;
  }

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Get the matching value:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);
  RSCMU300_GetMatchingValue (ToleranceError, tab, 0);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: indicates that the corresponding area of the limit lines is
/*           violated.
/*===========================================================================*/
ViStatus _VI_FUNC NSig_CalcArrPowAreaMatc (ViInt32   modulation,
                                                                  ViSession instrSession,
                                                                  ViInt32   StatisticsMode,
                                                                  ViPUInt32 UpperLimit,
                                                                  ViPUInt32 LowerLimit,
                                                                  ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, modulation, 0, 1, RSCMU_ERROR_PARAMETER1, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER3, errorMessage);

  switch (StatisticsMode)
  {
    case RSCMU300_AVERAGE:
      sprintf (wrtBuf, "CALC:ARR:POW:NBUR:%s:AVER:MATC:AREA?", modulation_type[modulation]);
      break;
    case RSCMU300_CURRENT:
      sprintf (wrtBuf, "CALC:ARR:POW:NBUR:%s:CURR:MATC:AREA?", modulation_type[modulation]);
      break;
    case RSCMU300_MAXIMUM:
      sprintf (wrtBuf, "CALC:ARR:POW:NBUR:%s:MAX:MATC:AREA?", modulation_type[modulation]);
      break;
    case RSCMU300_MINIMUM:
      sprintf (wrtBuf, "CALC:ARR:POW:NBUR:%s:MIN:MATC:AREA?", modulation_type[modulation]);
      break;
  }
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the upper Limit Matching
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%ld", UpperLimit);
  else *UpperLimit = RSCMU300_NAN_VI_INT32;

  // Get the lower Limit Matching
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%ld", LowerLimit);
  else *LowerLimit = RSCMU300_NAN_VI_INT32;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: This function outputs the burst power versus time in a fixed
/*           -Bit pattern and in the subranges defined by means of the
/*           CONFigure:SUBarrays:POWer command.
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ReadSubPow (ViInt32   modulation,
                                                          ViSession instrSession,
                                                          ViInt32   Mode,
                                                          ViReal64  BurstPower[],
                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[RSCMU300_SUBPOW_SAMPLES_MAX+1][20];

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:SUB:POW:NBUR:%s:%s?", modulation_type[modulation]
                                             , StrStatMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: This function outputs the burst power versus time in a fixed
/*           -Bit pattern and in the subranges defined by means of the
/*           CONFigure:SUBarrays:POWer command.
/*===========================================================================*/
ViStatus _VI_FUNC NSig_FetcSubPow (ViInt32   modulation,
                                                          ViSession instrSession,
                                                          ViInt32   Mode,
                                                          ViReal64  BurstPower[],
                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[RSCMU300_SUBPOW_SAMPLES_MAX+1][20];


  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:SUB:POW:NBUR:%s:%s?", modulation_type[modulation]
                                             , StrStatMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: This function outputs the burst power versus time in a fixed
/*           -Bit pattern and in the subranges defined by means of the
/*           CONFigure:SUBarrays:POWer command.
/*===========================================================================*/
ViStatus _VI_FUNC NSig_SampSubPow (ViInt32   modulation,
                                                          ViSession instrSession,
                                                          ViInt32   Mode,
                                                          ViReal64  BurstPower[],
                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[RSCMU300_SUBPOW_SAMPLES_MAX+1][20];


  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:SUB:POW:NBUR:%s:%s?", modulation_type[modulation]
                                             , StrStatMode[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}


/*****************************************************************************/
/* TEST OBJECT SPECTRUM MODULATION IN NON SIGNALLING
/*****************************************************************************/
/*===========================================================================*/
/* Function: Default Settings
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSpModContDef (ViInt32   modulation,
                                                                ViSession instrSession,
                                                                ViBoolean DefaultValues,
                                                                ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DEF:SPEC:MOD:%s:CONT %s", modulation_type[modulation]
                                            , mode_On_Off[DefaultValues]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Scope of measurement
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSpModScope (ViInt32   modulation,
                                                              ViSession instrSession,
                                                              ViInt32   MeasuredValuesType,
                                                              ViInt32   NbBurst,
                                                              ViInt32   repetition,
                                                              ViInt32   NbRepetition,
                                                              ViInt32   StopCondition,
                                                              ViInt32   StepMode,
                                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, repetition, 0, 2, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER7, errorMessage);

  if (repetition != RSCMU300_MULTIPLE)
    sprintf(wrtBuf, "CONF:SPEC:MOD:%s:CONT %s,%ld,%s,%s,%s", modulation_type[modulation]
                                                          , mode_ScopeMeas[MeasuredValuesType]
                                                          , NbBurst
                                                          , repetition_meas[repetition]
                                                          , mode_StopCondition[StopCondition]
                                                          , StrStepMode[StepMode]);
  else
    sprintf(wrtBuf, "CONF:SPEC:MOD:%s:CONT %s %ld %ld %s %s", modulation_type[modulation]
                                                          , mode_ScopeMeas[MeasuredValuesType]
                                                          , NbBurst
                                                          , NbRepetition
                                                          , mode_StopCondition[StopCondition]
                                                          , StrStepMode[StepMode]);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Repetition Mode
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSpModContRep (ViInt32   modulation,
                                                                ViSession instrSession,
                                                                ViInt32   Repetition,
                                                                ViInt32   StopCondition,
                                                                ViInt32   StepMode,
                                                                ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    Step_Mode[] = {"NONE","STEP"};

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, Repetition, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure tests cycles:
  sprintf (wrtBuf, "CONF:SPEC:MOD:%s:CONT:REP %s,%s,%s", modulation_type[modulation]
                                                       , repetition_meas[Repetition]
                                                       , mode_StopCondition[StopCondition]
                                                       , StrStepMode[StepMode]);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Default limit Lines
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSpModLimDef (ViInt32   modulation,
                                                               ViSession instrSession,
                                                               ViBoolean DefaultValues,
                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DEF:SPEC:MOD:%s:LIM:LINE %s", modulation_type[modulation]
                                                , mode_On_Off[DefaultValues]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Reference Power
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSpModLimRefp (ViInt32   modulation,
                                                                ViSession instrSession,
                                                                ViReal64  minPower,
                                                                ViReal64  maxPower,
                                                                ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_REAL64_RANGE(instrSession, minPower, RSCMU300_GSM_REFMINPOW_LIMMIN, RSCMU300_GSM_REFMINPOW_LIMMAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, maxPower, RSCMU300_GSM_REFMAXPOW_LIMMIN, RSCMU300_GSM_REFMAXPOW_LIMMAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD:%s:LIM:LINE:SYMM:RPOW %.12f,%.12f", modulation_type[modulation]
                                                                , minPower
                                                                , maxPower);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Limit Lines On/Off
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSpModLimMode (ViInt32   modulation,
                                                                ViSession instrSession,
                                                                ViBoolean limitLines,
                                                                ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, limitLines, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD:%s:LIM:LINE:SYMM:ENAB %s", modulation_type[modulation]
                                                           , mode_On_Off[limitLines]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Limit Lines
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSpModLim (ViInt32   modulation,
                                                            ViSession instrSession,
                                                            ViInt32   measurePoint,
                                                            ViBoolean enable,
                                                            ViReal64  minPower,
                                                            ViReal64  maxPower,
                                                            ViReal64  AbsLevel,
                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, measurePoint, RSCMU300_0_10MHZ, RSCMU300_1_80MHZ, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, enable, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD:%s:LIM:LINE:SYMM:FREQ%ld %.12f,%.12f,%.12f,%s", modulation_type[modulation]
                                                                         , measurePoint
                                                                         , minPower
                                                                         , maxPower
                                                                         , AbsLevel
                                                                         , mode_On_Off[enable]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Statistics count and Result Mode
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSpModCont (ViInt32   modulation,
                                                             ViSession instrSession,
                                                             ViInt32   MeasuredValuesType,
                                                             ViInt32   NbBurst,
                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD:%s:CONT:STAT %ld", modulation_type[modulation]
                                                  , NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  sprintf (wrtBuf, "CONF:SPEC:MOD:%s:CONT:RMOD %s", modulation_type[modulation]
                                                  , mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Number of bursts
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSpModStat (ViInt32   modulation,
                                                             ViSession instrSession,
                                                             ViInt32   NbBurst,
                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD:%s:CONT:STAT %ld", modulation_type[modulation]
                                                  , NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Result Mode
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSpModResMode (ViInt32   modulation,
                                                                ViSession instrSession,
                                                                ViInt32   MeasuredValuesType,
                                                                ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD:%s:CONT:RMOD %s", modulation_type[modulation]
                                                  , mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Repetition Mode
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSpModContRepSt (ViInt32   modulation,
                                                                  ViSession instrSession,
                                                                  ViInt32   NbRepetition,
                                                                  ViInt32   StopCondition,
                                                                  ViInt32   StepMode,
                                                                  ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:SPEC:MOD:%s:CONT:REP %ld,%s,%s", modulation_type[modulation]
                                                       , NbRepetition
                                                       , mode_StopCondition[StopCondition]
                                                       , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Measure Points
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSpModContMpo (ViInt32   modulation,
                                                                ViSession instrSession,
                                                                ViInt32   MeasurePoint,
                                                                ViBoolean Enable,
                                                                ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, MeasurePoint, RSCMU300_MPO1, RSCMU300_MPO11, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Enable, RSCMU300_OFF, RSCMU300_ON, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD:%s:MPO%ld:ENAB %s", modulation_type[modulation]
                                                   , MeasurePoint
                                                   , mode_On_Off[Enable]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Definition of Subarrays
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSubSpModRang (ViInt32   modulation,
                                                                ViSession instrSession,
                                                                ViInt32   StatisticsMode,
                                                                ViReal64  StartFrequency,
                                                                ViInt32   Samples,
                                                                ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"ALL","ARIT","MIN","MAX"};

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, StartFrequency, RSCMU300_SUBSPECMOD_FREQ_MIN, RSCMU300_SUBSPECMOD_FREQ_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Samples, RSCMU300_SUBSPECMOD_NUMBER_MIN, RSCMU300_SUBSPECMOD_NUMBER_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:SPEC:MOD:%s %s,%.12f,%ld", modulation_type[modulation]
                                                   , StrMode[StatisticsMode]
                                                   , StartFrequency
                                                   , Samples);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Init
/*===========================================================================*/
ViStatus _VI_FUNC NSig_InitSpMod (ViInt32   modulation,
                                                         ViSession instrSession,
                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  sprintf (wrtBuf, "INIT:SPEC:MOD:%s", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort
/*===========================================================================*/
ViStatus _VI_FUNC NSig_AborSpMod (ViInt32   modulation,
                                                         ViSession instrSession,
                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  sprintf (wrtBuf, "ABOR:SPEC:MOD:%s", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Stop
/*===========================================================================*/
ViStatus _VI_FUNC NSig_StopSpMod (ViInt32   modulation,
                                                         ViSession instrSession,
                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  sprintf (wrtBuf, "STOP:SPEC:MOD:%s", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Continue
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ContSpMod (ViInt32   modulation,
                                                         ViSession instrSession,
                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  sprintf (wrtBuf, "CONT:SPEC:MOD:%s", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Status
/*===========================================================================*/
ViStatus _VI_FUNC NSig_FetcSpModSt (ViInt32   modulation,
                                                           ViSession instrSession,
                                                           ViPInt32  MeasStatus,
                                                           ViPInt32  CurrentStatCycleCount,
                                                           ViPInt32  CurrentEvalPeriodCount,
                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  // Fetch the measurement status:
  sprintf (wrtBuf, "FETC:SPEC:MOD:%s:STAT?", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMeasStatVal(MeasStatus, tab, 0 );

  // Get the counter for current statistics cycle
  if (strcmp (tab[1], "NONE") != 0)
    sscanf (tab[1], "%ld", CurrentStatCycleCount);
  else *CurrentStatCycleCount = RSCMU300_OFF;

  // Get the counter for current evaluation period within a cycle
  if (strcmp (tab[2], "NONE") != 0)
    sscanf (tab[2], "%ld", CurrentEvalPeriodCount);
  else
    *CurrentEvalPeriodCount = RSCMU300_OFF;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event Reporting Mode
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSpModErep (ViInt32   modulation,
                                                             ViSession instrSession,
                                                             ViInt32   Mode,
                                                             ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD:%s:EREP %s", modulation_type[modulation]
                                             , StrErep[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Start single shot measurement and return results
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ReadSpMod (ViInt32   modulation,
                                                         ViSession instrSession,
                                                         ViPReal64 ReferencePower,
                                                         ViPInt32  Matching,
                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  sprintf (wrtBuf, "READ:SPEC:MOD:%s?", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the reference power:
  if ((RSCMU300_Status = RSCMU300_GetViReal64Value (tab, 0, ReferencePower)) < 0)
    return RSCMU300_Status;

  // Get the matching value:
  if ((RSCMU300_Status = RSCMU300_GetMatchingValue (Matching, tab, 1)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch
/*===========================================================================*/
ViStatus _VI_FUNC NSig_FetcSpMod (ViInt32   modulation,
                                                         ViSession instrSession,
                                                         ViPReal64 ReferencePower,
                                                         ViPInt32  Matching,
                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  sprintf (wrtBuf, "FETC:SPEC:MOD:%s?", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the reference power:
  if ((RSCMU300_Status = RSCMU300_GetViReal64Value (tab, 0, ReferencePower)) < 0)
    return RSCMU300_Status;

  // Get the matching value:
  if ((RSCMU300_Status = RSCMU300_GetMatchingValue (Matching, tab, 1)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample
/*===========================================================================*/
ViStatus _VI_FUNC NSig_SampSpMod (ViInt32   modulation,
                                                         ViSession instrSession,
                                                         ViPReal64 ReferencePower,
                                                         ViPInt32  Matching,
                                                         ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  sprintf (wrtBuf, "SAMP:SPEC:MOD:%s?", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the reference power:
  if ((RSCMU300_Status = RSCMU300_GetViReal64Value (tab, 0, ReferencePower)) < 0)
    return RSCMU300_Status;

  // Get the matching value:
  if ((RSCMU300_Status = RSCMU300_GetMatchingValue (Matching, tab, 1)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Array
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ReadArrSpMod (ViInt32   modulation,
                                                            ViSession instrSession,
                                                            ViReal64  BurstPower[],
                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[23][20];

  sprintf (wrtBuf, "READ:ARR:SPEC:MOD:%s?", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Array
/*===========================================================================*/
ViStatus _VI_FUNC NSig_FetcArrSpMod (ViInt32   modulation,
                                                            ViSession instrSession,
                                                            ViReal64  BurstPower[],
                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[23][20];

  sprintf (wrtBuf, "FETC:ARR:SPEC:MOD:%s?", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample Array
/*===========================================================================*/
ViStatus _VI_FUNC NSig_SampArrSpMod (ViInt32   modulation,
                                                            ViSession instrSession,
                                                            ViReal64  BurstPower[],
                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[23][20];

  sprintf (wrtBuf, "SAMP:ARR:SPEC:MOD:%s?", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: This function outputs the off-carrier power due to modulation in
/*           the subranges defined by means of the CONFigure:SUBarrays:SPECtrum:
/*           MODulation[:GMSK] command.
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ReadSubSpMod (ViInt32   modulation,
                                                            ViSession instrSession,
                                                            ViReal64  PowerValues[],
                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[11][20];

  sprintf (wrtBuf, "READ:SUB:SPEC:MOD:%s?", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues, BurstPowerTmp, PowerValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: This function outputs the off-carrier power due to modulation in
/*           the subranges defined by means of the CONFigure:SUBarrays:SPECtrum:
/*           MODulation[:GMSK] command.
/*===========================================================================*/
ViStatus _VI_FUNC NSig_FetcSubSpMod (ViInt32   modulation,
                                                            ViSession instrSession,
                                                            ViReal64  PowerValues[],
                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[11][20];

  sprintf (wrtBuf, "FETC:SUB:SPEC:MOD:%s?", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues, BurstPowerTmp, PowerValues);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: This function outputs the off-carrier power due to modulation in
/*           the subranges defined by means of the CONFigure:SUBarrays:SPECtrum:
/*           MODulation[:GMSK] command.
/*===========================================================================*/
ViStatus _VI_FUNC NSig_SampSubSpMod (ViInt32   modulation,
                                                            ViSession instrSession,
                                                            ViReal64  PowerValues[],
                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[11][20];

  sprintf (wrtBuf, "SAMP:SUB:SPEC:MOD:%s?", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues, BurstPowerTmp, PowerValues);

  return RSCMU300_Status;
}

/*****************************************************************************/
/* TEST OBJECT SPECTRUM SWITCHING IN NON SIGNALLING
/*****************************************************************************/
/*===========================================================================*/
/* Function: Default Settings
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSpSwContDef (ViInt32   modulation,
                                                               ViSession instrSession,
                                                               ViBoolean DefaultValues,
                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DEF:SPEC:SWIT:%s:CONT %s", modulation_type[modulation]
                                             , mode_On_Off[DefaultValues]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Scope of measurement
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSpSwScope (ViInt32   modulation,
                                                             ViSession instrSession,
                                                             ViInt32   MeasuredValuesType,
                                                             ViInt32   NbBurst,
                                                             ViInt32   repetition,
                                                             ViInt32   NbRepetition,
                                                             ViInt32   StopCondition,
                                                             ViInt32   StepMode,
                                                             ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, repetition, 0, 2, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER7, errorMessage);

  if (repetition != RSCMU300_MULTIPLE)
    sprintf(wrtBuf, "CONF:SPEC:SWIT:%s:CONT %s,%ld,%s,%s,%s", modulation_type[modulation]
                                                           , mode_ScopeMeas[MeasuredValuesType]
                                                           , NbBurst
                                                           , repetition_meas[repetition]
                                                           , mode_StopCondition[StopCondition]
                                                           , StrStepMode[StepMode]);
  else
    sprintf(wrtBuf, "CONF:SPEC:SWIT:%s:CONT %s %ld %ld %s %s", modulation_type[modulation]
                                                           , mode_ScopeMeas[MeasuredValuesType]
                                                           , NbBurst
                                                           , NbRepetition
                                                           , mode_StopCondition[StopCondition]
                                                           , StrStepMode[StepMode]);

  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Repetition Mode
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSpSwContRep (ViInt32   modulation,
                                                               ViSession instrSession,
                                                               ViInt32   Repetition,
                                                               ViInt32   StopCondition,
                                                               ViInt32   StepMode,
                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, Repetition, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:SPEC:SWIT:%s:CONT:REP %s,%s,%s", modulation_type[modulation]
                                                        , repetition_meas[Repetition]
                                                        , mode_StopCondition[StopCondition]
                                                        , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Default Limit Lines
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSpSwLimDef (ViInt32   modulation,
                                                              ViSession instrSession,
                                                              ViBoolean DefaultValues,
                                                              ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, DefaultValues, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DEF:SPEC:SWIT:%s:LIM:LINE %s", modulation_type[modulation]
                                                 , mode_On_Off[DefaultValues]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Limit Lines On/Off
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSpSwLimMode (ViInt32   modulation,
                                                               ViSession instrSession,
                                                               ViBoolean limitLines,
                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, limitLines, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:SWIT:%s:LIM:LINE:SYMM:ENAB %s", modulation_type[modulation]
                                                            , mode_On_Off[limitLines]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Limit Lines
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSpSwLim (ViInt32   modulation,
                                                           ViSession instrSession,
                                                           ViInt32   MeasurePoint,
                                                           ViBoolean enable,
                                                           ViReal64  minRelativeLimit,
                                                           ViReal64  maxRelativeLimit,
                                                           ViReal64  AbsoluteLimit,
                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, MeasurePoint, RSCMU300_MPO1, RSCMU300_MPO4, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, enable, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, minRelativeLimit, -99.9, 99.9, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, maxRelativeLimit, -99.9, 99.9, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, AbsoluteLimit, -99.9, 99.9, RSCMU_ERROR_PARAMETER6, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:SWIT:%s:LIM:LINE:SYMM:FREQ%ld %.12f,%.12f,%.12f,%s", modulation_type[modulation]
                                                                      , MeasurePoint
                                                                      , minRelativeLimit
                                                                      , maxRelativeLimit
                                                                      , AbsoluteLimit
                                                                      , mode_On_Off[enable]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Statistic Count
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSpSwCont (ViInt32   modulation,
                                                            ViSession instrSession,
                                                            ViInt32   MeasuredValuesType,
                                                            ViInt32   NbBurst,
                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD:%s:CONT:STAT %ld", modulation_type[modulation]
                                                  , NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  sprintf (wrtBuf, "CONF:SPEC:MOD:%s:CONT:RMOD %s", modulation_type[modulation]
                                                  , mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Number of bursts
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSpSwStat (ViInt32   modulation,
                                                            ViSession instrSession,
                                                            ViInt32   NbBurst,
                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU300_NBBURST_MIN, RSCMU300_NBBURST_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:SWIT:%s:CONT:STAT %ld", modulation_type[modulation]
                                                   , NbBurst);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Set Result Mode
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSpSwResMode (ViInt32   modulation,
                                                               ViSession instrSession,
                                                               ViInt32   MeasuredValuesType,
                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:SWIT:%s:CONT:RMOD %s", modulation_type[modulation]
                                                   , mode_ScopeMeas[MeasuredValuesType]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Repetition Mode
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSpSwContRepSt (ViInt32   modulation,
                                                                 ViSession instrSession,
                                                                 ViInt32   NbRepetition,
                                                                 ViInt32   StopCondition,
                                                                 ViInt32   StepMode,
                                                                 ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU300_MULTMEAS_MIN, RSCMU300_MULTMEAS_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:SPEC:SWIT:%s:CONT:REP %ld,%s,%s", modulation_type[modulation]
                                                        , NbRepetition
                                                        , mode_StopCondition[StopCondition]
                                                        , StrStepMode[StepMode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;
  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Measure Points
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSpSwContMpo (ViInt32   modulation,
                                                               ViSession instrSession,
                                                               ViInt32   MeasurePoint,
                                                               ViBoolean Enable,
                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, MeasurePoint, RSCMU300_MPO1, RSCMU300_MPO4, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, Enable, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:SWIT:%s:MPO%ld:ENAB %s", modulation_type[modulation]
                                                    , MeasurePoint
                                                    , mode_On_Off[Enable]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Definition of Subarrays
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSubSpSwRang (ViInt32   modulation,
                                                               ViSession instrSession,
                                                               ViInt32   StatisticsMode,
                                                               ViReal64  StartFrequency,
                                                               ViInt32   Samples,
                                                               ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"ALL","ARIT","MIN","MAX"};

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, StartFrequency, RSCMU300_SUBSPECSWITCH_FREQ_MIN, RSCMU300_SUBSPECSWITCH_FREQ_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Samples, RSCMU300_SUBSPECSWITCH_NUMBER_MIN, RSCMU300_SUBSPECSWITCH_NUMBER_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:SPEC:SWIT:%s %s,%.12f,%ld", modulation_type[modulation]
                                                    , StrMode[StatisticsMode]
                                                    , StartFrequency
                                                    , Samples);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Init
/*===========================================================================*/
ViStatus _VI_FUNC NSig_InitSpSw (ViInt32   modulation,
                                                        ViSession instrSession,
                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  sprintf (wrtBuf, "INIT:SPEC:SWIT:%s", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Abort
/*===========================================================================*/
ViStatus _VI_FUNC NSig_AborSpSw (ViInt32   modulation,
                                                        ViSession instrSession,
                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  sprintf (wrtBuf, "ABOR:SPEC:SWIT:%s", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Stop
/*===========================================================================*/
ViStatus _VI_FUNC NSig_StopSpSw (ViInt32   modulation,
                                                        ViSession instrSession,
                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  sprintf (wrtBuf, "STOP:SPEC:SWIT:%s", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Continue
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ContSpSw (ViInt32   modulation,
                                                        ViSession instrSession,
                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  sprintf (wrtBuf, "CONT:SPEC:SWIT:%s", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Status
/*===========================================================================*/
ViStatus _VI_FUNC NSig_FetcSpSwSt (ViInt32   modulation,
                                                          ViSession instrSession,
                                                          ViPInt32  MeasStatus,
                                                          ViPInt32  CurrentStatCycleCount,
                                                          ViPInt32  CurrentEvalPeriodCount,
                                                          ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  // Fetch the measurement status:
  sprintf (wrtBuf, "FETC:SPEC:SWIT:%s:STAT?", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the measurement status
  RSCMU300_Status = RSCMU300_GetMeasStatVal (MeasStatus, tab, 0);

  // Get the counter for current statistics cycle
  if (strcmp (tab[1], "NONE") != 0)
    sscanf (tab[1], "%ld", CurrentStatCycleCount);
  else *CurrentStatCycleCount = RSCMU300_OFF;

  // Get the counter for current evaluation period within a cycle
  if (strcmp (tab[2], "NONE") != 0)
    sscanf (tab[2], "%ld", CurrentEvalPeriodCount);
  else *CurrentEvalPeriodCount = RSCMU300_OFF;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event Reporting Mode
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ConfSpSwErep (ViInt32   modulation,
                                                            ViSession instrSession,
                                                            ViInt32   Mode,
                                                            ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:SWIT:%s:EREP %s", modulation_type[modulation]
                                              , StrErep[Mode]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ReadSpSw (ViInt32   modulation,
                                                        ViSession instrSession,
                                                        ViPReal64 referencePower,
                                                        ViPInt32  matching,
                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  sprintf (wrtBuf, "READ:SPEC:SWIT:%s?", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the Average Burst Power
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", referencePower);
  else *referencePower = RSCMU300_NAN;

  // Get the matching
  RSCMU300_Status = RSCMU300_GetMatchingValue(matching,tab, 1);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch
/*===========================================================================*/
ViStatus _VI_FUNC NSig_FetcSpSw (ViInt32   modulation,
                                                        ViSession instrSession,
                                                        ViPReal64 referencePower,
                                                        ViPInt32  matching,
                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  sprintf (wrtBuf, "FETC:SPEC:SWIT:%s?", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the Average Burst Power
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", referencePower);
  else *referencePower = RSCMU300_NAN;

  // Get the matching
  RSCMU300_Status = RSCMU300_GetMatchingValue(matching,tab, 1);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample
/*===========================================================================*/
ViStatus _VI_FUNC NSig_SampSpSw (ViInt32   modulation,
                                                        ViSession instrSession,
                                                        ViPReal64 referencePower,
                                                        ViPInt32  matching,
                                                        ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  sprintf (wrtBuf, "SAMP:SPEC:SWIT:%s?", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the Average Burst Power
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%le", referencePower);
  else *referencePower = RSCMU300_NAN;

  // Get the matching
  RSCMU300_Status = RSCMU300_GetMatchingValue(matching,tab, 1);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Array
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ReadArrSpSw (ViInt32   modulation,
                                                           ViSession instrSession,
                                                           ViReal64  BurstPower[],
                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[9][20];

  sprintf (wrtBuf, "READ:ARR:SPEC:SWIT:%s?", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Array
/*===========================================================================*/
ViStatus _VI_FUNC NSig_FetcArrSpSw (ViInt32   modulation,
                                                           ViSession instrSession,
                                                           ViReal64  BurstPower[],
                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[9][20];

  sprintf (wrtBuf, "FETC:ARR:SPEC:SWIT:%s?", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample Array
/*===========================================================================*/
ViStatus _VI_FUNC NSig_SampArrSpSw (ViInt32   modulation,
                                                           ViSession instrSession,
                                                           ViReal64  BurstPower[],
                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[9][20];

  sprintf (wrtBuf, "SAMP:ARR:SPEC:SWIT:%s?", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Read Subarray
/*===========================================================================*/
ViStatus _VI_FUNC NSig_ReadSubSpSw (ViInt32   modulation,
                                                           ViSession instrSession,
                                                           ViReal64  BurstPower[],
                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[9][20];

  sprintf (wrtBuf, "READ:SUB:SPEC:SWIT:%s?", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Fetch Subarray
/*===========================================================================*/
ViStatus _VI_FUNC NSig_FetcSubSpSw (ViInt32   modulation,
                                                           ViSession instrSession,
                                                           ViReal64  BurstPower[],
                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[9][20];

  sprintf (wrtBuf, "FETC:SUB:SPEC:SWIT:%s?", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Sample Subarray
/*===========================================================================*/
ViStatus _VI_FUNC NSig_SampSubSpSw (ViInt32   modulation,
                                                           ViSession instrSession,
                                                           ViReal64  BurstPower[],
                                                           ViChar    _VI_FAR errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[9][20];

  sprintf (wrtBuf, "SAMP:SUB:SPEC:SWIT:%s?", modulation_type[modulation]);
  if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU300_scanStringBurst ( rdBuf, BurstPowerTmp);

  RSCMU300_Status = RSCMU300_ReturnCMUResponse(NbOfMeasValues,BurstPowerTmp,BurstPower);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus RSCMU300_ConfEventReporting (ViSession  instrSession,
                                   ViChar    *command,
                                   ViInt32    Report,
                                   ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViChar      wrtBuf[WR_BUFFER_SIZE];

    sprintf (wrtBuf, "%s", command);

    RETMSG(RSCMU300_setEnum(instrSession, wrtBuf,
                         Report, StrErep,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Fetch Status only for Spectrum Modulation/Switching Combined!
/* Purpose : This function returns the status of the measurement with 2 Statistic Counter.
/*===========================================================================*/
ViStatus RSCMU300_FetcSpecMSwStatus (ViSession  instrSession,
                                  ViChar    *command,
                                  ViInt32   *MeasurementStatus,
                                  ViInt32   *CountingNo,
                                  ViInt32   *ModStatisticNo,
                                  ViInt32   *SwitchStatisticNo,
                                  ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE], wrtBuf[WR_BUFFER_SIZE];
    ViChar*     str;


    // Fetch the status of the Power/t measurement:
    sprintf(wrtBuf,"%s?", command);

    CHECKRETMSG(RSCMU300_getViString(instrSession, wrtBuf, rdBuf, RD_BUFFER_SIZE,0));

    if (!(str = strtok(rdBuf,",")))
        return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_INTERPRETING_RESPONSE, errorMessage);
    // Get the status of the measurement:
    CHECKRET(RSCMU300_getIndexFromString(instrSession, rdBuf, measurementStatusArr, MeasurementStatus));

    if (!(str = strtok(NULL,",")))
        return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_INTERPRETING_RESPONSE, errorMessage);
    if(!sscanf(str,"%ld",CountingNo))
        *CountingNo = RSCMU300_NONE;

    if (!(str = strtok(NULL,",")))
        return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_INTERPRETING_RESPONSE, errorMessage);
    if(!sscanf(str,"%ld",ModStatisticNo))
        *ModStatisticNo = RSCMU300_NONE;

    if (!(str = strtok(NULL,",")))
        return RSCMU300_Base_errorMessage(instrSession, RSCMU_ERROR_INTERPRETING_RESPONSE, errorMessage);
    if(!sscanf(str,"%ld",SwitchStatisticNo))
        *SwitchStatisticNo = RSCMU300_NONE;

    return RSCMU300_Status;
}


/*===========================================================================*/
/* Function: Variable Measure Points
/*===========================================================================*/
ViStatus RSCMU300_MeasSpecVarMeaPoint (ViSession instrSession,
                                    ViChar    *command,
                                    ViInt32   nr,
                                    ViInt32   enable,
                                    ViReal64  frequencyMHz,
                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_65,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, nr, RSCMU300_MPO1, RSCMU300_MPO4, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, enable, RSCMU300_OFF, RSCMU300_ON, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, frequencyMHz, -2.5, 2.5, RSCMU_ERROR_PARAMETER4, errorMessage);

  if (enable == RSCMU300_OFF)
    sprintf (wrtBuf, "%s%d %s", command, nr, mode_On_Off[enable]);
  else
    sprintf (wrtBuf, "%s%d %lf", command, nr, frequencyMHz);

  RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Measurement scalar
/* Purpose : This function starts the measurement and outputs some results.
/*===========================================================================*/
ViStatus RSCMU300_MeasSpecModSwitch (ViSession  instrSession,
                                  ViChar    *command,
                                  ViReal64  *refPowMod,
                                  ViInt32   *matchingMod,
                                  ViReal64  *refPowSwitch,
                                  ViInt32   *matchingSwitch,
                                  ViChar     errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      tab[100][100];
  GET_BUFS(instrSession);

  sprintf (wrtBuf, "%s?", command);
  CHECKRETMSG(RSCMU300_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE,0));

  // Separate the CMU response:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%lf", refPowMod);
  else *refPowMod = RSCMU300_NAN;

  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%lf", refPowSwitch);
  else *refPowSwitch = RSCMU300_NAN;

  RSCMU300_Status = RSCMU300_GetMatchingValue (matchingMod,tab, 2);

  RSCMU300_Status = RSCMU300_GetMatchingValue (matchingSwitch,tab, 3);

  return RSCMU300_Status;
}

/* ----------------------------------------------------------------------------
 * lokal function
 * ----------------------------------------------------------------------------*/
ViStatus RSCMU300_MeasArray (ViSession  instrSession,
                          ViChar    *command,
                          ViReal64   values[],
                          ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
    ViInt32     NbOfMeasValues;
    ViChar      valuesTmp[1000][20];

    sprintf (wrtBuf, "%s?", command);

    if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
        return RSCMU300_Status;

    // Find all values by breaking the read buffer:
    NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, valuesTmp);

    RSCMU300_Status = RSCMU300_ReturnCMUResponse (NbOfMeasValues, valuesTmp, values);

    return RSCMU300_Status;
}

/* ----------------------------------------------------------------------------
 * lokal function
 * ----------------------------------------------------------------------------*/
ViStatus RSCMU300_MeasArrayInt (ViSession  instrSession,
                             ViChar    *StrCommand,
                             ViInt32    values[],
                             ViChar     errorMessage[])
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
    ViInt32     NbOfMeasValues;
    ViChar      valuesTmp[669][20];
    ViInt32 i;

    sprintf (wrtBuf, "%s?", StrCommand);

    if ((RSCMU300_Status = RSCMU300_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
        return RSCMU300_Status;

    // Find all values by breaking the read buffer:
    NbOfMeasValues = RSCMU300_scanStringBurst (rdBuf, valuesTmp);

    for (i=0; i < (NbOfMeasValues); i++)
    {
      if (strncmp (valuesTmp[i], "NAN",3) != 0)
        sscanf (valuesTmp[i], "%d", &values[i]);
      else  values[i] = RSCMU300_NAN;
    }

    return RSCMU300_Status;
}

/*===========================================================================*/
/* local Function
/*===========================================================================*/
ViStatus RSCMU300_MeasSclarDemodBit (ViSession  instrSession,
                                  ViChar    *StrCommand,
                                  ViInt32   *result,
                                  ViChar     errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  sprintf (wrtBuf, "%s", StrCommand);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Get the result
  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf, "%d", result);
  else *result = RSCMU300_NAN;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* local Function
/*===========================================================================*/
ViStatus RSCMU300_MeasPeakDemodBit (ViSession  instrSession,
                                 ViChar    *StrCommand,
                                 ViInt32   *xValue,
                                 ViInt32   *yValue,
                                 ViChar     errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      Tab[100][100];

  sprintf (wrtBuf, "%s", StrCommand);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Split the multiple data values separated by a comma:
  RSCMU300_SeparateDataValues (rdBuf, ",", Tab);

  // Get the x-value
  if (strcmp (Tab[0], "NAN") != 0)
    sscanf (Tab[0], "%d", xValue);
  else *xValue = RSCMU300_NAN;

  // Get the y-value
  if (strcmp (Tab[0], "NAN") != 0)
    sscanf (Tab[0], "%d", yValue);
  else *yValue = RSCMU300_NAN;

  return RSCMU300_Status;
}
/*===========================================================================*/
/* local Function
/*===========================================================================*/
ViStatus RSCMU300_MeasIqanScalarSig (ViSession  instrSession,
                               ViChar    *StrCommand,
                               ViReal64  *EvmRMS,
                               ViReal64  *MerrRMS,
                               ViReal64  *PerrRMS,
                               ViReal64  *TimeErr,
                               ViReal64  *AvgBurstPow,
                               ViChar     errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      Tab[100][100];

  sprintf (wrtBuf, "%s?", StrCommand);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Split the multiple data values separated by a comma:
  RSCMU300_SeparateDataValues (rdBuf, ",", Tab);

  // Get the EVM RMS:
  if (strcmp (Tab[0], "NAN") != 0)
    sscanf (Tab[0], "%lf", EvmRMS);
  else *EvmRMS = RSCMU300_NAN;

  // Get the MERR RMS:
  if (strcmp (Tab[1], "NAN") != 0)
    sscanf (Tab[1], "%lf", MerrRMS);
  else *MerrRMS = RSCMU300_NAN;

  // Get the MERR RMS:
  if (strcmp (Tab[2], "NAN") != 0)
    sscanf (Tab[2], "%lf", PerrRMS);
  else *PerrRMS = RSCMU300_NAN;

  // Get the Timing Error:
  if (strcmp (Tab[3], "NAN") != 0)
    sscanf (Tab[3], "%lf", TimeErr);
  else *TimeErr = RSCMU300_NAN;

  // Get the Average Burst Power:
  if (strcmp (Tab[4], "NAN") != 0)
    sscanf (Tab[4], "%lf", AvgBurstPow);
  else *AvgBurstPow = RSCMU300_NAN;

  return RSCMU300_Status;
}

ViStatus RSCMU300_MeasIqanScalarNSig (ViSession  instrSession,
                               ViChar    *StrCommand,
                               ViReal64  *EvmRMS,
                               ViReal64  *MerrRMS,
                               ViReal64  *PerrRMS,
                               ViReal64  *AvgBurstPow,
                               ViChar     errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      Tab[100][100];

  sprintf (wrtBuf, "%s?", StrCommand);
  if ((RSCMU300_Status = RSCMU300_Query (instrSession, wrtBuf, rdBuf, RSCMU300_STB_ON, errorMessage)) < 0)
    return RSCMU300_Status;

  // Split the multiple data values separated by a comma:
  RSCMU300_SeparateDataValues (rdBuf, ",", Tab);

  // Get the EVM RMS:
  if (strcmp (Tab[0], "NAN") != 0)
    sscanf (Tab[0], "%lf", EvmRMS);
  else *EvmRMS = RSCMU300_NAN;

  // Get the MERR RMS:
  if (strcmp (Tab[1], "NAN") != 0)
    sscanf (Tab[1], "%lf", MerrRMS);
  else *MerrRMS = RSCMU300_NAN;

  // Get the MERR RMS:
  if (strcmp (Tab[2], "NAN") != 0)
    sscanf (Tab[2], "%lf", PerrRMS);
  else *PerrRMS = RSCMU300_NAN;

  // Get the Average Burst Power:
  if (strcmp (Tab[4], "NAN") != 0)
    sscanf (Tab[4], "%lf", AvgBurstPow);
  else *AvgBurstPow = RSCMU300_NAN;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Configure Subarrays
/* Purpose : this function is called by the global functions for the
/*           configuration of the subarrays
/*===========================================================================*/
ViStatus RSCMU300_ConfSubArr (ViSession  instrSession,
                           ViChar    *command,
                           ViInt32    Statistics,
                           ViReal64   StartPoint,
                           ViInt32    NumberOfValues,
                           ViChar     errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  GET_BUFS(instrSession);

  // The parameters check has to be done in the global function
  sprintf(wrtBuf, "%s %s,%lf,%d", command, StrSubArr[Statistics], StartPoint, NumberOfValues);

  RETMSG(RSCMU300_sendCmd(instrSession, wrtBuf));
}

/*---------------------------------------------------------------------------*/
/* Other functions
/*---------------------------------------------------------------------------*/
/*===========================================================================*/
/* Function: Get Alarm Results (ABIS)
/*===========================================================================*/
ViStatus _VI_FUNC  RSCMU300_GetAlarmResult (ViInt32 *Result,
                                                                   ViChar   TableOfDataValues[100][100],
                                                                   ViInt32  Index)
{
  if (strncmp ("NACT", TableOfDataValues[Index], 4) == 0)
    *Result = RSCMU300_ALARM_NACT;
  else if (strncmp ("ACT", TableOfDataValues[Index], 3) == 0)
    *Result = RSCMU300_ALARM_ACT;
  else if (strncmp ("NAPP",  TableOfDataValues[Index], 4) == 0)
    *Result = RSCMU300_ALARM_NAPP;
  else
    return RSCMU_ERROR_STAT_UNKNOWN;

  return VI_SUCCESS;
}


// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//      Functions for LabVIEW 5.x and higher
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#ifdef _OUTSIDEVEE_
/*===========================================================================*/
/* Function: RSCMU300_GSM_NSig_GetResourceName                               */
/* Purpose:  This function returns resource descriptor for GSMBS NSig option.*/
/*           Session parameter must contain at least 256 elements ViChar[256]*/
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_NSig_GetResourceName (ViSession      instrSession,
                                                                            ViSession      instrSessionBase,
                                                                            ViChar _VI_FAR sessionName[])
{
  ViStatus  RSCMU300_Status = VI_SUCCESS;
  ViInt32   comp;

  struct RSCMU300_Base_Globals     *p_globalvarBase;
  struct RSCMU300_GSM_NSig_Globals *p_globalvarGSM;

    /* Get a copy of the global data for base session. */
   if( (RSCMU300_Status = viGetAttribute( instrSessionBase
                                        , VI_ATTR_USER_DATA
                                        , (ViAddr)&p_globalvarBase
                                        )) < VI_SUCCESS )
   {
      return RSCMU300_Status;
   }

   /* Get a copy of the global data for this session. */
   if( (RSCMU300_Status = viGetAttribute( instrSession
                                        , VI_ATTR_USER_DATA
                                        , (ViAddr)&p_globalvarGSM
                                        )) < VI_SUCCESS )
   {
      return RSCMU300_Status;
   }

      // Hardware Connection
      comp = strncmp( "GPIB"
                    , p_globalvarBase->RSCMU300_tGlobal.RSCMU300_SCPIConnection
                    , 4
                    );

  if( comp == 0 )
      {
         sprintf( sessionName
                , "%s::%ld::%ld::INSTR"
                , p_globalvarBase->RSCMU300_tGlobal.RSCMU300_SCPIConnection
                , p_globalvarBase->RSCMU300_tGlobal.RSCMU300_primary_address
                , p_globalvarGSM->RSCMU300_tGlobal.RSCMU300_secondary_address
                );
      }
      else
      {
         sprintf( sessionName
                , "%s::INSTR"
                , p_globalvarBase->RSCMU300_tGlobal.RSCMU300_SCPIConnection
                );
      }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: RSCMU300_GSM_Sig_GetResourceName                                */
/* Purpose:  This function returns resource descriptor for GSMBS Sig option. */
/*           Session parameter must contain at least 256 elements ViChar[256]*/
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GSM_Sig_GetResourceName (ViSession      instrSession,
                                                                           ViSession      instrSessionBase,
                                                                           ViChar _VI_FAR sessionName[])
{
  ViStatus RSCMU300_Status = VI_SUCCESS;
  ViInt32  comp;

  struct RSCMU300_Base_Globals    *p_globalvarBase;
  struct RSCMU300_GSM_Sig_Globals *p_globalvarGSM;

    /* Get a copy of the global data for base session. */
   if( (RSCMU300_Status = viGetAttribute( instrSessionBase
                                        , VI_ATTR_USER_DATA
                                        , (ViAddr)&p_globalvarBase
                                        )) < VI_SUCCESS )
   {
      return RSCMU300_Status;
   }

   /* Get a copy of the global data for this session. */
   if( (RSCMU300_Status = viGetAttribute( instrSession
                                        , VI_ATTR_USER_DATA
                                        , (ViAddr)&p_globalvarGSM
                                        )) < VI_SUCCESS )
   {
      return RSCMU300_Status;
   }

      // Hardware Connection
      comp = strncmp( "GPIB"
                    , p_globalvarBase->RSCMU300_tGlobal.RSCMU300_SCPIConnection
                    , 4
                    );

  if( comp == 0 )
      {
         sprintf( sessionName
                , "%s::%ld::%ld::INSTR"
                , p_globalvarBase->RSCMU300_tGlobal.RSCMU300_SCPIConnection
                , p_globalvarBase->RSCMU300_tGlobal.RSCMU300_primary_address
                , p_globalvarGSM->RSCMU300_tGlobal.RSCMU300_secondary_address
                );
      }
      else
      {
         sprintf( sessionName
                , "%s::INSTR"
                , p_globalvarBase->RSCMU300_tGlobal.RSCMU300_SCPIConnection
                );
      }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Measurement scalar for narrow-band power
/* Purpose : This function starts the measurement and outputs the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_MeasNpow (ViSession  instrSession,
                                     ViInt32    command,
                                     ViReal64  *AvgPowCurr,
                                     ViReal64  *MinPowCurr,
                                     ViReal64  *MaxPowCurr,
                                     ViReal64  *AvgPowAvg,
                                     ViReal64  *MinPowAvg,
                                     ViReal64  *MaxPowAvg,
                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE], rdBuf[RD_BUFFER_SIZE];
  ViChar*     str;

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  sprintf (wrtBuf, "%s:NPOW?", StrCommand[command]);
  CHECKRETMSG(RSCMU300_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE,0));

  // Get the Average Power of Current Burst
  GET_VI_REAL64(*AvgPowCurr,rdBuf);
  // Get the Minimum Power of Current Burst
  GET_VI_REAL64(*MinPowCurr,NULL);
  // Get the Maximum Power of Current Burst
  GET_VI_REAL64(*MaxPowCurr,NULL);
  // Get the Average Power of Average Burst
  GET_VI_REAL64(*AvgPowAvg,NULL);
  // Get the Minimum Power of Average Burst
  GET_VI_REAL64(*MinPowAvg,NULL);
  // Get the Maximum Power of Average Burst
  GET_VI_REAL64(*MaxPowAvg,NULL);

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Measurement scalar for Power/t Multislot
/* Purpose : This function is called by the Read, Fetch and Sample.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_MeasScalPowerMSlot (ViSession  instrSession,
                                               ViInt32    command,
                                               ViInt32    channel,
                                               ViInt32    Slot,
                                               ViReal64   *BurstOutOfTol,
                                               ViReal64   *AvgBurstPwCurr,
                                               ViReal64   *AvgBurstPwAvg,
                                               ViReal64   *PeakBurstPwCurr,
                                               ViReal64   *TimingAdvError,
                                               ViInt32    *BurstMatching,
                                               ViChar     errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar      tab[100][100];
  GET_BUFS(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Slot, 0, 3, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "%s:POW:MSL:%s?", StrCommand[command],Channel_Type[channel]);
  CHECKRETMSG(RSCMU300_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE,0));

  // Split the multiple data values separated by a comma:
  RSCMU300_SeparateDataValues (rdBuf, ",", tab);

  // Get the burst out of tolerance:
  if (strcmp (tab[(6*Slot)], "NAN") != 0)
    sscanf (tab[(6*Slot)], "%le", BurstOutOfTol);
  else
    *BurstOutOfTol = RSCMU300_NAN;
  // Get the average burst power (current burst):
  if (strcmp (tab[(6*Slot)+1], "NAN") != 0)
    sscanf (tab[(6*Slot)+1], "%le", AvgBurstPwCurr);
  else
    *AvgBurstPwCurr = RSCMU300_NAN;
  // Get the average burst power of average trace:
  if (strcmp (tab[(6*Slot)+2], "NAN") != 0)
    sscanf (tab[(6*Slot)+2], "%le", AvgBurstPwAvg);
  else
    *AvgBurstPwAvg = RSCMU300_NAN;
  // Get the peak burst power (current burst):
  if (strcmp (tab[(6*Slot)+3], "NAN") != 0)
    sscanf (tab[(6*Slot)+3], "%le", PeakBurstPwCurr);
  else
    *PeakBurstPwCurr = RSCMU300_NAN;
  // Get the timing advance error:
  if (strcmp (tab[(6*Slot)+4], "NAN") != 0)
    sscanf (tab[(6*Slot)+4], "%le", TimingAdvError);
  else
    *TimingAdvError = RSCMU300_NAN;
  // Get the burst template matching:
  RSCMU300_GetMatchingValue (BurstMatching, tab, (6*Slot)+5);

  return RSCMU300_Status;
}


/*===========================================================================*/
/* Function: Measurement array for Power/t Multislot
/* Purpose : This function is called by the Read, Fetch and Sample array.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_MeasArrayPowerMslot (ViSession  instrSession,
                                                ViInt32    channel,
                                                ViInt32    Command,
                                                ViInt32    StatisticsMode,
                                                ViReal64   Values[],
                                                ViChar     errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar     *StrValue;
  ViInt16     Index = 0;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "%s:ARR:POW:MSL:%s:%s?", StrCommand[Command], Channel_Type[channel], StrStatMode[StatisticsMode]);
  CHECKRETMSG(RSCMU300_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE_ARRAY,0));

  // Find all values by breaking the read buffer:
  StrValue = strtok(rdBuf, ",");

  while (StrValue)
  {
    if (strcmp (StrValue, "NAN") != 0)
      sscanf (StrValue, "%le", &Values[Index]);
    else Values[Index] = RSCMU300_NAN;

    StrValue = strtok (NULL, ",");

    Index++;
  }

  return RSCMU300_Status;
}


/*===========================================================================*/
/* Function: Measurement Subarray for Power/t Multislot
/* Purpose : This function is called by the Read, Fetch and Sample subarray.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_MeasSubarrPowerMslot (ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   Command,
                                                 ViInt32   StatisticsMode,
                                                 ViReal64  Values[],
                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar     *StrValue;
  ViInt16     Index = 0;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, channel, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "%s:SUB:POW:MSL:%s:%s?", StrCommand[Command], Channel_Type[channel], StrStatMode[StatisticsMode]);
  CHECKRETMSG(RSCMU300_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE_ARRAY,0));

  // Find all values by breaking the read buffer:
  StrValue = strtok(rdBuf, ",");

  while (StrValue)
  {
    if (strcmp (StrValue, "NAN") != 0)
      sscanf (StrValue, "%le", &Values[Index]);
    else Values[Index] = RSCMU300_NAN;

    StrValue = strtok (NULL, ",");

    Index++;
  }

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Measurement scalar for RACH Test
/* Purpose : This function is called by the Read, Fetch and Sample.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_MeasScalRACH (ViSession  instrSession,
                                         ViInt32    command,
                                         ViReal64   *frameRate,
                                         ViReal64   *burstsSent,
                                         ViReal64   *progTime,
                                         ViChar     errorMessage[])
{
  ViStatus    RSCMU300_Status = VI_SUCCESS;
  ViChar*     str;
  GET_BUFS(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU300_checkVersion(instrSession,RSCMU300_V3_06,RSCMU_ERROR_FW_VERSION_INCOMPATIBLE));

  sprintf (wrtBuf, "%s:RXQ:RACH?", StrCommand[command]);
  CHECKRETMSG(RSCMU300_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE,0));

  GET_VI_REAL64(*frameRate,rdBuf);
  GET_VI_REAL64(*burstsSent,NULL);
  GET_VI_REAL64(*progTime,NULL);

  return RSCMU300_Status;
}









#endif

/*###########################################################################*/
/*                                                                           */
/*  VXI PLUG & PLAY COMPATIBILITY FUNCTIONS                                  */
/*                                                                           */
/*  These functions provide a VXIplug&play compatibily of this instrument    */
/*  driver with regard to the following documents:                           */
/*                                                                           */
/*  VPP-3.1: Instrument Drivers                                              */
/*      Architecture and Design                                              */
/*      Specification                                                        */
/*      Revision 4.0                                                         */
/*      February 5, 1996                                                     */
/*                                                                           */
/*  VPP-3.2: Instrument Driver                                               */
/*      Functional Body Specification                                        */
/*      Revision 4.0                                                         */
/*      February 2, 1996                                                     */
/*                                                                           */
/*  By: Jan Sima, ELCOM, a.s., Czech Republic                                */
/*                                                                           */
/*###########################################################################*/
#ifndef _REMVXIPNP

/*===========================================================================*/
/* Function: Initialize                                                      */
/* Purpose:  This function opens the instrument, queries the instrument      */
/*           for its ID, and initializes the instrument to a known state.    */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_init (ViRsrc     resourceName,
                                                        ViBoolean  IDQuery,
                                                        ViBoolean  resetDevice,
                                                        ViPSession instrSession)
{
    ViStatus    RSCMU300_status = VI_SUCCESS;
    ViString    p2str;
    ViInt32     board = 0,
                primaryAddr = 0,
                secondaryAddr = 0;
    ViChar      errorMessage[WR_BUFFER_SIZE];
    ViSession   rmHandle;

    p2str = resourceName;

    /* --- Set standard "C" locale --- */
    {
        char *locale;

        locale = setlocale(LC_ALL, "C");
    }

    if (strncmp (p2str, "GPIB", 4) != 0)
        return VI_ERROR_INV_RSRC_NAME;

    p2str += 4;

    if (p2str[0] >= '0' && p2str[0] <= '9')
        board = (p2str++)[0] - '0';

    if (strncmp (p2str, "::", 2) != 0)
        return VI_ERROR_INV_RSRC_NAME;

    if (sscanf (p2str += 2, "%ld", &primaryAddr) != 1)
        return VI_ERROR_INV_RSRC_NAME;

    p2str += (primaryAddr > 9) ? 2 : 1;

    if (strlen (p2str) != 0 && strncmp (p2str, "::", 2) != 0)
        return VI_ERROR_INV_RSRC_NAME;

    if (strlen (p2str) != 0) {
        if (sscanf (p2str += 2, "%ld", &secondaryAddr) != 1)
            return VI_ERROR_INV_RSRC_NAME;

        p2str += (secondaryAddr > 9) ? 2 : 1;

        if (strlen (p2str) != 0 && strcmp (p2str, "::INSTR") != 0)
            return VI_ERROR_INV_RSRC_NAME;
    }

    if (secondaryAddr == 0) {
        if ((RSCMU300_status = RSCMU300_Init_Base (instrSession, RSCMU300_GPIB, board, primaryAddr,
                                             IDQuery, resetDevice, errorMessage)) < 0)
            return RSCMU300_status;
    } else {
        if ((RSCMU300_status = viOpenDefaultRM (&rmHandle)) != 0)
            return RSCMU300_status;

        if ((RSCMU300_status = viOpen (rmHandle, resourceName, VI_NULL, VI_NULL, instrSession)) != 0)
            return RSCMU300_status;

        if ((RSCMU300_status = viGpibControlREN (*instrSession, VI_GPIB_REN_ASSERT)) < 0)
            return RSCMU300_status;
    }

    return RSCMU300_status;
}

/*===========================================================================*/
/* Function: Init GSM Non Signalling                                         */
/* Purpose:  This function initializes the GSM non signalling module's       */
/*           global data structures. This function is used in VEE where this */
/*           can not be a part of the VXIpnp init function.                  */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_initGSMNSig (ViSession  GSMBSNSigSession,
                                                               ViSession  BaseSession,
                                                               ViUInt32   GSMFunctionGpr)
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViSession   globalSession = 0;
    ViInt32     secondAddr = 0, comp = 1;
    ViChar      FctGrpBuffer[128]= "", resource[25]="";
    ViReal64    Flag = RSCMU300_OFF;
    ViChar      errorMessage[WR_BUFFER_SIZE];

    struct RSCMU300_Base_Globals     *p_globalvarBase;
    struct RSCMU300_GSM_NSig_Globals  *p_globalvarGSM;

    /* --- Set standard "C" locale --- */
    {
        char *locale;

        locale = setlocale(LC_ALL, "C");
    }

    // Which Function Group does the User want?
    switch (GSMFunctionGpr)
    {
      case RSCMU300_GSM400BS_NSIG:
        strcpy (FctGrpBuffer, "\"GSM400BS_NSig\"");
        break;
      case RSCMU300_GSM850BS_NSIG:
        strcpy (FctGrpBuffer, "\"GSM850BS_NSig\"");
        break;
      case RSCMU300_GSM900BS_NSIG:
        strcpy (FctGrpBuffer, "\"GSM900BS_NSig\"");
        break;
      case RSCMU300_GSM1800BS_NSIG:
        strcpy (FctGrpBuffer, "\"GSM1800BS_NSig\"");
        break;
      case RSCMU300_GSM1900BS_NSIG:
        strcpy (FctGrpBuffer, "\"GSM1900BS_NSig\"");
        break;
    }

    // Init the Error Message
    strcpy (errorMessage, "No Error");

    // Get the current options (= Function Group Names) in the CMU.
    if ((RSCMU300_Status = viGetAttribute (BaseSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
      return RSCMU300_K3G_errorMessage (BaseSession, RSCMU300_Status, errorMessage);

    // Find the Secondary address for GSM_NSig
    while ((comp != 0) && (secondAddr < 30))
    {
      comp = strncmp (p_globalvarBase->RSCMU300_tSecAddr[secondAddr].FctGrp, FctGrpBuffer, strlen(FctGrpBuffer));
      secondAddr++;
      if (comp == 0)  Flag = RSCMU300_ON;
    }

    if (Flag == RSCMU300_OFF)
      return RSCMU300_K3G_errorMessage (GSMBSNSigSession, RSCMU_ERROR_INVALID_FCT_GRP, errorMessage);

    // Allocate space for "struct RSCMU300_SESSION_Globals"
    if ((p_globalvarGSM = (struct RSCMU300_GSM_NSig_Globals *)malloc(sizeof(struct RSCMU300_GSM_NSig_Globals))) == 0)
      return RSCMU300_initCleanUp (globalSession, GSMBSNSigSession, RSCMU300_Status);

    if ((RSCMU300_Status = viSetAttribute(GSMBSNSigSession, VI_ATTR_USER_DATA,(ViAttrState)p_globalvarGSM)) < 0)
      return RSCMU300_initCleanUp (globalSession, GSMBSNSigSession, RSCMU300_Status);

    // Set initial values of variables for function Group 'GSM_NonSig' .
    strcpy (p_globalvarGSM->RSCMU300_tGlobal.FGrp_Name, FctGrpBuffer);
    p_globalvarGSM->RSCMU300_tGlobal.RSCMU300_primary_address = p_globalvarBase->RSCMU300_tGlobal.RSCMU300_primary_address;
    p_globalvarGSM->RSCMU300_tGlobal.RSCMU300_secondary_address = secondAddr - 1;
    p_globalvarGSM->RSCMU300_tGlobal.RSCMU300_TRACE = p_globalvarBase->RSCMU300_tGlobal.RSCMU300_TRACE;
    if (p_globalvarGSM->RSCMU300_tGlobal.RSCMU300_TRACE == RSCMU300_ON)
      p_globalvarGSM->RSCMU300_tGlobal.RSCMU300_AddrTargetFile = p_globalvarBase->RSCMU300_tGlobal.RSCMU300_AddrTargetFile;

    // Record the execution of this Init Function.
    p_globalvarBase->RSCMU300_tSecAddr[secondAddr - 1].SessionNb = GSMBSNSigSession;

    // Timeout changed from 10s to 30 seconds
    if ((RSCMU300_Status = viSetAttribute (GSMBSNSigSession, VI_ATTR_TMO_VALUE, 15000)) < 0)
      return RSCMU300_Status;

    return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Init GSM Signalling                                             */
/* Purpose:  This function initializes the GSM signalling module's           */
/*           global data structures. This function is used in VEE where this */
/*           can not be a part of the VXIpnp init function.                  */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_initGSMSig (ViSession   GSMSigSession,
                                                              ViSession   BaseSession,
                                                              ViUInt32    GSMFunctionGpr)
{
    ViStatus    RSCMU300_Status = VI_SUCCESS;
    ViSession   globalSession = 0;
    ViInt32     secondAddr = 0, comp = 1;
    ViReal64    Flag = RSCMU300_OFF;
    ViChar      FctGrpBuffer[128]= "", resource[25]="";
    ViChar      errorMessage[WR_BUFFER_SIZE];

    struct RSCMU300_Base_Globals     *p_globalvarBase;
    struct RSCMU300_GSM_Sig_Globals  *p_globalvarGSM;

    /* --- Set standard "C" locale --- */
    {
        char *locale;

        locale = setlocale(LC_ALL, "C");
    }

    // Which Function Group does the User want?
    switch (GSMFunctionGpr)
    {
      case RSCMU300_GSM400:
        strcpy (FctGrpBuffer, "\"GSM400BS_Sig\"");
        break;
      case RSCMU300_GSM900:
        strcpy (FctGrpBuffer, "\"GSM900BS_Sig\"");
        break;
      case RSCMU300_GSM1800:
        strcpy (FctGrpBuffer, "\"GSM1800BS_Sig\"");
        break;
      case RSCMU300_GSM1900:
        strcpy (FctGrpBuffer, "\"GSM1900BS_Sig\"");
        break;
    }

    // Init the Error Message
    strcpy (errorMessage, "No Error");

    // Get the current options (= Function Group Names) in the CMU.
    if ((RSCMU300_Status = viGetAttribute (BaseSession, VI_ATTR_USER_DATA,(ViAddr) &p_globalvarBase)) < 0)
      return RSCMU300_K3G_errorMessage (BaseSession, RSCMU300_Status, errorMessage);

    // Find the Secondary address for GSM_Sig
    while ((comp != 0) && (secondAddr < 30))
    {
      comp = strncmp (p_globalvarBase->RSCMU300_tSecAddr[secondAddr].FctGrp, FctGrpBuffer, strlen(FctGrpBuffer));
      secondAddr++;
      if (comp == 0)  Flag = RSCMU300_ON;
    }

    if (Flag == RSCMU300_OFF)
      return RSCMU300_K3G_errorMessage (GSMSigSession, RSCMU_ERROR_INVALID_FCT_GRP, errorMessage);

    // Allocate space for "struct RSCMU300_SESSION_Globals"
    if ((p_globalvarGSM = (struct RSCMU300_GSM_Sig_Globals *) malloc (sizeof (struct RSCMU300_GSM_Sig_Globals))) == 0)
      return RSCMU300_initCleanUp (globalSession, GSMSigSession, RSCMU300_Status);

    if ((RSCMU300_Status = viSetAttribute(GSMSigSession, VI_ATTR_USER_DATA,(ViAttrState)p_globalvarGSM)) < 0)
      return RSCMU300_initCleanUp (globalSession, GSMSigSession, RSCMU300_Status);

    // Set initial values of variables for function Group 'GSM_Sig'.
    strcpy (p_globalvarGSM->RSCMU300_tGlobal.FGrp_Name, FctGrpBuffer);
    p_globalvarGSM->RSCMU300_tGlobal.RSCMU300_primary_address = p_globalvarBase->RSCMU300_tGlobal.RSCMU300_primary_address;
    p_globalvarGSM->RSCMU300_tGlobal.RSCMU300_secondary_address = secondAddr - 1;
    p_globalvarGSM->RSCMU300_tGlobal.RSCMU300_TRACE = p_globalvarBase->RSCMU300_tGlobal.RSCMU300_TRACE;
    if (p_globalvarGSM->RSCMU300_tGlobal.RSCMU300_TRACE == RSCMU300_ON)
      p_globalvarGSM->RSCMU300_tGlobal.RSCMU300_AddrTargetFile = p_globalvarBase->RSCMU300_tGlobal.RSCMU300_AddrTargetFile;

    // Base CMU FW available
    strcpy (p_globalvarGSM->RSCMU300_tGlobal.CmuVersion, p_globalvarBase->RSCMU300_tGlobal.CmuVersion);
    p_globalvarGSM->RSCMU300_tGlobal.RSCMU300_FW_Version = p_globalvarBase->RSCMU300_tGlobal.RSCMU300_FW_Version;

    // Record the execution of this Init Function.
    p_globalvarBase->RSCMU300_tSecAddr[secondAddr - 1].SessionNb = GSMSigSession;

    // Record the "HandOverName" for the actual Session.
    switch (GSMFunctionGpr)
    {
      case RSCMU300_GSM400:
        strcpy (p_globalvarGSM->RSCMU300_tHandOver.HandOverSessionName, "\"GSM400MsDualBand\"");
        break;
      case RSCMU300_GSM900:
        strcpy (p_globalvarGSM->RSCMU300_tHandOver.HandOverSessionName, "\"GSM900MsDualBand\"");
        break;
      case RSCMU300_GSM1800:
        strcpy (p_globalvarGSM->RSCMU300_tHandOver.HandOverSessionName, "\"GSM1800MsDualBand\"");
        break;
      case RSCMU300_GSM1900:
        strcpy (p_globalvarGSM->RSCMU300_tHandOver.HandOverSessionName, "\"GSM1900MsDualBand\"");
        break;
    }

    // Timeout changed from 10s to 30 seconds
    if ((RSCMU300_Status = viSetAttribute (GSMSigSession, VI_ATTR_TMO_VALUE, 15000)) < 0)
      return RSCMU300_Status;

    return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Get Instrument Handle                                           */
/* Purpose:  This function passes the instrument handle from the first       */
/*           parameter to the second parameter. This function is used in VEE */
/*           where it allows to get the current instrument handle.           */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GetInstrumentHandle (ViSession instrumentHandle,
                                                                       ViSession *instrumentHandleOut)
{
    *instrumentHandleOut = instrumentHandle;
    return 0;
}

/*===========================================================================*/
/* Function: Reset                                                           */
/* Purpose:  This function resets the instrument.  If the reset function     */
/*           is not supported by the instrument, this function returns       */
/*           the warning VI_WARN_NSUP_RESET.                                 */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_reset (ViSession instrSession)
{
    return VI_WARN_NSUP_RESET;
}

/*===========================================================================*/
/* Function: Self-Test                                                       */
/* Purpose:  This function executes the instrument self-test and returns     */
/*           the result. If the self test function is not supported by the   */
/*           instrument, this function returns the warning                   */
/*           VI_WARN_NSUP_SELF_TEST.                                         */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_self_test (ViSession instrSession,
                                                             ViPInt16 testResult,
                                                             ViChar _VI_FAR testMessage[])
{
    return VI_WARN_NSUP_SELF_TEST;
}

/*===========================================================================*/
/* Function: Error Query                                                     */
/* Purpose:  This function queries the instrument error queue, and returns   */
/*           the result.                                                     */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_error_query (ViSession instrSession,
                                                               ViPInt32 errorCode,
                                                               ViChar _VI_FAR errorMessage[])
{
    return VI_WARN_NSUP_ERROR_QUERY;
}

/*===========================================================================*/
/* Function: Error Message                                                   */
/* Purpose:  This function translates the error return value from the        */
/*           instrument driver into a user-readable string.                  */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_error_message (ViSession instrSession,
                                                                 ViStatus statusCode,
                                                                 ViChar _VI_FAR errMessage[])
{
    return RSCMU300_K3G_errorMessage (instrSession, statusCode, errMessage);
}

/*===========================================================================*/
/* Function: Revision Query                                                  */
/* Purpose:  This function returns the driver and instrument revisions.      */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_revision_query (ViSession      instrSession,
                                                                  ViChar _VI_FAR driverRev[],
                                                                  ViChar _VI_FAR instrRev[])
{
    ViChar  errorMessage[WR_BUFFER_SIZE];

    return RSCMU300_K3G_RevisionQuery (instrSession, driverRev, instrRev, errorMessage);
}

/*===========================================================================*/
/* Function: Close                                                           */
/* Purpose:  This function closes the instrument.                            */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_close (ViSession instrSession)
{
    ViStatus RSCMU300_Status = VI_SUCCESS;
    ViChar  errorMessage[WR_BUFFER_SIZE];
    ViUInt16 secAddr;

    if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_GPIB_SECONDARY_ADDR, &secAddr)) < 0)
        return RSCMU300_Status;

    if (secAddr == 0) {
        if ((RSCMU300_Status = RSCMU300_Close_Base (instrSession, errorMessage)) < 0)
            return RSCMU300_Status;
    } else {
        struct RSCMU300_RF_NSig_Globals *p_globalvar;

        if ((RSCMU300_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvar)) < 0)
            return RSCMU300_Status;

        // Deallocate all system resources
        if ((RSCMU300_Status = viClose (instrSession)) < 0)
            return RSCMU300_Status;

        // Deallocate the space pointed by p_globalvar
        if (p_globalvar)
            free (p_globalvar);
    }
    return RSCMU300_Status;
}

#endif

