//=  Include File     =======================================================

#ifndef __K3G_HEADER
#define __K3G_HEADER
#endif

#include <vpptype.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

#ifndef _DLL
    #define _REMVXIPNP
#endif

#if defined(_MSC_VER) || defined(_CVI_)
    #define _OUTSIDEVEE_
#endif

/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
/*---------------------------------------------------------------------------*/
/* The codes for instrument specific ERRORS must be in the range             */
/* 0xBFFC0900 to 0xBFFC0FFF and defined as follows:                          */
/* #define PREFIX_SPECIFIC_ERROR (VI_INSTR_ERROR_OFFSET + n)                 */
/*                                                                           */
/* The codes for instrument specific WARNINGS must be in the range           */
/* 0x3FFC0900 to 0x3FFC0FFF and defined as follows:                          */
/* #define PREFIX_SPECIFIC_WARNING (VI_INSTR_WARNINGS_OFFSET + n)            */
/*                                                                           */
/* Where n represents each instrument specific error/warning number.         */
/* The valid range for n is 0x000 to 0x1FF  for CMU Base                     */
/* The valid range for n is 0x200 to 0x2FF  for K2G Option                   */
/* The valid range for n is 0x300 to 0x3FF  for K3G Option                   */
/* For ease of use the lower 16 bits of warnings and errors should not       */
/* overlap in the same driver.                                               */
/*                                                                           */
/*---------------------------------------------------------------------------*/
#ifdef _OUTSIDEVEE_
#define VI_INSTR_WARNING_OFFSET                          (0x3FFC0900L)
#define VI_INSTR_ERROR_OFFSET                  (_VI_ERROR+0x3FFC0900L)

#define RSCMU300_LIST_OF_SPECIFIC_K3G_ERROR_MESSAGES \
K3G_EXPAND(RSCMU300_ERROR_CALL_TO_BTS_FAILED,    (VI_INSTR_ERROR_OFFSET + 0x301L), "Call to base station failed") \
K3G_EXPAND(RSCMU300_ERROR_RELEASE_TO_BTS_FAILED, (VI_INSTR_ERROR_OFFSET + 0x302L), "Release to base station failed") \
K3G_EXPAND(RSCMU300_ERROR_SIGN_STAT,             (VI_INSTR_ERROR_OFFSET + 0x303L), "The RSCMU is in an internal signalling state in which the command is not allowed") \
K3G_EXPAND(RSCMU300_ERROR_HANDOVER_TARGET,       (VI_INSTR_ERROR_OFFSET + 0x304L), "The handover target is not available")

typedef enum {
#define K3G_EXPAND(id, value, text) id = value,
    RSCMU300_LIST_OF_SPECIFIC_K3G_ERROR_MESSAGES
#undef K3G_EXPAND
} RSCMU300_ErrorList_K3G;
#endif

/************************************************************/
/*                   CONSTANT PARAMETERS                    */
/************************************************************/

//GSM band
#define RSCMU300_GSM400    0
#define RSCMU300_GSM900    1
#define RSCMU300_GSM1800   2
#define RSCMU300_GSM1900   3
#ifndef _OUTSIDEVEE_
#define RSCMU300_GSM400BS_NSIG       4
#define RSCMU300_GSM400BS_SIG        5
#define RSCMU300_GSM850BS_NSIG       6
#define RSCMU300_GSM850BS_SIG        7
#define RSCMU300_GSM900BS_NSIG       8
#define RSCMU300_GSM900BS_SIG        9
#define RSCMU300_GSM1800BS_NSIG      12
#define RSCMU300_GSM1800BS_SIG       13
#define RSCMU300_GSM1900BS_NSIG      16
#define RSCMU300_GSM1900BS_SIG       17
#endif
//Trainning sequence
//      RSCMU300_OFF       0
#define RSCMU300_GSM0      1
#define RSCMU300_GSM1      2
#define RSCMU300_GSM2      3
#define RSCMU300_GSM3      4
#define RSCMU300_GSM4      5
#define RSCMU300_GSM5      6
#define RSCMU300_GSM6      7
#define RSCMU300_GSM7      8
#define RSCMU300_DUMMY     9
#define RSCMU300_ANY       10

//Bit sequence
//      RSCMU300_OFF       0
#define RSCMU300_PRBS      1
#define RSCMU300_DUMM      2
#define RSCMU300_ALL0      3
#define RSCMU300_EALL0     4
#define RSCMU300_EPRBS     5

//Signal shape
#define RSCMU300_TRAN_BURS 0
#define RSCMU300_TRAN_CONT 1

//Time mode
#define RSCMU300_OFFS      0
#define RSCMU300_GSM       1

//EPSK Reference Power Mode
//      RSCMU300_CURRENT   0
//      RSCMU300_AVERAGE   1
#define RSCMU300_DECOM     2
#define RSCMU300_DCOM      2

//Synchronization mode
#define RSCMU300_NUBCCH    0
#define RSCMU300_NUETRG    1

//Measurement report mode
#define RSCMU300_MREP_MANUAL   0
#define RSCMU300_MREP_RXQ      1
#define RSCMU300_MREP_AUTO     2

//External trigger input polarity
#define RSCMU300_RISING    0
#define RSCMU300_FALLING   1

//Values type
#define RSCMU300_SCALAR    0
#define RSCMU300_ARRAY     1

//Measure points
#define RSCMU300_MPO1      1
#define RSCMU300_MPO2      2
#define RSCMU300_MPO3      3
#define RSCMU300_MPO4      4
#define RSCMU300_MPO5      5
#define RSCMU300_MPO6      6
#define RSCMU300_MPO7      7
#define RSCMU300_MPO8      8
#define RSCMU300_MPO9      9
#define RSCMU300_MPO10     10
#define RSCMU300_MPO11     11

#define RSCMU300_0_10MHZ   1
#define RSCMU300_0_20MHZ   2
#define RSCMU300_0_25MHZ   3
#define RSCMU300_0_40MHZ   4
#define RSCMU300_0_60MHZ   5
#define RSCMU300_0_80MHZ   6
#define RSCMU300_1_00MHZ   7
#define RSCMU300_1_20MHZ   8
#define RSCMU300_1_40MHZ   9
#define RSCMU300_1_60MHZ   10
#define RSCMU300_1_80MHZ   11

//BTS channels
#define RSCMU300_TCH       0
#define RSCMU300_CCH       1
#define RSCMU300_NOCHAN    2

//Signaling controls
#define RSCMU300_SIGCONT_SRUN  0
#define RSCMU300_SIGCONT_SSTP  1
#define RSCMU300_SIGCONT_CCH   2
#define RSCMU300_SIGCONT_TCH   3
#define RSCMU300_SIGCONT_LUP   4
#define RSCMU300_SIGCONT_SLUP  5
#define RSCMU300_SIGCONT_RLUP  6
#define RSCMU300_SIGCONT_MOC   7
#define RSCMU300_SIGCONT_SMOC  8
#define RSCMU300_SIGCONT_RMOC  9
#define RSCMU300_SIGCONT_SCR   10
#define RSCMU300_SIGCONT_CREL  11

//Signaling states
#define RSCMU300_SIGSTATE_UNS  0
#define RSCMU300_SIGSTATE_SIP  1
#define RSCMU300_SIGSTATE_CCH  2
#define RSCMU300_SIGSTATE_TCH  3
#define RSCMU300_SIGSTATE_LUIP 4
#define RSCMU300_SIGSTATE_LUF  5
#define RSCMU300_SIGSTATE_CEST 6
#define RSCMU300_SIGSTATE_CREL 7
#define RSCMU300_SIGSTATE_CRIP 8
#define RSCMU300_SIGSTATE_CRF  9
#define RSCMU300_SIGSTATE_MOCP 10
#define RSCMU300_SIGSTATE_MOCF 11
#define RSCMU300_SIGSTATE_MTCP 12
#define RSCMU300_SIGSTATE_MTCF 13

//Bit stream
#define RSCMU300_LOOP      0
#define RSCMU300_ECHO      1
#define RSCMU300_PR9       2
#define RSCMU300_PR11      3
#define RSCMU300_PR15      4
#define RSCMU300_PR16      5
#define RSCMU300_LBBB      6
#define RSCMU300_HAND      7

//Location area flags
#define RSCMU300_NOTP      0
#define RSCMU300_PERF      1

//Channel type
#define RSCMU300_FRAT      0
#define RSCMU300_EFR       1
#define RSCMU300_E432      2
#define RSCMU300_HRAT      3
#define RSCMU300_FD144     4
#define RSCMU300_FD96      5
#define RSCMU300_FD48      6
#define RSCMU300_HD48      7
#define RSCMU300_HD24      8
#define RSCMU300_EGC1      9
#define RSCMU300_C1TM     10
#define RSCMU300_C2TM     11
#define RSCMU300_C3TM     12
#define RSCMU300_C4TM     13
#define RSCMU300_MC1T     14
#define RSCMU300_MC2T     15
#define RSCMU300_MC3T     16
#define RSCMU300_MC4T     17
#define RSCMU300_MC5T     18
#define RSCMU300_MC6T     19
#define RSCMU300_MC7T     20
#define RSCMU300_MC8T     21
#define RSCMU300_MC9T     22
#define RSCMU300_CS1      10
#define RSCMU300_CS2      11
#define RSCMU300_CS3      12
#define RSCMU300_CS4      13
#define RSCMU300_MCS1     14
#define RSCMU300_MCS2     15
#define RSCMU300_MCS3     16
#define RSCMU300_MCS4     17
#define RSCMU300_MCS5     18
#define RSCMU300_MCS6     19
#define RSCMU300_MCS7     20
#define RSCMU300_MCS8     21
#define RSCMU300_MCS9     22
#define RSCMU300_AMRHR    23
#define RSCMU300_AMRFR    24

//CCH Channel type
#define RSCMU300_SDCCH_4   0
#define RSCMU300_SDCCH_8   1
#define RSCMU300_FACCH_F   2
#define RSCMU300_SACCH     3

//Type of decoding
#define RSCMU300_STAN      0
#define RSCMU300_GUAR      1

//Test setup
#define RSCMU300_T1        1
#define RSCMU300_T2        2
#define RSCMU300_T3        3
#define RSCMU300_T4        4
#define RSCMU300_T5        5
#define RSCMU300_T6        6
#define RSCMU300_T7        7
#define RSCMU300_T8        8
#define RSCMU300_T9        9
#define RSCMU300_T10       10

//BER application
#define RSCMU300_BERAVERAGE    0
#define RSCMU300_BERSINGLE     1

//BER measurements
#define RSCMU300_BER       0
#define RSCMU300_RFER      1
#define RSCMU300_BBB       2
#define RSCMU300_DBLER     3

//Abis Interface Mode
#define RSCMU300_E1DF      0
#define RSCMU300_E1CRC4MF  1
#define RSCMU300_T1SF      2
#define RSCMU300_T1ESF     3
#define RSCMU300_T1CRC6ESF 4

//Abis Traffic Type
#define RSCMU300_TTFR    0
#define RSCMU300_TTEFR   1
#define RSCMU300_TTHR    2
#define RSCMU300_TF14    3
#define RSCMU300_TF96    4
#define RSCMU300_TF48    5

//Abis Time Slot Bit No
#define RSCMU300_BN01    0
#define RSCMU300_BN23    1
#define RSCMU300_BN45    2
#define RSCMU300_BN67    3
#define RSCMU300_BNR1    4
#define RSCMU300_BNR2    5
#define RSCMU300_BNR3    6
#define RSCMU300_BNR4    7
#define RSCMU300_BNR5    8
#define RSCMU300_BNR6    9
#define RSCMU300_BNR7    10

//Abis Start Sub Channel
#define RSCMU300_S168    0
#define RSCMU300_S16K    1
#define RSCMU300_S8K     2

//Abis Alarm indicators
#define RSCMU300_ALARM_NACT    0
#define RSCMU300_ALARM_ACT     1
#define RSCMU300_ALARM_NAPP    2

// Command defines
#define RSCMU300_COMMAND_CONF      0
#define RSCMU300_COMMAND_INIT      1
#define RSCMU300_COMMAND_ABOR      2
#define RSCMU300_COMMAND_STOP      3
#define RSCMU300_COMMAND_CONT      4
#define RSCMU300_COMMAND_READ      5
#define RSCMU300_COMMAND_FETC      6
#define RSCMU300_COMMAND_SAMP      7
#define RSCMU300_COMMAND_CALC      8

/************************************************************/
/*                     LIMITATION VALUES                    */
/************************************************************/

//Frequency Offset
#define RSCMU300_GSM_SIG_FREQNEG     -100000
#define RSCMU300_GSM_SIG_FREQPOS     +100000
#define RSCMU300_GSMNONSIG_FREQNEG       -10
#define RSCMU300_GSMNONSIG_FREQPOS       +10

//number of burst per statistics cycle
#define RSCMU300_NBBURST_MIN         1
#define RSCMU300_NBBURST_MAX         1000

//number of measurements
#define RSCMU300_MULTMEAS_MIN        1
#define RSCMU300_MULTMEAS_MAX        10000

//Error Limits
#define RSCMU300_PHASE_ERROR_LIMMAX  50
#define RSCMU300_FREQU_ERROR_LIMMAX  999
#define RSCMU300_PHASE_ERROR_LIMMIN  -50
#define RSCMU300_FREQU_ERROR_LIMMIN  -999

//TCH Max Level limits (dBm)
#define RSCMU300_TCH_LEVMAX_MIN      -137
#define RSCMU300_TCH_LEVMAX_MAX      -10

//Timeslot Number for the BTS
#define RSCMU300_BTS_TIMESLOT_MIN    0
#define RSCMU300_BTS_TIMESLOT_MAX    7

//Transmit timing delay (1/4 Bit)
#define RSCMU300_TX_DELAY_MIN        -64
#define RSCMU300_TX_DELAY_MAX        +64

//MS auto hook off alerting time (sec)
#define RSCMU300_ALERT_TIME_MIN      0
#define RSCMU300_ALERT_TIME_MAX      100

//PIN of the SIM card
#define RSCMU300_PIN_MIN             0
#define RSCMU300_PIN_MAX             9999

//Nb of Frames (BER)
#define RSCMU300_NBFRAMES_MIN        1
#define RSCMU300_NBFRAMESAVER_MAX    500
#define RSCMU300_NBFRAMESSENT_MAX    50000

//Offset added to the measured RX Level (dB)
#define RSCMU300_RXLEV_OFFSET_MIN    -200
#define RSCMU300_RXLEV_OFFSET_MAX    +100

//External trigger: delay time for TCH signal (Slot)
#define RSCMU300_SLOTOFFSET_MIN      0
#define RSCMU300_SLOTOFFSET_MAX      256

//External trigger: delay time for TCH signal (1/4 Bit)
#define RSCMU300_BITDELAY_MIN        0
#define RSCMU300_BITDELAY_MAX        624

//Power time bit offset
#define RSCMU300_TIMEBIT_MIN         -4
#define RSCMU300_TIMEBIT_MAX         +4

//AGC Holdoff time (sec)
#define RSCMU300_AGC_TIME_MIN        0
#define RSCMU300_AGC_TIME_MAX        100

//Bit stream synchronization
#define RSCMU300_SYNCH_TIME_MIN      0
#define RSCMU300_SYNCH_TIME_MAX      100

//Min/Max MSS Level in used timeslots (dBm)
#define RSCMU300_UTS_LEVEL_MIN       -200
#define RSCMU300_UTS_LEVEL_MAX       +100

//Power subarray range configuration
#define RSCMU300_SUBPOW_BIT_MIN      -10
#define RSCMU300_SUBPOW_BIT_MAX      +156.75
#define RSCMU300_SUBPOW_SAMPLES_MIN   0
#define RSCMU300_SUBPOW_SAMPLES_MAX   668

//Modulation subarray range configuration
#define RSCMU300_SUBMOD_BIT_MIN           -10
#define RSCMU300_SUBMOD_BIT_MAX          +146.75
#define RSCMU300_SUBMOD_SYMB_MIN            3
#define RSCMU300_SUBMOD_SYMB_MAX          144
#define RSCMU300_SUBMOD_SAMPLES_MIN         0
#define RSCMU300_SUBMOD_SAMPLES_MAX       588
#define RSCMU300_SUBMOD_EPSK_SAMPLES_MIN    0
#define RSCMU300_SUBMOD_EPSK_SAMPLES_MAX  142

//Spectrum modulation subarray range configuration
#define RSCMU300_SUBSPECMOD_FREQ_MIN   -1.80
#define RSCMU300_SUBSPECMOD_FREQ_MAX   +1.80
#define RSCMU300_SUBSPECMOD_NUMBER_MIN  1
#define RSCMU300_SUBSPECMOD_NUMBER_MAX  23

//Spectrum switching subarray range configuration
#define RSCMU300_SUBSPECSWITCH_FREQ_MIN    -1.80
#define RSCMU300_SUBSPECSWITCH_FREQ_MAX    +1.80
#define RSCMU300_SUBSPECSWITCH_NUMBER_MIN   1
#define RSCMU300_SUBSPECSWITCH_NUMBER_MAX   9

//Absolute level on used Timeslot (dBm)
#define RSCMU300_ABSLEVEL_MIN        -137
#define RSCMU300_ABSLEVEL_MAX        +13

//Relative level on unused Timeslot (dB)
#define RSCMU300_GSM_SIG_UNUSEDSLOTMIN       -47.0
#define RSCMU300_GSM_SIG_UNUSEDSLOTMAX      +130.0
#define RSCMU300_GSMBSNONSIG_UNUSEDSLOTMIN  -110.0
#define RSCMU300_GSMBSNONSIG_UNUSEDSLOTMAX   +40.0

//Reference Power for min and max power level (dBm)
#define RSCMU300_GSM_REFMINPOW_LIMMIN     -99.0
#define RSCMU300_GSM_REFMINPOW_LIMMAX      38.0
#define RSCMU300_GSM_REFMAXPOW_LIMMIN      34.0
#define RSCMU300_GSM_REFMAXPOW_LIMMAX      99.9

//Max. number of digits for a dialled number
#define RSCMU300_DNUM_MAX            20

//International Mobile Station Equipment Identity (IMEI)
//      Type Approval Code (TAC)
#define RSCMU300_IMEI_TAC_MIN           "000000"
#define RSCMU300_IMEI_TAC_MAX           "999999"
//      Final Assembly Code (FAC)
#define RSCMU300_IMEI_FAC_MIN           "00"
#define RSCMU300_IMEI_FAC_MAX           "99"
//      Serial Number (SNR)
#define RSCMU300_IMEI_SNR_MIN           "000000"
#define RSCMU300_IMEI_SNR_MAX           "999999"
//      Software Version Number (SVN)
#define RSCMU300_IMEI_SVN_MIN           "0"
#define RSCMU300_IMEI_SVN_MAX           "9"

//International Mobile Subscriber Identity (IMSI)
//      Mobile Network Code (MNC)
#define RSCMU300_IMSI_MNC_MIN           "000"
#define RSCMU300_IMSI_MNC_MAX           "999"
//      Mobile Country Code (MCC)
#define RSCMU300_IMSI_MCC_MIN           "00"
#define RSCMU300_IMSI_MCC_MAX           "99"
#define RSCMU300_IMSI_MCC_GSM1900_MIN   "00"
#define RSCMU300_IMSI_MCC_GSM1900_MAX   "999"
//      Mobile Subscriber Identity Number (MSIN)
#define RSCMU300_IMSI_MSIN_MIN          "0000000000"
#define RSCMU300_IMSI_MSIN_MAX          "9999999999"
#define RSCMU300_IMSI_MSIN_GSM1900_MIN  "000000000"
#define RSCMU300_IMSI_MSIN_GSM1900_MAX  "999999999"

// Modulation view
#define RSCMU300_MODVIEW_GMSK      0
#define RSCMU300_MODVIEW_EPSK      1
#define RSCMU300_MODVIEW_ANY       2
#define RSCMU300_MODVIEW_OFF       3

// Power filter
#define RSCMU300_FILTER_G500   0
#define RSCMU300_FILTER_B600   1


#define RSCMU300_MEAS       0
#define RSCMU300_MEAS_N1    1
#define RSCMU300_MEAS_P1    2
#define RSCMU300_MEAS_P2    3

//Spectrum/Switch Slot Count
#define RSCMU300_SINGLESLOT          0
#define RSCMU300_MULTISLOT           1

//Trigger
#define RSCMU300_TRIG_NONE           0
#define RSCMU300_TRIG_FRAMECLOCK     1


#define RSCMU300_LOWER     0
#define RSCMU300_UPPER     1

//Averaging Areas
#define RSCMU300_AVG_AREAS_A    0
#define RSCMU300_AVG_AREAS_B    1
#define RSCMU300_AVG_AREAS_AB   2

//Spectrum/Switch continuous statistical mode
#define RSCMU300_PEAK_HOLD           0
#define RSCMU300_STAT_COUNT          1

// Modulation view
#define RSCMU_MODVIEW_GMSK      0
#define RSCMU_MODVIEW_EPSK      1
#define RSCMU_MODVIEW_ANY       2

#define RSCMU300_N180  1
#define RSCMU300_N160  2
#define RSCMU300_N140  3
#define RSCMU300_N120  4
#define RSCMU300_N100  5
#define RSCMU300_N080  6
#define RSCMU300_N060  7
#define RSCMU300_N040  8
#define RSCMU300_N025  9
#define RSCMU300_N020 10
#define RSCMU300_N010 11
#define RSCMU300_REF  12
#define RSCMU300_P010 13
#define RSCMU300_P020 14
#define RSCMU300_P025 15
#define RSCMU300_P040 16
#define RSCMU300_P060 17
#define RSCMU300_P080 18
#define RSCMU300_P100 19
#define RSCMU300_P120 20
#define RSCMU300_P140 21
#define RSCMU300_P160 22
#define RSCMU300_P180 23
#define RSCMU300_NV4  24
#define RSCMU300_NV3  25
#define RSCMU300_NV2  26
#define RSCMU300_NV1  27
#define RSCMU300_PV1  28
#define RSCMU300_PV2  29
#define RSCMU300_PV3  30
#define RSCMU300_PV4  31

// Control Ack Type
#define RSCMU300_NORMAL_BURST  0
#define RSCMU300_ACCESS_BURST  1


// Punctering Scheme
#define RSCMU_P1       0
#define RSCMU_P2       1
#define RSCMU_P3       2


//AMR Codec Mode
#define RSCMU_AMR_CODMODE_4_75    1
#define RSCMU_AMR_CODMODE_5_15    2
#define RSCMU_AMR_CODMODE_5_9     3
#define RSCMU_AMR_CODMODE_6_7     4
#define RSCMU_AMR_CODMODE_7_4     5
#define RSCMU_AMR_CODMODE_7_95    6
#define RSCMU_AMR_CODMODE_10_2    7
#define RSCMU_AMR_CODMODE_12_2    8


#define RSCMU_MOD_PERR       0
#define RSCMU_MOD_EVM        1
#define RSCMU_MOD_MERR       2

// IQ Analyzer
#define RSCMU_ISIREMOVED    0
#define RSCMU_UNFILTERED    1

#define RSCMU_P38           0
#define RSCMU_P38REMOVED    1


/*****************************************************************************/
/*****************************************************************************/
/*======== Common Functions =================================================*/
/*****************************************************************************/
/*****************************************************************************/
//            GSMBS Non Signalling
ViStatus _VI_FUNC RSCMU300_Init_GSM_NSig (ViSession, ViPSession, ViUInt32, ViChar[]);
//               Group Configuration
//                  Input Level
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SensLevMode (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SensLevMax  (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SensLevAtt  (ViSession, ViInt32, ViChar[]);
//                  Trigger
ViStatus _VI_FUNC RSCMU300_GSM_NSig_TrigSour (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_TrigThrRFPow (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_TrigThrIFPow (ViSession,ViReal64,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_TrigSlop (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_TrigSourExt (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_TrigThr  (ViSession, ViInt32, ViChar[]);
//               Connection Control
//                  Analyser Settings
ViStatus _VI_FUNC RSCMU300_GSM_NSig_RfanChan       (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_RfanFreq       (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_RfanFreqOffset (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_RfanTseq       (ViSession, ViInt32, ViChar[]);
//                  Generator Object  RF-Generator
//                     Configuration
//                        RF Level
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SourRfgLevUtim (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SourRfgLevUnt  (ViSession, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_SourRfgFreqChan   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SourRfgFreq       (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SourRfgFreqOffset (ViSession, ViReal64, ViChar[]);
//                        Generator Modulation
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfRfgModBitSel  (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfRfgModTseqSel (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfRfgModTran    (ViSession, ViInt32, ViChar[]);
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitRfg (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborRfg (ViSession, ViChar[]);
//                        Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcRfgSt (ViSession, ViPInt32, ViChar[]);
//                  Input and Output Connectors
ViStatus _VI_FUNC RSCMU300_GSM_NSig_Inp              (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_Outp             (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SensCorrLossInp  (ViSession, ViInt32, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SourCorrLossOutp (ViSession, ViInt32, ViReal64, ViChar[]);
//                  Synchronization
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SourDmClock (ViSession, ViBoolean, ViReal64, ViChar[]);
//                  Wide Band Power
//                     Configuration
//                        Control
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfWpowContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                        Statistics
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfWpowContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitWpow (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborWpow (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopWpow (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContWpow (ViSession, ViChar[]);
//                        Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcWpowSt (ViSession, ViPInt32, ViPInt32, ViChar[]);
//                        Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfWpowErep (ViSession, ViInt32, ViChar[]);
//                     Results
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadWpow (ViSession, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcWpow (ViSession, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampWpow (ViSession, ViPReal64, ViChar[]);

//               Test Object Spectrum Common
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpComNoiseCorr (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpecLimLineSel (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_Close_GSM_NSig (ViSession, ViChar[]);
//            GSMBS Signalling
ViStatus _VI_FUNC RSCMU300_Init_GSM_Sig (ViSession, ViPSession, ViUInt32, ViChar[]);
//               Group Configuration
//                  Input Level
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensLevMode (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensLevMax  (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensLevAtt  (ViSession, ViInt32, ViChar[]);
//                  Trigger
ViStatus _VI_FUNC RSCMU300_GSM_Sig_TrigSour (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_TrigThrRFPow (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_TrigThrIFPow (ViSession,ViReal64,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_TrigSlop (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ExtTrigOutSignal (ViSession,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ExtTrigOutDelayEnable (ViSession,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ExtTrigOutDelayValue (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_TrigThr  (ViSession, ViInt32, ViChar[]);
//               Connection Control
//                  Call Setup and Cleardown
//                     Signalling State
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ProcSignAct  (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensSignStat (ViSession, ViPInt32, ViChar[]);
//                     Configuration
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSignSynchMode   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSignCchChan     (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSignTchChan     (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensSignTchChan     (ViSession, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSignTchTimeSlot (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensSignTchTimeSlot (ViSession, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSignTchType     (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBssTseq (ViSession,ViInt32,ViChar[]);
//                  Test Object INFO
//                     Frame Timing
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InfoFrameMult (ViSession, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InfoFrameSup  (ViSession, ViPInt32, ViChar[]);
//                     Network Data
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InfoNetwMcc     (ViSession, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InfoNetwMnc     (ViSession, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InfoNetwLocArea (ViSession, ViPUInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InfoNetwBsic    (ViSession, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InfoNetwLocUpd  (ViSession, ViPInt32, ViChar[]);
//                     SACCH Info
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InfoSacchReqPow (ViSession, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InfoSacchReqTim (ViSession, ViPInt32, ViChar[]);
//                  MS Signal Configuration
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssBitStr  (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBssPScheme (ViSession instrumentHandle_GSMSig,
                                                   ViInt32 MCS1, ViInt32 MCS2,
                                                   ViInt32 MCS3, ViInt32 MCS4,
                                                   ViInt32 MCS5, ViInt32 MCS6,
                                                   ViInt32 MCS71st,
                                                   ViInt32 MCS72nd,
                                                   ViInt32 MCS81st,
                                                   ViInt32 MCS82nd,
                                                   ViInt32 MCS91st,
                                                   ViInt32 MCS92nd,
                                                   ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssTxTim   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssSDRearrange (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssLevUtim (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssLevUnt  (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssDuplSpaceEnable (ViSession,ViBoolean,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssDlChan (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssForcHoppEnable (ViSession,ViBoolean,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssForcHoppMaio (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssForcHoppSeq (ViSession,ViChar[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssUlCchBerEnable (ViSession,ViBoolean,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssUlCchBerChType (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMssUlCchBerBitStr (ViSession,ViInt32,ViChar[]);

//                  Network
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwDef (ViSession, ViBoolean, ViChar[]);
//                     Mobile Settings
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwMsAutoHookOff (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwMsAutoTimingAdj (ViSession, ViInt32, ViChar[]);
//                     Subscriber ID
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwSubsScpin (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwSubsImei  (ViSession, ViChar[], ViChar[], ViChar[], ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwSubsImsi  (ViSession, ViChar[], ViChar[], ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwSubsDnum  (ViSession, ViChar[], ViChar[]);
//                     Measurement Report
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwMrepMode      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwMrepManRxlev  (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwMrepManRxQ    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwMrepAutRxLev  (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwMrepAutOffset (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfNetwMrepAutRxLQ   (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
//                  Input and Output Connectors
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Inp              (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Outp             (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SourCorrLossOutp (ViSession, ViInt32, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensCorrLossInp  (ViSession, ViInt32, ViReal64, ViChar[]);
//                  Synchronization
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SourDmClock (ViSession, ViBoolean, ViReal64, ViChar[]);
//                  External Trigger Input
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SourExtTrigPol        (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SourExtTrigSlotOffset (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SourExtTrigBitDelay   (ViSession, ViInt32, ViChar[]);
//                  Wide Band Power
//                     Configuration
//                        Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfWpowContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                        Statistics
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfWpowContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitWpow (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborWpow (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopWpow (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContWpow (ViSession, ViChar[]);
//                        Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcWpowSt (ViSession, ViPInt32, ViPInt32, ViChar[]);
//                        Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfWpowErep (ViSession, ViInt32, ViChar[]);
//                     Results
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadWpow (ViSession, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcWpow (ViSession, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampWpow (ViSession, ViPReal64, ViChar[]);


//                  P/t Multislot measurement
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitPowMsl (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborPowMsl (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopPowMsl (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContPowMsl (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPowMslStat (ViSession,ViInt32,ViInt32 *,ViInt32 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowMslErep (ViSession,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowMslCont (ViSession,ViInt32,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowMslContRep (ViSession,ViInt32,ViInt32,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowMslContRepStat (ViSession,ViInt32,ViInt32,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowMslMvi (ViSession,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowMslSco (ViSession,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowMslToff (ViSession,ViInt32,ViReal64,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowMslMeasSlot (ViSession,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowMslFilt (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowMslFilter (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowMslLimGlev (ViSession,ViInt32,ViReal64,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubPowMslRang (ViSession,ViInt32,ViInt32,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadPowMsl (ViSession,ViInt32,ViInt32,ViReal64[],ViReal64 *,ViReal64 *,ViReal64 *,ViReal64 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPowMsl (ViSession,ViInt32,ViInt32,ViReal64 *,ViReal64 *,ViReal64 *,ViReal64 *,ViReal64 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampPowMsl (ViSession,ViInt32,ViInt32,ViReal64 *,ViReal64 *,ViReal64 *,ViReal64 *,ViReal64 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcPowMslLimMatc (ViSession,ViInt32,ViInt32,ViInt32 *,ViInt32 *,ViInt32 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrPowMsl (ViSession,ViInt32,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrPowMsl (ViSession,ViInt32,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrPowMsl (ViSession,ViInt32,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcArrPowMslLimMatc (ViSession,ViInt32,ViInt32,ViInt32 *,ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensPowMslAreaLimTime (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensPowMslAreaLimLevel (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensPowMslAreaLimInfo (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensPowMslAreaLimSTime (ViSession, ViInt32, ViReal64 *, ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubArrPowMsl (ViSession,ViInt32,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubArrPowMsl (ViSession,ViInt32,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubArrPowMsl (ViSession,ViInt32,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcPowMslAreaLimMatc (ViSession,ViInt32,ViInt32,ViInt32 *,ViInt32 *,ViChar[]);




//               Test Object Spectrum Common
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpComNoiseCorr (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpecLimLineSel (ViSession, ViInt32, ViChar[]);

//               Test Object RXQuality Common
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfRxqContBitStr (ViSession,ViInt32,ViChar[]);
//               Test Object RXQuality: RF (CMU)
//                  Common Controls
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfRxqContHtim (ViSession, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfRxqContDef  (ViSession, ViBoolean, ViChar[]);
//                  BER measurement
//                     Configuration
//                        Test Setup
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBerTset (ViSession, ViInt32, ViChar[]);
//                        Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBerCont        (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBerContRep     (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBerContLevUtim (ViSession, ViInt32, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBerContLevUnt  (ViSession, ViInt32, ViReal64, ViChar[]);
//                        Limits
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBerLimDef  (ViSession, ViInt32, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBerLimCLII (ViSession, ViInt32, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBerLimCLIB (ViSession, ViInt32, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBerLimFERR (ViSession, ViInt32, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBerLimDBLER (ViSession,ViInt32,ViReal64,ViChar[]);

//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitBer (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborBer (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopBer (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContBer (ViSession, ViChar[]);
//                        Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcBerSt (ViSession, ViPInt32, ViPInt32, ViChar[]);
//                        Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBerErep (ViSession, ViInt32, ViChar[]);
//                     Results
//                        RFER
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_ReadBer        (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_FetcBer        (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_SampBer        (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_CalcBerLimMatc (ViSession, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                        BER
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_ReadBer         (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_FetcBer         (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_SampBer         (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_CalcBerLimMatc  (ViSession, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                        BBB
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Bbb_ReadBer         (ViSession, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Bbb_FetcBer         (ViSession, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Bbb_SampBer         (ViSession, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Bbb_CalcBerLimMatc  (ViSession, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                        BER circuit-switched data
ViStatus _VI_FUNC RSCMU300_GSM_Sig_BerCsd_ReadBer      (ViSession, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_BerCsd_FetcBer      (ViSession, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_BerCsd_SampBer      (ViSession, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
//                        RFER packet-switched data
ViStatus _VI_FUNC RSCMU300_GSM_Sig_RferPsd_ReadBer     (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_RferPsd_FetcBer     (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_RferPsd_SampBer     (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
//                        BER packet-switched data
ViStatus _VI_FUNC RSCMU300_GSM_Sig_BerPsd_ReadBer      (ViSession, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_BerPsd_FetcBer      (ViSession, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_BerPsd_SampBer      (ViSession, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
//                  BER Average measurement
//                     Configuration
//                        Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBavCont        (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBavContRep     (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBavContLevUtim (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBavContLevUnt  (ViSession, ViReal64, ViChar[]);
//                        Limits
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBavLimDef  (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBavLimCLII (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBavLimCLIB (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBavLimFERR (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBavLimDBLER (ViSession,ViReal64,ViChar[]);

//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitBav (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborBav (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopBav (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContBav (ViSession, ViChar[]);
//                        Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcBavSt (ViSession, ViPInt32, ViPInt32, ViChar[]);
//                        Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfBavErep (ViSession, ViInt32, ViChar[]);
//                     Results
//                        RFER
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_ReadBav        (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_FetcBav        (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_SampBav        (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_CalcBavLimMatc (ViSession, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                        BER
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_ReadBav         (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_FetcBav         (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_SampBav         (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_CalcBavLimMatc  (ViSession, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                        BBB
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Bbb_ReadBav         (ViSession, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Bbb_FetcBav         (ViSession, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Bbb_SampBav         (ViSession, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Bbb_CalcBavLimMatc  (ViSession, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                        BER circuit-switched data
ViStatus _VI_FUNC RSCMU300_GSM_Sig_BerCsd_ReadBav      (ViSession, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_BerCsd_FetcBav      (ViSession, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_BerCsd_SampBav      (ViSession, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
//                        RFER packet-switched data
ViStatus _VI_FUNC RSCMU300_GSM_Sig_RferPsd_ReadBav     (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_RferPsd_FetcBav     (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_RferPsd_SampBav     (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
//                        BER packet-switched data
ViStatus _VI_FUNC RSCMU300_GSM_Sig_BerPsd_ReadBav      (ViSession, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_BerPsd_FetcBav      (ViSession, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_BerPsd_SampBav      (ViSession, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
//               Test Object RXQuality: Abis
//                  Configuration
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisIMode       (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisTType       (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisPCMTimeSlot (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisTSBitNo     (ViSession, ViInt32, ViChar[]);
//             Start Values
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisStarPCMTimeSlot (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisStarSubChan     (ViSession, ViInt32, ViChar[]);
//          Scan
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitAbisScan   (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborAbisScan   (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcAbisScanSt (ViSession, ViInt32 *, ViChar[]);
//          Alarm
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitAbisAlarm   (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborAbisAlarm   (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcAbisAlarmSt (ViSession, ViInt32 *, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensAbisAlarm   (ViSession, ViInt32 *, ViInt32 *, ViInt32 *, ViInt32 *, ViChar[]);
//          BER
//             Configuration
//                Test Setup
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBerTset (ViSession, ViInt32, ViChar[]);
//              Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBerContDef     (ViSession, ViInt32, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBerCont        (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBerContRep     (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBerContLevUtim (ViSession, ViInt32, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBerContLevUnt  (ViSession, ViInt32, ViReal64, ViChar[]);
//                Limits
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBerLimDef  (ViSession, ViInt32, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBerLimCLII (ViSession, ViInt32, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBerLimCLIB (ViSession, ViInt32, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBerLimFERR (ViSession, ViInt32, ViReal64, ViChar[]);
//             Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitAbisBer (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborAbisBer (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopAbisBer (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContAbisBer (ViSession, ViChar[]);
//                Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcAbisBerSt   (ViSession, ViInt32 *, ViInt32 *, ViChar[]);
//                Event Reporting Status
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBerErep (ViSession, ViInt32, ViChar[]);
//             Results
//                RFER
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_ReadAbisBer        (ViSession, ViReal64 *, ViReal64 *, ViReal64 *, ViReal64 *, ViInt32 *, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_FetcAbisBer        (ViSession, ViReal64 *, ViReal64 *, ViReal64 *, ViReal64 *, ViInt32 *, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_SampAbisBer        (ViSession, ViReal64 *, ViReal64 *, ViReal64 *, ViReal64 *, ViInt32 *, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_CalcAbisBerLimMatc (ViSession, ViInt32 *, ViInt32 *, ViInt32 *, ViInt32 *, ViChar[]);
//                BER
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_ReadAbisBer        (ViSession, ViReal64 *, ViReal64 *, ViReal64 *, ViInt32 *, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_FetcAbisBer        (ViSession, ViReal64 *, ViReal64 *, ViReal64 *, ViInt32 *, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_SampAbisBer        (ViSession, ViReal64 *, ViReal64 *, ViReal64 *, ViInt32 *, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_CalcAbisBerLimMatc (ViSession, ViInt32 *, ViInt32 *, ViInt32 *, ViChar[]);
//          BAV
//             Configuration
//                Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBavContDef     (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBavCont        (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBavContRep     (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBavContLevUtim (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBavContLevUnt  (ViSession, ViReal64, ViChar[]);
//                Limits
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBavLimDef  (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBavLimCLII (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBavLimCLIB (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBavLimFERR (ViSession, ViReal64, ViChar[]);
//             Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitAbisBav (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborAbisBav (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopAbisBav (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContAbisBav (ViSession, ViChar[]);
//                Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcAbisBavSt (ViSession, ViInt32 *, ViInt32 *, ViChar[]);
//                Event Reporting Status
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfAbisBavErep (ViSession, ViInt32, ViChar[]);
//             Results
//                RFER
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_ReadAbisBav        (ViSession, ViReal64 *, ViReal64 *, ViReal64 *, ViReal64 *, ViInt32 *, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_FetcAbisBav        (ViSession, ViReal64 *, ViReal64 *, ViReal64 *, ViReal64 *, ViInt32 *, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_SampAbisBav        (ViSession, ViReal64 *, ViReal64 *, ViReal64 *, ViReal64 *, ViInt32 *, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_CalcAbisBavLimMatc (ViSession, ViInt32 *, ViInt32 *, ViInt32 *, ViInt32 *, ViChar[]);
//                BER
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_ReadAbisBav        (ViSession, ViReal64 *, ViReal64 *, ViReal64 *, ViInt32 *, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_FetcAbisBav        (ViSession, ViReal64 *, ViReal64 *, ViReal64 *, ViInt32 *, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_SampAbisBav        (ViSession, ViReal64 *, ViReal64 *, ViReal64 *, ViInt32 *, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Ber_CalcAbisBavLimMatc (ViSession, ViInt32 *, ViInt32 *, ViInt32 *, ViChar[]);

//          RACH
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfRachBurstsSent (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfRachRepTime (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfRachCCHLevUtim (ViSession,ViReal64,ViChar []);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfRachCCHLevUnt (ViSession,ViReal64,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfRachLimFERR (ViSession,ViReal64,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitRach (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborRach (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopRach (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContRach (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcRachStat (ViSession,ViInt32 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfRachErep (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_ReadRach (ViSession,ViReal64 *,ViReal64 *,ViReal64 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_FetcRach (ViSession,ViReal64 *,ViReal64 *,ViReal64 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_SampRach (ViSession,ViReal64 *,ViReal64 *,ViReal64 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_Rfer_CalcRachLimMatc (ViSession,ViInt32 *,ViChar[]);


//               Application functions
//                  Communicate with BTS
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SyncToBts (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_Close_GSM_Sig (ViSession, ViChar[]);

//          I/Q-IF
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_ConfIQIFRXTX    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_ConfIQIFRXPath  (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_ConfIQIFTXPath  (ViSession, ViInt32, ViChar[]);

//          AMR
ViStatus _VI_FUNC RSCMU300_GSM_Sig_NetwAmrHrCModeDL (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_NetwAmrHrCModeUL (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_NetwAmrHrRSet (ViSession,ViInt32,ViInt32,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_NetwAmrFrCModeDL (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_NetwAmrFrCModeUL (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_NetwAmrFrRSet (ViSession,ViInt32,ViInt32,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensMssAmrHrDl (ViSession,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensMssAmrHrUl (ViSession,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensMssAmrFrDl (ViSession,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensMssAmrFrUl (ViSession,ViInt32 *,ViChar[]);

//            Utility functions
//               Instrument Software Version
ViStatus _VI_FUNC RSCMU300_K3G_RevisionQuery (ViSession, ViChar[], ViChar[], ViChar[]);
//               General Instrument Information
ViStatus _VI_FUNC RSCMU300_K3G_errorMessage (ViSession, ViStatus, ViChar[]);

//               FW MMI Version
ViStatus _VI_FUNC RSCMU300_K3G_GetMMIFwVers (ViSession,ViChar[],ViChar[]);

//            GSMBS Signalling & Non Signalling

//               Test Object Power Narrow Band
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_InitNpow (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_AborNpow (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_StopNpow (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_ContNpow (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_FetcNpowStat (ViSession, ViInt32 *, ViInt32 *, ViInt32 *, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_ConfNpowErep (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_ConfNpowCont (ViSession,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_ConfNpowContRep (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_ConfNpowContStat (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_ReadNpow (ViSession, ViReal64 *, ViReal64 *, ViReal64 *, ViReal64 *, ViReal64 *, ViReal64 *, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_FetcNpow (ViSession, ViReal64 *, ViReal64 *, ViReal64 *, ViReal64 *, ViReal64 *, ViReal64 *, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_SigNSig_SampNpow (ViSession, ViReal64 *, ViReal64 *, ViReal64 *, ViReal64 *, ViReal64 *, ViReal64 *, ViChar[]);







/*****************************************************************************/
/*****************************************************************************/
/*======== GMSK Functions ===================================================*/
/*****************************************************************************/
/*****************************************************************************/
//            GSMBS Non Signalling
//               Test Object Power
//                  Configuration
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmContDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmScope   (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowgGmFilter (ViSession,ViInt32,ViChar[]);

//                     Limit Lines
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmLimDef     (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmLimLowMode (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmLimUppMode (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmLimLow     (ViSession, ViInt32, ViBoolean, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean,
                                                                                ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmLimUpp     (ViSession, ViInt32, ViBoolean, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean,
                                                                                ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViChar[]);
//                     Time
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmTimeBit (ViSession, ViReal64, ViChar[]);
//                     Statistics
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmCont      (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmStat      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmResMode   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Measurement
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSubPowGmRang (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);
//                  Control
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitPowGm (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborPowGm (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopPowGm (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContPowGm (ViSession, ViChar[]);
//                     Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcPowGmSt (ViSession, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowGmErep (ViSession, ViInt32, ViChar[]);
//                  Results
//                     Scalar
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadPowGm        (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcPowGm        (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampPowGm        (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcPowGmMatcLim (ViSession, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Array
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrPowGm         (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrPowGm         (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrPowGm         (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcArrPowGmMatcLim  (ViSession, ViInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcArrPowGmAreaMatc (ViSession, ViInt32, ViPUInt32, ViPUInt32, ViChar[]);
//                     SubArray
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSubPowGm (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSubPowGm (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSubPowGm (ViSession, ViInt32, ViReal64[], ViChar[]);
//               Test Object Modulation Perror
//                  Configuration
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrGmContDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrGmScope   (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrGmContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Limits
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrGmLim (ViSession, ViInt32, ViReal64, ViReal64, ViReal64, ViChar[]);
//                     Time
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrGmTimeDec (ViSession, ViInt32, ViChar[]);
//                     Statistics
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrGmCont      (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrGmStat      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrGmResMode   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrGmContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Measurement
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSubPerrGmRang (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);
//                  Control
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitPerrGm (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborPerrGm (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopPerrGm (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContPerrGm (ViSession, ViChar[]);
//                     Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcPerrGmSt (ViSession, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrGmErep (ViSession, ViInt32, ViChar[]);
//                  Results
//                     Scalar
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadPerrGm        (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcPerrGm        (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampPerrGm        (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcPerrGmMatcLim (ViSession, ViInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Array
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrPerrGm (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrPerrGm (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrPerrGm (ViSession, ViInt32, ViReal64[], ViChar[]);
//                     SubArray
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSubPerrGm (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSubPerrGm (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSubPerrGm (ViSession, ViInt32, ViReal64[], ViChar[]);
//               Test Object Spectrum Modulation
//                  Configuration
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmContDef (ViSession, ViBoolean, ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_SpecModAvgAreas (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpecModFSelFTimeD (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmScope   (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Limit Lines
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmLimDef  (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmLimRefp (ViSession, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmLimMode (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmLim     (ViSession, ViInt32, ViBoolean, ViReal64, ViReal64, ViReal64, ViChar[]);
//                     Statistics
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmCont      (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmStat      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmResMode   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     MeasX
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmContMpo (ViSession, ViInt32, ViBoolean, ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpecModVarMpo (ViSession,ViInt32,ViInt32,ViReal64,ViChar[]);

//                     Measurement
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSubSpModGmRang (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSubSpecModTime  (ViSession,ViInt32,ViReal64,ViInt32,ViChar[]);

//                  Control
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitSpModGm (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborSpModGm (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopSpModGm (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContSpModGm (ViSession, ViChar[]);
//                     Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSpModGmSt (ViSession, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModGmErep (ViSession, ViInt32, ViChar[]);
//                  Results
//                     Scalar
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSpModGm (ViSession, ViPReal64, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSpModGm (ViSession, ViPReal64, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSpModGm (ViSession, ViPReal64, ViPInt32, ViChar[]);
//                     Array
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrSpModGm (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrSpModGm (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrSpModGm (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrVarSpecMod (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrVarSpecMod (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrVarSpecMod (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrSpecModTime (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrSpecModTime (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrSpecModTime (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcSpecModAreaLimMatc (ViSession,ViInt32 *,ViChar[]);

//                     SubArray
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSubSpModGm (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSubSpModGm (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSubSpModGm (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSubArrSpecModTime (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSubArrSpecModTime (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSubArrSpecModTime (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_SensSpecModLimLineUsed (ViSession,ViInt32 *,ViChar[]);

//               Test Object Spectrum Switching
//                  Configuration
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmContDef (ViSession, ViBoolean, ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpecSwitFSelFTimeD (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_SpecSwitContStatMod (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_SpecSwitNoOfSlot (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmScope   (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmSlotCount (ViSession,ViInt32,ViChar[]);

//                     Limit Lines
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmLimDef  (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmLimMode (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmLim (ViSession instrumentHandle,
                                                   ViInt32 measurePoint,
                                                   ViBoolean enable,
                                                   ViReal64 minimumRelativeLimit_dBc,
                                                   ViReal64 maximumRelativeLimit_dBc,
                                                   ViReal64 absoluteLimit_dBm,
                                                   ViChar errorMessage[]);
//                     Statistics
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmCont      (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmStat      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmResMode   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     MeasX
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmContMpo (ViSession, ViInt32, ViBoolean, ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpecSwVarMpo (ViSession,ViInt32,ViInt32,ViReal64,ViChar[]);

//                     Measurement
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSubSpSwGmRang (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSubSpecSwitTime (ViSession,ViInt32,ViReal64,ViInt32,ViChar[]);

//                  Control
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitSpSwGm (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborSpSwGm (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopSpSwGm (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContSpSwGm (ViSession, ViChar[]);
//                     Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSpSwGmSt (ViSession, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwGmErep (ViSession, ViInt32, ViChar[]);
//                  Results
//                     Scalar
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSpSwGm (ViSession, ViPReal64, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSpSwGm (ViSession, ViPReal64, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSpSwGm (ViSession, ViPReal64, ViPInt32, ViChar[]);
//                     Array
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrSpSwGm (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrSpSwGm (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrSpSwGm (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrVarSpecSwit (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrVarSpecSwit (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrVarSpecSwit (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrSpecSwitTime (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrSpecSwitTime (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrSpecSwitTime (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcSpecSwiAreaLimMatc (ViSession,ViInt32 *,ViChar[]);

//                     SubArray
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSubSpSwGm (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSubSpSwGm (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSubSpSwGm (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSubArrSpecSwitTime (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSubArrSpecSwitTime (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSubArrSpecSwitTime (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_SensSpecSwiLimLineUsed (ViSession,ViInt32 *,ViChar[]);

//               Test Object Spectrum Modulation/Switching
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpecMSwContRep (ViSession,ViInt32,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitSpecMSw        (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborSpecMSw        (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopSpecMSw        (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContSpecMSw        (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSpecMSwStat    (ViSession,ViInt32 *,ViInt32 *,ViInt32 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpecMSwErep    (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSpecMSw (ViSession,ViReal64 *,ViInt32 *,ViReal64 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSpecMSw (ViSession,ViReal64 *,ViInt32 *,ViReal64 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSpecMSw (ViSession,ViReal64 *,ViInt32 *,ViReal64 *,ViInt32 *,ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrSpecMSw (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrSpecMSw (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrSpecMSw (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcSpecMSwAreaLimMatc (ViSession,ViInt32 *,ViInt32 *,ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrVarSpecMSw (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrVarSpecMSw (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrVarSpecMSw (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_SensSpecMswLimLineUsed (ViSession,ViInt32 *,ViChar[]);

//            GSMBS Signalling
//               Test Object Power
//                  Configuration
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmContDef (ViSession, ViInt32, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmScope   (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmContRep (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowgGmFilter (ViSession,ViInt32,ViChar[]);

//                     Limit Lines
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmLimDef     (ViSession, ViInt32, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmLimLowMode (ViSession, ViInt32, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmLimUppMode (ViSession, ViInt32, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmLimLow     (ViSession, ViInt32, ViInt32, ViBoolean, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean,
                                                                               ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmLimUpp     (ViSession, ViInt32, ViInt32, ViBoolean, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean,
                                                                               ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViChar[]);
//                     Time
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmTimeBit (ViSession, ViInt32, ViReal64, ViChar[]);
//                     Statistics
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmCont      (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmStat      (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmResMode   (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Measurement
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubPowGmRang (ViSession, ViInt32, ViInt32, ViReal64, ViInt32, ViChar[]);
//                  Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitPowGm (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborPowGm (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopPowGm (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContPowGm (ViSession, ViInt32, ViChar[]);
//                     Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPowGmSt (ViSession, ViInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowGmErep (ViSession, ViInt32, ViInt32, ViChar[]);
//                  Results
//                     Scalar
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadPowGm        (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPowGm        (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampPowGm        (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcPowGmMatcLim (ViSession, ViInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Array
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrPowGm         (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrPowGm         (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrPowGm         (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcArrPowGmMatcLim  (ViSession, ViInt32, ViInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcArrPowGmAreaMatc (ViSession, ViInt32, ViInt32, ViPInt32, ViPInt32, ViChar[]);
//                     SubArray
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubPowGm (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubPowGm (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubPowGm (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
//                  Power vs Slot
//                     Configuration
//                        Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPSlotGmContDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPSlotGmContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                        Statistics
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPSlotGmContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitPSlotGm (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborPSlotGm (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopPSlotGm (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContPSlotGm (ViSession, ViChar[]);
//                        Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPSlotGmSt (ViSession, ViPInt32, ViPInt32, ViChar[]);
//                        Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPSlotGmErep (ViSession, ViInt32, ViChar[]);
//                     Results
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadPSlotGm (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPSlotGm (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampPSlotGm (ViSession, ViReal64[], ViChar[]);
//               Test Object Modulation Perror
//                  Configuration
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrGmContDef (ViSession, ViInt32, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrGmScope   (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrGmContRep (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Limits
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrGmLim (ViSession, ViInt32, ViInt32, ViReal64, ViReal64, ViReal64, ViChar[]);
//                     Time
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrGmTimDec (ViSession, ViInt32, ViInt32, ViChar[]);
//                     Statistics
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrGmCont      (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrGmStat      (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrGmResMode   (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrGmContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Measurement
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubPerrGmRang (ViSession, ViInt32, ViInt32, ViReal64, ViInt32, ViChar[]);
//                  Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitPerrGm (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborPerrGm (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopPerrGm (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContPerrGm (ViSession, ViInt32, ViChar[]);
//                     Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPerrGmSt (ViSession, ViInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrGmErep (ViSession, ViInt32, ViInt32, ViChar[]);
//                  Results
//                     Scalar
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadPerrGm        (ViSession, ViInt32, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPerrGm        (ViSession, ViInt32, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampPerrGm        (ViSession, ViInt32, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcPerrGmMatcLim (ViSession, ViInt32, ViInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Array
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrPerrGm (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrPerrGm (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrPerrGm (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
//                     SubArray
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubPerrGm (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubPerrGm (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubPerrGm (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
//               Test Object Spectrum Modulation
//                  Configuration
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmContDef (ViSession, ViInt32, ViBoolean, ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_SpecModAvgAreas (ViSession,ViInt32,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpecModFSelFTimeD (ViSession,ViInt32,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmScope   (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmContRep (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Limit Lines
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmLimDef  (ViSession, ViInt32, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmLimRefp (ViSession, ViInt32, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmLimMode (ViSession, ViInt32, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmLim     (ViSession, ViInt32, ViInt32, ViBoolean, ViReal64, ViReal64, ViReal64, ViChar[]);
//                     Statistics
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmCont      (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmStat      (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmResMode   (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     MeasX
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmContMpo (ViSession, ViInt32, ViInt32, ViBoolean, ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpecModVarMpo (ViSession,ViInt32,ViInt32,ViInt32,ViReal64,ViChar[]);

//                     Measurement
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubSpModGmRang (ViSession, ViInt32, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubSpecModTime  (ViSession,ViInt32,ViInt32,ViReal64,ViInt32,ViChar[]);

//                  Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitSpModGm (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborSpModGm (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopSpModGm (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContSpModGm (ViSession, ViInt32, ViChar[]);
//                     Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSpModGmSt (ViSession, ViInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModGmErep (ViSession, ViInt32, ViInt32, ViChar[]);
//                  Results
//                     Scalar
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSpModGm (ViSession, ViInt32, ViPReal64, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSpModGm (ViSession, ViInt32, ViPReal64, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSpModGm (ViSession, ViInt32, ViPReal64, ViPInt32, ViChar[]);
//                     Array
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrSpModGm (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrSpModGm (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrSpModGm (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrVarSpecMod (ViSession,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrVarSpecMod (ViSession,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrVarSpecMod (ViSession,ViInt32,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrSpecModTime (ViSession,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrSpecModTime (ViSession,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrSpecModTime (ViSession,ViInt32,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcSpecModAreaLimMatc (ViSession,ViInt32,ViInt32 *,ViChar[]);

//                     SubArray
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubSpModGm (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubSpModGm (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubSpModGm (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubArrSpecModTime (ViSession,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubArrSpecModTime (ViSession,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubArrSpecModTime (ViSession,ViInt32,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensSpecModLimLineUsed (ViSession,ViInt32,ViInt32 *,ViChar[]);

//               Test Object Spectrum Switching
//                  Configuration
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmContDef (ViSession, ViInt32, ViBoolean, ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpecSwitFSelFTimeD (ViSession,ViInt32,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_SpecSwitContStatMod (ViSession,ViInt32,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_SpecSwitNoOfSlot (ViSession,ViInt32,ViInt32,ViChar[]);


ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmScope   (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmContRep (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmSlotCount (ViSession,ViInt32,ViInt32,ViChar[]);

//                     Limit Lines
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmLimDef  (ViSession, ViInt32, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmLimMode (ViSession, ViInt32, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmLim (ViSession instrumentHandle,
                                                  ViInt32 channel,
                                                  ViInt32 measurePoint,
                                                  ViBoolean enable,
                                                  ViReal64 minRelativeLimit_dB,
                                                  ViReal64 maxRelativeLimit_dB,
                                                  ViReal64 absoluteLimit_dBm,
                                                  ViChar errorMessage[]);
//                     Statistics
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmCont      (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmStat      (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmResMode   (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     MeasX
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmContMpo (ViSession, ViInt32, ViInt32, ViBoolean, ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpecSwVarMpo (ViSession,ViInt32,ViInt32,ViInt32,ViReal64,ViChar[]);

//                     Measurement
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubSpSwGmRang (ViSession, ViInt32, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubSpecSwitTime  (ViSession,ViInt32,ViInt32,ViReal64,ViInt32,ViChar[]);
//                  Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitSpSwGm (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborSpSwGm (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopSpSwGm (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContSpSwGm (ViSession, ViInt32, ViChar[]);
//                     Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSpSwGmSt (ViSession, ViInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwGmErep (ViSession, ViInt32, ViInt32, ViChar[]);
//                  Results
//                     Scalar
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSpSwGm (ViSession, ViInt32, ViPReal64, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSpSwGm (ViSession, ViInt32, ViPReal64, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSpSwGm (ViSession, ViInt32, ViPReal64, ViPInt32, ViChar[]);
//                     Array
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrSpSwGm (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrSpSwGm (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrSpSwGm (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrVarSpecSwit (ViSession,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrVarSpecSwit (ViSession,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrVarSpecSwit (ViSession,ViInt32,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrSpecSwitTime (ViSession,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrSpecSwitTime (ViSession,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrSpecSwitTime (ViSession,ViInt32,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcSpecSwiAreaLimMatc (ViSession,ViInt32,ViInt32 *,ViChar[]);

//                     SubArray
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubSpSwGm (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubSpSwGm (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubSpSwGm (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubArrSpecSwitTime (ViSession,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubArrSpecSwitTime (ViSession,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubArrSpecSwitTime (ViSession,ViInt32,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensSpecSwiLimLineUsed (ViSession,ViInt32,ViInt32 *,ViChar[]);

//               Test Object Spectrum Modulation/Switching
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpecMSwContRep (ViSession,ViInt32,ViInt32,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitSpecMSw        (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborSpecMSw        (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopSpecMSw        (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContSpecMSw        (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSpecMSwStat    (ViSession,ViInt32,ViInt32 *,ViInt32 *,ViInt32 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpecMSwErep    (ViSession,ViInt32,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSpecMSw (ViSession,ViInt32,ViReal64 *,ViInt32 *,ViReal64 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSpecMSw (ViSession,ViInt32,ViReal64 *,ViInt32 *,ViReal64 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSpecMSw (ViSession,ViInt32,ViReal64 *,ViInt32 *,ViReal64 *,ViInt32 *,ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrSpecMSw (ViSession,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrSpecMSw (ViSession,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrSpecMSw (ViSession,ViInt32,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcSpecMSwAreaLimMatc (ViSession,ViInt32,ViInt32 *,ViInt32 *,ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrVarSpecMSw (ViSession,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrVarSpecMSw (ViSession,ViInt32,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrVarSpecMSw (ViSession,ViInt32,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_SensSpecMswLimLineUsed (ViSession,ViInt32,ViInt32 *,ViChar[]);




/*****************************************************************************/
/*****************************************************************************/
/*======== EPSK Functions ===================================================*/
/*****************************************************************************/
/*****************************************************************************/
//            GSMBS Non Signalling
//               Test Object Power
//                  Configuration
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpContDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpScope   (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowgEpFilter (ViSession,ViInt32,ViChar[]);

//                     Limit Lines
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpLimDef     (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpLimLowMode (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpLimUppMode (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpLimLow     (ViSession, ViInt32, ViBoolean, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64,
                                                                                ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpLimUpp     (ViSession, ViInt32, ViBoolean, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64,
                                                                                ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViChar[]);
//                     Time
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpTimeBit (ViSession, ViReal64, ViChar[]);
//                     Reference Power
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpRPMode (ViSession, ViInt32, ViChar[]);
//                     Statistics
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpCont      (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpStat      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpResMode   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Measurement
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSubPowEpRang (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);
//                  Control
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitPowEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborPowEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopPowEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContPowEp (ViSession, ViChar[]);
//                     Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcPowEpSt (ViSession, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPowEpErep (ViSession, ViInt32, ViChar[]);
//                  Results
//                     Scalar
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadPowEp        (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcPowEp        (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampPowEp        (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcPowEpMatcLim (ViSession, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Array
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrPowEp         (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrPowEp         (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrPowEp         (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcArrPowEpMatcLim  (ViSession, ViInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcArrPowEpAreaMatc (ViSession, ViInt32, ViPUInt32, ViPUInt32, ViChar[]);
//                     SubArray
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSubPowEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSubPowEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSubPowEp (ViSession, ViInt32, ViReal64[], ViChar[]);
//               Test Object Mod. OEMP
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfOempEpLimDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfOempEpUppLim (ViSession, ViInt32, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfOempUppLim95 (ViSession, ViReal64, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfModEpRPMode (ViSession,ViInt32,ViChar[]);

//               Test Object Mod. Overview
//                  Configuration
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfOverEpContDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfOverEpScope   (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfOverEpContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Statistics
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfOverEpCont      (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfOverEpStat      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfOverEpResMode   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfOverEpContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                  Control
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitOverEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborOverEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopOverEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContOverEp (ViSession, ViChar[]);
//                     Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcOverEpSt (ViSession, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfOverEpErep (ViSession, ViInt32, ViChar[]);
//                  Results
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadOverEp (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64,
                                                                       ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcOverEp (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64,
                                                                       ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampOverEp (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64,
                                                                       ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcOverEpMatcLim (ViSession, ViInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//               Test Object Mod. Evmagnitude
//                  Configuration
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfEvmEpContDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfEvmEpScope   (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfEvmEpContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Statistics
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfEvmEpCont      (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfEvmEpStat      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfEvmEpResMode   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfEvmEpContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Measurement
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSubEvmEpRang (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                  Control
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitEvmEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborEvmEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopEvmEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContEvmEp (ViSession, ViChar[]);
//                     Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcEvmEpSt (ViSession, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfEvmEpErep (ViSession, ViInt32, ViChar[]);
//                  Results
//                     Scalar
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadEvmEp        (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcEvmEp        (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampEvmEp        (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcEvmEpMatcLim (ViSession, ViInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Array
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrEvmEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrEvmEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrEvmEp (ViSession, ViInt32, ViReal64[], ViChar[]);
//                     SubArray
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSubEvmEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSubEvmEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSubEvmEp (ViSession, ViInt32, ViReal64[], ViChar[]);
//               Test Object Modulation Perror
//                  Configuration
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrEpContDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrEpScope   (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrEpContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Statistics
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrEpCont      (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrEpStat      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrEpResMode   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrEpContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Measurement
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSubPerrEpRang (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                  Control
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitPerrEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborPerrEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopPerrEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContPerrEp (ViSession, ViChar[]);
//                     Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcPerrEpSt (ViSession, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfPerrEpErep (ViSession, ViInt32, ViChar[]);
//                  Results
//                     Scalar
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadPerrEp        (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcPerrEp        (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampPerrEp        (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcPerrEpMatcLim (ViSession, ViInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Array
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrPerrEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrPerrEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrPerrEp (ViSession, ViInt32, ViReal64[], ViChar[]);
//                     SubArray
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSubPerrEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSubPerrEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSubPerrEp (ViSession, ViInt32, ViReal64[], ViChar[]);
//               Test Object Modulation Merror
//                  Configuration
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfMerrEpContDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfMerrEpScope   (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfMerrEpContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Statistics
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfMerrEpCont      (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfMerrEpStat      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfMerrEpResMode   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfMerrEpContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Measurement
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSubMerrEpRang (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                  Control
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitMerrEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborMerrEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopMerrEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContMerrEp (ViSession, ViChar[]);
//                     Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcMerrEpSt (ViSession, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfMerrEpErep (ViSession, ViInt32, ViChar[]);
//                  Results
//                     Scalar
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadMerrEp        (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcMerrEp        (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampMerrEp        (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_CalcMerrEpMatcLim (ViSession, ViInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Array
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrMerrEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrMerrEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrMerrEp (ViSession, ViInt32, ViReal64[], ViChar[]);
//                     SubArray
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSubMerrEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSubMerrEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSubMerrEp (ViSession, ViInt32, ViReal64[], ViChar[]);
//               Test Object Spectrum Modulation
//                  Configuration
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpContDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpScope   (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Limit Lines
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpLimDef  (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpLimRefp (ViSession, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpLimMode (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpLim     (ViSession, ViInt32, ViBoolean, ViReal64, ViReal64, ViReal64, ViChar[]);
//                     Statistics
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpCont      (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpStat      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpResMode   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     MeasX
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpContMpo (ViSession, ViInt32, ViBoolean, ViChar[]);
//                     Measurement
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSubSpModEpRang (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);
//                  Control
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitSpModEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborSpModEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopSpModEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContSpModEp (ViSession, ViChar[]);
//                     Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSpModEpSt (ViSession, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpModEpErep (ViSession, ViInt32, ViChar[]);
//                  Results
//                     Scalar
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSpModEp (ViSession, ViPReal64, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSpModEp (ViSession, ViPReal64, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSpModEp (ViSession, ViPReal64, ViPInt32, ViChar[]);
//                     Array
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrSpModEp (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrSpModEp (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrSpModEp (ViSession, ViReal64[], ViChar[]);
//                     SubArray
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSubSpModEp (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSubSpModEp (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSubSpModEp (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfModDemodBits (ViSession,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrModDemodBits (ViSession,ViInt32,ViInt32[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrModDemodBits (ViSession,ViInt32,ViInt32[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrModDemodBits (ViSession,ViInt32,ViInt32[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadScalModDemodBits (ViSession,ViInt32,ViInt32,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcScalModDemodBits (ViSession,ViInt32,ViInt32,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampScalModDemodBits (ViSession,ViInt32,ViInt32,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadPeakModDemodBits (ViSession,ViInt32,ViInt32 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcPeakModDemodBits (ViSession,ViInt32,ViInt32 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampPeakModDemodBits (ViSession,ViInt32,ViInt32 *,ViInt32 *,ViChar[]);


ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfIqanContRmod (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfIqanContRep (ViSession,ViInt32,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfIqanIQFilter (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfIqanRotation (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitIqan (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborIqan (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopIqan (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContIqan (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcIqanStat (ViSession,ViInt32 *,ViInt32 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfIqanErep (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadIqan (ViSession,ViReal64 *,ViReal64 *,ViReal64 *,ViReal64 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcIqan (ViSession,ViReal64 *,ViReal64 *,ViReal64 *,ViReal64 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampIqan (ViSession,ViReal64 *,ViReal64 *,ViReal64 *,ViReal64 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrIqanIPh (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrIqanQPh (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrIqanIPh (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrIqanQPh (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrIqanIPh (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrIqanQPh (ViSession,ViReal64[],ViChar[]);


//               Test Object Spectrum Switching
//                  Configuration
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpContDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpScope   (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpSlotCount (ViSession,ViInt32,ViChar[]);

//                     Limit Lines
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpLimDef  (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpLimMode (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpLim (ViSession instrumentHandle,
                                                   ViInt32 measurePoint,
                                                   ViBoolean enable,
                                                   ViReal64 minRelativeLimit_dB,
                                                   ViReal64 maxRelativeLimit_dB,
                                                   ViReal64 absoluteLimit_dBm,
                                                   ViChar errorMessage[]);
//                     Statistics
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpCont      (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpStat      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpResMode   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     MeasX
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpContMpo (ViSession, ViInt32, ViBoolean, ViChar[]);
//                     Measurement
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSubSpSwEpRang (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);
//                  Control
ViStatus _VI_FUNC RSCMU300_GSM_NSig_InitSpSwEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_AborSpSwEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_StopSpSwEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ContSpSwEp (ViSession, ViChar[]);
//                     Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSpSwEpSt (ViSession, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ConfSpSwEpErep (ViSession, ViInt32, ViChar[]);
//                  Results
//                     Scalar
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSpSwEp (ViSession, ViPReal64, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSpSwEp (ViSession, ViPReal64, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSpSwEp (ViSession, ViPReal64, ViPInt32, ViChar[]);
//                     Array
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadArrSpSwEp (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcArrSpSwEp (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampArrSpSwEp (ViSession, ViReal64[], ViChar[]);
//                     SubArray
ViStatus _VI_FUNC RSCMU300_GSM_NSig_ReadSubSpSwEp (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_FetcSubSpSwEp (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_SampSubSpSwEp (ViSession, ViReal64[], ViChar[]);
//            GSMBS Signalling
//               Test Object Power
//                  Configuration
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpContDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpScope   (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowgEpFilter (ViSession,ViInt32,ViChar[]);

//                     Limit Lines
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpLimDef     (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpLimLowMode (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpLimUppMode (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpLimLow (ViSession, ViInt32, ViBoolean, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpLimUpp (ViSession, ViInt32, ViBoolean, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViReal64, ViBoolean, ViChar[]);
//                     Time
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpTimeBit (ViSession, ViReal64, ViChar[]);
//                     Reference Power
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpRPMode (ViSession, ViInt32, ViChar[]);
//                     Statistics
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpCont      (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpStat      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpResMode   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Measurement
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubPowEpRang (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);
//                  Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitPowEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborPowEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopPowEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContPowEp (ViSession, ViChar[]);
//                     Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPowEpSt (ViSession, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPowEpErep (ViSession, ViInt32, ViChar[]);
//                  Results
//                     Scalar
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadPowEp        (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPowEp        (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampPowEp        (ViSession, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcPowEpMatcLim (ViSession, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Array
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrPowEp         (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrPowEp         (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrPowEp         (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcArrPowEpMatcLim  (ViSession, ViInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcArrPowEpAreaMatc (ViSession, ViInt32, ViPInt32, ViPInt32, ViChar[]);
//                     SubArray
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubPowEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubPowEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubPowEp (ViSession, ViInt32, ViReal64[], ViChar[]);
//               Test Object Mod. OEMP Limits
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfOempEpLimDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfOempEpUppLim (ViSession, ViInt32, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfOempUppLim95 (ViSession, ViReal64, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfModEpRPMode (ViSession,ViInt32,ViChar[]);

//               Test Object Mod. Overview
//                  Configuration
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfOverEpContDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfOverEpScope   (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfOverEpContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Statistics
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfOverEpCont      (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfOverEpStat      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfOverEpResMode   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfOverEpContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                  Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitOverEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborOverEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopOverEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContOverEp (ViSession, ViChar[]);
//                     Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcOverEpSt (ViSession, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfOverEpErep (ViSession, ViInt32, ViChar[]);
//                  Results
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadOverEp (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcOverEp (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampOverEp (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcOverEpMatcLim (ViSession, ViInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//               Test Object Mod. Evmagnitude
//                  Configuration
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfEvmEpContDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfEvmEpScope   (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfEvmEpContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Statistics
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfEvmEpCont      (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfEvmEpStat      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfEvmEpResMode   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfEvmEpContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Measurement
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubEvmEpRang (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                  Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitEvmEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborEvmEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopEvmEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContEvmEp (ViSession, ViChar[]);
//                     Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcEvmEpSt (ViSession, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfEvmEpErep (ViSession, ViInt32, ViChar[]);
//                  Results
//                     Scalar
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadEvmEp        (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcEvmEp        (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampEvmEp        (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcEvmEpMatcLim (ViSession, ViInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Array
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrEvmEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrEvmEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrEvmEp (ViSession, ViInt32, ViReal64[], ViChar[]);
//                     SubArray
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubEvmEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubEvmEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubEvmEp (ViSession, ViInt32, ViReal64[], ViChar[]);
//               Test Object Modulation Perror
//                  Configuration
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrEpContDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrEpScope   (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrEpContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Statistics
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrEpCont      (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrEpStat      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrEpResMode   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrEpContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Measurement
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubPerrEpRang (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                  Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitPerrEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborPerrEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopPerrEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContPerrEp (ViSession, ViChar[]);
//                     Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPerrEpSt (ViSession, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfPerrEpErep (ViSession, ViInt32, ViChar[]);
//                  Results
//                     Scalar
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadPerrEp        (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPerrEp        (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampPerrEp        (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcPerrEpMatcLim (ViSession, ViInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Array
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrPerrEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrPerrEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrPerrEp (ViSession, ViInt32, ViReal64[], ViChar[]);
//                     SubArray
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubPerrEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubPerrEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubPerrEp (ViSession, ViInt32, ViReal64[], ViChar[]);
//               Test Object Modulation Merror
//                  Configuration
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMerrEpContDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMerrEpScope   (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMerrEpContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Statistics
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMerrEpCont      (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMerrEpStat      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMerrEpResMode   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMerrEpContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Measurement
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubMerrEpRang (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                  Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitMerrEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborMerrEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopMerrEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContMerrEp (ViSession, ViChar[]);
//                     Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcMerrEpSt (ViSession, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfMerrEpErep (ViSession, ViInt32, ViChar[]);
//                  Results
//                     Scalar
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadMerrEp        (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcMerrEp        (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampMerrEp        (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_CalcMerrEpMatcLim (ViSession, ViInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Array
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrMerrEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrMerrEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrMerrEp (ViSession, ViInt32, ViReal64[], ViChar[]);
//                     SubArray
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubMerrEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubMerrEp (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubMerrEp (ViSession, ViInt32, ViReal64[], ViChar[]);
//               Test Object Spectrum Modulation
//                  Configuration
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpContDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpScope   (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     Limit Lines
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpLimDef  (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpLimRefp (ViSession, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpLimMode (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpLim     (ViSession, ViInt32, ViBoolean, ViReal64, ViReal64, ViReal64, ViChar[]);
//                     Statistics
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpCont      (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpStat      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpResMode   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     MeasX
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpContMpo (ViSession, ViInt32, ViBoolean, ViChar[]);
//                     Measurement
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubSpModEpRang (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);
//                  Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitSpModEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborSpModEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopSpModEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContSpModEp (ViSession, ViChar[]);
//                     Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSpModEpSt (ViSession, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpModEpErep (ViSession, ViInt32, ViChar[]);
//                  Results
//                     Scalar
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSpModEp (ViSession, ViPReal64, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSpModEp (ViSession, ViPReal64, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSpModEp (ViSession, ViPReal64, ViPInt32, ViChar[]);
//                     Array
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrSpModEp (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrSpModEp (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrSpModEp (ViSession, ViReal64[], ViChar[]);
//                     SubArray
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubSpModEp (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubSpModEp (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubSpModEp (ViSession, ViReal64[], ViChar[]);


ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfModDemodBits (ViSession,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrModDemodBits (ViSession,ViInt32,ViInt32[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrModDemodBits (ViSession,ViInt32,ViInt32[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrModDemodBits (ViSession,ViInt32,ViInt32[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadScalModDemodBits (ViSession,ViInt32,ViInt32,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcScalModDemodBits (ViSession,ViInt32,ViInt32,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampScalModDemodBits (ViSession,ViInt32,ViInt32,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadPeakModDemodBits (ViSession,ViInt32,ViInt32 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcPeakModDemodBits (ViSession,ViInt32,ViInt32 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampPeakModDemodBits (ViSession,ViInt32,ViInt32 *,ViInt32 *,ViChar[]);

ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfIqanContRmod (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfIqanContRep (ViSession,ViInt32,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfIqanIQFilter (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfIqanRotation (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitIqan (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborIqan (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopIqan (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContIqan (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcIqanStat (ViSession,ViInt32 *,ViInt32 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfIqanErep (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadIqan (ViSession,ViReal64 *,ViReal64 *,ViReal64 *,ViReal64 *,ViReal64 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcIqan (ViSession,ViReal64 *,ViReal64 *,ViReal64 *,ViReal64 *,ViReal64 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampIqan (ViSession,ViReal64 *,ViReal64 *,ViReal64 *,ViReal64 *,ViReal64 *,ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrIqanIPh (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrIqanQPh (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrIqanIPh (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrIqanQPh (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrIqanIPh (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrIqanQPh (ViSession,ViReal64[],ViChar[]);

//               Test Object Spectrum Switching
//                  Configuration
//                     Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpContDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpScope   (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpSlotCount (ViSession,ViInt32,ViChar[]);

//                     Limit Lines
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpLimDef  (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpLimMode (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpLim (ViSession instrumentHandle,
                                                  ViInt32 measurePoint,
                                                  ViBoolean enable,
                                                  ViReal64 minRelativeLimit_dB,
                                                  ViReal64 maxRelativeLimit_dB,
                                                  ViReal64 absoluteLimit_dBm,
                                                  ViChar errorMessage[]);
//                     Statistics
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpCont      (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpStat      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpResMode   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
//                     MeasX
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpContMpo (ViSession, ViInt32, ViBoolean, ViChar[]);
//                     Measurement
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSubSpSwEpRang (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);
//                  Control
ViStatus _VI_FUNC RSCMU300_GSM_Sig_InitSpSwEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_AborSpSwEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_StopSpSwEp (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ContSpSwEp (ViSession, ViChar[]);
//                     Measurement Status
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSpSwEpSt (ViSession, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
//                     Event Reporting System
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ConfSpSwEpErep (ViSession, ViInt32, ViChar[]);
//                  Results
//                     Scalar
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSpSwEp (ViSession, ViPReal64, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSpSwEp (ViSession, ViPReal64, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSpSwEp (ViSession, ViPReal64, ViPInt32, ViChar[]);
//                     Array
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadArrSpSwEp (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcArrSpSwEp (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampArrSpSwEp (ViSession, ViReal64[], ViChar[]);
//                     SubArray
ViStatus _VI_FUNC RSCMU300_GSM_Sig_ReadSubSpSwEp (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_FetcSubSpSwEp (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_Sig_SampSubSpSwEp (ViSession, ViReal64[], ViChar[]);



// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//      Functions for LabVIEW 5.x and higher
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#ifdef _OUTSIDEVEE_
ViStatus _VI_FUNC RSCMU300_GSM_Sig_GetResourceName  (ViSession, ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_GSM_NSig_GetResourceName (ViSession, ViSession, ViChar[]);
#endif

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//          VXI PLUG & PLAY COMPATIBILITY FUNCTIONS
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#ifndef _REMVXIPNP

ViStatus _VI_FUNC RSCMU300_GetInstrumentHandle (ViSession, ViSession*);
ViStatus _VI_FUNC RSCMU300_initGSMNSig (ViSession, ViSession, ViUInt32);
ViStatus _VI_FUNC RSCMU300_initGSMSig (ViSession, ViSession, ViUInt32);

ViStatus _VI_FUNC RSCMU300_init (ViRsrc, ViBoolean, ViBoolean, ViPSession);

ViStatus _VI_FUNC RSCMU300_reset (ViSession);
ViStatus _VI_FUNC RSCMU300_self_test (ViSession, ViPInt16, ViChar[]);
ViStatus _VI_FUNC RSCMU300_error_query (ViSession, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_error_message (ViSession, ViStatus, ViChar[]);
ViStatus _VI_FUNC RSCMU300_revision_query (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_close (ViSession);

#endif


#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
